      PROGRAM SYNSPEC
C
C =====================================================================I
C                                                                      I
C Program for evaluting synthetic spectra for a given model atmosphere I
C                                                                      I
C *****************                                                    I
C VERSION SYNSPEC42u                                                   I
C *****************                                                    I
CJB- VERSION FOR LINUX TO BE COMPILED BY:
CJB- VERSION FOR RADIATIVE ACCEL. WITH SPECIAL OUTPUT OF FLUX
CJB IN EACH DEPTH AND FREQUENCY IN UNIT 20
C                                                                      I
C Input: the same as input to TLUSTY or TLUSDISK - unit 5              I
C        additional 6 lines of input - unit 55 (proc. START and INIBL0)I
C        chemical composition - unit 56 (if a switch is on in unit 55) I
C        model atmosphere - unit 8  (procedures INPMOD or INKUR)       I
C        line list        - unit 19 (procedure INISET)                 I
C                                                                      I
C Output: diagnostic outprint - unit 6 (several procedures)            I
C         synthetic spectrum  - unit 7 (procedure OUTPRI)              I
C         flux in continuum   - unit 17 (procedure OUTPRI)             I
C         identification table- unit 12 (procedure INIBLA)             I
C         partial equiv.widths- unit 16 (procedure OUTPRI)             I
C         elapsed time        - unit 69 (procedure TIMING - UNIX only) I
CJB       flux at each depth and frequency -spectrum.20
C                                                                      I
C      -- if specific intensities are also calculated (set up by the   I
C         input on unit 55), there are two aditional output files:     I
C                                                                      I
C         specific intensities - unit 10                               I
C         specific intensities in continuum - unit 18                  I
C                                                                      I
C      -- in the iron-curtain option (IMODE=-2), there is another      I
C         output file:                                                 I
C         monochromatic opacities - unit 27                            I
C                                                                      I
C     ***  The contents of units 7 and 17 serve as an input to the     I
C          program ROTIN, which performs rotational and instrumental   I
C          ROTIN, which performs rotational and instrumental           I
C          convolutions, and sets up files for a plot.                 I
C                                                                      I
C Basic options: controlled by switch IMODE                            I
C IMODE    =  0 - normal synthetic spectrum                            I
C                 (ie. identification table + emergent flux)           I
C          =  1 - detailed profiles of a few individual lines          I
C          =  2 - emergent flux in the continuum (without the          I
C                 contribution of lines)                               I
C          = -1 - only identification table, ie. a list of lines which I
C                 contribute to opacity in a given wavelength          I
C                 region, together with their approximate equivalent   I
C                 widths. Synthetic spectrum is not calculated.        I
C          = -2 - the "iron curtain" option, ie. a monochromatic       I
c                 opacity for a homogeneous slab of a given T and n_e  I
C                                                                      I
C                                                                      I
C ==================================================================== I
C
C
      INCLUDE 'PARAMS.FOR'
C
      COMMON/LBLANK/IBLANK,NBLANK
      COMMON/NXTINI/ALM00,ALST00,NXTSET,INLIST
      COMMON/IPRNTR/IPRIN
      OPEN(UNIT=12,STATUS='UNKNOWN')
      OPEN(UNIT=14,STATUS='UNKNOWN')
CJB     
        OPEN(20,FILE='lambda',STATUS='OLD')
        READ(20,'(////)')
        READ(20,*)zmaz1,zmaz2
c       nacital zo 6-teho riadku v angstremoch
        close(20)
        zmaz=0.5d-1*(zmaz1+zmaz2)
        if (zmaz.lt.150.d0) open(19,file='gf0150',status='old')
        if (zmaz.gt.1.5d2.and.zmaz.lt.3.d2)
     p  open(19,file='gf0300',status='old')
        if (zmaz.gt.3.d2.and.zmaz.lt.8.d2) 
     p  open(19,file='gf0800',status='old')
        if (zmaz.gt.800.d0) open(19,file='gfend',status='old')
        OPEN(20,FILE='spectrum.20',STATUS='UNKNOWN')
CJB
C
C     INITIALIZATION - INPUT OF BASIC PARAMETERS AND MODEL ATMOSPHERE
C
      IBLANK=0
      NXTSET=0
      CALL START
      IF(INMOD.GT.0) CALL INPMOD
      IF(INMOD.EQ.0) CALL INKUR
      IF(ICHANG.NE.0) CALL CHANGE
      CALL INIMOD
      CALL TINT
      CALL INIBL0
    5 IF(IMODE.LT.2) CALL INILIN
      IF(IPRIN.GE.-1) call timing(0,0)
C
C     ACTUAL CALCULATION OF THE SYNTHETIC SPECTRUM
C
   10 IBLANK=IBLANK+1
      CALL RESOLV
      IF(IPRIN.GE.-1) call timing(1,iblank)
      IF(IMODE.LT.0) GO TO 20
      if(ifreq.le.10.and.inmod.le.1) then
         CALL RTECD
       else
         call RTE
      end if
      CALL IDTAB
      CALL OUTPRI
      IF(IPRIN.GE.-1) call timing(2,iblank)
   20 CONTINUE
      IF(IBLANK.LT.NBLANK) GO TO 10
      IF(NXTSET.EQ.1) GO TO 5
cjb
        close(19)
        close(20)
c     STOP
      END
C
C ********************************************************************
C
C
C

      SUBROUTINE START
C     ================
C
C     General input and initialization procedure
C
      IMPLICIT LOGICAL (L)
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      COMMON/IPRNTR/IPRIN
C
C ------------------------------------------------
C Additional basic input parameters - from unit 55
C ------------------------------------------------
C
C     IMODE     =  0 - normal synthetic spectrum
C               =  1 - detailed profiles of a few individual lines
C               =  2 - emergent flux in the continuum (without the
C                      contribution of lines)
C               = -1 - identification table, ie. a list of lines which
C                      contribute to opacity in a given wavelength
C                      region, together with their approximate equivalent
C                      widths. Synthetic spectrum is not calculated.
C               = -2 - the "iron curtain" option, ie. a monochromatic 
C                      opacity for a homogeneous slab of a given T and n_e
C
C     IDSTD      - index of the "standard depth" (ie the depth at which
C                  the continuum optical depth is of the order of unity)
C                  (for detailed explanation see the code TLUSTY)
C
C     IPRIN      - determines the amount of output:
C                =0 - standard output:
C                     condensed output on unit 6 (basics + error messages),
C                     no output on unit 36 (depths of formation);
C                     normal output on 16 (equivalent widths);
C                     normal output on 12 (identification table)
C                >0 - more output:
C                     =1 - emergent flux on unit 6, no unit 36
C                     =2 - identification table + flux on unit 6, no unit 36
C                     =3 - as before, plus unit 36 (depths of formation);
C                     =4 - as before, plus unit 37 (contribution functions);
C                <0 - less output:
C                     =-1 - no output on unit 16
C                     =-2 - no output on units 16 and 12
C
C     INMOD      = 0  -  input model atmosphere as a Kurucz model
C                        (read by procedure INKUR)
C                = 1  -  input model atmosphere is a model calculated
C                        by the program TLUSTY
C                        (read by procedure INPMOD)
C                = 2  -  input model is a model of the vertical structure
C                        of one ring of an accretion disk
C     INTRPL     - switch indicating whether the input model has to be
C                  interpolated to the present depth scale;
C                  for details see procedure INPMOD
C     ICHANG     - switch indicating whether the populations from the
C                  input model have to be updated;
C                  for details see procedure CHANGE
C     ICHEMC     - switch indicating that new chemical composition will
C                  be read from unit 56
C     IOPHLI     - switch for treatment the Lyman line wings -see LYMLIN
C
      mode=0
      read(1,*,err=10,end=10) mode
   10 continue
      READ(55,*) IMODE,IDSTD,IPRIN
      READ(55,*) INMOD,INTRPL,ICHANG,ICHEMC
      READ(55,*) IOPHLI
      if(mode.eq.0) then
         call initia
       else
         call start0
      end if
C
      if(iophli.ge.3) call getlal(iophli)
      IF(IMODE.LT.-1) THEN
         ND=1
         IDSTD=1
      END IF
      IF(INMOD.GT.0.AND.INTRPL.GT.0) READ(55,*) (DM(I),I=1,ND)
C
      return
      end
C
C
C     ****************************************************************
C
C

      SUBROUTINE START0
C     =================
C
C     "Old" input and initialization procedure
C
      IMPLICIT LOGICAL (L)
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      PARAMETER (MFRQ=120)
      PARAMETER (WI1=911.753578, WI2=227.837832)
      CHARACTER*30 FIDATA(MION),FIODF1(MION),FIODF2(MION),FIBFCS(MION)
      CHARACTER*1 BLNK
      COMMON/IONFIL/FIDATA,FIODF1,FIODF2,FIBFCS
      COMMON/IPRNTR/IPRIN
      common/dissol/fropc(mlevel),indexp(mlevel)
      CHARACTER*10 TYPLEV(MLEVEL)
      CHARACTER*4 TYPION(MIOEX)
      DIMENSION IIPR(5,6),IETEXP(10),IETFIX(10)
      COMMON/PRINTP/TYPLEV
      COMMON/CENTRL/ZND,IFZ0
      COMMON/TOPCS/CTOP(MFIT,MLEVEL), ! sigma = alog10(sigma/10^-18) of fit point
     +             XTOP(MFIT,MLEVEL)  ! x = alog10(nu/nu0) of fit point 
      DATA BLNK /' '/
C
C ------------------------------------
C Basic input parameters - atmospheres
C ------------------------------------
C
      CALL READBF
      IF(INMOD.LE.1) THEN
         READ(IBUFF,*) TEFF,GRAV
         TSTAR=0.
         WANGLE=0.
         IFZ0=1
       ELSE IF(INMOD.EQ.2) THEN
C
C ------------------------------
C Basic input parameters - disks
C ------------------------------
C
C     Input is the same as for TLUSDISK:
C
         READ(IBUFF,*) INPUT,IFZ0
         READ(IBUFF,*) DISPAR
         READ(IBUFF,*) HMIX
      END IF
C
C ----------------------------
C other basic input parameters 
C ----------------------------
C
      READ(IBUFF,*) LTE,LTGREY,LCHC,ISPLIN,CHMAX
      if(teff.lt.0) teff=abs(teff)
      IF(ISPLIN.LT.0) THEN
         IF(ISPLIN.LE.-5) THEN
            ISPLIN=-ISPLIN
          ELSE
            ISPLIN=0
         END IF
         READ(IBUFF,*,ERR=3) IBC,IRDER,ILMCOR,ILPSCT,ILASCT,
     *                       IRTE,IDLTE
         IF(IRTE.GE.2) READ(IBUFF,*) DJMAX,NTRALI
      END IF
    3 CONTINUE
      IFALI=5
      IFPOPR=4
      IATREF=1
      READ(IBUFF,*,ERR=4) NITER,ND,NATOM,NION,NLEVEL,
     *                    IFALI,IFPOPR,IATREF
    4 CONTINUE
      IF(IFALI.GT.10) THEN
         IFALI=IFALI-10
         READ(IBUFF,*,err=5) IFPREC,IOVER,ITLAS,IELCOR
         READ(IBUFF,*,ERR=5) IACCP,IACDP
         READ(IBUFF,*,ERR=5) ILDER,IBPOPE,CHMAXT,NLAMT
      END IF
c
    5 CONTINUE
      IF(NION.LT.0) THEN
         NION=-NION
         READ(IBUFF,*,ERR=6) NTERST
      END IF
      NLEVEL=IABS(NLEVEL)
    6 CONTINUE
C
      if(iatref.gt.100) then
         iatref=iatref-100
         modref=2
       else if(iatref.gt.0) then
         modref=1
       else if(iatref.eq.0) then
         iatref=1
         modref=0
       else if(iatref.gt.-100) then
         iatref=-iatref
         modref=0
       else if(iatref.gt.-200) then
         iatref=-iatref-100
         modref=-1
         READ(IBUFF,*) nrefia
      end if
C
C     check the dimensions
C
      if(nd.gt.mdepth) call quit('nd too large')
      if(nlevel.gt.mlevel) call quit('nlevel too large')
      if(natom.gt.matom) call quit('natom too large')
      if(nion.gt.mion) call quit('nion too large')
      if(iatref.gt.natom) call quit('conflict in iatref')
C
C ----------------------------
C Frequency points and weights
C ----------------------------
C
      READ(IBUFF,*) NJREAD
c     if(njread.gt.mfreq) call quit('njread too large')
C 
      IF(NJREAD.GT.0) THEN
        NFREQC=NJREAD
        DO 9 IJ=1,NJREAD
           READ(IBUFF,*,ERR=8) FRQEXP
    8      CONTINUE
    9   CONTINUE
      ELSE
        NFREQC=-NJREAD
        READ(IBUFF,*,ERR=10) FRCMAX
      ENDIF
C
   10 NFFIX=0
      IFLEV=0
      READ(IBUFF,*,ERR=11) NFFIX,IFSUB,IFLEV
   11 POPZER=1.D-30
      IF(IFLEV.LT.0) READ(IBUFF,*) POPZER
C
      WRITE(6,601) TEFF,GRAV
C
C --------------------
C Turbulent velocities
C --------------------
C
C     ITB       =  0 - depth-independent turbulent velocity is assumed
C               >  0 - depth-dependent turbulent velocity
C     VTB       -  value of depth-independent turbulence
C                  (in km/sec or cm/sec, depending on the numerical value)
C ---------------------
C     VTURB(ID) -  values of depth-dependent turbulence
C                  (in km/sec or cm/sec, depending on the numerical value)
C                  (to be read ONLY if ITB > 0)
C
      READ(IBUFF,*) ITB,VTB
      IF(VTB.EQ.0.) VTB=2.
      IF(VTB.LT.1.E3) VTB=VTB*1.E5
      IF(ITB.EQ.0) THEN
         DO 15 ID=1,ND
   15       VTURB(ID)=VTB
       ELSE
         READ(IBUFF,*) (VTURB(ID),ID=1,ND)
         DO 17 ID=1,ND
            IF(VTURB(ID).LT.1.E3) VTURB(ID)=VTURB(ID)*1.E5
   17    CONTINUE
      END IF
C
C ----------------------------------------------------
C Input parameters for explicit and non-explicit atoms
C ----------------------------------------------------
C
C     Input parameters are read by procedure STATE
C     (see description there)
C
      CALL STATE0(0)
      ID=1
      IF(IPRIN.GE.1) WRITE(6,607) YTOT(ID),WMY(ID),WMM(ID)
      DO 20 I=1,NLEVEL
         ILK(I)=0
   20 CONTINUE
C -------------------------------------
C Input of parameters for explicit ions
C -------------------------------------
C
C    NFIRST(I) -  index of the first explicit level of ion I;
C    NLAST(I)  -  index of the last explicit level of ion I
C    NNEXT(I)  -  index of the ground state of the next higher
C                 ionization state;
C    IZ(I)     -  effective charge ( = 1 for neutrals, 2 for once
C                 ionized, etc.)
C    MODEFF    -  mode of evaluating the free-free cross-section:
C              =  0 - free-free opacity is neglected
C              =  1 - hydrogenic cross-section with Gaunt factor
C                     set to unity
C              =  2 - hydrogenic cross-section with exact Gaunt
C                     factor
C              <  0 - non-standard expression, given by the user
C                     supplied procedure FFCROS
C    NFF       -  mode of considering "modified free-free" opacity,
C                 ie. allowing for the photoionization from higher,
C                 non-explicit, LTE energy levels of the ion I;
C              =  0 - this contribution is neglected
C              >  0 - main quantum number of the first non-explicit
C                     level
C    TYPION(I) -  character*4 string containing the name of the ion
C                 which appears in outputs (unit 6)
C
      IF(IPRIN.GE.1) WRITE(6,613)
      IELHM=0
      IELHE1=0
      IELHE2=0
      IATHE=0
      DO 50 I=1,NION
         READ(IBUFF,*) NFIRST(I),NLAST(I),NNEXT(I),IZ(I),IUPSUM(I),
     *             ICUP,MODEFF,NFF,TYPION(I)
         IF(NFIRST(I).LT.0) THEN
            READ(IBUFF,*) ifil1,ifil2
            nfirst(i)=iabs(nfirst(i))
         END IF
         IF(NNEXT(I).LT.0) NNEXT(I)=IABS(NNEXT(I))
         IF(NLAST(I).LT.0) NLAST(I)=IABS(NLAST(I))
         FF(I)=0.
         IF(NFF.GT.0) FF(I)=EH/H*IZ(I)*IZ(I)/NFF/NFF
         FIBFCS(I)=BLNK
         NFIRST(I)=IABS(NFIRST(I))
         N0I=NFIRST(I)
         N1I=NLAST(I)
         NKI=NNEXT(I)
         IFREE(I)=MODEFF
         DO 30 IAT=1,NATOM
            IF(N0I.GE.N0A(IAT).AND.NKI.LE.NKA(IAT)) IA=IAT
   30    CONTINUE
         DO 40 II=N0I,N1I
            IEL(II)=I
   40       IATM(II)=IA
         ILK(NKI)=I
         IATM(NKI)=IA
         IF(NKI.EQ.NKA(IA)) IEL(NKI)=I
         IF(IPRIN.GE.1) 
     *   WRITE(6,614) I,TYPION(I),N0I,N1I,NKI,IZ(I),IUPSUM(I),ICUP,
     *                FF(I)
C
         IF(NUMAT(IA).EQ.1) THEN
            IATH=IA
            IF(IZ(I).EQ.1) IELH=I
            IF(IZ(I).EQ.0) IELHM=I
         END IF
         IF(NUMAT(IA).EQ.2) THEN
            IATHE=IA
            IF(IZ(I).EQ.1) IELHE1=I
            IF(IZ(I).EQ.2) IELHE2=I
         END IF
   50 CONTINUE
      if(iath.gt.0) then
      N0H=N0A(IATH)
      N1H=NLAST(IELH)
      NKH=NNEXT(IELH)
      N0HN=NFIRST(IELH)
      N0M=0
      IF(IELHM.GT.0) N0M=NFIRST(IELHM)
      else
      n0h=0
      n1h=0
      nkh=0
      n0hn=0
      end if
C
      IF(IPRIN.GE.1) WRITE(6,603) INMOD,ND,IDSTD,INTRPL,ICHANG,
     *             NATOM,NION,NLEVEL,
     *             IELH,IELHM,IATH
C
C -----------------------------------------
C Parameters for individual explicit levels
C -----------------------------------------
C
C     ENION(I)   - ionization energy of level I (with respect to the
C                  ground level of the next ionization state
C                  may be given either in ergs, eV, cm**-1,
C                  or as frequency (sec**-1)
C                  also, if ENION = 0., the program assigns the
C                  hydrogenic ionization energy, assuming that the
C                  principal quantum number is the order number of level
C                  within the corresponding ion;
C     G(I)       - statistical weight; the input G(I)=0. has the
C                  analogous meaning;
C     NQUANT(I)  - principal quantum number; again for NQUANT(I)=0 the
C                  program assigns the order number;
C                < 0 - indicates that the given level is kept in LTE
C                      (even if the model is NLTE);
C                      NQUANT is then set to ABS(NQUANT)
C     TYPLEV(I)  - character*10 string - spectroscopic identification
C                  (appears only in outputs), but may also be used as an
C                  identifier in case of using the pretabulated 
C                  Opacity Project photoionization cross-section data
C     IFWOP(I)   > 0 - occupation probability for level I
C                  is calculated, and is used consistently in statistical
C                  equilibrium, and for determining opacities/emissivities;
C                = 0 - occupation probability put to 1 (usual option);
C                < 0 - signals that the level is a so-called merged level
C                      (i.e. the Rydberg states lumped together)
      IMER=0
      IF(IPRIN.GE.1) WRITE(6,615)
      DO 60 I=1,NLEVEL
         IE=IEL(I)
         N0I=NFIRST(IE)
         NKI=NNEXT(IE)
         IQ=I-N0I+1
         X=IQ*IQ
         ifwop(i)=0
         IZZ=IZ(IE)
         READ(IBUFF,*) 
     *   ENION(I),G(I),NQUANT(I),TYPLEV(I),ifwop(i)
         if(ifwop(i).lt.0.and.i.ne.nlast(ie)) 
     *      call quit('conflict in negative ifwop')
         IF(I.LT.NKI) THEN
            E=ENION(I)
            E0=E
            IF(E.LT.0.) THEN
               E=-E
               E0=E
            END IF
            IF(E.EQ.0.) THEN
               if(izz.le.2) then
               w0=wi1
               if(izz.eq.2) w0=wi2
               WL0=W0*X
               IF(WL0.GT.2000.) THEN
                  ALM=1.E8/(WL0*WL0) 
                  XN1=64.328+29498.1/(146.-ALM)+255.4/(41.-ALM)
                  WL0=WL0/(XN1*1.D-6+1.D0)
               END IF 
               E0=H*CL*1.D8/WL0       
               else
               E0=EH*IZZ*IZZ/X
               end if
            END IF
            IF(E.GT.1.D-7.AND.E.LT.100.) E0=1.6018D-12*E
            IF(E.GT.100..AND.E.LT.1.D7) E0=1.9857D-16*E
            IF(E.GT.1.D7) E0=H*E
            IF(ENION(I).GE.0.) THEN
              ENION(I)=E0
            ELSE
              ENION(I)=-E0
            ENDIF
            IF(G(I).EQ.0.) G(I)=2.D0*X
            IF(NQUANT(I).EQ.0) NQUANT(I)=IQ
          ELSE
c            if(modref.ge.0) nref(iatm(i))=nka(iatm(i))
            IF(G(I).EQ.0..AND.NKI.EQ.NKA(IATM(I))) G(I)=1.
         END IF
         if(ifwop(i).lt.0) then
            enion(i)=0.
            ff(ie)=0.
            IMER=IMER+1
            IMRG(I)=IMER
            IIMER(IMER)=I
         endif
         fropc(ii)=0.
         IF(IPRIN.GE.1) WRITE(6,616) I,TYPLEV(I),TYPION(IE),
     *      ENION(I),G(I),NQUANT(I),IEL(I),ILK(I),IATM(I)
   60 CONTINUE
C
C -------------------------------------
C Parameters for individual transitions
C -------------------------------------
C
C     For each transition considered in any option:
C
C     II      -  index of the lower level
C     JJ      -  index of the upper level
C
C
C     MODE    - mode of treating treating the radiative rates in the
C               transition.
C             =  0  -  detailed radiative balance (ie. radiative rates
C                      are not evaluated; but collisional rates are);
C             >  0  -  primarily linearized transition;
C             <  0  -  primarily ALI transition;
C     IFANCY  -  different meaning for lines and continua:
C       lines -  for = 0  -  Doppler profile
C                for = 1 or -1 -  Voigt profile
C                for = 2 or -2  - Stark (+ Doppler) profile
C                                 for hydrogenic lines;
C                for ge 10 - non-standard expression, given by a user
C                            supplied subroutine (PROFSP)
C             >  0  - the absorption profile for the last frequency point
C                     is taken to be 0
C             <  0  - the absorption profile for the last frequency point
C                     is evaluated exactly
C       cont. -  for = 0  -  hydrogenic photoionization cross-section,
C                            with Gaunt factor set to 1;
C                    = 1  -  hydrogenic cross-section with the exact
C                            Gaunt factor;
C                    = 2  -  cross-section by a Peach-type
C                            expression (see SIGK);
C                    = 3  -  modified Peach-type expression (called
C                            Henry-type  -  see SIGK);
C                    = 4  -  Butler's fit formula (polynomial fits to
C                            the Opacity Project results);
C                    = 5  -  cross-section from Verner tables;
C                    = 7  -  hydrogenic cross-section with the Gaunt
C                            factor from Klaus Werner;
C                    = 9  -  Opacity Project data stored in a special file.
C                            They are pretabulated and stored in file
C                            RBF.DAT
C                   > 49 and < 100 - special cross-section for
C                            a superlevel, precalculated.
c                            IFANCY then indicates the input unit number
C                            from which the data are read
C                   >100  -  Opacity Project data, immediately following
C                            the given record. There are IFANCY-100 data
C                            points.
C                for < 0  -  non-standard expression, given by a user
C                            supplied subroutine (SPSIGK)
C
C          for H- : for any IFANCY > 0  - standard expression
C          for He I:
C             IFANCY = 11 or = 13  -  Opacity Project cross section
C                                     Seaton-Ferney's cubic fits
C             IFANCY = 11  means that the multiplicity S=1 (singlet)
C             IFANCY = 13  means that the multiplicity S=3 (triplet)
C             IFANCY = 10  cross section, based on Opacity Project,
C                          but appropriately averaged for an averaged level
C                          (see explanation in SBFHE1)
C             IFANCY = 21  Cross-section for ground state from Koester
C                          fit (A&A 149, 423)
C
C
      II0=0
      IASV=0
  100 CONTINUE
      READ(IBUFF,*) II,JJ,MODE,IFANCY,ICOLIS,IFRQ0,IFRQ1,OSC,CPARAM
      IF(II.EQ.0) THEN
         IF(JJ.EQ.0) GO TO 120
         II0=JJ-1
         GO TO 100
      END IF
      if(iabs(mode).eq.2) then
         READ(IBUFF,*) kdo
         go to 100
      end if
      IF(IFANCY.GT.49.and.ifancy.lt.100) IASV=1
      if(iabs(mode).eq.3.or.iabs(mode).eq.4) go to 100
      II=II+II0
      JJ=JJ+II0
      IE=IEL(II)
      N0I=NFIRST(IE)
      NKI=NNEXT(IE)
      if(iabs(mode).eq.5) READ(IBUFF,*) fropc(ii)
      IF(JJ.GE.NKI) THEN
      LPC=.FALSE.
      IF(IELHE2.GE.0) THEN
         IF(II.GE.NFIRST(IELHE2).AND.II.LE.NLAST(IELHE2)
     *     .AND.IFWOP(II).GE.0) LPC=.TRUE.
      END IF
      IF(II.GE.N0HN.AND.II.LE.N1H.AND.IFWOP(II).GE.0) LPC=.TRUE.
      IF(LPC) THEN
         MODE=5
         XI=NQUANT(II)
         X2=XI+1.
         IF(FROPC(II).GE.0.) THEN
            FROPC(II)=ENION(II)/6.6256E-27*XI*XI/(X2*X2)
            IF(TEFF.LT.1.E4.AND.XI.LT.1.1) FROPC(II)=FROPC(II)*3.
          ELSE
            FROPC(II)=ABS(FROPC(II))
         END IF
      END IF
      END IF
      IF(JJ.LT.NKI) THEN
          LINE=.TRUE.
       ELSE
          LINE=.FALSE.
      END IF
      IF(MODE.EQ.0) GO TO 100
      IF(LINE) GO TO 110
C
C   -----------------------------------------------------
C   Additional input parameters for continuum transitions
C   -----------------------------------------------------
C
C     Only for IFANCY = 2, 3, or 4
C     S0, ALF, BET, GAM  - parameters for evaluation the
C         photoionization cross-section
C
      IF(IFANCY.GE.2.AND.IFANCY.LE.4) 
     *   READ(IBUFF,*) S0BF(II),ALFBF(II),BETBF(II),GAMBF(II)
C
C   -----------------------------------------------------
C   Additional input parameters for continuum transitions -TOPBASE DATA
C   -----------------------------------------------------
C
C     Only for IFANCY > 100 there are IFANCY-100 fit points
C
C     XTOP(MFIT,MCROSS) -  x = alog10(nu/nu0) of a fit point
C     CTOP(MFIT,MCROSS) -  sigma = alog10(sigma/10^-18) of a fit point
C
C     there are IFANCY-100 fit points
C
      IF(IFANCY.GT.100) THEN
         NFIT=IFANCY-100
         IF(NFIT.GT.MFIT) call quit(' nfit too large (TOPBASE fits)')
         READ(IBUFF,*) (XTOP(IFIT,II),IFIT=1,NFIT)
         READ(IBUFF,*) (CTOP(IFIT,II),IFIT=1,NFIT)
      END IF
      IBF(II)=IFANCY
      INDEXP(II)=IABS(MODE)
      GO TO 100
C
C  -----------------------------------------------------------
C  Additional input parameters for "clasical" line transitions
C   (i.e. those not represented by ODF's - ie ABS(MODE)=1)
C  -----------------------------------------------------------
C
  110 CONTINUE
      READ(IBUFF,*) LCOMP,INTMOD,NF,XMAX,TSTD
      IF(IFANCY.EQ.1) READ(IBUFF,*) GAMR,STARK1,STARK2,
     *              STARK3,VDWH
      GO TO 100
  120 CONTINUE
C
C -----------------------------------------
C Input parameters for additional opacities
C -----------------------------------------
C
C     IOPADD  -  switch whether to calculate additional opacities
C             =  0  -  no additional opacities
C             >  0  -  some additional opacities, the user either
C                      employs existing expressions in OPADD, or add his
C                      own expressions into OPADD
C
C     for IOPADD > 0, there are the following existing possibilities
C                (for details, see OPADD); the relevant opacity is
C                evaluated if the values of the following switches are 
C                non-zero:
C -----------------------------------------
C     IRSCT   -  Rayleigh scattering
C     IOPHMI  -  H- opacity (both bound-free and free-free), assuming LTE.
C                Note that H- can be considered as one of explicit ions,
C                then the opacity is automatically calculated (in NLTE if
C                such model is calculated). In this case one must give
C                IOPHMI=0 in order not to calculate H- opacity twice.
C     IOPH2P  -  opacity of H2+  (molecular hydrogen ion)
C     IOPHE1  -  approximate, hydrogenic, opacity of neutral helium
C                given as a sum of bound-free transitions from averaged
C                levels with principal quantum numbers between that next
C                to the highest level considered explicitly and IOPHE1
C     IOPHE2  -  the same for ionized helium
C
      READ(IBUFF,*) IOPADD
      IF(IOPADD.GT.0) THEN
         READ(IBUFF,*) IRSCT,IOPHMI,IOPH2P,IOPHE1,IOPHE2
      END IF
C
      IF(IPRIN.GE.1) WRITE(6,605) IOPADD,IOPHMI,IOPH2P,IRSCT,IOPHLI
C
C
C     ------------------------------------------
C     Input parameters for normal run of TLUSTY;
C     have no meaning here
C     ------------------------------------------
C
      IF(LTGREY) THEN
	 READ(IBUFF,*) NDGR
 	 READ(IBUFF,*) IDGR
         if(ndgr.lt.0) read(ibuff,*) tg1
 	 IF(IDGR.EQ.1) READ(IBUFF,*) TG1,TG2,TG3
        ELSE
          READ(IBUFF,*) INTRPL,ICHNG
          IF(ICHNG.GT.0) THEN
          DO 250 I=1,NLEVEL
  250        READ(IBUFF,*) I1
          END IF
      END IF
      READ(IBUFF,*) NLAMBD
      DO 260 I=1,NLAMBD
         READ(IBUFF,*) NETEXP,(IETEXP(J),J=1,NETEXP)
         READ(IBUFF,*) IFFIX,NETFIX,(IETFIX(J),J=1,NETFIX)
  260 CONTINUE
      READ(IBUFF,*) ICLMAT
      IF(ICLMAT.EQ.0) THEN
         LCHMAT=.FALSE.
       ELSE
         READ(IBUFF,*) INHE,INRE,INPC,INSE,INMP,NDRE,NN
         READ(IBUFF,*) LCHMAT
         IF(LCHMAT) READ(IBUFF,*) INHE0,INRE0,INPC0,INSE0,
     *                        INMP0,NDRE0,NN0
      END IF
C
      READ(IBUFF,*) IACC,IACD,CHMIT,ITEK
      IF(ITEK.LT.0)  READ(IBUFF,*) KANTik
C
C ------------------------------------
C Other parameters for TLUSTY - meaningless here
C
      READ(IBUFF,*,END=66) IWINBL
      IF(IWINBL.EQ.1) THEN
         READ(IBUFF,*,END=66) ALBE
       ELSE IF(IWINBL.EQ.2) THEN
         READ(IBUFF,*,END=66) ALBE
       ELSE IF(IWINBL.EQ.3) THEN
         READ(IBUFF,*,END=66) ALCON0,ALCHE2
         READ(IBUFF,*,END=66) NUMMOD
         IF(NUMMOD.GT.0) THEN
            DO 360 I=1,NUMMOD
               READ(IBUFF,*,END=66) IJ1,IJ2,ALB
  360       CONTINUE
         END IF
      END IF
      READ(IBUFF,*,END=66) NPGPOP
      IF(NPGPOP.GT.0) THEN
         READ(IBUFF,*,END=66) ((IIPR(I,J),I=1,6),J=1,NPGPOP)
      END IF
      READ(IBUFF,*,END=66) ICRSW,SWPFAC,SWPLIM,SWPINC
C
   66 CONTINUE
      IF(ITB.EQ.0) WRITE(6,608) VTB*1.E-5
      IF(ITB.NE.0) WRITE(6,609) (VTURB(I),I=1,ND)
      DO 70 I=1,ND
   70    VTURB(I)=VTURB(I)*VTURB(I)
C
  601 FORMAT(31X,'*******************************************'/
     * 31X,'I',41X,'I'/
     * 31X,'I   S Y N T H E T I C   S P E C T R U M   I'/
     * 31X,'I',41X,'I'/
     * 31X,'I',8X,'FOR MODEL ATMOSPHERE WITH',8X,'I'/
     * 31X,'I',41X,'I'/
     * 31X,'I',14X,'TEFF  =',F7.0,13X,'I'/
     * 31X,'I',14X,'LOG G =',F7.2,13X,'I'/
     * 31X,'I',41X,'I'/
     * 31X,'*******************************************')
  602 FORMAT(//' EXPLICIT LEVELS AND OPACITY SOURCES'/
     *         ' -----------------------------------'//
     *'   I',2X,'IONIZ.ENERGY',5X,'G  NQUANT IEL ILK IAT IBF ',
     *3X,'S0',5X,'ALF',4X,'BET',4X,'GAM'/)
  603 FORMAT(//' BASIC INPUT PARAMETERS'/
     *         ' ----------------------'/
     *            ' INMOD  =',I5/
     *            ' ND     =',I5/
     *            ' IDSTD  =',I5/
     *            ' INTRPL =',I5/
     *            ' ICHANG =',I5/
     *            ' NATOM  =',I5/
     *            ' NION   =',I5/
     *            ' NLEVEL =',I5/
     *            ' IELH   =',I5/
     *            ' IELHM  =',I5/
     *            ' IATH   =',I5)
  605 FORMAT(//' ADDITIONAL OPACITY SOURCES'/
     *            ' --------------------------'/
     * ' IOPADD                             =',I3/
     * ' IOPHMI  (H-  OPACITY IN LTE)       =',I3/
     * ' IOPH2P  (H2+  OPACITY)             =',I3/
     * ' IRSCT   (RAYLEIGH SCATTERING)      =',I3/
     * ' IOPHLI  (LYMAN LINES WINGS)        =',I3)
  607 FORMAT(///' YTOT   =',F11.5/' WMY    =',1PE15.5/
     *  ' WMM    =',E15.5)
  608 FORMAT(//' TURBULENT VELOCITY  -  DEPTH-INDEPENDENT   VTURB =',
     * 1PE10.3,'  KM/S'/
     *            ' ------------------'/)
  609 FORMAT(//' TURBULENT VELOCITY  -  DEPTH-DEPENDENT'/
     *            ' ------------------'/
     * 1H ,1P10E10.3)
  611 FORMAT(1H ,I3,1PE15.7,0PF9.2,I3,4I4,1X,4F7.2)
  613 FORMAT(//' EXPLICIT IONS INCLUDED'/
     *            ' ----------------------'//
     *  ' ION     N0    N1    NK    IZ  IUPSUM ICUP       FF'/)
  614 FORMAT(1H ,A4,6I6,1PD15.3)
  615 FORMAT(//' EXPLICIT ENERGY LEVELS INCLUDED'/
     *            ' -------------------------------'//
     * ' NO.   LEVEL    ION   ION.EN.(ERG)        G   NQUANT',
     * '  IEL  ILK  IAT'/)
  616 FORMAT(1H ,I3,2X,A10,A4,1PD15.7,0PF10.2,4I5)
  618 FORMAT(F11.3,F10.3)
c
      RETURN
      END
C
C
C ********************************************************************
C
C
      SUBROUTINE INITIA
C     =================
C
C     driver for input and initializations - "new" routine
C
      IMPLICIT LOGICAL (L)
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      PARAMETER (MFRQ=120)
      PARAMETER (WI1=911.753578, WI2=227.837832)
      COMMON/IPRNTR/IPRIN
      common/dissol/fropc(mlevel),indexp(mlevel)
      CHARACTER*10 TYPLEV(MLEVEL)
      CHARACTER*4 TYPION(MIOEX),TYPIOI
      CHARACTER*30 FIDATA(MION),FIODF1(MION),FIODF2(MION),FIBFCS(MION),
     *             FILEI
      CHARACTER*20 FINSTD
      CHARACTER*1 BLNK
      DIMENSION IIPR(5,6),IETEXP(10),IETFIX(10)
      COMMON/PRINTP/TYPLEV
      COMMON/IONDAT/IATI(MION),IZI(MION),NLEVS(MION),NLLIM(MION)
      COMMON/IONFIL/FIDATA,FIODF1,FIODF2,FIBFCS
      COMMON/INUNIT/IUNIT
      COMMON/STRPAR/IMER,ITR,IC,IL,IP,NLASTE,NHOD
      DIMENSION IGLE(18),IGMN(25),IGFE(26),IGNI(28)
      DATA IGLE/2,1,2,1,6,9,4,9,6,1,2,1,6,9,4,9,6,1/
      DATA IGMN/2,1,2,1,6,9,4,9,6,1,2,1,6,9,4,9,6,1,
     *          10,21,28,25,6,7,6/
      DATA IGFE/2,1,2,1,6,9,4,9,6,1,2,1,6,9,4,9,6,1,
     *          10,21,28,25,6,25,30,25/
      DATA IGNI/2,1,2,1,6,9,4,9,6,1,2,1,6,9,4,9,6,1,
     *          10,21,28,25,6,25,28,21,10,21/
      DATA BLNK /' '/
C
      CALL READBF
C
C ------------------------------------
C Basic input parameters - atmospheres
C ------------------------------------
C
      IF(INMOD.LE.1) THEN
         READ(IBUFF,*) TEFF,GRAV
       ELSE IF(INMOD.EQ.2) THEN
C
C ------------------------------
C Basic input parameters - disks
C ------------------------------
C
C     Input is the same as for TLUSDISK:
C
         READ(IBUFF,*) INPUT,IFZ0
         READ(IBUFF,*) DISPAR
      END IF
C
C ----------------------------
C other basic input parameters 
C ----------------------------
C
      READ(IBUFF,*) LTE,LTGREY
      READ(IBUFF,*) FINSTD
      CALL NSTPAR(FINSTD)
C
C
C ----------------------------
C Frequency points and weights
C ----------------------------
C
      READ(IBUFF,*) NFREAD
      NJREAD=NFREAD
C
      IF(NJREAD.LT.0) THEN
         NJREAD=-NJREAD
         NFREQC=NJREAD
         DO IJ=1,NJREAD
            READ(IBUFF,*) FREQEXP
         END DO   
       ELSE
         NFREQC=NJREAD
      END IF
C
   30 CONTINUE
C
      WRITE(6,601) TEFF,GRAV
C
C ----------------------------------------------------
C     turbulent velocities
C ----------------------------------------------------
C
      IF(VTB.LT.1.E3) VTB=VTB*1.E5
      DO ID=1,ND
         VTURB(ID)=VTB
      END DO
C
C ----------------------------------------------------
C Input parameters for explicit and non-explicit atoms
C ----------------------------------------------------
C
C     Input parameters are read by procedure STATE
C     (see description there)
C
      CALL STATE0(1)
      ID=1
      IF(IPRIN.GE.1) WRITE(6,607) YTOT(ID),WMY(ID),WMM(ID)
      DO I=1,NLEVEL
         ILK(I)=0
      END DO
C
C --------------------------------------------------------------
C Input of parameters for explicit ions, levels, and transitions
C --------------------------------------------------------------
C
      ILEV=0
      IATLST=0
      ION=0
      IA=0
      IUNIT=24
      NATOM=0
      WRITE(6,613)
   10 CONTINUE
      READ(IBUFF,*,END=20,ERR=20) IATII,IZII,NLEVSI,ILASTI,ILVLIN,
     *              NONSTD,TYPIOI,FILEI
      IF(ILASTI.EQ.0) THEN
         ION=ION+1
         IATI(ION)=IATII
         IZI(ION)=IZII
         NLEVS(ION)=NLEVSI
         TYPION(ION)=TYPIOI
         FIDATA(ION)=FILEI
         NLLIM(ION)=ILVLIN
         IUPSUM(ION)=0
         FIBFCS(ION)=BLNK
         MODEFF=1
         NFF=0
         IF(IATI(ION).EQ.1.AND.IZI(ION).EQ.0) THEN 
            IUPSUM(ION)=-100
            MODEFF=2
         END IF
         IF(IATI(ION).EQ.2.AND.IZI(ION).EQ.1) THEN
            MODEFF=2
         END IF
         IF(NONSTD.GT.0) THEN
            READ(IBUFF,*) IUPSUM(ION),ICUP,MODEFF,NFF
          ELSE IF(NONSTD.LT.0) THEN
            READ(IBUFF,*) ifil1,ifil2,FIODF1(ION),
     *                    FIODF2(ION),FIBFCS(ION)
            IF(FIBFCS(ION).NE.' ') THEN
               IUNIT=IUNIT+1
               INBFCS(ION)=IUNIT
            END IF
            IUPSUM(ION)=1
         END IF
C
         IF(IATI(ION).EQ.IATLST) THEN
            NFIRST(ION)=ILEV
          ELSE
            NFIRST(ION)=ILEV+1
            IATLST=IATI(ION)
            IA=IATEX(IATLST)
            N0A(IA)=NFIRST(ION)
            NATOM=MAX(NATOM,IA)
         END IF
         NLAST(ION)=NFIRST(ION)+NLEVS(ION)-1
         NNEXT(ION)=NLAST(ION)+1
         ILEV=NNEXT(ION)
         IZ(ION)=IZI(ION)+1 
         IF(NFF.GT.0) FF(ION)=EH/H*IZ(ION)*IZ(ION)/NFF/NFF
C
         N0I=NFIRST(ION)
         N1I=NLAST(ION)
         NKI=NNEXT(ION)
         IFREE(ION)=MODEFF
         DO II=N0I,N1I
            IEL(II)=ION
            IATM(II)=IA
         END DO
         ILK(NKI)=ION
         IATM(NKI)=IA
C
         IF(NUMAT(IA).EQ.1) THEN
            IATH=IA
            IF(IZ(ION).EQ.1) IELH=ION
            IF(IZ(ION).EQ.0) IELHM=ION
         END IF
         IF(NUMAT(IA).EQ.2) THEN
            IATHE=IA
            IF(IZ(ION).EQ.1) IELHE1=ION
            IF(IZ(ION).EQ.2) IELHE2=ION
         END IF
C         
         IF(IPRIN.GE.1) 
     *   WRITE(6,614) TYPION(ION),N0I,N1I,NKI,IZ(ION),
     *                IUPSUM(ION),ICUP,FF(ION)
C   
       ELSE IF(ILASTI.GT.0) THEN
         ENION(ILEV)=0.
         G(ILEV)=ILASTI
         NQUANT(ILEV)=1
         TYPLEV(ILEV)=TYPIOI
         IFWOP(ILEV)=0
         IEL(ILEV)=ION
         NKA(IA)=NNEXT(ION)
         IF(ILASTI.EQ.1.AND.IATII.GT.IZII) THEN
            IF(IATII.LT.25) THEN
               G(ILEV)=IGLE(IATII-IZII)
             ELSE IF(IATII.EQ.25) THEN
               G(ILEV)=IGMN(IATII-IZII)
             ELSE IF(IATII.EQ.26) THEN
               G(ILEV)=IGFE(IATII-IZII)
             ELSE IF(IATII.EQ.28) THEN
               G(ILEV)=IGNI(IATII-IZII)
            ENDIF
         ENDIF
       ELSE
         GO TO 20
      END IF 
      GO TO 10    
   20 CONTINUE
      NION=ION
      NLEVEL=NKI
C     
      if(iath.gt.0) then
      N0H=N0A(IATH)
      N1H=NLAST(IELH)
      NKH=NNEXT(IELH)
      N0HN=NFIRST(IELH)
      N0M=0
      IF(IELHM.GT.0) N0M=NFIRST(IELHM)
      else
      n0h=0
      n1h=0
      nkh=0
      n0hn=0
      end if
C
      IF(IPRIN.GE.1) WRITE(6,603) INMOD,ND,IDSTD,INTRPL,ICHANG,
     *             NATOM,NION,NLEVEL,
     *             IELH,IELHM,IATH
C
C -----------------------------------------
C Parameters for individual explicit levels
C -----------------------------------------
C
      IMER=0
      ITR=0
      IC=0
      IL=0
      IP=0
C
      DO ION=1,NION
         CALL RDATA(ION) 
         NFF=NQUANT(NLAST(ION))+1
         IF(NFF.GT.0) FF(ION)=EH/H*IZ(ION)*IZ(ION)/NFF/NFF
      END DO
C
      IF(IPRIN.GE.1) WRITE(6,615)
      DO I=1,NLEVEL
         IF(IPRIN.GE.1)
     *   WRITE(6,616) I,TYPLEV(I),TYPION(IEL(I)),ENION(I),G(I),
     *                NQUANT(I),IEL(I),ILK(I),IATM(I)
      END DO
C
C -----------------------------------------
C Input parameters for additional opacities
C -----------------------------------------
C
      IF(IPRIN.GE.1) WRITE(6,605) IOPADD,IOPHMI,IOPH2P,IRSCT,IOPHLI
C
C
      IF(VTB.LT.1.E3) VTB=VTB*1.E5
      DO ID=1,ND
         VTURB(ID)=VTB
      END DO   
      WRITE(6,608) VTB*1.E-5
      DO I=1,ND
         VTURB(I)=VTURB(I)*VTURB(I)
      END DO   
C
  601 FORMAT(31X,'*******************************************'/
     * 31X,'I',41X,'I'/
     * 31X,'I   S Y N T H E T I C   S P E C T R U M   I'/
     * 31X,'I',41X,'I'/
     * 31X,'I',8X,'FOR MODEL ATMOSPHERE WITH',8X,'I'/
     * 31X,'I',41X,'I'/
     * 31X,'I',14X,'TEFF  =',F7.0,13X,'I'/
     * 31X,'I',14X,'LOG G =',F7.2,13X,'I'/
     * 31X,'I',41X,'I'/
     * 31X,'*******************************************')
  602 FORMAT(//' EXPLICIT LEVELS AND OPACITY SOURCES'/
     *         ' -----------------------------------'//
     *'   I',2X,'IONIZ.ENERGY',5X,'G  NQUANT IEL ILK IAT IBF ',
     *3X,'S0',5X,'ALF',4X,'BET',4X,'GAM'/)
  603 FORMAT(//' BASIC INPUT PARAMETERS'/
     *         ' ----------------------'/
     *            ' INMOD  =',I5/
     *            ' ND     =',I5/
     *            ' IDSTD  =',I5/
     *            ' INTRPL =',I5/
     *            ' ICHANG =',I5/
     *            ' NATOM  =',I5/
     *            ' NION   =',I5/
     *            ' NLEVEL =',I5/
     *            ' IELH   =',I5/
     *            ' IELHM  =',I5/
     *            ' IATH   =',I5)
  605 FORMAT(//' ADDITIONAL OPACITY SOURCES'/
     *            ' --------------------------'/
     * ' IOPADD                             =',I3/
     * ' IOPHMI  (H-  OPACITY IN LTE)       =',I3/
     * ' IOPH2P  (H2+  OPACITY)             =',I3/
     * ' IRSCT   (RAYLEIGH SCATTERING)      =',I3/
     * ' IOPHLI  (LYMAN LINES WINGS)        =',I3)
  607 FORMAT(///' YTOT   =',F11.5/' WMY    =',1PE15.5/
     *  ' WMM    =',E15.5)
  608 FORMAT(//' TURBULENT VELOCITY  -  DEPTH-INDEPENDENT   VTURB =',
     * 1PE10.3,'  KM/S'/
     *            ' ------------------'/)
  609 FORMAT(//' TURBULENT VELOCITY  -  DEPTH-DEPENDENT'/
     *            ' ------------------'/
     * 1H ,1P10E10.3)
  611 FORMAT(1H ,I3,1PE15.7,0PF9.2,I3,4I4,1X,4F7.2)
  613 FORMAT(//' EXPLICIT IONS INCLUDED'/
     *            ' ----------------------'//
     *  ' ION     N0    N1    NK    IZ  IUPSUM ICUP       FF'/)
  614 FORMAT(1H ,A4,6I6,1PD15.3)
  615 FORMAT(//' EXPLICIT ENERGY LEVELS INCLUDED'/
     *            ' -------------------------------'//
     * ' NO.   LEVEL    ION   ION.EN.(ERG)        G   NQUANT',
     * '  IEL  ILK  IAT'/)
  616 FORMAT(1H ,I3,2X,A10,A4,1PD15.7,0PF10.2,4I5)
  618 FORMAT(F11.3,F10.3)
C
      RETURN
      END
C     
C     
C ************************************************************************    
C     
C     
C  
      SUBROUTINE RDATA(ION)
C     =====================
C 
      IMPLICIT LOGICAL (L)
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      PARAMETER (MFRQ=120)
      PARAMETER (WI1=911.753578, WI2=227.837832)
      PARAMETER (T15=1.D-15)
      CHARACTER*10 TYPLEV(MLEVEL)
      CHARACTER*4 TYPION(MION),TYPIOI
      CHARACTER*30 FIDATA(MION),FIODF1(MION),FIODF2(MION),FIBFCS(MION),
     *             FILEI
      CHARACTER*1 A
      COMMON/IONDAT/IATI(MION),IZI(MION),NLEVS(MION),NLLIM(MION)
      COMMON/IONFIL/FIDATA,FIODF1,FIODF2,FIBFCS
      COMMON/TOPCS/CTOP(MFIT,MCROSS), !sigma=alog10(sigma/10^-18) of fit point
     *             XTOP(MFIT,MCROSS)  ! x = alog10(nu/nu0) of fit point 
      COMMON/PRINTP/TYPLEV
      COMMON/INUNIT/IUNIT
      COMMON/STRPAR/IMER,ITR,IC,IL,IP,NLASTE,NHOD
      common/dissol/fropc(mlevel),indexp(mlevel)
C
      IUNIT=IUNIT+1
      OPEN(IUNIT,FILE=FIDATA(ION),STATUS='OLD')
C
C     read the first record - a label for the energy level input
C  
      READ(IUNIT,501) A
  501 FORMAT(A1)
C
C   -----------------------------------------------------
C   input parameters for explicit energy levels
C   -----------------------------------------------------
C  
      DO IL=1,NLEVS(ION)
         I=IL+NFIRST(ION)-1
         IE=IEL(I)
         N0I=NFIRST(IE)
         NKI=NNEXT(IE)
         IQ=I-N0I+1
         X=IQ*IQ
         ifwop(i)=0
         IZZ=IZ(IE)
         READ(IUNIT,*) 
     *   ENION(I),G(I),NQUANT(I),TYPLEV(I),ifwop(i)
         if(ifwop(i).lt.0.and.i.ne.nlast(ie)) 
     *   call quit('conflict in negative ifwop')
         IF(I.LT.NKI) THEN
            E=ENION(I)
            E0=E
            IF(E.LT.0.) THEN
               E=-E
               E0=E
            END IF
            IF(E.EQ.0.) THEN
               if(izz.le.2) then
               w0=wi1
               if(izz.eq.2) w0=wi2
               WL0=W0*X
               IF(WL0.GT.2000.) THEN
                  ALM=1.E8/(WL0*WL0) 
                  XN1=64.328+29498.1/(146.-ALM)+255.4/(41.-ALM)
                  WL0=WL0/(XN1*1.D-6+1.D0)
               END IF 
               E0=H*CL*1.D8/WL0       
               else
               E0=EH*IZZ*IZZ/X
               end if
            END IF
            IF(E.GT.1.D-7.AND.E.LT.100.) E0=1.6018D-12*E
            IF(E.GT.100..AND.E.LT.1.D7) E0=1.9857D-16*E
            IF(E.GT.1.D7) E0=H*E
            IF(ENION(I).GE.0.) THEN
              ENION(I)=E0
            ELSE
              ENION(I)=-E0
            ENDIF
            IF(G(I).EQ.0.) G(I)=2.D0*X
            IF(NQUANT(I).EQ.0) NQUANT(I)=IQ
          ELSE
c            if(modref.ge.0) nref(iatm(i))=nka(iatm(i))
            IF(G(I).EQ.0..AND.NKI.EQ.NKA(IATM(I))) G(I)=1.
         END IF
         if(ifwop(i).lt.0) then
            enion(i)=0.
            ff(ie)=0.
            IMER=IMER+1
            IMRG(I)=IMER
            IIMER(IMER)=I
         endif
         fropc(i)=0.
      END DO
c
C ----------------------------------------------------------------------
C
C   skip lines if more levels than needed, and skip the continuum transition 
C   label
C
    5 READ(IUNIT,501) A
      IF(A.NE.'*') GO TO 5
      II0=NFIRST(ION)-1
      ILLIM=NLLIM(ION)+II0
      JCORR=0
C
C   -----------------------------------------------------
C   input parameters for continuum transitions
C   -----------------------------------------------------
C
   10 CONTINUE
      READ(IUNIT,*,END=20,ERR=15) II,JJ,MODE,IFANCY,ICOLIS,
     *                            IFRQ0,IFRQ1,OSC,CPARAM
      IF(IABS(MODE).GT.100) READ(IUNIT,*) FR0INP
      if(iabs(mode).eq.2) then
         READ(IUNIT,*) kdo
         go to 10
      end if
      IF(IFANCY.GT.49.and.ifancy.lt.100) IASV=1
      if(iabs(mode).eq.3.or.iabs(mode).eq.4) go to 10
      IF(II.EQ.0) THEN
         IF(JJ.EQ.0) GO TO 30
         II0=JJ-1
         GO TO 10
      END IF
      IF(IABS(MODE).EQ.5 .OR. IABS(MODE).EQ.15) THEN
         READ(IUNIT,*) FROPCI
      END IF
      IF(II.EQ.1) JCORR=NLEVS(ION)+1-JJ
      II=II+II0
      JJ=JJ+II0+JCORR
      FROPC(II)=FROPCI
      N0I=NFIRST(IE)
      NKI=NNEXT(IE)
      IF(JJ.GE.NKI) THEN
      LPC=.FALSE.
      IF(IELHE2.GE.0) THEN
         IF(II.GE.NFIRST(IELHE2).AND.II.LE.NLAST(IELHE2)
     *     .AND.IFWOP(II).GE.0) LPC=.TRUE.
      END IF
      IF(II.GE.N0HN.AND.II.LE.N1H.AND.IFWOP(II).GE.0) LPC=.TRUE.
      IF(LPC) THEN
         MODE=5
         XI=NQUANT(II)
         X2=XI+1.
         IF(FROPC(II).GE.0.) THEN
            FROPC(II)=ENION(II)/6.6256E-27*XI*XI/(X2*X2)
            IF(TEFF.LT.1.E4.AND.XI.LT.1.1) FROPC(II)=FROPC(II)*3.
          ELSE
            FROPC(II)=ABS(FROPC(II))
         END IF
      END IF
      END IF
      IF(MODE.EQ.0) THEN
         IF(II.LT.NLAST(ION)) GO TO 10
         IF(II.EQ.NLAST(ION)) GO TO 15
      END IF
C
C   -----------------------------------------------------
C   Additional input parameters for continuum transitions
C   -----------------------------------------------------
C
C     Only for IFANCY = 2, 3, or 4
C     S0BF, ALFBF, BETBF, GAMBF  - parameters for evaluation the
C         photoionization cross-section
C
      IF(IFANCY.GE.2.AND.IFANCY.LE.4)
     *   READ(IUNIT,*) S0BF(II),ALFBF(II),BETBF(II),GAMBF(II)
C
C   -----------------------------------------------------
C   Additional input parameters for continuum transitions -TOPBASE DATA
C   -----------------------------------------------------
C
C     Only for IFANCY > 100 there are IFANCY-100 fit points
C
C     XTOP(MFIT,MCROSS) -  x = alog10(nu/nu0) of a fit point
C     CTOP(MFIT,MCROSS) -  sigma = alog10(sigma/10^-18) of a fit point
C
C     there are IFANCY-100 fit points
C
      IF(IFANCY.GT.100) THEN
         NFIT=IFANCY-100
         IF(NFIT.GT.MFIT) call quit(' nfit too large (TOPBASE fits)')
         READ(IUNIT,*) (XTOP(IFIT,II),IFIT=1,NFIT)
         READ(IUNIT,*) (CTOP(IFIT,II),IFIT=1,NFIT)
      END IF
      IBF(II)=IFANCY
      INDEXP(II)=IABS(MODE)
      IF(II.LT.NLAST(ION)) GO TO 10
   15 READ(IUNIT,501) A
      IF(A.NE.'*') GO TO 15
C
C  -----------------------------------------------------------
C  Input parameters for line transitions
C  -----------------------------------------------------------
C
   20 CONTINUE
      READ(IUNIT,*,END=30,ERR=30) II,JJ,MODE,IFANCY,ICOLIS,
     *                              IFRQ0,IFRQ1,OSC,CPARAM
      IF(IABS(MODE).GT.100) READ(IUNIT,*) FR0INP
      IF(JJ.GT.NLEVS(ION)) THEN
         IF(IABS(MODE).EQ.2) THEN
            READ(IUNIT,*) K1,K2,K3,X1,X2,X3,K4
            GO TO 20
         END IF
         IF(IABS(MODE).EQ.1) READ(IUNIT,*) LCMP
         IF(IABS(IFANCY).EQ.1) READ(IUNIT,*) GAMR,STARK1,STARK2,
     *              STARK3,VDWH
         GO TO 20
      END IF
      if(iabs(mode).eq.2) then
         READ(IUNIT,*) K1,K2,K3,X1,X2,X3,K4
         go to 20
      end if
      if(iabs(mode).eq.3.or.iabs(mode).eq.4) go to 20
      IF(MODE.EQ.0) GO TO 20
C
C  -----------------------------------------------------------
C  Additional input parameters for "clasical" line transitions
C   (i.e. those not represented by ODF's - ie ABS(MODE)=1)
C  -----------------------------------------------------------
C
      READ(IUNIT,*) LCOMP,INTMOD,NF,XMAX,TSTD
      IF(IABS(IFANCY).EQ.1) READ(IUNIT,*) GAMR,STARK1,STARK2,
     *              STARK3,VDWH
      GO TO 20
C
   30 CONTINUE
      RETURN
      END
c
c
C    *****************************************************************
c
C
      SUBROUTINE NSTPAR(FINSTD)
C     ==========================
C
C     settiing up the default values of various input flags, and
C     input of non-standard values of various input flags and parameters
C
      IMPLICIT LOGICAL (L)
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
C 
      PARAMETER(MVAR=92)
      PARAMETER(INPFI=4)
      CHARACTER*(*) FINSTD
      CHARACTER*6 PVALUE(MVAR)
      CHARACTER*80 TEXT
      CHARACTER VARNAM(MVAR)*6
      CHARACTER*20 BLNK
      CHARACTER*6 BLNK6
C
      DATA VARNAM /'ISPLIN','IRTE  ','IBC   ','ILMCOR','ILPSCT',
     *             'ILASCT','DJMAX ','NTRALI',
     *             'IFALI ','IFPOPR','JALI  ','IFRALI',
     *             'IFPREC','IELCOR','ICHC  ','IRSPLT','IATREF',
     *             'MODREF','IACPP ','IACPD ','IFLEV ','IDLTE ',
     *             'POPZER',
     *             'IOVER ','ITLAS ','IFSUB ','NITER ','NLAMBD',
     *             'ND    ',
     *             'NELSC ','IHECOR','IBFINT','IRDER ',
     *             'CHMAX ','ILDER ','IBPOPE','CHMAXT','NLAMT ',
     *             'INTRPL','ICHANG',
     *             'INHE  ','INRE  ','INPC  ','INSE  ','INMP  ',
     *             'INDL  ','NDRE  ','TAUDIV','IDLST ',
     *             'ICONV ','IPRESS','ITEMP ','IPRINT',
     *             'IOPADD','IRSCT ','IOPHMI','IOPH2P','IOPHE1',
     *             'IOPHE2',
     *             'IACC  ','IACD  ','ITEK  ','ORELAX',
     *             'IWINBL','NPGPOP',
     *             'ICRSW ','SWPFAC','SWPLIM','SWPINC',
     *             'TAUFIR','TAULAS','ABROS0','TSURF ','ALBAVE',
     *             'DION0 ','NDGREY','IDGREY','NCONIT','IPRING',
     *             'IHM   ','IH2   ','IH2P  ',
     *             'TRAD  ','WDIL  ',
     *             'HMIX0 ','VTB   ',
     *             'FRCMAX','FRCMIN','FRLMAX','FRLMIN',
     *             'DFTAIL','NFTAIL'/
C
      DATA PVALUE /'     0','     3','     3','     1','     0',
     *             '     0',' 1.D-3','     3',
     *             '     5','     4','     1','     0',
     *             '     1','   100','     0','     1','     1',
     *             '     1','     7','     4','     0','  1000',
     *             '1.D-20',
     *             '     1','   100','     0','    30','     1',
     *             '    70',
     *             '     0','     0','     1','     3',
     *             ' 1.D-3','     0','     1','     0','     1',
     *             '     0','     0',
     *             '     1','     2','     3','     4','     0',
     *             '     0','     0','   0.5','     5',
     *             '     0','     0','     0','     0',
     *             '     0','     0','     0','     0','     0',
     *             '     0',
     *             '     7','     4','     5','  1.D0',
     *             '     0','     0',
     *             '     0',' 1.D-1',' 1.D-3','  3.D0',
     *             ' 1.D-7',' 316.0','   0.4','    0.','    0.',
     *             '    1.','     0','     0','     0','     1',
     *             '     0','     0','     0',
     *             '    0.','    0.',
     *             '    0.','    2.',
     *             '    0.',' 1.D12','    0.',' 1.D13',
     *             '  0.25','    21'/
C
      DATA BLNK/'                    '/,BLNK6/'      '/
C
      IF(FINSTD.NE.BLNK) 
     *   OPEN(UNIT=INPFI,NAME=FINSTD,STATUS='UNKNOWN')
C
      INDV=-1
C
C    go through the input file line by line
c
   10 CONTINUE
      K0=1
      READ(INPFI,500,END=70,ERR=70) TEXT
  500 FORMAT(A)
   20 CONTINUE
      CALL GETWRD(TEXT,K0,K1,K2)
      IF(K1.EQ.0) GO TO 60
      K0=K2+2
      IF(TEXT(K1:K2).EQ.'=') GO TO 20
      INDV=-INDV
      IF(INDV.EQ.1) THEN
         DO 40 I=1,MVAR
            IF(TEXT(K1:K2).EQ.VARNAM(I)(1:K2-K1+1)) GO TO 50
   40    CONTINUE
         CALL GETWRD(TEXT,K0,K1,K2)
         IF(K1.EQ.0) THEN
            K0=1
   45       READ(INPFI,500,END=70) TEXT
            CALL GETWRD(TEXT,K0,K1,K2)
            IF(K1.EQ.0) GO TO 45
         END IF
         K0=K2+2
         INDV=-INDV
         GO TO 20
   50    CONTINUE
         IVAR=I
       ELSE
         PVALUE(IVAR)=BLNK6
         PVALUE(IVAR)(6-K2+K1:6)=TEXT(K1:K2)
      END IF
      GO TO 20
   60 CONTINUE
      GO TO 10
   70 CONTINUE
C
      DO I=1,MVAR
         WRITE(84,684) PVALUE(I)
  684    FORMAT(1X,A)
      END DO
C
      CLOSE(UNIT=84)
      REWIND(84)
      READ(84,*) 
     *             ISPLIN,IRTE  ,IBC   ,ILMCOR,ILPSCT,
     *             ILASCT,DJMAX ,NTRALI,
     *             IFALI ,IFPOPR,JALI  ,IFRALI,
     *             IFPREC,IELCOR,ICHC  ,IRSPLT,IATREF,
     *             MODREF,IACPP ,IACPD ,IFLEV ,IDLTE,
     *             POPZER,
     *             IOVER ,ITLAS ,IFSUB ,NITER ,NLAMBD,ND,
     *             NELSC ,IHECOR,IBFINT,IRDER ,
     *             CHMAX ,ILDER ,IBPOPE,CHMAXT,NLAMT ,
     *             INTRPL,ICHANG,
     *             INHE  ,INRE  ,INPC  ,INSE  ,INMP  ,
     *             INDL  ,NDRE  ,TAUDIV,IDLST ,
     *             ICONV ,IPRESS,ITEMP ,IPRINT,
     *             IOPADD,IRSCT ,IOPHMI,IOPH2P,IOPHE1,IOPHE2,
     *             IACC  ,IACD  ,ITEK  ,ORELAX,
     *             IWINBL,NPGPOP,
     *             ICRSW ,SWPFAC,SWPLIM,SWPINC,
     *             TAUFIR,TAULAS,ABROS0,TSURF ,ALBAVE,
     *             DION0 ,NDGREY,IDGREY,NCONIT,IPRING,
     *             IHM   ,IH2   ,IH2P  ,
     *             TRAD  ,WDIL  ,
     *             HMIX0 ,VTB   ,
     *             FRCMAX,FRCMIN,FRLMAX,FRLMIN,
     *             DFTAIL,NFTAIL
C      
      LCHC=.FALSE.
      IF(ICHC.EQ.1) LCHC=.TRUE.
      NFFIX=IFRALI
      RETURN
      END
C
C
C    ***************************************************************
C
C
      SUBROUTINE GETWRD(TEXT,K0,K1,K2)
C
C  FINDS NEXT WORD IN TEXT FROM INDEX K0. NEXT WORD IS TEXT(K1:K2)
C  THE NEXT WORD STARTS AT THE FIRST ALPHANUMERIC CHARACTER AT K0
C  OR AFTER. IT ENDS WITH THE LAST ALPHANUMERIC CHARACTER IN A ROW
C  FROM THE START
C
C  TAKEN FROM MULTI - M. CARLSSON (1976)
C
C     INCLUDE 'IMPLIC.FOR'
      PARAMETER (MSEPAR=7)
      CHARACTER*(*) TEXT
      CHARACTER SEPAR(MSEPAR)
      DATA SEPAR/' ','(',')','=','*','/',','/
C
      K1=0
      DO 400 I=K0,LEN(TEXT)
        IF(K1.EQ.0) THEN
          DO 100 J=1,MSEPAR
            IF(TEXT(I:I).EQ.SEPAR(J)) GOTO 200
  100     CONTINUE
          K1=I
C
C  NOT START OF WORD
C
  200     CONTINUE
        ELSE
          DO 300 J=1,MSEPAR
            IF(TEXT(I:I).EQ.SEPAR(J)) GOTO 500
  300     CONTINUE
        ENDIF
  400 CONTINUE
C
C  NO NEW WORD. RETURN K1=K2=0
C
      K1=0
      K2=0
      GOTO 999
C
C  NEW WORD IN TEXT(K1:I-1)
C
  500 CONTINUE
      K2=I-1
C
  999 CONTINUE
      RETURN
      END
C
C
C     ****************************************************************
C
C
      SUBROUTINE STATE0(MODOLD)
C     =========================
C
C     Initialization of the basic parameters for the Saha equation
C
      INCLUDE 'PARAMS.FOR'
      DIMENSION D(4,MATOM),XI(9,MATOM),XIFE(10)
C
C    Standard atomic constants for first 30 species:
C
C            Element Atomic  Solar    Std.
C                    weight abundance highest 
C                                     ionization stage 
      DATA D/'  H ', 1.008, 1.00E 0, 2.,
     *       '  HE', 4.003, 1.00D-1, 3.,
     *       '  LI', 6.941, 3.9D-12, 3.,
     *       '  BE', 9.012, 1.1D-11, 3.,
     *       '  B ',10.810, 6.2D-10, 4.,
     *       '  C ',12.011, 3.68D-4, 5.,
     *       '  N ',14.007, 1.14D-4, 5.,
     *       '  O ',16.000, 6.70D-4, 5.,
     *       '  F ',18.918, 3.63D-8, 4.,
     *       '  NE',20.179, 2.79D-5, 4.,
     *       '  NA',22.990, 1.72D-6, 4.,
     *       ' MG ',24.305, 3.43D-5, 4.,
     *       ' AL ',26.982, 2.49D-6, 4.,
     *       ' SI ',28.086, 3.51D-5, 5.,
     *       ' P  ',30.974, 2.67D-7, 5.,
     *       ' S  ',32.060, 1.61D-5, 5.,
     *       ' CL ',35.453, 4.42D-7, 5.,
     *       ' AR ',39.948, 4.42D-6, 5.,
     *       ' K  ',39.098, 1.11D-7, 5.,
     *       ' CA ',40.080, 2.12D-6, 5.,
     *       ' SC ',44.956, 1.16D-9, 5.,
     *       ' TI ',47.900, 5.44D-8, 5.,
     *       ' V  ',50.941, 1.25D-8, 5.,
     *       ' CR ',51.996, 4.96D-7, 5.,
     *       ' MN ',54.938, 1.57D-7, 5.,
     *       ' FE ',55.847, 2.49D-5, 5.,
     *       ' CO ',58.933, 3.13D-8, 5.,
     *       ' NI ',58.700, 1.89D-6, 5.,
     *       ' CU ',63.546, 2.79D-8, 5.,
     *       ' ZN ',65.380, 2.60D-8, 5./
C
C     Ionization potentials for first 30 species:
      DATA XI/
C
C     Element Ionization potentials (eV) 
C              I     II      III     IV       V     VI     VII    VIII
C
     *'  H ',13.595,  0.   ,  0.   ,  0.   ,  0.  ,  0.  ,  0.  ,  0.  ,
     *'  HE',24.580, 54.400,  0.   ,  0.   ,  0.  ,  0.  ,  0.  ,  0.  ,
     *'  LI', 5.392, 75.619,122.451,  0.   ,  0.  ,  0.  ,  0.  ,  0.  ,
     *'  BE', 9.322, 18.206,153.850,217.713,  0.  ,  0.  ,  0.  ,  0.  ,
     *'  B ', 8.296, 25.149, 37.920,259.298,340.22,  0.  ,  0.  ,  0.  ,
     *'  C ',11.264, 24.376, 47.864, 64.476,391.99,489.98,  0.  ,  0.  ,
     *'  N ',14.530, 29.593, 47.426, 77.450, 97.86,551.93,667.03,  0.  ,
     *'  O ',13.614, 35.108, 54.886, 77.394,113.87,138.08,739.11,871.39,
     *'  F ',17.418, 34.980, 62.646, 87.140,114.21,157.12,185.14,953.6 ,
     *'  NE',21.559, 41.070, 63.500, 97.020,126.30,157.91,207.21,239.0 ,
     *'  NA', 5.138, 47.290, 71.650, 98.880,138.37,172.09,208.44,264.16,
     *'  MG', 7.664, 15.030, 80.120,102.290,141.23,186.49,224.9 ,265.96, 
     *' AL ', 5.984, 18.823, 28.440,119.960,153.77,190.42,241.38,284.53, 
     *' SI ', 8.151, 16.350, 33.460, 45.140,166.73,205.11,246.41,303.07, 
     *' P  ',10.484, 19.720, 30.156, 51.354, 65.01,220.41,263.31,309.26,
     *' S  ',10.357, 23.400, 35.000, 47.290, 72.50, 88.03,280.99,328.8 ,
     *' CL ',12.970, 23.800, 39.900, 53.500, 67.80, 96.7 ,114.27,348.3 ,
     *' AR ',15.755, 27.620, 40.900, 59.790, 75.00, 91.3 ,124.0 ,143.46,
     *' K  ', 4.339, 31.810, 46.000, 60.900, 82.6 , 99.7 ,118.0 ,155.0 ,
     *' CA ', 6.111, 11.870, 51.210, 67.700, 84.39,109.0 ,128.0 ,147.0 ,
     *' SC ', 6.560, 12.890, 24.750, 73.900, 92.0 ,111.1 ,138.0 ,158.7 ,
     *' TI ', 6.830, 13.630, 28.140, 43.240, 99.8 ,120.0 ,140.8 ,168.5 ,
     *' V  ', 6.740, 14.200, 29.700, 48.000, 65.2 ,128.9 ,151.0 ,173.7 ,
     *' CR ', 6.763, 16.490, 30.950, 49.600, 73.0 , 90.6 ,161.1 ,184.7 ,
     *' MN ', 7.432, 15.640, 33.690, 53.000, 76.0 , 97.0 ,119.24,196.46,
     *' FE ', 7.870, 16.183, 30.652, 54.800, 75.0 , 99.1 ,125.0 ,151.06,
     *' CO ', 7.860, 17.060, 33.490, 51.300, 79.5 ,102.0 ,129.0 ,157.0 ,
     *' NI ', 7.635, 18.168, 35.170, 54.900, 75.5 ,108.0 ,133.0 ,162.0 ,
     *' CU ', 7.726, 20.292, 36.830, 55.200, 79.9 ,103.0 ,139.0 ,166.0 ,
     *' ZN ', 9.394, 17.964, 39.722, 59.400, 82.6 ,108.0 ,134.0 ,174.0 /
C
C
      DATA XIFE /8*0.,233.6,262.1/
      DATA NTOTA /30/
C
C     An element (hydrogen through zinc) can be considered in one of
C     the three following options:
C     1. explicitly - some of energy levels of some of its ionization
C                     states are considered explicitly, ie. their
C                     populations are determined by solving statistical
C                     equilibrium
C     2. implicitly - the atom is assumed not to contribute to
C                     opacity; but is allowed to contribute to the
C                     total number of particles and to the total charge;
C                     the latter is evaluated assuming LTE ionization
C                     balance, ie. by solving a set of Saha equations
C     3. not considered at all
C
C     Input:
C
C     For each element from 1 (hydrogen) to NATOMS, the following
C     parameters:
C
C     MA     =  0  - if the element is not considered (option 3)
C            =  1  - if the element is non-explicit (option 2)
C            =  2  - if the element is explicit (option 1)
C     NA0,NAK - have the meaning only for MA=2; indicate that the
C               explicit energy levels of the present species have
C               the indices between NA0 and NAK (NAK is thus the index
C               of the highest ionization state, which is represented
C               as one-level ion).
C     ION    -  has the meaning for MA=1 only;
C               if ION=0, standard number of ionization degrees is
C                         considered
C                         (counting the neutral state also; so for 
C                         instance to treat all stages of He requires
C                         ION=3, which is a default anyhow).
C               if ION>0, then ION ionization degrees is considered
C     MODPF  -  mode of evaluation of partition functions
C            =  0  -  standard evaluation (see procedure PARTF)
C            >  0  -  partition functions evaluated from the
C                     Opacity Project ionization fraction tables
C            <  0  -  non-standard evaluation, by user supplied
C                     procedure PFSPEC
C     ABN    -  if ABN=0, solar abundance is assumed (given above;
C                         abundance here is assumed as relative
C                         to hydrogen by number
C               if ABN>0, non-solar abundance ABN is assumed; in an
C                         arbitrary scale
C               if ABN<0, non-solar abundance ABN is assumed;
C                         (-ABN times the solar value)
C     PFS    -  see above
C
      READ(IBUFF,*) NATOMS
      WRITE(6,600)
      IAT=0
      IREF=0
      IF(NATOMS.LT.0) NATOMS=-NATOMS
C
      DO 10 I=1,MATOM
         DO 10 J=1,MION0
   10       RR(I,J)=0.
      DO ID=1,ND
         YTOT(ID)=0.
         WMY(ID)=0.
      END DO
C
      DO 20 I=1,MATOM
         TYPAT(I)=D(1,I)
         LGR(I)=.TRUE.
         LRM(I)=.TRUE.
         IATEX(I)=-1
 	 IF(I.LE.NATOMS) THEN
 	    IF(MODOLD.EQ.0) THEN
               READ(IBUFF,*) MA,NA0,NAK,ION,MODPF(I),ABN,
     *                       (PFSTD(J,I),J=1,5)
               MA=IABS(MA)
             ELSE
               READ(IBUFF,*) MA,ABN,MODPF(I)
               ION=0
            END IF
 	  ELSE IF(MOD(IMODE,10).LE.1) THEN
 	    MA=1
 	    ABN=0.
 	    ION=0
 	    MODPF(I)=0
           ELSE
 	    MA=0
 	 END IF
         AMAS(I)=D(2,I)
         ABND(I)=D(3,I)
         if(iref.gt.0) abnd(i)=d(3,i)*abnd(iref)/d(3,iref)
         IONIZ(I)=D(4,I)
C
C        increase the standard highest ionization for Teff larger
C        than 50000 K for N, O, Ne, and Fe
C
         IF(TEFF.GT.5.D4) THEN
            IF(I.EQ.7) IONIZ(I)=6
            IF(I.EQ.8) IONIZ(I)=7
            IF(I.EQ.26) IONIZ(I)=9
            IF(I.EQ.28) IONIZ(I)=9
         END IF
C
         DO 15 J=1,8
   15       ENEV(I,J)=xi(1+J,I)
         IF(MA.EQ.0) GO TO 20
         LGR(I)=.FALSE.
         IF(ABN.GT.0) ABND(I)=ABN
         IF(ABN.LT.0) ABND(I)=ABS(ABN)*D(3,I)
         IF(ION.NE.0) IONIZ(I)=ION
         IF(ABN.GT.1.E6) THEN
            READ(IBUFF,*) (ABNDD(I,ID),ID=1,ND)
          ELSE
            DO ID=1,ND
               ABNDD(I,ID)=ABND(I)
            END DO
         END IF
         IF(MA.EQ.1) THEN
            LRM(I)=.FALSE.
            IATEX(I)=0
          ELSE
            IAT=IAT+1
            IATEX(I)=IAT
            IF(IAT.EQ.IATREF) THEN
               IREF=I
               DO ID=1,ND
                  ABNREF(ID)=ABNDD(I,ID)
               END DO
            END IF
C
C           store parameters for explicit atoms
C
            DO ID=1,ND
               ABUND(IAT,ID)=ABNDD(I,ID)
            END DO
            AMASS(IAT)=AMAS(I)*HMASS
            NUMAT(IAT)=I
            IF(MODOLD.EQ.0) THEN
               N0A(IAT)=NA0
               NKA(IAT)=NAK
            END IF
         END IF
         DO ID=1,ND
            YTOT(ID)=YTOT(ID)+ABNDD(I,ID)
            WMY(ID)=WMY(ID)+ABNDD(I,ID)*AMAS(I)
         END DO
         ABN=ABND(I)/D(3,I)
         IF(MA.EQ.1) WRITE(6,601) I,TYPAT(I),ABND(I),ABN
         IF(MA.EQ.2) WRITE(6,602) I,TYPAT(I),ABND(I),ABN,IAT,NA0,NAK
   20 CONTINUE
      IF(MOD(IMODE,10).LE.1) NATOMS=MATOM
      DO ID=1,ND
         WMM(ID)=WMY(ID)*HMASS/YTOT(ID)
      END DO
      DO JJ=1,NATOMS
         DO ID=1,ND
            RELAB(JJ,ID)=1.
         END DO
      END DO
C
      IF(ICHEMC.NE.1) go to 100
C
C     abundance change with respect to the model atmosphere input
C     (unit 5);
C     this option is switched on by the parameter ICHEMC (read from
C     unit 55), if it is non-zero, an additional input from
C     unit 56 is required
C
C     unit 56 input:
C
C     NCHANG  -  number of chemical elements for which the abundances
C                are going to be changes;
C
C     then there are NCHANG records, each contains:
C
C     I       - atomic number
C     ABN     - new abundance; coded using the same conventions as in
C               the standard input
C
      READ(56,*,ERR=566,END=566) NCHANG
      WRITE(6,610)
      DO 60 II=1,NCHANG
         READ(56,*) I,ABN
         ABND(I)=D(3,I)
         IF(ABN.GT.0) ABND(I)=ABN
         IF(ABN.LT.0) ABND(I)=-ABN*D(3,I)
         IF(ABN.GT.1.E6) THEN
            READ(56,*) (ABNDD(I,ID),ID=1,ND)
          ELSE
            DO ID=1,ND
               ABNDD(I,ID)=ABND(I)
            END DO
         END IF
         LGR(I)=.FALSE.
         IF(IATEX(I).GT.0) THEN
            DO ID=1,ND
               RELAB(IATEX(I),ID)=ABNDD(I,ID)/ABUND(IATEX(I),ID)
               ABUND(IATEX(I),ID)=ABNDD(I,ID)
            END DO
         END IF
         ABNR=ABND(I)/D(3,I)
         WRITE(6,601) I,TYPAT(I),ABND(I),ABNR
   60 CONTINUE
C
C     renormalize abundances to have the standard element abundance
C     equal to unity
C
  100 IF(IREF.LE.1) RETURN
      write(6,620)
      DO 30 I=1,MATOM
         IAT=IATEX(I)
         IF(IAT.LT.0) GO TO 30
         DO ID=1,ND
            ABNDD(I,ID)=ABNDD(I,ID)/ABNREF(ID)
            YTOT(ID)=YTOT(ID)+ABNDD(I,ID)
            WMY(ID)=WMY(ID)+ABNDD(I,ID)*AMAS(I)
         END DO
         ABNR=ABND(I)/D(3,I)
         IF(IAT.EQ.0) THEN
            WRITE(6,601) I,TYPAT(I),ABND(I),ABNR
          ELSE
            DO ID=1,ND
               ABUND(IAT,ID)=ABNDD(I,ID)
            END DO 
            WRITE(6,602) I,TYPAT(I),ABND(I),ABNR,IAT,N0A(IAT),NKA(IAT)
         END IF
   30 CONTINUE
      DO ID=1,ND
         WMM(ID)=WMY(ID)*HMASS/YTOT(ID)
      END DO
      RETURN
  566 WRITE(6,656)
      STOP
c
  600 FORMAT(1H0//' CHEMICAL ELEMENTS INCLUDED'/
     *            ' --------------------------'//
     * ' NUMBER  ELEMENT           ABUNDANCE'/1H ,16X,
     * 'A=N(ELEM)/N(H)  A/A(SOLAR)'/)
  601 FORMAT(1H ,I4,3X,A5,1P2E14.2)
  602 FORMAT(1H ,I4,3X,A5,1P2E14.2,3X,
     *       'EXPLICIT: IAT=',I3,'  N0A=',I3,'  NKA=',I3)
  610 FORMAT(//'    CHEMICAL ELEMENTS INCLUDED - CHANGED (unit 56)'
     *           /'    --------------------------'//
     * ' NUMBER  ELEMENT           ABUNDANCE'/1H ,16X,
     * 'A=N(ELEM)/N(H)  A/A(SOLAR)'/)
  620 FORMAT(1H0//'    CHEMICAL ELEMENTS INCLUDED - RENORMALIZATION'/
     *            '    --------------------------'//
     * ' NUMBER  ELEMENT           ABUNDANCE'/1H ,16X,
     * 'A=N(ELEM)/N(H)  A/A(SOLAR)'/)
  656 FORMAT(//' CHEMICAL COMPOSITION COULD NOT BE READ FROM '
     *       'UNIT 56',//,' STOP.')
      END
C
C
C     ****************************************************************
C
C
      SUBROUTINE INIMOD
C
C   SET UP COMMON/RRRVAL/  - VALUES OF  N(ION)/U(ION) FOR ALL THE ATOMS
C   AND IONS CONSIDERED
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      COMMON/BLAPAR/RELOP,SPACE0,CUTOF0,TSTD,DSTD,ALAMC
      COMMON/HPOPST/HPOP
C
c     1. "low-temperature" ionization fractions 
c         (using Hamburg partition functions)
c
      if(teff.ge.0.) then
      DO 50 ID=1,ND
         CALL STATE(ID,TEMP(ID),ELEC(ID),S1)
         HPOP=DENS(ID)/WMM(ID)/YTOT(ID)
         DO 10 J=1,MION0
            DO 10 I=1,MATOM
   10       RRR(ID,J,I)=RR(I,J)*HPOP
         IF(ID.NE.IDSTD) GO TO 50
         TSTD=TEMP(ID)
         VTS=VTURB(ID)
         DSTD=SQRT(1.4E7*TSTD+VTS)
         WRITE(6,601) ID,TEMP(ID),ELEC(ID)
         DO 20 I=1,MATOM
   20       WRITE(6,602) TYPAT(I),(RR(I,J),J=1,MION0-1)
         WRITE(6,603)
         DO 30 I=1,MATOM
   30       WRITE(6,602) TYPAT(I),(PFSTD(J,I),J=1,MION0-1)
   50 CONTINUE
c
c     2. "high-temperature" ionization fractions 
c         (using the Opacity Project ionization fractions)
c
      else
      do id=1,nd
         do ion=1,mion
            do iat=1,matom
               rrr(id,ion,iat)=0.
            end do
         end do
      end do
      CALL FRAC1
      ID=IDSTD
      HPOP=DENS(ID)/WMM(ID)/YTOT(ID)
      WRITE(6,604) ID,TEMP(ID),ELEC(ID)
      DO 60 I=1,MATOM
         WRITE(6,605) TYPAT(I),(RRR(ID,J,I)/hpop,J=1,MION)
         ioniz(i)=i+1
   60 continue
      end if
C
  601 FORMAT(/' N/U  AT THE STANDARD DEPTH  (ID =',I3, 
     *         ' ; T,Ne = ',F8.1,1PE12.3,' )'/
     *         ' --------------------------'//)
  602 FORMAT(1H ,A4,1P8E9.2)
  603 FORMAT(//' PARTITION FUNCTIONS AT THE STANDARD DEPTH'/
     *        ' ------------------------------------------'//)
  604 FORMAT(/' N/U  AT THE STANDARD DEPTH  - OP DATA',
     * '  (ID =',I3,' ; T,Ne = ',F8.1,1PE12.3,' )'//)
  605 FORMAT(1H ,A4,(1P8E9.2))
      RETURN
      END
C
C
C ********************************************************************
C
      SUBROUTINE STATE(ID,T,ANE,Q)
C
C   LTE SAHA EQUATIONS
C
      INCLUDE 'PARAMS.FOR'
      dimension FFI(MION0)
C
      Q=0.
      TLN=LOG(T)*1.5
      TK=BOLK*T
      THL=11605./T
      X=SQRT(T/ANE)
      XMX=2.145E4*SQRT(X)
      DCH=EH/XMX/XMX/TK
      DO 50 I=1,NATOMS
         IF(LGR(I)) GO TO 50
         ION=IONIZ(I)
         RQ=0.
         RS=1.
         CALL PARTF(I,1,T,ANE,XMX,UM)
         PFSTD(1,I)=UM
         JMAX=1
         DO 10 J=2,ION
            J1=J-1
            DCHT=DCH*J1
            FI=36.113+TLN-THL*ENEV(I,J1)+DCHT
            X=J
            XMAX=XMX*SQRT(X)
            CALL PARTF(I,J,T,ANE,XMAX,U)
            PFSTD(J,I)=U
            FI=EXP(FI)*U/UM/ANE
            FFI(J)=FI
            IF(FFI(J).GT.1.) JMAX=J
            UM=U
   10    CONTINUE
         IF(JMAX.LT.ION) THEN
         R=1.
         DO 20 J=JMAX+1,ION
            R=R*FFI(J)
            RR(I,J)=R/PFSTD(J,I)
            RS=RS+R
            RQ=RQ+(J-1)*R
   20    CONTINUE
         END IF
         IF(JMAX.GT.1) THEN
         R=1.
         DO 30 JJ=1,JMAX-1
            J=JMAX-JJ
            R=R/FFI(J+1)
            RR(I,J)=R/PFSTD(J,I)
            RS=RS+R
            RQ=RQ+(J-1)*R
   30    CONTINUE
         END IF
         ABND(I)=ABNDD(I,ID)
         RR(I,JMAX)=ABND(I)/RS
         DO 40 J=1,ION
            IF(J.NE.JMAX) RR(I,J)=RR(I,J)*RR(I,JMAX)
            if(rr(i,j).lt.1.e-35) rr(i,j)=0.
   40    CONTINUE
         RR(I,JMAX)=RR(I,JMAX)/PFSTD(JMAX,I)
         X=RQ/RS
         IF(LRM(I)) GO TO 50
         if(i.gt.1) Q=X*ABND(I)+Q
   50 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE TINT
C
C     LOGARITHMIC INTERPOLATION COEFFICIENTS FOR INTERPOLATION OF
C     TEMP(ID) TO THE VALUES  5000,10000,20000,40000
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      DIMENSION TT(4)
      DATA TT /3.699, 4.000, 4.301, 4.602/
C
      DO 10 ID=1,ND
         T=LOG10(TEMP(ID))
         J=3
         IF(T.GT.TT(3)) J=4
         JT(ID)=J
         X=(TT(J)-TT(J-1))*(TT(J)-TT(J-2))*(TT(J-1)-TT(J-2))
         TI0(ID)=(T-TT(J-2))*(T-TT(J-1))*(TT(J-1)-TT(J-2))/X
         TI1(ID)=(T-TT(J-2))*(TT(J)-T)*(TT(J)-TT(J-2))/X
         TI2(ID)=(T-TT(J-1))*(T-TT(J))*(TT(J)-TT(J-1))/X
   10 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE INIBL0
C
C     AUXILIARY INITIALIZATION PROCEDURE
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      parameter (un=1.)
      logical lasdel
      DIMENSION CROSS(MCROSS,MFREQ),
     *          ABSO(MFREQ),EMIS(MFREQ),SCAT(2)
      COMMON/LIMPAR/ALAM0,ALAM1,FRMIN,FRLAST,FRLI0,FRLIM
      COMMON/BLAPAR/RELOP,SPACE0,CUTOF0,TSTD,DSTD,ALAMC
      COMMON/CONTLH/SCL1(2),ICONTL
      COMMON/HHEPRF/IHYDPR,IHE1PR,IHE2PR
      COMMON/HE2PAR/IFHE2,IHE2L,ILWHE2,MHE10,MHE20
      COMMON/NXTINI/ALM00,ALST00,NXTSET,INLIST
      common/lasers/lasdel
C
C --------------------------------------------------------------
C Parameters controlling an evaluation of the synthetic spectrum
C
C --------------------------------------------------------------
C
C     ALAM0, ALAM1 - synthetic spectrum is evaluated between wavelengths
C                    ALAM0 (initial) and ALAM1 (final), given in Anstroms
C     CUTOF0       - cutoff parameter for normal lines (given in Angstroms)
C                    ie the maximum distance from the line center, in
C                    which the opacity in the line is allowd to contribute
C                    to the total opacity (recommended 5 - 10)
C     CUTOFS       - dummy
C     RELOP        - the minimum value of the ratio (opacity in the line
C                    center)/(opacity in continuum), for which is the line
C                    taken into account (usually 1d-4 to 1d-3)
C     SPACE        - the maximum distance of two neighbouring frequency
C                    points for evaluating the spectrum; in Angstroms
C
C     INLTE        = 0  -  pure LTE (no line in NLTE)
C                  ne.0 -  NLTE option, ie one or more lines treated
C                          in the exact or approximate NLTE approach
C     ICONTL       = 1  -  Lyman and Balmer lines are considered as a
C                          continuum opacity source
C                  ne.1 -  Lyman and Balmer lines are not considered as
C                          an continuum opacity source
C     INLIST       = 1  -  line list is read in the "original" format
C                          (see procedure INISET)
C                  ne.1 -  line list is read in the "new" format
C                          (see procedure INISET)
C     IFHE2        gt.0 -  He II line opacity in the first four series
C                          (Lyman, Balmer, Paschen, Brackett)
C                          for lines with lambda < 3900 A
C                          is taken into account even if line list
C                          does not contain any He II lines (i.e.
C                          He II lines are treated as the hydrogen lines)
C
C     IHYDPR      = 0  - means that hydrogen lines Stark profiles
C                        are calculated by approximate formulae
C                 > 0  - hydrogen lines Stark profiles are calculated
C                        in detail, using the Schoening & Butler tables;
C                        (for 1-2 to 1-5; 2-3 to 2-10).
C                        the tables are stored in file FOR0xx.dat,
C                        where xx=IHYDPR;
C                        higher Balmer lines are calculated as before
C
C     the meaning of other parameters is quite analogous, for the
C     following lines
C
C     IHE1PR    - He I lines at 4471, 4026, 4387, and 4922 Angstroms
C                 (tables calculated by Barnard, Cooper, and Shamey)
C     IHE2PR    - for the He II lines calculated by Schoening and Butler,
C
      READ(55,*) IFREQ,INLTE,ICONTL,INLIST,IFHE2
      READ(55,*) IHYDPR,IHE1PR,IHE2PR
      READ(55,*) ALAM0,ALAST,CUTOF0,CUTOFS,RELOP,SPACE
      if(inlte.lt.10) then
         lasdel=.true.
       else if(inlte.le.20) then
         inlte=inlte-10
         lasdel=.false.
       else if(inlte.le.30) then
         inlte=inlte-20
         ifreq=11
         lasdel=.true.
       else if(inlte.le.40) then
         inlte=inlte-30
         ifreq=11
         lasdel=.false.
      end if
C
c     VTB    - turbulent velocity (in km/s). In non-negative, this
C              value overwrites the value given by the standard input
C
      read(55,*,err=20,end=20) VTB
      if(vtb.ge.0.) then
         WRITE(6,608) VTB
  608    FORMAT(//' TURBULENT VELOCITY  -  CHANGED TO   VTURB =',
     *    1PE10.3,'  KM/S'/
     *            ' ------------------'/)
      do 10 id=1,nd
           vturb(id)=vtb*vtb*1.e10
   10 continue
      end if
C
      TSTD=TEMP(IDSTD)
      VTS=VTURB(IDSTD)
      DSTD=SQRT(1.4E7*TSTD+VTS)
   20 continue
C
C     angle points (in case the specific intensities are evaluated
C
C     NMU0      -    number of angles:
C               >0 - and if also ANG0>0, angles (mu's) equidistant 
C                    between 1 and ANG0
C               >0 - and if also ANG0<0, angles (mu's) equidistant 
C                    between 0.7 and ANG0, and sinuses equidistatnt for
C                    others
C               <0 - angles read in the next record
C     ANG0      -    minimum mu (see above)
C     IFLUX     -    mode for evaluating angle-dependent intensities and
C                    the corresponding flux:
C               =0 - no specifiec intensities are evaluated; only usual
C                    flux is stored (unit 7 and 17)
C               =1 - specific intensities are evaluated; 
C                    and stored on unit 18
C               =2 - (interesting only for the case of macroscopic
C                    velocity field); specific intensities evaluated by
C                    a simple formal solution (RESOLV)
C
      NMU0=1
      ANG0=1.
      ANGL(1)=1.
      WANGL(1)=0.
      IFLUX=0
      READ(55,*,end=100,err=100) NMU0,ANG0,IFLUX
C
C     determinantion of the angle points and weights
C
      IF(NMU0.LT.0) THEN
         NMU0=IABS(NMU0)
         READ(55,*) (ANGL(IMU),IMU=1,NMU0)
         DO 30 IMU=2,NMU0-1
   30       WANGL(IMU)=0.5*(ANGL(IMU-1)+ANGL(IMU+1))
         WANGL(1)=0.5*(ANGL(1)-ANGL(2))
         WANGL(NMU0)=0.5*(ANGL(NMU0-1)-ANGL(NMU0))
       ELSE
         IF(ANG0.GT.0.) THEN
            IF(NMU0.GT.1) THEN
            DMU=(1.-ANG0)/(NMU0-1)
            DO 40 IMU=1,NMU0
               ANGL(IMU)=1.-(IMU-1)*DMU
               WANGL(IMU)=DMU
   40       CONTINUE
            WANGL(1)=0.5*DMU
            WANGL(NMU0-1)=0.5*DMU
            WANGL(NMU0)=2.*DMU
            END IF 
          ELSE
            ANGH=0.70710678
            DMU=ANGH/(NMU0-1)
            DO 50 IMU=1,NMU0
               ANGL(IMU)=(IMU-1)*DMU
               ANGL(IMU)=SQRT(1.-ANGL(IMU)**2)
               IF(IMU.GT.1.AND.IMU.LT.NMU0) 
     *            WANGL(IMU)=0.5*(ANGL(IMU-1)+ANGL(IMU+1))
   50       CONTINUE
            WANGL(1)=0.5*(ANGL(1)-ANGL(2))
            WANGL(NMU0)=0.5*(ANGL(NMU0-1)-ANGL(NMU0))
            IF(ANG0.LT.0.) DMU=(ANGH+ANG0)/(NMU0-1)
            DO 60 IMU=1,NMU0-2
               ANGL(IMU+NMU0)=ANGH-IMU*DMU
               WANGL(IMU+NMU0)=DMU
   60       CONTINUE
            WANGL(NMU0)=WANGL(NMU0)+0.5*DMU
            WANGL(2*NMU0-3)=0.5*DMU
            WANGL(2*NMU0-2)=2.*DMU
            NMU0=2*NMU0-2
         END IF
      END IF
      IF(NMU0.LE.0) GO TO 100
      WRITE(6,609) NMU0,(ANGL(I),I=1,NMU0)
  609 FORMAT(//' SPECIFIC INTENSITIES COMPUTED FOR',I3,
     *         ' ANGLES  mu=cos(theta) ='/
     *         ' ---------------------------------',
     *         '------------------------'//
     *         (10F7.2))
  100 CONTINUE
C
      IF(IMODE.EQ.-1) THEN
         INLTE=0
         CUTOF0=0.
      END IF
C
      ALAMC=(ALAM0+ALAST)*0.5
      SPACF=2.997925E18/ALAMC/ALAMC*SPACE
      WRITE(6,601) ALAM0,ALAST,CUTOF0,RELOP,SPACF,SPACE
      CUTOF0=0.1*CUTOF0
      SPACE0=SPACE*0.1
      ALAM0=1.D-1*ALAM0
      ALAST=1.D-1*ALAST
      ALAMC=ALAMC*0.1
      ALST00=ALAST
      FRLAST=2.997925D17/ALAST
      NFREQ=2
      FREQ(1)=2.997925D17/ALAM0
      FREQ(2)=FRLAST
      CALL SIGAVS
      IF(IHYDPR.GT.0) CALL HYDINI(IHYDPR)
      IF(IHE1PR.GT.0) CALL HE1INI(IHE1PR)
      IF(IHE2PR.GT.0) CALL HE2INI(IHE2PR)
C
C     auxiliary quantities for dissolved fractions
C
      DO ID=1,ND
         CALL DWNFR0(ID)
      END DO
C
c     pretabulate expansion coefficients for the Voigt function
c
      CALL PRETAB
c
c     calculate the characteristic standard opacity
c
      IF(IMODE.LE.2) THEN
         CALL CROSET(CROSS)
         DO 150 ID=1,ND
            CALL OPAC(ID,CROSS,ABSO,EMIS,SCAT)
            ABSTD(ID)=MIN(ABSO(1),ABSO(2))
  150    CONTINUE
      END IF
C
  502 FORMAT(16I5)
  503 FORMAT(4F10.3,2E10.3)
  601 FORMAT(//'----------------------------------------------'/
     *           ' BASIC INPUT PARAMETERS FOR SYNTHETIC SPECTRA'/
     *           ' ---------------------------------------------'/
     *           ' INITIAL LAMBDA',28X,1H=,F10.3,' ANGSTROMS'/
     *           ' FINAL   LAMBDA',28X,1H=,F10.3,' ANGSTROMS'/
     *           ' CUTOFF PARAMETER',26X,1H=,F10.3,' ANGSTROMS'/
     *           ' MINIMUM VALUE OF (LINE OPAC.)/(CONT.OPAC) =',1PE10.1/
     *           ' MAXIMUM FREQUENCY SPACING',17X,1H=,1PE10.3,'  I.E.',
     *             0PF6.3,'  ANGSTROMS'/
     *           ' ---------------------------------------------'/)
      RETURN
      END
C
C ***********************************************************************
C
      SUBROUTINE RESOLV
C
C     driver for evaluating opacities and emissivities which then
C     enter the solution of the radiative transfer equation
C     (RTE or RTEDFE)
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INTEGER  MSC(2,MDEPTH)
      DIMENSION CROSS(MCROSS,MFREQ),
     *          ABSO(MFREQ),EMIS(MFREQ),SCAT(2)
      COMMON CH(MFREQ,MDEPTH),ET(MFREQ,MDEPTH),SC(2,MDEPTH),MSC
      COMMON/HYLPAR/IHYL,ILOWH,M10,M20
      COMMON/LBLANK/IBLANK,NBLANK
      COMMON/CONTLH/SCL1(2),ICONTL
      COMMON/HPOPST/HPOP
C
      IHYL=-1
C
C     set up the partial line list for the current interval
C
      CALL INISET
C   
C     select possible hydrogen lines that may contribute to the opacity
C
      IF(IMODE.NE.-1) CALL HYLSET
C   
C     select possible He II lines that may contribute to the opacity
C
      IF(IMODE.NE.-1) CALL HE2SET
C
C     output of information about selected lines
C
      CALL INIBLA
C
C     photoinization cross-sections
C
      CALL CROSET(CROSS)
C     
C     monochromatic opacity and emissivity including all contributing
C     lines and continua
C
      IF(IMODE.GE.-1) THEN
      DO 40 ID=1,ND
         CALL OPAC(ID,CROSS,ABSO,EMIS,SCAT)
         ABSTD(ID)=0.5*(ABSO(1)+ABSO(2))
         DO 30 IJ=1,NFREQ
            CH(IJ,ID)=ABSO(IJ)
            ET(IJ,ID)=EMIS(IJ)
            IF(IJ.GT.2) GO TO 30
            SC(IJ,ID)=SCAT(IJ)+ELEC(ID)*6.6516E-25
            X=SCL1(IJ)/SC(IJ,ID)*1000.
            MSC(IJ,ID)=1000-X
   30    CONTINUE
   40 CONTINUE
C
C     output of information about selected hydrogen lines
C
      CALL INIBLH
C
C     the "iron curtain option - output of monochromatic opacities
C     on Unit 27
C     the actual stored quantities are:
C     WLAM(IJ)      - wavelength
C     ABSO(IJ)/HPOP - opacity normalized per one hydrogen atom
C
      ELSE
         ID=1
         CALL OPAC(ID,CROSS,ABSO,EMIS,SCAT)
         DO 50 IJ=3,NFREQ
            ABSO(IJ)=ABSO(IJ)/HPOP
            WRITE(27,627) WLAM(IJ),ABSO(IJ)
   50    CONTINUE
  627 format(f15.3,1pe15.5)
      END IF
      RETURN
      END
C
C *******************************************************************
C
      SUBROUTINE RTE
C
C     solution of the radiative transfer equation by Feautrier method
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INCLUDE 'LINDAT.FOR'
      DIMENSION D(3,3,MDEPTH),ANU(3,MDEPTH),AANU(MDEPTH),DDD(MDEPTH),
     *       AA(3,3),BB(3,3),CC(3,3),VL(3),AMU(3),WTMU(3),
     *       DT(MDEPTH),TAU(MDEPTH),
     *       RDD(MDEPTH),FKK(MDEPTH),ST0(MDEPTH),SS0(MDEPTH),
     *       RINT(MDEPTH,MMU)
      REAL*4 TYPION(9)
      INTEGER MSC(2,MDEPTH)
      COMMON CH(MFREQ,MDEPTH),ET(MFREQ,MDEPTH),SCAT(2,MDEPTH),MSC
      COMMON/EMFLUX/FLUX(MFREQ)
      COMMON/CONTLH/SCL1(2),ICONTL
      COMMON/IPRNTR/IPRIN
      COMMON/BLAPAR/RELOP,SPACE0,CUTOF0,TSTD,DSTD,ALAMC
      COMMON/CTRFUN/CINT1(MDEPTH),CINT2(MDEPTH),
     *   CTRI(MDEPTH),CTRR(MDEPTH),XKAR(MDEPTH),
     *   ABXLI(MFREQ),EMXLI(MFREQ),IJCTR(MFREQ)
      COMMON/REFDEP/IREFD(MFREQ)
      COMMON/CENTRL/ZND,IFZ0
c     PARAMETER (NMU = 3)
      PARAMETER (UN=1.D0, HALF=0.5D0)
      PARAMETER (THIRD=UN/3., QUART=UN/4., SIXTH=UN/6.D0)
      PARAMETER (TAUREF = 0.6666666666667)
      DATA AMU/.887298334620742D0,.5D0,.112701665379258D0/,
     1     WTMU/.277777777777778D0,.444444444444444D0,.277777777777778D0
     1         /
      DATA TYPION /4H I  ,4H II ,4H III,4H IV ,4H V  ,
     *             4H VI ,4H VII,4HVIII,4H IX /
C
      NMU=3
      ND1=ND-1
C
C     Overall loop over frequencies 
C
      DO 100 IJ=1,NFREQ
      TAUMIN=CH(IJ,1)/DENS(1)*DM(1)*HALF
      TAU(1)=TAUMIN
      IREF=1
      DO 10 I=1,ND1
         DT(I)=(DM(I+1)-DM(I))*(CH(IJ,I+1)/DENS(I+1)+CH(IJ,I)/DENS(I))*
     *         HALF
         ST0(I)=ET(IJ,I)/CH(IJ,I)
         SS0(I)=-(FRX1(IJ)*SCAT(2,I)+FRX2(IJ)*SCAT(1,I))/CH(IJ,I)
         TAU(I+1)=TAU(I)+DT(I)
         IF(TAU(I).LE.TAUREF.AND.TAU(I+1).GT.TAUREF) IREF=I
   10 CONTINUE
      IREFD(IJ)=IREF
      ST0(ND)=ET(IJ,ND)/CH(IJ,ND)
      SS0(ND)=-(FRX1(IJ)*SCAT(2,ND)+FRX2(IJ)*SCAT(1,ND))/CH(IJ,ND)
      FR=FREQ(IJ)
      IF(ICONTL.EQ.1.OR.IJ.GT.2) GO TO 17
      DO 15 I=1,ND
   15    SS0(I)=SS0(I)*MSC(IJ,I)*1.E-3
   17 CONTINUE
      BNU=BN*(FR*1.E-15)**3
      PLAND=BNU/(EXP(HK*FR/TEMP(ND  ))-UN)
      DPLAN=BNU/(EXP(HK*FR/TEMP(ND-1))-UN)
      DPLAN=(PLAND-DPLAN)/DT(ND1)
C
C   +++++++++++++++++++++++++++++++++++++++++
C   FIRST PART  -  VARIABLE EDDINGTON FACTORS
C   +++++++++++++++++++++++++++++++++++++++++
C
      ALB1=0.
c      IF(IWINDB.NE.0) ALB1=ALBEDO(IJ)/(UN+ALBEDO(IJ))/HALF
      DO 21 I=1,NMU
C
C   ************************
C   UPPER BOUNDARY CONDITION
C   ************************
C
         ID=1
         DTP1=DT(1)
         Q0=0.
         P0=0.
C
C       allowance for non-zero optical depth at the first depth point
C
         TAMM=TAUMIN/AMU(I)
         IF(TAMM.GT.0.01) THEN
            P0=UN-EXP(-TAMM)
          ELSE
            P0=TAMM*(UN-HALF*TAMM*(UN-TAMM*THIRD*(UN-QUART*TAMM)))
         END IF
         EX=UN-P0
         Q0=Q0+P0*AMU(I)*WTMU(I)
C
         DIV=DTP1/AMU(I)*THIRD
         VL(I)=DIV*(ST0(ID)+HALF*ST0(ID+1))+ST0(ID)*P0
         DO 20 J=1,NMU
            BB(I,J)=SS0(ID)*WTMU(J)*(DIV+P0)-ALB1*WTMU(J)
   20       CC(I,J)=-HALF*DIV*SS0(ID+1)*WTMU(J)
         BB(I,I)=BB(I,I)+AMU(I)/DTP1+UN+DIV
         CC(I,I)=CC(I,I)+AMU(I)/DTP1-HALF*DIV
         ANU(I,ID)=0.
   21 CONTINUE
C
C     Matrix inversion: instead of calling MATINV, a very fast inlined 
C     routine MINV3 for a specific 3 x 3 matrix inversion
C
C     CALL MATINV(BB,NMU,3)
C
C     ******************************
      BB(2,1)=BB(2,1)/BB(1,1)
      BB(2,2)=BB(2,2)-BB(2,1)*BB(1,2)
      BB(2,3)=BB(2,3)-BB(2,1)*BB(1,3)
      BB(3,1)=BB(3,1)/BB(1,1)
      BB(3,2)=(BB(3,2)-BB(3,1)*BB(1,2))/BB(2,2)
      BB(3,3)=BB(3,3)-BB(3,1)*BB(1,3)-BB(3,2)*BB(2,3)
C
      BB(3,2)=-BB(3,2)
      BB(3,1)=-BB(3,1)-BB(3,2)*BB(2,1)
      BB(2,1)=-BB(2,1)
C
      BB(3,3)=UN/BB(3,3)
      BB(2,3)=-BB(2,3)*BB(3,3)/BB(2,2)
      BB(2,2)=UN/BB(2,2)
      BB(1,3)=-(BB(1,2)*BB(2,3)+BB(1,3)*BB(3,3))/BB(1,1)
      BB(1,2)=-BB(1,2)*BB(2,2)/BB(1,1)
      BB(1,1)=UN/BB(1,1)
C
      BB(1,1)=BB(1,1)+BB(1,2)*BB(2,1)+BB(1,3)*BB(3,1)
      BB(1,2)=BB(1,2)+BB(1,3)*BB(3,2)
      BB(2,1)=BB(2,2)*BB(2,1)+BB(2,3)*BB(3,1)
      BB(2,2)=BB(2,2)+BB(2,3)*BB(3,2)
      BB(3,1)=BB(3,3)*BB(3,1)
      BB(3,2)=BB(3,3)*BB(3,2)
C     ******************************
C
      DO 22 I=1,NMU
         DO 22 J=1,NMU
            S=0.
            DO 23 K=1,NMU
   23          S=S+BB(I,K)*CC(K,J)
            D(I,J,ID)=S
            ANU(I,1)=ANU(I,1)+BB(I,J)*VL(J)
   22 CONTINUE
C
C   *******************
C   NORMAL DEPTH POINTS
C   *******************
C
      DO 34 ID=2,ND1
         DTM1=DTP1
         DTP1=DT(ID)
         DT0=HALF*(DTM1+DTP1)
         AL=UN/DTM1/DT0
         GA=UN/DTP1/DT0
         BE=AL+GA
         A=(UN-HALF*AL*DTP1*DTP1)*SIXTH
         C=(UN-HALF*GA*DTM1*DTM1)*SIXTH
         B=UN-A-C
         VL0=A*ST0(ID-1)+B*ST0(ID)+C*ST0(ID+1)
         DO 30 I=1,NMU
            DO 30 J=1,NMU
               AA(I,J)=-A*SS0(ID-1)*WTMU(J)
               CC(I,J)=-C*SS0(ID+1)*WTMU(J)
               BB(I,J)=B*SS0(ID)*WTMU(J)
   30    CONTINUE
         DO 31 I=1,NMU
            DIV=AMU(I)**2
            VL(I)=VL0
            AA(I,I)=AA(I,I)+DIV*AL-A
            CC(I,I)=CC(I,I)+DIV*GA-C
            BB(I,I)=BB(I,I)+DIV*BE+B
   31    CONTINUE
         DO 32 I=1,NMU
            S1=0.
            DO 36 J=1,NMU
               S=0.
               S1=S1+AA(I,J)*ANU(J,ID-1)
               DO 35 K=1,NMU
   35             S=S+AA(I,K)*D(K,J,ID-1)
   36          BB(I,J)=BB(I,J)-S
            VL(I)=VL(I)+S1
   32    CONTINUE
C
C     Matrix inversion: instead of calling MATINV, a very fast inlined 
C     routine MINV3 for a specific 3 x 3 matrix inversion
C
C     CALL MATINV(BB,NMU,3)
C
C     ******************************
      BB(2,1)=BB(2,1)/BB(1,1)
      BB(2,2)=BB(2,2)-BB(2,1)*BB(1,2)
      BB(2,3)=BB(2,3)-BB(2,1)*BB(1,3)
      BB(3,1)=BB(3,1)/BB(1,1)
      BB(3,2)=(BB(3,2)-BB(3,1)*BB(1,2))/BB(2,2)
      BB(3,3)=BB(3,3)-BB(3,1)*BB(1,3)-BB(3,2)*BB(2,3)
C
      BB(3,2)=-BB(3,2)
      BB(3,1)=-BB(3,1)-BB(3,2)*BB(2,1)
      BB(2,1)=-BB(2,1)
C
      BB(3,3)=UN/BB(3,3)
      BB(2,3)=-BB(2,3)*BB(3,3)/BB(2,2)
      BB(2,2)=UN/BB(2,2)
      BB(1,3)=-(BB(1,2)*BB(2,3)+BB(1,3)*BB(3,3))/BB(1,1)
      BB(1,2)=-BB(1,2)*BB(2,2)/BB(1,1)
      BB(1,1)=UN/BB(1,1)
C
      BB(1,1)=BB(1,1)+BB(1,2)*BB(2,1)+BB(1,3)*BB(3,1)
      BB(1,2)=BB(1,2)+BB(1,3)*BB(3,2)
      BB(2,1)=BB(2,2)*BB(2,1)+BB(2,3)*BB(3,1)
      BB(2,2)=BB(2,2)+BB(2,3)*BB(3,2)
      BB(3,1)=BB(3,3)*BB(3,1)
      BB(3,2)=BB(3,3)*BB(3,2)
C     ******************************
C
         DO 33 I=1,NMU
            ANU(I,ID)=0.
            DO 33 J=1,NMU
               S=0.
               DO 37 K=1,NMU
   37             S=S+BB(I,K)*CC(K,J)
               D(I,J,ID)=S
               ANU(I,ID)=ANU(I,ID)+BB(I,J)*VL(J)
   33    CONTINUE
   34 CONTINUE
C
C   ************
C   LOWER BOUNDARY CONDITION
C   ************
C
      ID=ND
C
C     First option:
C     b.c. is different from stellar atmospheres; expresses symmetry
C     at the central plane   I(taumax,-mu,nu)=I(taumax,+mu,nu)
C
      IF(IFZ0.EQ.0) THEN
         B=DTP1*HALF
         A=0.
         DO 190 I=1,NMU
            BI=B/AMU(I)
            AI=A/AMU(I)
            VL(I)=ST0(ID)*BI+ST0(ID-1)*AI
            DO 180 J=1,NMU
               AA(I,J)=-AI*SS0(ID-1)*WTMU(J)
  180          BB(I,J)=BI*SS0(ID)*WTMU(J)
            AA(I,I)=AA(I,I)+AMU(I)/DTP1-AI
            BB(I,I)=BB(I,I)+AMU(I)/DTP1+BI
  190    CONTINUE
         DO 220 I=1,NMU
            S1=0.
            DO 210 J=1,NMU
               S=0.
               S1=S1+AA(I,J)*ANU(J,ID-1)
               DO 200 K=1,NMU
  200             S=S+AA(I,K)*D(K,J,ID-1)
  210          BB(I,J)=BB(I,J)-S
            VL(I)=VL(I)+S1
  220    CONTINUE
C
C     Second option:
C     b.c. is the same as in stellar atmospheres - the last depth point
C     is not at the central plane
C
      ELSE
      DO 41 I=1,NMU
         AA(I,I)=AMU(I)/DTP1
         VL(I)=PLAND+AMU(I)*DPLAN+AA(I,I)*ANU(I,ID-1)
         DO 40 J=1,NMU
   40       BB(I,J)=-AA(I,I)*D(I,J,ID-1)
         BB(I,I)=BB(I,I)+AA(I,I)+UN
   41 CONTINUE
      END IF
C
C     Matrix inversion: instead of calling MATINV, a very fast inlined 
C     routine MINV3 for a specific 3 x 3 matrix inversion
C
C     CALL MATINV(BB,NMU,3)
C
C     ******************************
      BB(2,1)=BB(2,1)/BB(1,1)
      BB(2,2)=BB(2,2)-BB(2,1)*BB(1,2)
      BB(2,3)=BB(2,3)-BB(2,1)*BB(1,3)
      BB(3,1)=BB(3,1)/BB(1,1)
      BB(3,2)=(BB(3,2)-BB(3,1)*BB(1,2))/BB(2,2)
      BB(3,3)=BB(3,3)-BB(3,1)*BB(1,3)-BB(3,2)*BB(2,3)
C
      BB(3,2)=-BB(3,2)
      BB(3,1)=-BB(3,1)-BB(3,2)*BB(2,1)
      BB(2,1)=-BB(2,1)
C
      BB(3,3)=UN/BB(3,3)
      BB(2,3)=-BB(2,3)*BB(3,3)/BB(2,2)
      BB(2,2)=UN/BB(2,2)
      BB(1,3)=-(BB(1,2)*BB(2,3)+BB(1,3)*BB(3,3))/BB(1,1)
      BB(1,2)=-BB(1,2)*BB(2,2)/BB(1,1)
      BB(1,1)=UN/BB(1,1)
C
      BB(1,1)=BB(1,1)+BB(1,2)*BB(2,1)+BB(1,3)*BB(3,1)
      BB(1,2)=BB(1,2)+BB(1,3)*BB(3,2)
      BB(2,1)=BB(2,2)*BB(2,1)+BB(2,3)*BB(3,1)
      BB(2,2)=BB(2,2)+BB(2,3)*BB(3,2)
      BB(3,1)=BB(3,3)*BB(3,1)
      BB(3,2)=BB(3,3)*BB(3,2)
C     ******************************
C
      DO 42 I=1,NMU
         ANU(I,ID)=0.
         DO 42 J=1,NMU
            D(I,J,ID)=0.
            ANU(I,ID)=ANU(I,ID)+BB(I,J)*VL(J)
   42 CONTINUE
C
C   ************
C   BACKSOLUTION
C   ************
C
      DO 54 ID=ND-1,1,-1
         DO 50 I=1,NMU
            DO 50 J=1,NMU
               ANU(I,ID)=ANU(I,ID)+D(I,J,ID)*ANU(J,ID+1)
   50    CONTINUE
         AJ=0.
         AK=0.
         DO 52 I=1,NMU
            DIV=WTMU(I)*ANU(I,ID)
            AJ=AJ+DIV
            AK=AK+DIV*AMU(I)**2
   52    CONTINUE
         FKK(ID)=AK/AJ
   54 CONTINUE
C
C     surface Eddington actor
C
      AH=0.
      DO 53 I=1,NMU
   53    AH=AH+WTMU(I)*AMU(I)*ANU(I,1)
      FH=AH/AJ-HALF*ALB1
C
      FKK(ND)=THIRD
C
C
C   +++++++++++++++++++++++++++++++++++++++++
C   SECOND PART  -  DETERMINATION OF THE MEAN INTENSITIES
C   RECALCULATION OF THE TRANSFER EQUATION WITH GIVEN EDDINGTON FACTORS
C   +++++++++++++++++++++++++++++++++++++++++
C
      DTP1=DT(1)
      DIV=DTP1*THIRD
      BBB=FKK(1)/DTP1+FH+DIV+SS0(1)*(DIV+Q0)
      CCC=FKK(2)/DTP1-HALF*DIV*(UN+SS0(2))
      VLL=DIV*(ST0(1)+HALF*ST0(2))+ST0(1)*Q0
      AANU(1)=VLL/BBB
      DDD(1)=CCC/BBB
      DO 60 ID=2,ND1
         DTM1=DTP1
         DTP1=DT(ID)
         DT0=HALF*(DTP1+DTM1)
         AL=UN/DTM1/DT0
         GA=UN/DTP1/DT0
         A=(UN-HALF*DTP1*DTP1*AL)*SIXTH
         C=(UN-HALF*DTM1*DTM1*GA)*SIXTH
         AAA=AL*FKK(ID-1)-A*(UN+SS0(ID-1))
         CCC=GA*FKK(ID+1)-C*(UN+SS0(ID+1))
         BBB=(AL+GA)*FKK(ID)+(UN-A-C)*(UN+SS0(ID))
         VLL=A*ST0(ID-1)+C*ST0(ID+1)+(UN-A-C)*ST0(ID)
         BBB=BBB-AAA*DDD(ID-1)
         DDD(ID)=CCC/BBB
         AANU(ID)=(VLL+AAA*AANU(ID-1))/BBB
   60 CONTINUE
C
C     Lower boundary condition
C     1.option -  different from stellar atmospheres
C
      IF(IFZ0.EQ.0) THEN
         B=DTP1*HALF
         BBB=FKK(ND)/DTP1+B*(UN+SS0(ND))
         AAA=FKK(ND-1)/DTP1
         VLL=B*ST0(ND)
       ELSE
C
C     Lower boundary condition
C     2.option - stellar atmospheric
C
         BBB=FKK(ND)/DTP1+HALF
         AAA=FKK(ND1)/DTP1
         VLL=HALF*PLAND+DPLAN*THIRD
      END IF
      BBB=BBB-AAA*DDD(ND1)
      RDD(ND)=(VLL+AAA*AANU(ND1))/BBB
Cjb   
      PREVL=2.997925E18/FREQ(IJ)
      DO 70 IID=1,ND1
         ID=ND-IID
         RDD(ID)=AANU(ID)+DDD(ID)*RDD(ID+1)
C
C        here is the correct expression for flux
C        (notice that flux is generally defined in between grid points;
C        here I take the convention that FL at depth ID is in fact
C        flux(id+1/2)
C	 Hubeny 1993, private communication
C        FL= 4*PI*EDD.FLUX        ! IN [ERG/S/CM**2/(1/S)]
C        PREVL=LAMBDA IN ANGSTREM  
C
Cjb     IJ=120 and IJ=1,3 of the next set overlay,
Cjb     that is why the output is for IJ>=4
Cjb     in the future treatment keep in mind that
Cjb     Hubeny's ID point corresponds to Kurucz ID+1 point
Cjb     as Hubeny omits 1. depth point of the Kurucz model
C 
         FL=(RDD(ID+1)*FKK(ID+1)-RDD(ID)*FKK(ID))/DT(ID)*4.*3.1415927
         IF(IJ.GT.3.AND.ID.LT.ND-1)THEN
           FL00=(FL01+FL)*0.5
           WRITE(20,'(I3,I4,F12.4,D12.4)')IJ,ID+1,PREVL,
     P     FL00
C           WRITE(20,'(I3,I4,D11.3,F12.4,D12.4)')IJ,ID+1,DM(ID+1),PREVL,
C     P     FL00
         ENDIF  
         FL01=FL
Cjb        
   70 CONTINUE
      FLUX(IJ)=FH*RDD(1)
C
C     if needed (if iprin.ge.3), output of interesting physical
C     quantities at the monochromatic optical depth  tau(nu)=2/3
C
      IF(IPRIN.ge.3) THEN
      T0=LOG(TAU(IREF+1)/TAU(IREF))
      X0=LOG(TAU(IREF+1)/TAUREF)/T0
      X1=LOG(TAUREF/TAU(IREF))/T0
      DMREF=EXP(LOG(DM(IREF))*X0+LOG(DM(IREF+1))*X1)
      TREF=EXP(LOG(TEMP(IREF))*X0+LOG(TEMP(IREF+1))*X1)
      STREF=EXP(LOG(ST0(IREF))*X0+LOG(ST0(IREF+1))*X1)
      SCREF=EXP(LOG(-SS0(IREF))*X0+LOG(-SS0(IREF+1))*X1)
      SSREF=EXP(LOG(-SS0(IREF)*RDD(IREF))*X0+
     *           LOG(-SS0(IREF+1)*RDD(IREF+1))*X1)
      SREF=STREF+SSREF
      ALM=2.997925E18/FREQ(IJ)
      WRITE(36,636) IJ,ALM,IREF,DMREF,TREF,SCREF,STREF,SSREF,SREF
  636 FORMAT(1H ,I3,F10.3,I4,1PE10.3,0PF10.1,1X,1P3E10.3,E11.3)
      END IF
C
C   THIRD PART  -  DETERMINATION OF THE SPECIFIC INTENSITIES
C   RECALCULATION OF THE TRANSFER EQUATION WITH GIVEN SOURCE FUNCTION
C
      if(iflux.eq.0) go to 100
      DO 85 IMU=1,NMU0
      ANX=ANGL(IMU)
      DTP1=DT(1)
      DIV=DTP1*THIRD/ANX
C
      TAMM=TAUMIN/ANX
      IF(TAMM.LT.0.01) THEN
         P0=TAMM*(UN-HALF*TAMM*(UN-TAMM*THIRD*(UN-QUART*TAMM)))
       ELSE
         P0=UN-EXP(-TAMM)
      END IF
C
      BBB=ANX/DTP1+UN+DIV
      CCC=ANX/DTP1-HALF*DIV
      VLL=(DIV+P0)*(ST0(1)-SS0(1)*RDD(1))
     *    +HALF*DIV*(ST0(2)-SS0(2)*RDD(2))
      AANU(1)=VLL/BBB
      DDD(1)=CCC/BBB
      DIV=ANX*ANX
      DO 82 ID=2,ND1
         DTM1=DT(ID-1)
         DTP1=DT(ID)
         DT0=HALF*(DTP1+DTM1)
         AL=UN/DTM1/DT0
         GA=UN/DTP1/DT0
         A=(UN-HALF*DTP1*DTP1*AL)*SIXTH
         C=(UN-HALF*DTM1*DTM1*GA)*SIXTH
         AAA=DIV*AL-A
         CCC=DIV*GA-C
         BBB=DIV*(AL+GA)+UN-A-C
         VLL=A*(ST0(ID-1)-SS0(ID-1)*RDD(ID-1))+
     *       C*(ST0(ID+1)-SS0(ID+1)*RDD(ID+1))+
     *       (UN-A-C)*(ST0(ID)-SS0(ID)*RDD(ID))
         BBB=BBB-AAA*DDD(ID-1)
         DDD(ID)=CCC/BBB
         AANU(ID)=(VLL+AAA*AANU(ID-1))/BBB
   82 CONTINUE
C
C     Lower boundary condition
C     1.option -  different from stellar atmospheres
C
      IF(IFZ0.EQ.0) THEN
         B=DTP1*HALF/ANX
         BBB=ANX/DTP1+B*(UN+SS0(ND))
         AAA=ANX/DTP1
         VLL=B*ST0(ND)
       ELSE
C
C     Lower boundary condition
C     2.option - stellar atmospheric
C
         AAA=ANX/DTP1
         BBB=AAA+UN
         VLL=PLAND+ANX*DPLAN
      END IF
C
      RINT(ND,IMU)=(VLL+AAA*AANU(ND1))/(BBB-AAA*DDD(ND1))
      DO 84 IID=1,ND1
         ID=ND-IID
         RINT(ID,IMU)=AANU(ID)+DDD(ID)*RINT(ID+1,IMU)
   84 CONTINUE
   85 CONTINUE
c
      FLX=0.
      DO 86 IMU=1,NMU0
         RINT(1,IMU)=RINT(1,IMU)/HALF
         FLX=FLX+ANGL(IMU)*WANGL(IMU)*RINT(1,IMU)
   86 CONTINUE
      FLX=FLX*HALF
c     FLUX(IJ)=FLX
C
C     output of emergent specific intensities to Unit 10 
C     and 18 (continuum)
C
      IF(IJ.GT.2) THEN
         WRITE(10,641) WLAM(IJ),FLX,(RINT(1,IMU),IMU=1,NMU0)
       ELSE
         WRITE(18,641) WLAM(IJ),FLX,(RINT(1,IMU),IMU=1,NMU0)
      END IF
c
      if(iprin.eq.4) then
c
c     compute contribution function C_i (ctri) and C_r (ctrr)
c     following Magain (1986, A&A 163, 135)
c
       if(ijctr(ij).gt.0) then
         xfr0=(freq(ij)-freq(2))/(freq(1)-freq(2))
         tauc=ch(1,1)/dens(1)*dm(1)*half
         do 150 id=1,nd
           chc1=ch(1,id)
           chc2=ch(2,id)
           chcc=chc2+xfr0*(chc1-chc2)
           etc1=et(1,id)
           etc2=et(2,id)
           etcc=etc2+xfr0*(etc1-etc2)
           stcc=etcc/chcc
           cint=cint2(id)+xfr0*(cint1(id)-cint2(id))
           avx=(chc1+chc2)*0.5*relop
           call linop(id,abxli,emxli,avx)
           sli0=emxli(ij)/abxli(ij)
           abt0=ch(ij,id)
           emt0=et(ij,id)
           stt0=emt0/abt0
           Xkar(id)=abxli(ij)+chcc*stcc/cint
           ctri(id)=tauc*abt0/chc1*stt0*exp(-tau(id))
           if(tau(id).gt.70.) ctri(id)=0.
           ctrr(id)=tauc/chc1*abxli(ij)*(un-sli0/cint)
           if(id.lt.nd) then
             dtc=(ch(1,id+1)/dens(id+1)+ch(1,id)/dens(id))
             tauc=tauc+half*dtc*(dm(id+1)-dm(id))
           endif
  150    continue
         taurs=Xkar(1)/dens(1)*dm(1)*half
         xcti=ctri(1)*half*(dm(2)-dm(1))
         xctr=ctrr(1)*half*(dm(2)-dm(1))
         do 155 i=1,nd-1
           ctrr(i)=ctrr(i)*exp(-taurs)
           if(i.eq.1) xctr=xctr*exp(-taurs)
           if(i.gt.1) then
             xcti=xcti+ctri(i)*half*(dm(i+1)-dm(i-1))
             xctr=xctr+ctrr(i)*half*(dm(i+1)-dm(i-1))
           endif
           if(taurs.gt.70.) ctrr(i)=0.
           dtrs=(dm(i+1)-dm(i))*(Xkar(i+1)/dens(i+1)+Xkar(i)/dens(i))
           taurs=taurs+half*dtrs
  155    continue
         ctrr(nd)=0.
         alam=2.997925d18/freq(ij)
         il0=ijctr(ij)
         il=indlin(il0)
         iat=indat(il)/100
         ion=mod(indat(il),100)
         write(37,376) il,alam,typat(iat),typion(ion),iref,dmref,tref
  376    format(i5,f11.4,2x,2a4,i8,1pe12.4,0pf10.1)
         do 156 id=1,nd
           ctrip=ctri(id)/xcti
           ctrrp=ctrr(id)/xctr
           write(37,377) id,dm(id),tau(id),ctrip,ctrrp
  377      format(i4,1p4e12.4)
  156    continue
       else if(ij.eq.1) then
         do 161 id=1,nd
           cint1(id)=rint(id,nmu0)
  161    continue
       else if(ij.eq.2) then
         do 162 id=1,nd
           cint2(id)=rint(id,nmu0)
  162    continue
       endif
      endif
  100 CONTINUE
  641 FORMAT(1H ,f10.3,1pe15.5/(1P5E15.5))
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE OUTPRI
C
C     Output of synthetic spectrum
C
C     Output onto unit 7 serves as an input to the next program
C     ROTINS, which performs convolutions for the rotational and
C     instrumental broadening, and plots the synthetic spectrum
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      PARAMETER (UN=1.,CAS=1./2.997925D18,EQWC=1.19917D22)
      DIMENSION FLX(3),REL(3),ALX(3)
      COMMON/EMFLUX/FLUX(MFREQ)
      COMMON/LBLANK/IBLANK,NBLANK
      COMMON/IPRNTR/IPRIN
C
C     output of synthetic spectrum on unit 7
C
      DO 10 IJ=3,NFREQ
         FLAM=FLUX(IJ)*FREQ(IJ)*FREQ(IJ)*CAS
         WRITE(7,701) WLAM(IJ),FLAM
   10 CONTINUE
C
C     output of the continuum flux on unit 17
C
      FLAM=FLUX(1)*FREQ(1)*FREQ(1)*CAS
      WRITE(17,701) WLAM(1),FLAM
      IF(IBLANK.EQ.NBLANK) THEN
         FLAM=FLUX(2)*FREQ(2)*FREQ(2)*CAS
         WRITE(17,701) WLAM(2),FLAM
      END IF
C
C     unit 6 and 16 outputs
C
      if(iprin.le.-1) return
      if(iprin.ge.1) then
      WRITE(6,600)
      WRITE(6,601)
      end if
      K1=0
      EQW=0.
      EQWP=0.
      IF(IBLANK.EQ.1) EQWT=0.
      IF(IBLANK.EQ.1) EQWTP=0.
      XX=UN/(FREQ(2)-FREQ(1))
      XXX=UN/(FREQ(1)+FREQ(2))/(FREQ(1)+FREQ(2))
      DO 20 IJ=1,NFREQ
         FLAM=FLUX(IJ)*FREQ(IJ)*FREQ(IJ)*CAS
         CONT=((FREQ(IJ)-FREQ(1))*FLUX(2)+(FREQ(2)-FREQ(IJ))*FLUX(1))*XX
         RE0=FLUX(IJ)/CONT
         EQW=EQW+(UN-RE0)*W(IJ)
         REP=RE0
         IF(REP.GT.UN) REP=UN
         EQWP=EQWP+(UN-REP)*W(IJ)
         if(iprin.le.0) go to 20
         K1=K1+1
         FLX(K1)=LOG10(FLAM)
         ALX(K1)=WLAM(IJ)
         REL(K1)=RE0
         IF(K1.EQ.3.OR.IJ.EQ.NFREQ) THEN
            WRITE(6,602) (ALX(I),FLX(I),REL(I),I=1,K1)
            K1=0
         END IF
   20 CONTINUE
C
C     output of partial equivalent widths on unit 16
C
      EQW=EQW*EQWC*XXX
      EQWT=EQWT+EQW
      EQWP=EQWP*EQWC*XXX
      EQWTP=EQWTP+EQWP
      if(iprin.gt.0) WRITE(6,603) EQW,EQWP,EQWT,EQWTP
      WRITE(16,616) WLAM(1),WLAM(2),EQW,EQWP,EQWT,EQWTP
C
  600 FORMAT(/' EMERGENT RADIATION'/' ------------------'/)
  601 FORMAT(3('   LAMBDA  LOG HLAM    REL')/)
  602 FORMAT(3(2X,F9.3,F8.4,F7.3))
  603 FORMAT(/,'  EQUIVALENT WIDTH THIS SET  =',2F8.1,' mA'/
     *            '  EQUIVALENT WIDTH TOTAL     =',2F8.1,' mA'//)
  616 FORMAT(2F12.3,4F12.1)
  701 FORMAT(F11.4,1PE15.5)
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE CROSET(CROSS)
C
C     SET UP COMMON/PHOPAR/  - PHOTOIONIZATION CROSS-SECTIONS
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'SYNTHP.FOR'
      DIMENSION CROSS(MCROSS,MFREQ)
      common/dissol/fropc(mlevel),indexp(mlevel)
C
      IJ0=2
      IF(NFREQ.EQ.1) IJ0=1
      IF(IMODE.EQ.2) IJ0=NFREQ
      DO 10 IJ=1,IJ0
         DO 10 IT=1,MCROSS
   10       CROSS(IT,IJ)=0.
      DO 30 IT=1,NLEVEL
         IF(INDEXP(IT).NE.5) THEN
            DO 20 IJ=1,IJ0
               FR=FREQ(IJ)
               CROSS(IT,IJ)=SIGK(FR,IT,0)
   20       CONTINUE
         ELSE
            DO 25 IJ=1,IJ0
               FR=FREQ(IJ)
               CROSS(IT,IJ)=SIGK(FR,IT,1)
               IF(FR.LT.FROPC(IT)) CROSS(IT,IJ)=0.
   25       CONTINUE
         END IF
   30 CONTINUE
C
C     PARAMETERS FOR CALCULATING ADDITIONAL OPACITIES
C
      IF(IOPADD.EQ.0) GO TO 50
      DO 40 IJ=1,IJ0
         FR=FREQ(IJ)
         CALL OPADD(-1,IJ,1,FR,CROSS,X1,X2,X3)
   40 CONTINUE
   50 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
C
 
      FUNCTION SIGK(FR,ITR,MODE)
C     ==========================
C
C     driver for evaluating the photoionization cross-sections
C
C     Input: FR  -  frequency
C            ITR -  index of the transition
c            mode - =0 cross-section equal to zero longward of edge
c            mode - >0 cross-section non-zero (extrapolated) longward of edge
C
      INCLUDE 'PARAMS.FOR'
      PARAMETER (SIH0=2.815D29, E10=2.3025851)
      CHARACTER*10 TYPLEV(MLEVEL)
      COMMON/PRINTP/TYPLEV
      COMMON/TOPCS/CTOP(MFIT,MCROSS), ! sigma = alog10(sigma/10^-18) of fit point
     +             XTOP(MFIT,MCROSS)  ! x = alog10(nu/nu0) of fit point 
      DIMENSION XFIT(MFIT) , ! local array containing x     for OP data
     +          SFIT(MFIT)   ! local array containing sigma for OP data
C
      PEACH(X,S,A,B)  =A*X**S*(B+X*(1.-B))*1.E-18
      HENRY(X,S,A,B,C)=A*X**S*(C+X*(B-2.*C+X*(1.+C-B)))*1.E-18
C
      SIGK=0.
      IF(IBF(ITR).EQ.0) RETURN
      II=ITR
      FR0=ENION(II)/6.6256E-27
      IF(mode.eq.0  .and. FR.LT.FR0) RETURN
      IF(FR0.LE.0.) RETURN
C
C     IBF(ITR) is the switch controlling the mode of evaluation of the
C        cross-section:
C      = 0  hydrogenic cross-section, with Gaunt factor set to 1
C      = 1  hydrogenic cross-section with exact Gaunt factor
C      = 2  Peach-type expression (see function PEACH)
C      = 3  Henry-type expression (see function HENRY)
C      = 4  Butler new calculations
C      = 7  hydrogenic cross-section with Gaunt factor from K. Werner
C      = 9  Opacity project fits (routine TOPBAS - interpolations)
C      > 100 - cross-sections extracted form TOPBASE, for several points
C           In this case, IBF-100 is the number of points
C      < 0  non-standard, user supplied expression (user should update
C           subroutine SPSIGK)
C
C      for H- : for any IBF > 0  - standard expression
C      for He I:
C       for IBF = 11 or = 13  -  Opacity Project cross section
C                Seaton-Ferney's cubic fits, Hummer's procedure (HEPHOT)
C           IBF = 11  means that the multiplicity S=1 (singlet)
C           IBF = 13  means that the multiplicity S=3 (triplet)
C       for IBF = 10  - cross section, based on Opacity Project, but
C                       appropriately averaged for an averaged level
C
C
      IB=IBF(ITR)
      IQ=NQUANT(II)
      IE=IEL(II)
      IF(IB.LT.0) GO TO 60
      IF(IE.EQ.IELHM) GO TO 40
      IF(IE.EQ.IELHE1.AND.IB.GE.10.AND.IB.LE.13) GO TO 50
      CH=IZ(IE)*IZ(IE)
      IQ5=IQ*IQ*IQ*IQ*IQ
C
      IF(IB.EQ.0) THEN
C
C        hydrogenic expression (for IBF = 0)
C
         SIGK=SIH0/FR/FR/FR*CH*CH/IQ5
C
C        exact hydrogenic - with Gaunt factor (for IBF=1)
C
       ELSE IF(IB.EQ.1) THEN
         SIGK=SIH0/FR/FR/FR*CH*CH/IQ5
         SIGK=SIGK*GAUNT(IQ,FR/CH)
       ELSE IF(IB.EQ.2) THEN
C
C        Peach-type formula (for IBF=2)
C
         IF(GAMBF(II).GT.0) THEN
            IF(GAMBF(II).LT.1.E6) THEN
              FR0=2.997925E18/GAMBF(II)
            ELSE
              FR0=GAMBF(II)
            END IF
            IF(FR.LT.FR0) RETURN        
         END IF 
         FREL=FR0/FR
         SIGK=PEACH(FREL,S0BF(II),ALFBF(II),BETBF(II))
       ELSE IF(IB.EQ.3) THEN
C
C        Henry-type formula (for IBF=3)
C
         FREL=FR0/FR
         SIGK=HENRY(FREL,S0BF(II),ALFBF(II),BETBF(II),GAMBF(II))
C
C     Butler expression
C
       ELSE IF(IB.EQ.4) THEN
         FREL=FR0/FR
         XL=LOG(FREL)
         SL=S0BF(II)+XL*(ALFBF(II)+XL*BETBF(II))
         SIGK=EXP(SL)
C
C     exact hydrogenic - with Gaunt factor from K Werner (for IBF=7)
C
       ELSE IF(IB.EQ.7) THEN
         IQ5=IQ*IQ*IQ*IQ*IQ
         SIGK=SIH0/(FR*FR*FR)*CH*CH/IQ5*GNTK(IQ,FR/CH)
C
C     selected Opacity Project data (for IBF=9)
C     (c.-s. evaluated by routine TOPBAS which needs an input file RBF.DAT)
C
       ELSE IF(IB.EQ.9) THEN
         SIGK=TOPBAS(FR,FR0,TYPLEV(II))
C
C     other Opacity Project data (for IBF>100)
C     (c.-s. evaluated by interpolating from direct input data)
C
       ELSE IF(IB.GT.100) THEN
         NFIT=IB-100
         X = LOG10(FR/FR0)
         IF(X.LT.XTOP(1,II)) THEN
            SIGM=0.
          ELSE
            DO IFIT = 1,NFIT
               XFIT(IFIT) = XTOP(IFIT,II)
               SFIT(IFIT) = CTOP(IFIT,II)
            END DO
            SIGM  = YLINTP (X,XFIT,SFIT,NFIT,MFIT)
            SIGM  = 1.D-18*EXP(E10*SIGM)
         END IF
         SIGK=SIGM
      END IF
      RETURN
C
C     special expression for H-
C
   40 SIGK=SBFHMI(FR)
      RETURN
C
C     He I cross-sections
C
   50 SIGK=SBFHE1(II,IB,FR)
      RETURN
C
C     non-standard, user supplied form of cross-section (for IBF < 0)
C
   60 CALL SPSIGK(ITR,IB,FR,SIGSP)
      SIGK=SIGSP
      RETURN
      END
C
C
C     ****************************************************************
C
C
 
      FUNCTION GAUNT(I,FR)
C     ====================
C
C     Hydrogenic bound-free Gaunt factor for the principal quantum
C     number I and frequency FR
C
      INCLUDE 'PARAMS.FOR'
      X=FR/2.99793E14
      GAUNT=1.
      IF(I.GT.10) GO TO 16
      GO TO (1,2,3,4,5,6,7,8,9,10),I
    1 GAUNT=1.2302628+X*(-2.9094219E-3+X*(7.3993579E-6-8.7356966E-9*X))
     *+(12.803223/X-5.5759888)/X
      GO TO 16
    2 GAUNT=1.1595421+X*(-2.0735860E-3+2.7033384E-6*X)+(-1.2709045+
     *(-2.0244141/X+2.1325684)/X)/X
      GO TO 16
    3 GAUNT=1.1450949+X*(-1.9366592E-3+2.3572356E-6*X)+(-0.55936432+
     *(-0.23387146/X+0.52471924)/X)/X
      GO TO 16
    4 GAUNT=1.1306695+X*(-1.3482273E-3+X*(-4.6949424E-6+2.3548636E-8*X))
     *+(-0.31190730+(0.19683564-5.4418565E-2/X)/X)/X
      GO TO 16
    5 GAUNT=1.1190904+X*(-1.0401085E-3+X*(-6.9943488E-6+2.8496742E-8*X))
     *+(-0.16051018+(5.5545091E-2-8.9182854E-3/X)/X)/X
      GO TO 16
    6 GAUNT=1.1168376+X*(-8.9466573E-4+X*(-8.8393133E-6+3.4696768E-8*X))
     *+(-0.13075417+(4.1921183E-2-5.5303574E-3/X)/X)/X
      GO TO 16
    7 GAUNT=1.1128632+X*(-7.4833260E-4+X*(-1.0244504E-5+3.8595771E-8*X))
     *+(-9.5441161E-2+(2.3350812E-2-2.2752881E-3/X)/X)/X
      GO TO 16
    8 GAUNT=1.1093137+X*(-6.2619148E-4+X*(-1.1342068E-5+4.1477731E-8*X))
     *+(-7.1010560E-2+(1.3298411E-2 -9.7200274E-4/X)/X)/X
      GO TO 16
    9 GAUNT=1.1078717+X*(-5.4837392E-4+X*(-1.2157943E-5+4.3796716E-8*X))
     *+(-5.6046560E-2+(8.5139736E-3-4.9576163E-4/X)/X)/X
      GO TO 16
   10 GAUNT=1.1052734+X*(-4.4341570E-4+X*(-1.3235905E-5+4.7003140E-8*X))
     *+(-4.7326370E-2+(6.1516856E-3-2.9467046E-4/X)/X)/X
   16 RETURN
      END
C
C
C     ****************************************************************
C
C
 
      FUNCTION GNTK(I,FR)
C     ===================
C
C     Hydrogenic bound-free Gaunt factor for the principal quantum
C     number I and frequency FR (from Klaus Werner)
C
      INCLUDE 'PARAMS.FOR'
      GNTK=1.
      IF(I.GT.3) GO TO 16
      Y=1./FR      
      GO TO (1,2,3),I
    1 GNTK=0.9916+Y*(2.71852D13-Y*2.26846D30)
      GO TO 16
    2 GNTK=1.1050-Y*(2.37490D14-Y*4.07677D28)
      GO TO 16
    3 GNTK=1.1010-Y*(0.98632D14-Y*1.03540D28)
   16 RETURN
      END
C
C
C     ****************************************************************
C
C
 
      SUBROUTINE SPSIGK(ITR,IB,FR,SIGSP)
C     ==================================
C
C     Non-standard evaluation of the photoionization cross-sections
C     Basically user-suppled procedure; here are some examples
C
      INCLUDE 'PARAMS.FOR'
      SIGSP=0.
C
C     Special formula for the He I ground state
C
      IF(IB.EQ.-201) SIGSP=7.3E-18*EXP(1.373-2.311E-16*FR)
C
C     Special formula for the averaged <n=2> level of He I
C
      IF(IB.EQ.-202) SIGSP=SGHE12(FR)
C
C     Carbon ground configuration levels 2p2 1D and 1S
C
      IF(IB.EQ.-602.OR.IB.EQ.-603) THEN
         CALL CARBON(IB,FR,SG)
         SIGSP=SG
      END IF
C
C     Hidalgo (Ap.J. 153, 981, 1968) photoionization data
C
      IF(IB.LE.-101.AND.IB.GE.-137) SIGSP=HIDALG(IB,FR)
C
C     Reilman and Manson (Ap.J. Suppl. 40, 815, 1979) photoionization data
C
      IF(IB.LE.-301.AND.IB.GE.-337) SIGSP=REIMAN(IB,FR)
      RETURN
      END
C
C
C
C     ****************************************************************
C
C
 
      SUBROUTINE CARBON(IB,FR,SG)
C     ===========================
C
C     Photoionization cross-section for neutral carbon 2p1D and 2p1S
C     levels (G.B.Taylor - private communication)
C
      INCLUDE 'PARAMS.FOR'
      DIMENSION FR2(34),SG2(34),FR3(45),SG3(45)
      DATA FR2/ 0.74, 0.75, 0.76, 0.77, 0.78, 0.79, 0.80, 0.81, 0.82,
     *                0.83,       0.85, 0.86, 0.87, 0.88, 0.89, 0.90,
     *          0.91, 0.92, 0.93, 0.94, 0.95, 0.96, 0.97, 0.98, 0.99,
     *          1.00, 1.10, 1.20, 1.30, 1.45, 1.50, 1.60, 1.80, 2./
      DATA SG2/ 12.04, 12.03, 12.09, 12.26, 12.60, 13.24, 14.36, 16.24,
     *          19.28, 23.94, 37.41, 42.88, 44.76, 43.41, 40.46, 37.19,
     *          34.26, 31.82, 29.96, 28.57, 27.68, 27.37, 27.84, 29.69,
     *          34.45, 46.35, 13.80, 11.54, 10.40,  8.96,  8.54,  7.47,
     *           6.53,  5.66/
      DATA FR3/ 0.66, 0.68, 0.70, 0.72, 0.74, 0.76, 0.78, 0.80, 0.82,
     *          0.84, 0.86, 0.864,0.866,0.868,0.87, 0.874,0.876,0.88,
     *          0.882,0.884,0.886,0.888,0.89 ,0.894,0.896,0.898,0.90,
     *          0.904,0.908,0.910,0.920,0.94, 0.98, 1.00, 1.10, 1.20,
     *          1.26, 1.34, 1.36, 1.40, 1.46, 1.60, 1.70, 1.80, 2./
      DATA SG3/ 13.94, 13.29, 12.56, 11.73, 10.82, 10.18,  8.62,  7.27,
     *           5.74,  4.14,  4.61,  5.92,  6.94,  8.34, 10.21, 16.12,
     *          20.64, 34.56, 44.82, 57.71, 73.09, 89.99,106.38,127.08,
     *         128.38,124.44,117.17, 99.32, 82.95, 76.05, 52.65, 33.23,
     *          21.29, 18.69, 12.62, 11.44,  9.77,  7.53, 10.47,  9.65,
     *          10.19,  7.28,  6.70,  6.11,  4.96/
      DATA NC2,NC3/34,45/
      DATA FR0/3.28805E15/
      F=FR/FR0
      IF(IB.NE.-602) GO TO 25
      J=2
      IF(F.LE.FR2(1)) GO TO 20
      DO 10 I=2,NC2
         J=I
         IF(F.GT.FR2(I-1).AND.F.LE.FR2(I)) GO TO 20
   10 CONTINUE
   20 SG=(F-FR2(J-1))/(FR2(J)-FR2(J-1))*(SG2(J)-SG2(J-1))+SG2(J-1)
      SG=SG*1.E-18
   25 IF(IB.NE.-603) GO TO 50
      J=2
      IF(F.LE.FR3(1)) GO TO 40
      DO 30 I=2,NC3
         J=I
         IF(F.GT.FR3(I-1).AND.F.LE.FR3(I)) GO TO 40
   30 CONTINUE
   40 SG=(F-FR3(J-1))/(FR3(J)-FR3(J-1))*(SG3(J)-SG3(J-1))+SG3(J-1)
      SG=SG*1.E-18
   50 CONTINUE
      RETURN
      END
C
C
C     ****************************************************************
C
 
      FUNCTION SGHE12(FR)
C     ===================
C
C     Special formula for the photoionization cross-section from the
C     averaged <n=2> level of He I
C
      INCLUDE 'PARAMS.FOR'
      DATA C1/3.E0/,C2/9.E0/,C3/1.6E1/,
     * A1/6.45105E-18/,A2/3.02E-19/,A3/9.9847E-18/,A4/1.1763673E-17/,
     * A5/3.63662E-19/,A6/-2.783E2/,A7/1.488E1/,A8/-2.311E-1/,
     * E1/3.5E0/,E2/3.6E0/,E3/1.91E0/,E4/2.9E0/,E5/3.3E0/
      X=FR*1.E-15
      XX=LOG(FR)
      SGHE12=(C1*(A1/X**E1+A2/X**E2)+A3/X**E3+C2*(A4/X**E4+A5/X**E5)+
     *       C1*EXP(A6+XX*(A7+XX*A8)))/C3
      RETURN
      END
C
C
C     ****************************************************************
C
C
      FUNCTION HIDALG(IB,FR)
C     ======================
C
C     Read table of wavelengths and photo-ionization cross-sections
C     from Hidalgo (1968, Ap. J., 153, 981) for the species indicated by IB
C     (Hidalgo's number = INDEX = -IB-100).
C     Compute linearly interpolated value of the cross-section
C     at the frequency FR.
C
      INCLUDE 'PARAMS.FOR'
      DIMENSION WL1(20),WL2(20),WL(20),SIG0(20,24),SIGS(20)
C
      DATA WL1 /
     *  39.1, 80.9, 97.6,100.1,104.3,107.2,108.7,111.9,113.6,115.4,
     * 117.1,119.0,124.8,126.9,129.1,131.3,133.6,136.0,138.5,141.1/
      DATA WL2 /
     *  68.5, 80.9,100.1,120.9,158.8,165.7,177.3,190.6,200.7,206.2,
     * 211.9,218.0,224.5,231.3,246.3,5*0./
      DATA SIG0 /
     *120*0.,
     *.0460,.2400,.3500,.3700,.4000,.4300,.4400,.4600,.4700,.4900,
     *.5000,.5200,.5700,.6200, 6*0.,
     * 80*0.,
     *.0092,.1000,.1900,.2100,.2300,.2500,.2600,.2900,.3000,.3200,
     *.3400,.3500,.4100,.4300,.4500,.4800,.5000,.5300,.5600,.5900,
     * 20*0.,
     *.3400,.4600,.6300,.7700,.9100,1.080, 14*0.,
     * 20*0.,
     *.0064,.1100,.2200,.4100,.9400,1.000,1.300,1.600, 12*0.,
     * 80*0.,
     *.0370,.0650,.1300,.2400,.5500,.6300,.7700,.9500,1.100,1.250,
     * 10*0.,
     * 40*0.,
     *.0220,.0390,.0800,.1500,.3500,.4000,.4900,.6200,.7200,.7800,
     *.8500,.9300,1.020,
     * 7*0./
C
      INDEX=-IB-100
      NUM=20
      IF(INDEX.GE.13.AND.INDEX.LE.27) NUM=15
      DO 10 I=1,NUM
         IF(INDEX.LT.13) WL(I)=WL1(I)
         IF(INDEX.GE.13) WL(I)=WL2(I)
         SIGS(I)=SIG0(I,INDEX)
   10 CONTINUE
C
      WLAM=2.997925E18/FR
      IL=1
      IR=NUM
      DO 50 I=1,NUM-1
        IF(WLAM.GE.WL(I).AND.WLAM.LE.WL(I+1)) THEN
          IL=I
          IR=I+1
          GO TO 60
        ENDIF
 50   CONTINUE
C
C     LINEAR INTERPOLATION:
C
 60   SIGM=(SIGS(IR)-SIGS(IL))*(WLAM-WL(IL))/(WL(IR)-WL(IL))
     *      + SIGS(IL)
C
C     IF OUTSIDE WAVELENGTH RANGE SET TO FIRST(LAST) VALUE:
C
       IF(WLAM.LE.WL(1)) SIGM=SIGS(1)
       IF(WLAM.GE.WL(NUM)) SIGM=SIGS(NUM)
C
C     IF LAST NON-ZERO SIG VALUES, NO INTERPOLATION:
C
c       IF(SIGS(IR).EQ.0.) SIGM=SIGS(IL)
C
      HIDALG=SIGM*1.E-18
      RETURN
      END
C
C
C     ****************************************************************
C
C
      FUNCTION REIMAN(IB,FR)
C     ======================
C
C     Read table of photon energies and photo-ionization cross-sections
C     from Reilman & Manson (1979, Ap. J. Suppl., 40, 815) for the species 
C     indicated by IB
C    
C     Compute linearly interpolated value of the cross-section 
C     at the frequency FR.
C
C     (At the moment, only a few transitions are considered)
C
      INCLUDE 'PARAMS.FOR'
      DIMENSION HEV(30),F0(30),SIG0(30,2),SIGS(30)
C
      DATA HEV /
     * 130.,160.,190.,210.,240.,270.,300.,330.,360.,390.,
     * 420.,450.,480.,510.,540.,570.,600.,630.,660.,690.,
     * 720.,750.,780.,810.,840.,870.,900.,930.,960.,990./
      DATA SIG0 /
     * 3*0.,     4.422E-1, 3.478E-1, 
     * 2.794E-1, 2.286E-1, 1.899E-1, 1.598E-1, 1.360E-1,
     * 1.169E-1, 1.013E-1, 8.845E-2, 7.776E-2, 6.877E-2,
     * 6.114E-2, 5.463E-2, 4.904E-2, 4.419E-2, 3.998E-2,
     * 3.629E-2, 3.305E-2, 3.019E-2, 2.766E-2, 2.540E-2,
     * 2.339E-2, 2.158E-2, 1.996E-2, 1.850E-2, 1.718E-2,
     * 4*0.,     1.981E-1, 1.584E-1, 
     * 1.290E-1, 1.066E-1, 8.932E-2, 7.567E-2, 6.475E-2,
     * 5.589E-2, 4.862E-2, 4.259E-2, 3.754E-2, 3.329E-2,
     * 2.966E-2, 2.656E-2, 2.388E-2, 2.157E-2, 1.954E-2,
     * 1.777E-2, 1.621E-2, 1.484E-2, 1.362E-2, 1.253E-2,
     * 1.155E-2, 1.067E-2, 9.888E-3, 9.179E-3/
C
      INDEX=-IB-300
      NUM=30  
      DO 10 I=1,NUM
         F0(I)=HEV(I)*2.418573E14
         SIGS(I)=SIG0(I,INDEX)
   10 CONTINUE
C 
      IL=1
      IR=NUM
      DO 50 I=1,NUM-1
        IF(FR.GE.F0(I).AND.FR.LE.F0(I+1)) THEN
          IL=I
          IR=I+1
          GO TO 60
        ENDIF
 50   CONTINUE
C
C     LINEAR INTERPOLATION:
C
 60   SIGM=(SIGS(IR)-SIGS(IL))*(FR-F0(IL))/(F0(IR)-F0(IL))
     *      + SIGS(IL)
C
C     IF OUTSIDE WAVELENGTH RANGE SET TO FIRST(LAST) VALUE:
C
       IF(FR.LE.F0(1)) SIGM=SIGS(1)
       IF(FR.GE.F0(NUM)) SIGM=SIGS(NUM)
C
C     IF LAST NON-ZERO SIG VALUES, NO INTERPOLATION:
C
c       IF(SIGS(IR).EQ.0.) SIGM=SIGS(IL)   
C
      REIMAN=SIGM*1.E-18
      RETURN
      END
C
C
C     ****************************************************************
C
C
 
      FUNCTION SBFHE1(II,IB,FR)
C     =========================
C
C     Calculates photoionization cross sections of neutral helium
C     from states with n = 1, 2, 3, 4.
C
C     The levels are either non-averaged (l,s) states, or some
C     averaged levels.
C     The program allows only two standard possibilities of
C     constructing averaged levels:
C     i)  all states within given principal quantum number n (>1) are
C         lumped together
C     ii) all siglet states for given n, and all triplet states for
C         given n are lumped together separately (there are thus two
C         explicit levels for a given n)
C
C     The cross sections are calculated using appropriate averages
C     of the Opacity Project cross sections, calculated by procedure
C     HEPHOT
C
C     Input parameters:
C      II    - index of the lower level (in the numbering of explicit
C              levels)
C      IB    - photoionization switch IBF for the given transition
C            = 10  -  means that the given transition is from an
C                     averaged level
C            = 11  -  the given transition is from non-averaged
C                     singlet state
C            = 13  -  the given transition is from non-averaged
C                     triplet state
C      FR    - frequency
C
      INCLUDE 'PARAMS.FOR'
C
      NI=NQUANT(II)
      IGI=INT(G(II)+0.01)
      IS=IB-10
C
C     ----------------------------------------------------------------
C     IB=11 or 13  - photoionization from an non-averaged (l,s) level
C     ----------------------------------------------------------------
C
      IF(IS.EQ.1.OR.IS.EQ.3) THEN
         IL=(IGI/IS-1)/2
         SBFHE1=HEPHOT(IS,IL,NI,FR)
      END IF
C
C     ----------------------------------------------------------------
C     IS=10 - photoionization from an averaged level
C     ----------------------------------------------------------------
C
      IF(IS.EQ.0) THEN
         IF(NI.EQ.2) THEN
C
C ********    photoionization from an averaged level with n=2
C
            IF(IGI.EQ.4) THEN
C
C      a) lower level is an averaged singlet state
C
               SBFHE1=(HEPHOT(1,0,2,FR)+3.D0*HEPHOT(1,1,2,FR))/9.D0
            ELSE IF(IGI.EQ.12) THEN
C
C      b) lower level is an averaged triplet state
C
               SBFHE1=(HEPHOT(3,0,2,FR)+3.D0*HEPHOT(3,1,2,FR))/9.D0
            ELSE IF(IGI.EQ.16) THEN
C
C      c) lower level is an average of both singlet and triplet states
C
               SBFHE1=(HEPHOT(1,0,2,FR)+3.D0*(HEPHOT(1,1,2,FR)+
     *                HEPHOT(3,0,2,FR))+9.D0*HEPHOT(3,1,2,FR))/1.6D1
            ELSE
               GO TO 10
            END IF
C
C
C ********    photoionization from an averaged level with n=3
C
         ELSE IF(NI.EQ.3) THEN
            IF(IGI.EQ.9) THEN
C
C      a) lower level is an averaged singlet state
C
               SBFHE1=(HEPHOT(1,0,3,FR)+3.D0*HEPHOT(1,1,3,FR)+
     *                5.D0*HEPHOT(1,2,3,FR))/9.D0
            ELSE IF(IGI.EQ.27) THEN
C
C      b) lower level is an averaged triplet state
C
               SBFHE1=(HEPHOT(3,0,3,FR)+3.D0*HEPHOT(3,1,3,FR)+
     *                5.D0*HEPHOT(3,2,3,FR))/9.D0
            ELSE IF(IGI.EQ.36) THEN
C
C      c) lower level is an average of both singlet and triplet states
C
               SBFHE1=(HEPHOT(1,0,3,FR)+3.D0*HEPHOT(1,1,3,FR)+
     *                5.D0*HEPHOT(1,2,3,FR)+
     *                3.D0*HEPHOT(3,0,3,FR)+9.D0*HEPHOT(3,1,3,FR)+
     *                15.D0*HEPHOT(3,2,3,FR))/3.6D0
            ELSE
               GO TO 10
            END IF
         ELSE IF(NI.EQ.4) THEN
C
C ********    photoionization from an averaged level with n=4
C
            IF(IGI.EQ.16) THEN
C
C      a) lower level is an averaged singlet state
C
               SBFHE1=(HEPHOT(1,0,4,FR)+3.D0*HEPHOT(1,1,4,FR)+
     *                 5.D0*HEPHOT(1,2,4,FR)+
     *                 7.D0*HEPHOT(1,3,4,FR))/1.6D1
            ELSE IF(IGI.EQ.48) THEN
C
C      b) lower level is an averaged triplet state
C
               SBFHE1=(HEPHOT(3,0,4,FR)+3.D0*HEPHOT(3,1,4,FR)+
     *                 5.D0*HEPHOT(3,2,4,FR)+
     *                 7.D0*HEPHOT(3,3,4,FR))/1.6D1
            ELSE IF(IGI.EQ.64) THEN
C
C      c) lower level is an average of both singlet and triplet states
C
               SBFHE1=(HEPHOT(1,0,4,FR)+3.D0*HEPHOT(1,1,4,FR)+
     *                 5.D0*HEPHOT(1,2,4,FR)+
     *                 7.D0*HEPHOT(1,3,4,FR)+
     *                 3.D0*HEPHOT(3,0,4,FR)+
     *                 9.D0*HEPHOT(3,1,4,FR)+
     *                 15.D0*HEPHOT(3,2,4,FR)+
     *                 21.D0*HEPHOT(3,3,4,FR))/6.4D1
            ELSE
               GO TO 10
            END IF
         ELSE
            GO TO 10
         END IF
      END IF
      RETURN
   10 WRITE(6,601) NI,IGI,IS
  601 FORMAT(1H0/' INCONSISTENT INPUT TO PROCEDURE SBFHE1'/
     * ' QUANTUM NUMBER =',I3,'  STATISTICAL WEIGHT',I4,'  S=',I3)
      STOP
      END
C
C
C     ****************************************************************
C
C
 
      FUNCTION HEPHOT(S,L,N,FREQ)
C     ===========================
C
C           EVALUATES HE I PHOTOIONIZATION CROSS SECTION USING SEATON
C           FERNLEY'S CUBIC FITS TO THE OPACITY PROJECT CROSS SECTIONS
C           UP TO SOME ENERGY "EFITM" IN THE RESONANCE-FREE ZONE.  BEYOND
C           THIS ENERGY LINEAR FITS TO LOG SIGMA IN LOG (E/E0) ARE USED.
C           THIS EXTRAPOLATION SHOULD BE USED UP TO THE BEGINNING OF THE
C           RESONANCE ZONE "XMAX", BUT AT PRESENT IT IS USED THROUGH IT.
C           BY CHANGING A FEW LINES THAT ARE PRESENTLY COMMENTED OUT,
C           FOR ENERGIES IN THE RESONANCE ZONE A VALUE OF 1/100 OF THE
C           THRESHOLD CROSS SECTION IS USED -- THIS IS PURELY AD HOC AND
C           ONLY A TEMPORARY MEASURE.  OBVIOUSLY ANY OTHER VALUE OR FUNCTIONAL
C           FORM CAN BE INSERTED HERE.
C
C           CALLING SEQUENCE INCLUDES:
C                S = MULTIPLICITY, EITHER 1 OR 3
C                L = ANGULAR MOMENTUM, 0, 1, OR 2;
C                    for L > 2 - hydrogenic expresion
C                FREQ = FREQUENCY
C
C           DGH JUNE 1988 JILA, slightly modified by I.H.
C
      INCLUDE 'PARAMS.FOR'
      INTEGER S,L,SS,LL
      DIMENSION COEF(4,53),IST(3,2),N0(3,2),
     *          FL0(53),A(53),B(53),XMAX(53),XFITM(53)
C
      DATA IST/1,36,20,11,45,28/
      DATA N0/1,2,3,2,2,3/
C
      DATA FL0/
     . 2.521D-01,-5.381D-01,-9.139D-01,-1.175D+00,-1.375D+00,-1.537D+00,
     .-1.674D+00,-1.792D+00,-1.896D+00,-1.989D+00,-4.555D-01,-8.622D-01,
     .-1.137D+00,-1.345D+00,-1.512D+00,-1.653D+00,-1.774D+00,-1.880D+00,
     .-1.974D+00,-9.538D-01,-1.204D+00,-1.398D+00,-1.556D+00,-1.690D+00,
     .-1.806D+00,-1.909D+00,-2.000D+00,-9.537D-01,-1.204D+00,-1.398D+00,
     .-1.556D+00,-1.690D+00,-1.806D+00,-1.909D+00,-2.000D+00,-6.065D-01,
     .-9.578D-01,-1.207D+00,-1.400D+00,-1.558D+00,-1.692D+00,-1.808D+00,
     .-1.910D+00,-2.002D+00,-5.749D-01,-9.352D-01,-1.190D+00,-1.386D+00,
     .-1.547D+00,-1.682D+00,-1.799D+00,-1.902D+00,-1.995D+00/
C
      DATA XFITM/
     . 3.262D-01, 6.135D-01, 9.233D-01, 8.438D-01, 1.020D+00, 1.169D+00,
     . 1.298D+00, 1.411D+00, 1.512D+00, 1.602D+00, 7.228D-01, 1.076D+00,
     . 1.206D+00, 1.404D+00, 1.481D+00, 1.464D+00, 1.581D+00, 1.685D+00,
     . 1.777D+00, 9.586D-01, 1.187D+00, 1.371D+00, 1.524D+00, 1.740D+00,
     . 1.854D+00, 1.955D+00, 2.046D+00, 9.585D-01, 1.041D+00, 1.371D+00,
     . 1.608D+00, 1.739D+00, 1.768D+00, 1.869D+00, 1.803D+00, 7.360D-01,
     . 1.041D+00, 1.272D+00, 1.457D+00, 1.611D+00, 1.741D+00, 1.855D+00,
     . 1.870D+00, 1.804D+00, 9.302D-01, 1.144D+00, 1.028D+00, 1.210D+00,
     . 1.362D+00, 1.646D+00, 1.761D+00, 1.863D+00, 1.954D+00/
C
      DATA A/
     . 6.95319D-01, 1.13101D+00, 1.36313D+00, 1.51684D+00, 1.64767D+00,
     . 1.75643D+00, 1.84458D+00, 1.87243D+00, 1.85628D+00, 1.90889D+00,
     . 9.01802D-01, 1.25389D+00, 1.39033D+00, 1.55226D+00, 1.60658D+00,
     . 1.65930D+00, 1.68855D+00, 1.62477D+00, 1.66726D+00, 1.83599D+00,
     . 2.50403D+00, 3.08564D+00, 3.56545D+00, 4.25922D+00, 4.61346D+00,
     . 4.91417D+00, 5.19211D+00, 1.74181D+00, 2.25756D+00, 2.95625D+00,
     . 3.65899D+00, 4.04397D+00, 4.13410D+00, 4.43538D+00, 4.19583D+00,
     . 1.79027D+00, 2.23543D+00, 2.63942D+00, 3.02461D+00, 3.35018D+00,
     . 3.62067D+00, 3.85218D+00, 3.76689D+00, 3.49318D+00, 1.16294D+00,
     . 1.86467D+00, 2.02110D+00, 2.24231D+00, 2.44240D+00, 2.76594D+00,
     . 2.93230D+00, 3.08109D+00, 3.21069D+00/
C
      DATA B/
     .-1.29000D+00,-2.15771D+00,-2.13263D+00,-2.10272D+00,-2.10861D+00,
     .-2.11507D+00,-2.11710D+00,-2.08531D+00,-2.03296D+00,-2.03441D+00,
     .-1.85905D+00,-2.04057D+00,-2.02189D+00,-2.05930D+00,-2.03403D+00,
     .-2.02071D+00,-1.99956D+00,-1.92851D+00,-1.92905D+00,-4.58608D+00,
     .-4.40022D+00,-4.39154D+00,-4.39676D+00,-4.57631D+00,-4.57120D+00,
     .-4.56188D+00,-4.55915D+00,-4.41218D+00,-4.12940D+00,-4.24401D+00,
     .-4.40783D+00,-4.39930D+00,-4.25981D+00,-4.26804D+00,-4.00419D+00,
     .-4.47251D+00,-3.87960D+00,-3.71668D+00,-3.68461D+00,-3.67173D+00,
     .-3.65991D+00,-3.64968D+00,-3.48666D+00,-3.23985D+00,-2.95758D+00,
     .-3.07110D+00,-2.87157D+00,-2.83137D+00,-2.82132D+00,-2.91084D+00,
     .-2.91159D+00,-2.91336D+00,-2.91296D+00/
C
      DATA XMAX/
     . 3.84251D-01, 9.89081D-01, 1.34758D+00, 1.60093D+00, 1.79766D+00,
     . 1.95867D+00, 2.09411D+00, 2.21217D+00, 2.31555D+00, 2.40796D+00,
     . 8.54216D-01, 1.25914D+00, 1.52406D+00, 1.74001D+00, 1.91064D+00,
     . 2.05087D+00, 2.17074D+00, 2.27614D+00, 2.37017D+00, 1.38737D+00,
     . 1.63108D+00, 1.82209D+00, 1.97849D+00, 2.11121D+00, 2.26666D+00,
     . 2.38139D+00, 2.47258D+00, 1.36716D+00, 1.60889D+00, 1.86129D+00,
     . 2.01803D+00, 2.15086D+00, 2.26617D+00, 2.36801D+00, 2.45919D+00,
     . 9.86915D-01, 1.35996D+00, 1.60525D+00, 1.81878D+00, 1.97653D+00,
     . 2.10895D+00, 2.22480D+00, 2.32641D+00, 2.47969D+00, 1.06043D+00,
     . 1.39913D+00, 1.64584D+00, 1.85192D+00, 2.01031D+00, 2.15231D+00,
     . 2.26861D+00, 2.37124D+00, 2.46305D+00/
C
      DATA ((COEF(I,J),I=1,4),J=1,10)/
     . 8.734D-01,-1.545D+00,-1.093D+00, 5.918D-01, 9.771D-01,-1.567D+00,
     .-4.739D-01,-1.302D-01, 1.174D+00,-1.638D+00,-2.831D-01,-3.281D-02,
     . 1.324D+00,-1.692D+00,-2.916D-01, 9.027D-02, 1.445D+00,-1.761D+00,
     .-1.902D-01, 4.401D-02, 1.546D+00,-1.817D+00,-1.278D-01, 2.293D-02,
     . 1.635D+00,-1.864D+00,-8.252D-02, 9.854D-03, 1.712D+00,-1.903D+00,
     .-5.206D-02, 2.892D-03, 1.782D+00,-1.936D+00,-2.952D-02,-1.405D-03,
     . 1.845D+00,-1.964D+00,-1.152D-02,-4.487D-03/
      DATA ((COEF(I,J),I=1,4),J=11,19)/
     . 7.377D-01,-9.327D-01,-1.466D+00, 6.891D-01, 9.031D-01,-1.157D+00,
     .-7.151D-01, 1.832D-01, 1.031D+00,-1.313D+00,-4.517D-01, 9.207D-02,
     . 1.135D+00,-1.441D+00,-2.724D-01, 3.105D-02, 1.225D+00,-1.536D+00,
     .-1.725D-01, 7.191D-03, 1.302D+00,-1.602D+00,-1.300D-01, 7.345D-03,
     . 1.372D+00,-1.664D+00,-8.204D-02,-1.643D-03, 1.434D+00,-1.715D+00,
     .-4.646D-02,-7.456D-03, 1.491D+00,-1.760D+00,-1.838D-02,-1.152D-02/
      DATA ((COEF(I,J),I=1,4),J=20,27)/
     . 1.258D+00,-3.442D+00,-4.731D-01,-9.522D-02, 1.553D+00,-2.781D+00,
     .-6.841D-01,-4.083D-03, 1.727D+00,-2.494D+00,-5.785D-01,-6.015D-02,
     . 1.853D+00,-2.347D+00,-4.611D-01,-9.615D-02, 1.955D+00,-2.273D+00,
     .-3.457D-01,-1.245D-01, 2.041D+00,-2.226D+00,-2.669D-01,-1.344D-01,
     . 2.115D+00,-2.200D+00,-1.999D-01,-1.410D-01, 2.182D+00,-2.188D+00,
     .-1.405D-01,-1.460D-01/
      DATA ((COEF(I,J),I=1,4),J=28,35)/
     . 1.267D+00,-3.417D+00,-5.038D-01,-1.797D-02, 1.565D+00,-2.781D+00,
     .-6.497D-01,-5.979D-03, 1.741D+00,-2.479D+00,-6.099D-01,-2.227D-02,
     . 1.870D+00,-2.336D+00,-4.899D-01,-6.616D-02, 1.973D+00,-2.253D+00,
     .-3.972D-01,-8.729D-02, 2.061D+00,-2.212D+00,-3.072D-01,-1.060D-01,
     . 2.137D+00,-2.189D+00,-2.352D-01,-1.171D-01, 2.205D+00,-2.186D+00,
     .-1.621D-01,-1.296D-01/
      DATA ((COEF(I,J),I=1,4),J=36,44)/
     . 1.129D+00,-3.149D+00,-1.910D-01,-5.244D-01, 1.431D+00,-2.511D+00,
     .-3.710D-01,-1.933D-01, 1.620D+00,-2.303D+00,-3.045D-01,-1.391D-01,
     . 1.763D+00,-2.235D+00,-1.829D-01,-1.491D-01, 1.879D+00,-2.215D+00,
     .-9.003D-02,-1.537D-01, 1.978D+00,-2.213D+00,-2.066D-02,-1.541D-01,
     . 2.064D+00,-2.220D+00, 3.258D-02,-1.527D-01, 2.140D+00,-2.225D+00,
     . 6.311D-02,-1.455D-01, 2.208D+00,-2.229D+00, 7.977D-02,-1.357D-01/
      DATA ((COEF(I,J),I=1,4),J=45,53)/
     . 1.204D+00,-2.809D+00,-3.094D-01, 1.100D-01, 1.455D+00,-2.254D+00,
     .-4.795D-01, 6.872D-02, 1.619D+00,-2.109D+00,-3.357D-01,-2.532D-02,
     . 1.747D+00,-2.065D+00,-2.317D-01,-5.224D-02, 1.853D+00,-2.058D+00,
     .-1.517D-01,-6.647D-02, 1.943D+00,-2.055D+00,-1.158D-01,-6.081D-02,
     . 2.023D+00,-2.070D+00,-6.470D-02,-6.800D-02, 2.095D+00,-2.088D+00,
     .-2.357D-02,-7.250D-02, 2.160D+00,-2.107D+00, 1.065D-02,-7.542D-02/
C
      IF(L.GT.2) GO TO 20
C
C          SELECT BEGINNING AND END OF COEFFICIENTS
C
      SS=(S+1)/2
      LL=L+1
      NSL0=N0(LL,SS)
      I=IST(LL,SS)+N-NSL0
C
C          EVALUATE CROSS SECTION
C
      FL=LOG10(FREQ/3.28805E15)
      X=FL-FL0(I)
      IF(X.GE.-0.001D0) THEN
         IF(X.LT.XFITM(I)) THEN
            P=COEF(4,I)
            DO 10 K=1,3
               P=X*P+COEF(4-K,I)
   10       CONTINUE
            HEPHOT=1.D-18*1.D1**P
          ELSE
C           OTHERWISE REMOVE INSTRUCTION AND 3 FOLLOWING "C"
C         ELSE IF(X.LT.XMAX(I)) THEN
            HEPHOT=1.D-18*1.D1**(A(I)+B(I)*X)
C         ELSE
C           HEPHOT=1.D-18*1.D1**(COEF(1,I)-2.0D0)
          END IF
       ELSE
          HEPHOT=0.
      END IF
      RETURN
C
C     Hydrogenic expression for L > 2
C      [multiplied by relative population of state (s,l,n), ie.
C       by  stat.weight(s,l)/stat.weight(n)]
C
   20 GN=2.D0*N*N
      HEPHOT=2.815D29/FREQ/FREQ/FREQ/N**5*(2*L+1)*S/GN
      RETURN
      END
C
C
C     ****************************************************************
C
C
 
      FUNCTION TOPBAS(FREQ,FREQ0,TYPLV)
C     ==================================
C
C     Procedure calculates the photo-ionisation cross section SIGMA in 
C     [cm^2] at frequency FREQ. FREQ0 is the threshold frequency from
C     level I of ion KI. Threshold cross-sections will be of the order
C     of the numerical value of 10^-18.
C     Opacity-Project (OP) interpolation fit formula
C
      INCLUDE 'PARAMS.FOR'
      PARAMETER    (E10=2.3025851)
      PARAMETER    (MMAXOP = 200,! maximum number of levels in OP data
     +              MOP    =  15 )! maximum number of fit points per level
      CHARACTER*10  IDLVOP(MMAXOP) ! level identifyer Opacity-Project data
      CHARACTER*10  TYPLV
      LOGICAL*2     LOPREA   
      COMMON /TOPB/ SOP(MOP,MMAXOP) ,! sigma = alog10(sigma/10^-18) of fit point
     +              XOP(MOP,MMAXOP) ,! x = alog10(nu/nu0) of fit point 
     +              NOP(MMAXOP)     ,! number of fit points for current level
     +              NTOTOP          ,! total number of levels in OP data
     +              IDLVOP         ,! level identifyer Opacity-Project data
     +              LOPREA   ! .T. OP data read in; .F. OP data not yer read in
      DIMENSION XFIT(MOP) ,! local array containing x     for OP data
     +          SFIT(MOP)  ! local array containing sigma for OP data
C
C     Read OP data if not yet done
C
      TOPBAS=0.
      IF (.NOT.LOPREA) CALL OPDATA
      X = LOG10(FREQ/FREQ0)
      DO IOP = 1,NTOTOP
         IF (IDLVOP(IOP).EQ.TYPLV) THEN
C           level has been detected in OP-data file
            IF (NOP(IOP).LE.0) GO TO 20
            DO IFIT = 1,NOP(IOP)
               XFIT(IFIT) = XOP(IFIT,IOP)
               SFIT(IFIT) = SOP(IFIT,IOP)
            END DO
            SIGM  = YLINTP (X,XFIT,SFIT,NOP(IOP),MOP)
            SIGM  = 1.D-18*EXP(E10*SIGM)
            TOPBAS=SIGM
            GO TO 10
         END IF
      END DO
   10 RETURN
C     Level is not found ,or no data for this level, in RBF.DAT
   20 WRITE (61,100) TYPLV    
  100 FORMAT ('SIGMA.......: OP DATA NOT AVAILABLE FOR LEVEL ',A10)
      RETURN
      END
C

C     ******************************************************************
C
C
      SUBROUTINE OPDATA
C     =================
C
C     Procedure reads photo-ionization cross sections fit coefficients
C     based on Opacity-Project (OP) data from file RBF.DAT
C     Data, as stored, requires linear interpolation.
C
C     Meaning of global variables:
C        NTOTOP    = total number of levels in Opacity Project data
C        IDLVOP() = level identifyer of current level
C        NOP()     = number of fit points for current level
C        XOP(,)    = x     = alog10(nu/nu0)       of fit point
C        SOP(,)    = sigma = alog10(sigma/10^-18) of fit point 
C      
      INCLUDE 'PARAMS.FOR'
      PARAMETER    (MMAXOP = 200,! maximum number of levels in OP data
     +              MOP    =  15 )! maximum number of fit points per level
      CHARACTER*10  IDLVOP(MMAXOP) ! level identifyer Opacity-Project data
      LOGICAL*2     LOPREA   
      COMMON /TOPB/ SOP(MOP,MMAXOP) ,! sigma = alog10(sigma/10^-18) of fit point
     +              XOP(MOP,MMAXOP) ,! x = alog10(nu/nu0) of fit point 
     +              NOP(MMAXOP)     ,! number of fit points for current level
     +              NTOTOP          ,! total number of levels in OP data
     +              IDLVOP         ,! level identifyer Opacity-Project data
     +              LOPREA   ! .T. OP data read in; .F. OP data not yer read in
      CHARACTER*4 IONID
C
      OPEN (UNIT=40,FILE='RBF.DAT',STATUS='OLD')
C     Skip header
      DO IREAD = 1, 21
         READ (40,*)
      END DO
      IOP = 0
C         = initialize sequential level index op Opacity Project data 
C     Read number of elements in file
      READ (40,*) NEOP
      DO IEOP = 1, NEOP
C        Skip element name header
         DO IREAD = 1, 3
            READ (40,*)
         END DO
C        Read number of ionization stages of current element in  file
         READ (40,*) NIOP
         DO IIOP = 1, NIOP
C           Read ion identifyer, atomic & electron number, # of levels 
C           for current ion
            READ (40,*) IONID, IATOM_OP, IELEC_OP, NLEVEL_OP
            DO ILOP = 1, NLEVEL_OP
C              Increase sequential level index of Opacity Project data
               IOP = IOP+1
C              Read level identifyer and number of sigma fit points
               READ (40,*) IDLVOP(IOP), NOP(IOP)
C              Read normalized log10 frequency and log10 cross section values
               DO IS = 1, NOP(IOP)
                  READ (40,*) INDEX, XOP(IS,IOP), SOP(IS,IOP)
               END DO
            END DO
         END DO
      END DO
      NTOTOP  = IOP
C             = total number of levels in Opacity Project data
      LOPREA  = .TRUE.
C             = set flag as data has been read in
C
      RETURN
      END
C
C
C
C     ******************************************************************
C
C
      FUNCTION YLINTP (XINT,X,Y,N,NTOT)
C     =================================
C
C     linear interpolation routine. Determines YINT = Y(XINT) from 
C     grid Y(X) with N points and dimension NTOT. 
C
      INCLUDE 'PARAMS.FOR'
      DIMENSION X(NTOT),Y(NTOT)
C
C     bisection (see Numerical Recipes par 3.4 page 90)
      JL = 0
      JU = N+1
10    IF (JU-JL.GT.1) THEN
         JM = (JU+JL)/2
         IF ((X(N).GT.X(1)).EQV.(XINT.GT.X(JM))) THEN
            JL = JM
         ELSE
            JU = JM
         END IF
         GO TO 10
      END IF
      J = JL
      IF (J.EQ.N) J = J-1
      IF (J.EQ.0) J = J+1
      RC         = (Y(J+1)-Y(J))/(X(J+1)-X(J))
      YLINTP = RC*(XINT-X(J))+Y(J)
C
      RETURN
      END
C
C
C     ****************************************************************
C
C

      SUBROUTINE OPAC(ID,CROSS,ABSO,EMIS,SCAT)
C     ========================================
C
C     Absorption, emission, and scattering coefficients
C     at depth ID and for several frequencies (some or all)
C
C     Input: ID    - depth index
C            CROSS - two dimensional array of photoionization
C                    cross-sections
C     Output: ABSO - array of absorption coefficient
C             EMIS - array of emission coefficient
C             SCAT - array of scattering coefficient (all scattering
C                    mechanisms except electron scattering)
C
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      DIMENSION CROSS(MCROSS,MFREQ)
      DIMENSION ABSO(MFREQ),EMIS(MFREQ),SCAT(MFREQ),
     *          ABLIN(MFREQ),EMLIN(MFREQ)
      COMMON/HYLPAR/IHYL,ILOWH,M10,M20
      COMMON/HE2PAR/IFHE2,IHE2L,ILWHE2,MHE10,MHE20
      COMMON/BLAPAR/RELOP,SPACE0,CUTOF0,TSTD,DSTD,ALAMC
      COMMON/CONTLH/SCL1(2),ICONTL
      common/dissol/fropc(mlevel),indexp(mlevel)
      PARAMETER (UN=1.,TEN15=1.E-15,CSB=2.0706E-16,CFF=3.68E8)
      data frh/3.28805d+15/
C
      IF(IMODE.EQ.-1.AND.ID.NE.IDSTD) RETURN
      T=TEMP(ID)
      ANE=ELEC(ID)
      T1=UN/T
      HKT=HK*T1
      TK=HKT/H
      SRT=UN/SQRT(T)
      SGFF=CFF*SRT
      CON=CSB*T1*SRT
      conts=1.e-36/con
      ABLY=0.
      EMLY=0.
      SCLY=0.
      IJ0=2
      IF(NFREQ.EQ.1) IJ0=1
      IF(IMODE.EQ.2) IJ0=NFREQ
      M=3
      IF(ICONTL.EQ.1) M=1
C
C     Opacity and emissivity in continuum
C     **** calculated only in the first and the last frequency *****
C
      DO 200 IJ=1,IJ0
         FR=FREQ(IJ)
         FR15=FR*TEN15
         BNU=BN*FR15*FR15*FR15
         HKF=HKT*FR
         ABF=0.
         EBF=0.
         AFF=0.
         DO 100 IL=1,NION
            N0I=NFIRST(IL)
            N1I=NLAST(IL)
            NKE=NNEXT(IL)
            XN=POPUL(NKE,ID)
C
C           Bound-free contribution + possibly
c            pseudo-continuum (accounting for dissolved fraction)
C
            DO 10 II=N0I,N1I
               IF(IBF(II).EQ.0) GO TO 10
               SG=0.
               IF(IFWOP(II).LT.0) THEN
                  SG=SGMERG(II,ID,FR,DSG)
                ELSE
                  SG=CROSS(II,IJ)
                  IF(INDEXP(II).EQ.5) THEN
                     IZZ=IZ(IEL(II))
                     FR0=ENION(II)/6.6256E-27
                     CALL DWNFR1(FR,FR0,ID,IZZ,DW1)
                     SG=SG*DW1
                  END IF
               END IF
               ABF=ABF+SG*POPUL(II,ID)
               XX=SG*XN*EXP(ENION(II)*TK)
               IF(XX.lt.conts) go to 10
               EBF=EBF+XX*CON*G(II)/G(NKE)
   10       CONTINUE
            IT=IFREE(IL)
            IF(IT.EQ.0) GO TO 100
C
C           Free-free contribution
C
            IE=IL
            IF(IE.EQ.IELHM) GO TO 65
            CH=IZ(IL)*IZ(IL)
            SF1=CH*XN*SGFF/(FR*FR*FR)
C
C           The following expression is the so-called modified free-free
C           opacity, ie. allowing for the photoionization from higher,
C           non-explicit, LTE energy levels of the ion IL
C
            HKFM=HKT*MIN(FF(IL),FR)
            SF2=EXP(HKFM)
            IF(IT.NE.2) GO TO 50
            SG=GFREE(T,FR/CH)
            SF2=SF2+SG-UN
   50       SFF=SF1*SF2
            GO TO 70
   65       SFF=SFFHMI(XN,FR,T)
   70       AFF=AFF+SFF
  100    CONTINUE
C
C        Additional opacities
C
         CALL OPADD(0,IJ,ID,FR,CROSS,ABAD,EMAD,SCAD)   
         IF(IOPHLI.NE.0) CALL LYMLIN(ID,FR,ABLY,EMLY,SCLY)
C
C        Total opacity and emissivity
C
         X=EXP(-HKF)
         X1=UN-X
         BNE=BNU*X*ANE
         ABSO(IJ)=ABF+ANE*(X1*AFF-X*EBF)+ANE*SIGE+ABAD+ABLY
         EMIS(IJ)=BNE*(AFF+EBF)+EMAD+EMLY
         IF(IJ.GT.2) GO TO 200
         SCAT(IJ)=SCAD+SCLY
         SCL1(IJ)=SCLY
         IF(IJ.GT.1) GO TO 200
         ABLY1=ABLY
         EMLY1=EMLY
  200 CONTINUE
      AVAB=(ABSO(1)+ABSO(2))*0.5*RELOP
      IF(NFREQ.LE.2.OR.IMODE.EQ.-1) RETURN
      IF(IMODE.EQ.2) GO TO 225
C
C    hydrogen lines
C     *** calculated only for the first and the last frequency
C         for IHYL = 0
C
      IF(IHYL.EQ.0) CALL HYDLIN(ID,1,2,ABLIN,EMLIN)
C
C     interpolated continuum and hydrogen line opacity and emissivity
C     for all frequencies
C
      DO 210 IJ=3,NFREQ
         ABSO(IJ)=FRX1(IJ)*ABSO(2)+FRX2(IJ)*ABSO(1)
  210    EMIS(IJ)=FRX1(IJ)*EMIS(2)+FRX2(IJ)*EMIS(1)
      IF(IHYL.NE.0) GO TO 217
      DO 215 IJ=M,NFREQ
         ABSO(IJ)=ABSO(IJ)+FRX1(IJ)*ABLIN(2)+FRX2(IJ)*ABLIN(1)
  215    EMIS(IJ)=EMIS(IJ)+FRX1(IJ)*EMLIN(2)+FRX2(IJ)*EMLIN(1)
  217 CONTINUE
C
C     **** Opacity and emissivity in lines ****
C
      CALL LINOP(ID,ABLIN,EMLIN,AVAB)
      DO 220 IJ=3,NFREQ
         ABSO(IJ)=ABSO(IJ)+ABLIN(IJ)
         EMIS(IJ)=EMIS(IJ)+EMLIN(IJ)
  220 CONTINUE
  225 CONTINUE
C
C     **** Detailed opacity and emissivity in hydrogen lines ****
C          (for IHYL=1)
C
      IF(IHYL.LT.0) GO TO 240
      IF(IHYL.EQ.0.AND.IMODE.LT.2) GO TO 240
      CALL HYDLIN(ID,M,NFREQ,ABLIN,EMLIN)
      DO 230 IJ=M,NFREQ
         ABSO(IJ)=ABSO(IJ)+ABLIN(IJ)
         EMIS(IJ)=EMIS(IJ)+EMLIN(IJ)
  230 CONTINUE
  240 CONTINUE
C
C     **** Detailed opacity and emissivity in HE II lines ****
C          (for IHE2L=1)
C
      IF(IHE2L.LE.0) GO TO 260
      CALL HE2LIN(ID,M,NFREQ,ABLIN,EMLIN)
      DO 250 IJ=M,NFREQ
         ABSO(IJ)=ABSO(IJ)+ABLIN(IJ)
         EMIS(IJ)=EMIS(IJ)+EMLIN(IJ)
  250 CONTINUE
  260 CONTINUE
C
C     opacity due to detailed photoinization cross-section
C     (from tables; including resonance features)
C     The two routines may be called and correspond to different formats
C     as well as difference in INPUT!
C
      CALL PHTION(ID,ABSO,EMIS)
      CALL PHTX(ID,ABSO,EMIS)
C
      IF(ICONTL.EQ.1) RETURN
      ABSO(1)=ABSO(1)-ABLY1
      EMIS(1)=EMIS(1)-EMLY1
      ABSO(2)=ABSO(2)-ABLY
      EMIS(2)=EMIS(2)-EMLY
      RETURN
      END
C
C
C ********************************************************************
C
C
      FUNCTION SGMERG(II,ID,FR,DSG)
C     =============================
C     formal routine - taken from TLUSTY, but not used here
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      PARAMETER (FRH=3.28805E15, PH2=2.815D29*2., EHB=157802.77355)
C
      sgmerg=0.
      if(id.gt.0) return
      IE=IEL(II)
      CH=IZ(IE)*IZ(IE)
      T1=1./TEMP(ID)
      EX=EHB*CH*T1
      II0=NQUANT(II-1)+1
      SUM=0.
      SUD=0.
      DO 10 I=II0,NLMX
         X=I
         XI=1./(X*X)
         FREDG=FRH*CH*XI
         IF(FR.LT.FREDG) GO TO 10
         EXI=EXP(EX*XI)
c         S=EXI*WNHINT(I,ID)*XI/X
c         SUM=SUM+S
c         SUD=SUD+S*XI
   10 CONTINUE
      SG0=PH2/(FR*FR*FR*G(II))*CH*CH
      SGMERG=SUM*SG0
      DSG=-SUD*SG0*EX*T1
      RETURN
      END
C
C
C     ****************************************************************
C
      FUNCTION GFREE(T,FR)
C     ====================
C
C     Hydrogenic free-free Gaunt factor, for temperature T and
C     frequency FR
C
      INCLUDE 'PARAMS.FOR'
      THET=5040.4/T
      IF(THET.LT.4.E-2) THET=4.E-2
      X=FR/2.99793E14
      IF(X.GT.1) GO TO 10
      IF(X.LT.0.2) X=0.2
      GFREE=(1.0823+2.98E-2/THET)+(6.7E-3+1.12E-2/THET)/X
      RETURN
   10 C1=(3.9999187E-3-7.8622889E-5/THET)/THET+1.070192
      C2=(6.4628601E-2-6.1953813E-4/THET)/THET+2.6061249E-1
      C3=(1.3983474E-5/THET+3.7542343E-2)/THET+5.7917786E-1
      C4=3.4169006E-1+1.1852264E-2/THET
      GFREE=((C4/X-C3)/X+C2)/X+C1
      RETURN
      END
C
C ********************************************************************
C ********************************************************************
C
      FUNCTION SFFHMI(POPI,FR,T)
C     ==========================
C
C     Free-free cross section for H- (After Kurucz,1970,SAO 309, P.80)
C
      INCLUDE 'PARAMS.FOR'
      SFFHMI=(1.3727E-25+(4.3748E-10-2.5993E-7/T)/FR)*POPI/FR
      RETURN
      END
C
C 
C ********************************************************************
C
C
      SUBROUTINE LYMLIN(ID,FREQ,ABLY,EMLY,SCLY)
C     =========================================
C
C     OPACITY OF THE LYMAN LINES WINGS (ALPHA - DELTA)
C     WITH APPROXIMATE PARTIAL REDISTRIBUTION
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      DIMENSION SN(4),SR(4),SS(4),GS(4),FRLY(4),BNLY(4),GA(4)
      DATA FRLY / 2.4660375E15, 2.9227111E15, 3.0825469E15, 3.156528E15/
     *    ,BNLY / 5.527E-2,     4.090E-2,     2.699E-2,     1.855E-2  /,
     *     SN   / 1.308E5,      5.280E3,      5.847E2,      1.078E2   /,
     *     SR   / 1.218E-16,    9.196E-17,    1.058E-16,    1.296E-16 /,
     *     SS   / 9.478E-3,     1.600E-2,     1.441E-2,     1.547E-2  /,
     *     GS   / 7.237E-8,     5.432E-6,     5.821E-5,     4.027E-4  /,
     *     GA   / 1.000,        1.791,        2.362,        2.801 /
C
      data icomp/0/
      if(iath.le.0) return
      if(icomp.eq.0) then
         icomp=1
         read(4,*,err=10,end=10) ifstrk,ifnat,ifres,ifprd,ifsti
         go to 11
   10    continue
         ifstrk=0
         ifnat=1
         ifres=1
         ifprd=0
         ifsti=0
         if(iophli.lt.0) then
            ifstrk=1
            ifprd=1
         end if
   11    continue
      end if
c
      ABLY=0.
      EMLY=0.
      SCLY=0.
      P=POPUL(N0HN,ID)
      T=TEMP(ID)
      ANE=ELEC(ID)
      DO 40 I=1,4
         DFR=ABS(FRLY(I)-FREQ)
         IF(DFR.LE.5.E11) DFR=1.E12
         DFR2=DFR*DFR
         DFRS=SQRT(DFR)
         COR=(2.*FREQ/(FREQ+FRLY(I)))**2
         F=1.
         IF(iabs(IOPHLI).EQ.2) F=FEAUTR(FREQ,T,ID)
         STARK=SS(I)*ANE*F/DFR2/DFRS
         if(ifstrk.eq.0) stark=0.
         if(ifnat.eq.0) sn(i)=0.
         if(ifres.eq.0) sr(i)=0.
         SGLY=SN(I)*(1.+SR(I)*P)*COR/DFR2+STARK
         sgly=sgly*wnhint(i+1,id)
         GAMA=1./(GA(I)+GS(I)*ANE*F/DFRS)
         if(ifprd.eq.0) gama=0.
         ABLY=ABLY+P*SGLY
         EMLY=EMLY+POPUL(N0HN+I,ID)*SGLY*BNLY(I)*(1.-GAMA)
         if(ifsti.ne.0) ably=ably-popul(n0hn+i,id)*sgly/(i+1)/(i+1)
         SCLY=SCLY+P*SGLY*GAMA
   40 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
      FUNCTION FEAUTR(FREQ,T,ID)
C     ==========================
C
C     LYMAN-ALPHA STARK BROADENING AFTER N.FEAUTRIER
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      DIMENSION DL(20),F05(20),F10(20),F20(20),F40(20),X(4)
      DATA F05 / 0.0537, 0.0964, 0.1330, 0.3105, 0.4585, 0.6772, 0.8229,
     *           0.8556, 0.9250, 0.9618, 0.9733, 1.1076, 1.0644, 1.0525,
     *           0.8841, 0.8282, 0.7541, 0.7091, 0.7164, 0.7672/
      DATA F10 / 0.1986, 0.2764, 0.3959, 0.5740, 0.7385, 0.9448, 1.0292,
     *           1.0317, 0.9947, 0.8679, 0.8648, 0.9815, 1.0660, 1.0793,
     *           1.0699, 1.0357, 0.9245, 0.8603, 0.8195, 0.7928/
      DATA F20 / 0.4843, 0.5821, 0.7003, 0.8411, 0.9405, 1.0300, 1.0029,
     *           0.9753, 0.8478, 0.6851, 0.6861, 0.8554, 0.9916, 1.0264,
     *           1.0592, 1.0817, 1.0575, 1.0152, 0.9761, 0.9451/
      DATA F40 / 0.7862, 0.8566, 0.9290, 0.9915, 1.0066, 0.9878, 0.8983,
     *           0.8513, 0.6881, 0.5277, 0.5302, 0.6920, 0.8607, 0.9111,
     *           0.9651, 1.0793, 1.1108, 1.1156, 1.1003, 1.0839/
      DATA DL / -150., -120., -90., -60., -40., -20., -10., -8., -4.,
     *          -2., 2., 4., 8., 10., 20., 40., 60., 90., 120., 150./
      DLAM=2.997925E18/FREQ-1215.685
      DO 10 I=2,20
         IF(DLAM.LE.DL(I)) GO TO 20
   10 CONTINUE
      I=20
   20 J=I-1
      C=DL(J)-DL(I)
      A=(DLAM-DL(I))/C
      B=(DL(J)-DLAM)/C
      X(1)=F05(J)*A+F05(I)*B
      X(2)=F10(J)*A+F10(I)*B
      X(3)=F20(J)*A+F20(I)*B
      X(4)=F40(J)*A+F40(I)*B
      J=JT(ID)
      Y=TI0(ID)*X(J)+TI1(ID)*X(J-1)+TI2(ID)*X(J-2)
      FEAUTR=0.5*(Y+1.)
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE HYLSET
C     =================
C
C     Initialization procedure for treating the hydrogen line opacity
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'SYNTHP.FOR'
      DIMENSION ALB(15)
      COMMON/HYLPAR/IHYL,ILOWH,M10,M20
      COMMON/HHEPRF/IHYDPR,IHE1PR,IHE2PR
      DATA ALB /656.28,486.13,434.05,410.17,397.01,
     *          388.91,383.54,379.79,377.06,375.02,
     *          373.44,372.19,371.20,370.39,369.72/
C
C     IHYL=-1  -  hydrogen lines are excluded a priori
C
      IHYL=-1
      if(iath.le.0) return
      IF(FREQ(2).GE.3.28805E15) RETURN
      AL0=2.997925E17/FREQ(1)
      AL1=2.997925E17/FREQ(2)
      IF(grav.lt.6.) then
         IF(AL0.GT.160..AND.AL1.LT.364.6) RETURN
         IF(AL0.GT.506..AND.AL1.LT.630.) RETURN
         IF(AL0.GT.680..AND.AL1.LT.820.3) RETURN
C         IF(AL0.GT.1500.) RETURN
       else
         IF(AL0.GT.200..AND.AL1.LT.364.6) RETURN
         IF(AL0.GT.540..AND.AL1.LT.600.) RETURN
         IF(AL0.GT.720..AND.AL1.LT.820.3) RETURN
C         IF(AL0.GT.1500.) RETURN
      end if
C
C     otherwise, hydrogen lines are included
C
      IHYL=0
      M20=40
      IF(AL1.LT.364.) THEN
         ILOWH=1
         FRION=3.28805E15
         M10=SQRT(3.28805E15/(FRION-FREQ(2)))
         IF(FRION.GT.FREQ(1)) M20=SQRT(3.28805E15/(FRION-FREQ(1)))
         IHYL=1
         IF(AL0.GT.123.) IHYL=0
         IF(AL0.GT.104..AND.AL1.LT.120.) IHYL=0
         IF(AL0.GT.98.5.AND.AL1.LT.102.) IHYL=0
         IF(IMODE.EQ.2.OR.IHYDPR.GT.0.OR.GRAV.GE.6.) IHYL=1
       ELSE IF(AL1.LT.820.) THEN
         ILOWH=2
         FRION=8.2225E14
         M10=SQRT(3.289017E15/(FRION-FREQ(2)))
         IF(FRION.GT.FREQ(1)) M20=SQRT(3.289017E15/(FRION-FREQ(1))) 
         DO 10 I=1,15
            AL=ALB(I)
            IF(AL.LT.AL0-1..OR.AL.GT.AL1+1.) GO TO 10
            IHYL=1
            GO TO 20
   10    CONTINUE
   20    CONTINUE
         IF(IMODE.EQ.2.OR.IHYDPR.GT.0.OR.GRAV.GE.6.) IHYL=1
       ELSE IF(AL1.LT.1458.) THEN
         ILOWH=3
         FRION=3.6544142E14
         M10=SQRT(3.289017E15/(FRION-FREQ(2)))
         IF(FRION.GT.FREQ(1)) M20=SQRT(3.289017E15/(FRION-FREQ(1))) 
         IHYL=1
         IF(AL0.GT.1310.) IHYL=0
         IF(AL0.GT.1124..AND.AL1.LT.1250.) IHYL=0
         IF(AL0.GT.1035..AND.AL1.LT.1060.) IHYL=0
         IF(IMODE.EQ.2.OR.GRAV.GE.6.) IHYL=1
       ELSE IF(AL1.LT.2278.) THEN
         ILOWH=4
         FRION=2.0555837E14
         M10=SQRT(3.289017E15/(FRION-FREQ(2)))
         IHYL=1
       ELSE IF(AL1.LT.3281.) THEN
         ILOWH=5
         FRION=1.315589E14
         M10=SQRT(3.289017E15/(FRION-FREQ(2)))
         IHYL=1
       ELSE IF(AL1.LT.4466.) THEN
         ILOWH=6
         FRION=9.136394E13
         M10=SQRT(3.289017E15/(FRION-FREQ(2)))
         IHYL=1
       ELSE 
         ILOWH=7
         FRION=6.7120228E13
         M10=SQRT(3.289017E15/(FRION-FREQ(2)))
         IHYL=1
      END IF
c     WRITE(6,601) ILOWH,M20+1
c 601 FORMAT(1H0/ ' *** HYDROGEN LINES CONTRIBUTE'/
c    * '     THE NEAREST LINE ON THE SHORT-WAVELENGTH SIDE IS',
c    * I3,'  TO ',I3/)
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE HYDLIN(ID,I0,I1,ABSOH,EMISH)
C     =======================================
C
C     opacity and emissivity of hydrogen lines  
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      PARAMETER (FRH1=3.28805E15,FRH2=FRH1/4.,UN=1.,SIXTH=1./6.)
      PARAMETER (CPP=4.1412E-16,CPJ=157803.) 
      PARAMETER (C00=1.25E-9,CDOP=1.284523E12,CID=0.02654,TWO=2.)
      PARAMETER (CPJ4=CPJ/4.,AL10=2.3025851,CINV=UN/2.997925E18)
      PARAMETER (CID1=0.01497)
      logical lquasi
      DIMENSION PJ(40),PRF0(36),WLINE(12),OSCH(12),
     *          ABSO(MFREQ),EMIS(MFREQ),ABSOH(MFREQ),EMISH(MFREQ)
      COMMON/HHEPRF/IHYDPR,IHE1PR,IHE2PR
      COMMON/HYLPAR/IHYL,ILOWH,M10,M20
      COMMON/AUXHYD/XK,FXK,BETAD,DBETA
      COMMON/HYDPRF/PRFHYD(12,MDEPTH,36),WLHYD(12,36),NWLHYD(12)
      DATA WLINE  /1215.67, 1025.72, 972.537, 949.743,
     *             6562.80, 4861.32, 4340.46, 4101.73,
     *             3970.07, 3889.05, 3835.38, 3797.90/
      DATA OSCH   /0.4162,  0.0791,   0.02899,  0.01394,
     *             0.6407,  0.1193,   0.04467,  0.02209,
     *             1.27D-2, 8.036D-3, 5.429D-3, 3.851D-3/
      DATA FRH    /3.289017E15/
C
      if(iath.le.0) return
      izz=1
      DO 1 IJ=I0,I1
         ABSO(IJ)=0.
         EMIS(IJ)=0.
         ABSOH(IJ)=0.
         EMISH(IJ)=0.
    1 CONTINUE
       T=TEMP(ID)
       T1=UN/T
       SQT=SQRT(T)
       ANE=ELEC(ID)
       ANES=EXP(SIXTH*LOG(ANE))
C
C     populations of the first 40 levels of hydrogen
C
      ANP=POPUL(NKH,ID)
      PP=CPP*ANE*ANP*T1/SQT
      NLH=N1H-N0HN+1
      if(ifwop(n1h).lt.0) nlh=nlh-1
      DO 5 IL=1,40
         X=IL*IL
         IF(IL.LE.NLH) PJ(IL)=POPUL(N0HN+IL-1,ID)/X
         IF(IL.GT.NLH) PJ(IL)=PP*EXP(CPJ/X*T1)*wnhint(il,id)
    5 CONTINUE
      p2=pp*exp(cpj4*t1)
C
C     Frequency- and line-independent parameters for evaluating the
C     asymptotic Stark profile
C
      F00=C00*ANES*ANES*ANES*ANES
      DOP0=1.E8*SQRT(1.65E8*T+VTURB(ID))
C
C -------------------------------------------------------------------
C     overall loop over spectral series (only in the infrared region)
C -------------------------------------------------------------------
C
      ISERL=ILOWH
      ISERU=ILOWH
      IF(WLAM(I0).GT.17000..AND.WLAM(I1).LT.21000.) THEN
         ISERL=3
         ISERU=4
       ELSE IF(WLAM(I0).GT.22700.) THEN
         ISERL=4
         ISERU=5
         IF(WLAM(I0).GT.32800.) ISERU=6
         IF(WLAM(I0).GT.44660.) ISERU=7
      END IF
C
      DO 200 I=ISERL,ISERU
      II=I*I
      XII=UN/II
      PLTEI=PP*EXP(CPJ*T1*XII)*II
      POPI=PJ(I)*II
      IF(I.EQ.1) FRH=3.28805E15
C
C     determination of which hydrogen lines contribute in a current 
C     frequency region
C
      M1=M10
      IF(I.LT.ILOWH) M1=ILOWH-1
      M2=M1+1
      IF(M1.LT.I+1) M1=I+1
      IF(grav.lt.3..and.M1.LE.6.AND.I.EQ.2) GO TO 10
      IF(grav.lt.3..and.M1.LE.4.AND.I.EQ.1) GO TO 10
      M1=M1-1
      M2=M20+3
      IF(M1.LT.I+1) M1=I+1
   10 CONTINUE
      if(grav.gt.3.) then
         m2=m2+5
         m1=m1-3
         if(m1.gt.i+6) m1=m1-3 
      end if
      if(grav.gt.6.) then
         m2=m2+2
         m1=m1-1
         if(m1.gt.i+6) m1=m1-1 
      end if
      IF(M1.LT.I+1) M1=I+1
      IF(M2.GT.40) M2=40
      if(id.eq.1) write(6,666) i,m1,m2
  666 format(/' hydrogen lines contribute - ilow=',i2,', iup from ',i3,
     *       ' to',i3/)
C
      A=0.
      E=0.
      DO 15 IJ=I0,I1
         ABSO(IJ)=0.
         EMIS(IJ)=0.
   15 CONTINUE
C
C     loop over lines which contribute at given wavelength region
C
      DO 100 J=M1,M2
         IF(I.EQ.1.AND.J.LE.5.AND.IOPHLI.LT.0) GO TO 100
         IF(IHYDPR.GT.0.AND.
     *     (I.EQ.1.AND.J.LE.5.OR.I.EQ.2.AND.J.LE.10)) THEN
	    IF(I.EQ.1) THEN
               ILINE=J-1
             ELSE
               ILINE=J+2
            END IF
	    NWL=NWLHYD(ILINE)
            DO 20 IWL=1,NWL
   20          PRF0(IWL)=PRFHYD(ILINE,ID,IWL)
            FID=CID*OSCH(ILINE)
            DO 50 IJ=I0,I1
               AL=ABS(WLAM(IJ)-WLINE(ILINE))
               IF(AL.LT.1.E-4) AL=1.E-4
               AL=LOG10(AL)
               DO 30 IWL=1,NWL-1
                  IW0=IWL
                  IF(AL.LE.WLHYD(ILINE,IWL+1)) GO TO 40
   30          CONTINUE
   40          IW1=IW0+1
               PRF=(PRF0(IW0)*(WLHYD(ILINE,IW1)-AL)+PRF0(IW1)*
     *             (AL-WLHYD(ILINE,IW0)))/
     *             (WLHYD(ILINE,IW1)-WLHYD(ILINE,IW0))
               SG=EXP(PRF*AL10)*FID
               ABSO(IJ)=ABSO(IJ)+SG*wnhint(j,id)
               EMIS(IJ)=EMIS(IJ)+SG*PJ(J)
   50       CONTINUE
          ELSE
            CALL STARK0(I,J,izz,XKIJ,WL0,FIJ,FIJ0)
            FXK=F00*XKIJ
            FXK1=UN/FXK
            DOP=DOP0/WL0
            DBETA=WL0*WL0*CINV*FXK1
            BETAD=DOP*DBETA
            FID=CID*FIJ*DBETA
            FID0=CID1*FIJ0/DOP
            CALL DIVSTR(BETAD,AD,DIV)
            lquasi=i.eq.1.and.j.eq.2.and.iophli.ge.3
            DO 60 IJ=I0,I1
               fr=freq(ij)
               BETA=ABS(WLAM(IJ)-WL0)*FXK1
               if(lquasi.and.wlam(ij).gt.1220.) then
                  call allard(wlam(ij),popi,anp,prq)
                  sg=prq*5.44518e-23
                  sg=sg+STARKA(BETA,BETAD,AD,DIV,UN)*FID
                  abso(ij)=abso(ij)+sg
                  emis(ij)=emis(ij)+sg*p2
               else
c              if(beta.gt.5.e4) go to 60
               SG=STARKA(BETA,BETAD,AD,DIV,TWO)*FID
               if(iophli.eq.2.and.i.eq.1.and.j.eq.2) 
     *            sg=sg*feautr(fr,t,id)
               if(fid0.gt.0.) then
                  xd=beta/betad
c                 if(xd.lt.5.) sg=sg+exp(-xd*xd)*fid0
               end if
               ABSO(IJ)=ABSO(IJ)+SG*wnhint(j,id)
               EMIS(IJ)=EMIS(IJ)+SG*PJ(J)
               end if
   60       CONTINUE
         END IF
  100 CONTINUE
C
C     resulting absorption and emission coefficients
C
      DO 110 IJ=I0,I1
         EMIS(IJ)=EMIS(IJ)*II
         ABSO(IJ)=ABSO(IJ)*POPI-EMIS(IJ)
  110 CONTINUE
C
C     add contributions for different spectral series
C
      DO 160 IJ=I0,I1
         ABSOH(IJ)=ABSOH(IJ)+ABSO(IJ)
         EMISH(IJ)=EMISH(IJ)+EMIS(IJ)
  160 CONTINUE
  200 CONTINUE
C
C     finally, multiply EMISH by 2h nu^3/c^2
C
      DO 210 IJ=I0,I1
         F=FREQ(IJ)
         F15=F*1.E-15
         EMISH(IJ)=1.4743E-2*F15*F15*F15*EMISH(IJ)
  210 CONTINUE
      RETURN
      END
C
C
C ********************************************************************
C
C
      SUBROUTINE HE2SET
C     =================
C
C     Initialization procedure for treating the He II line opacity
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'SYNTHP.FOR'
      COMMON/HE2PAR/IFHE2,IHE2L,ILWHE2,MHE10,MHE20
      COMMON/HHEPRF/IHYDPR,IHE1PR,IHE2PR
      dimension frhe(12)
      DATA FRHE /1.3158153D+16, 3.2895381D+15, 1.4624854D+15,
     *           8.2261878D+14, 5.2647201D+14, 3.6560459D+14,
     *           2.6860713D+14, 2.0565220D+14, 1.6249055D+14,
     *           1.3161730D+14, 1.0877460D+14, 9.1400851D+13/
C
C     IHE2L=-1  -  He II lines are excluded a priori
C
      IHE2L=-1
      IF(IFHE2.LE.0) RETURN
      IF(FREQ(2).GE.1.315812E16) RETURN
      AL0=2.997925E17/FREQ(1)
      AL1=2.997925E17/FREQ(2)
c      IF(AL0.GT.390.) RETURN
      if(grav.lt.6.) then
         IF(AL0.GT.31..AND.AL1.LT.91.1) RETURN
         IF(AL0.GT.26.1.AND.AL1.LT.29.8) RETURN
         IF(AL0.GT.24.8.AND.AL1.LT.25.1) RETURN
         IF(AL0.GT.122.1.AND.AL1.LT.162.9) RETURN
         IF(AL0.GT.165.1.AND.AL1.LT.204.9) RETURN
         IF(AL0.GT.109..AND.AL1.LT.120.9) RETURN
         IF(AL0.GT.103..AND.AL1.LT.107.9) RETURN
         IF(AL0.GT.99.7.AND.AL1.LT.102.) RETURN
         IF(AL0.GT.320.8.AND.AL1.LT.364.4) RETURN
         IF(AL0.GT.273.8.AND.AL1.LT.319.8) RETURN
         IF(AL0.GT.251.6.AND.AL1.LT.272.8) RETURN
         IF(AL0.GT.239.0.AND.AL1.LT.250.6) RETURN
         IF(AL0.GT.231.1.AND.AL1.LT.238.0) RETURN
         IF(AL0.GT.225.8.AND.AL1.LT.230.1) RETURN
       else
         IF(AL0.GT.33..AND.AL1.LT.91.1) RETURN
         IF(AL0.GT.124.1.AND.AL1.LT.160.9) RETURN
         IF(AL0.GT.167.1.AND.AL1.LT.202.9) RETURN
         IF(AL0.GT.111..AND.AL1.LT.118.9) RETURN
         IF(AL0.GT.322.8.AND.AL1.LT.364.4) RETURN
         IF(AL0.GT.275.8.AND.AL1.LT.317.8) RETURN
         IF(AL0.GT.253.6.AND.AL1.LT.270.8) RETURN
         IF(AL0.GT.241.0.AND.AL1.LT.248.6) RETURN
         IF(AL0.GT.233.1.AND.AL1.LT.236.0) RETURN
      end if
C
C     otherwise, He II lines are included
C
      IHE2L=1
      MHE10=60
      MHE20=60
      IF(AL1.LT.91.) THEN
         ILWHE2=1
       ELSE IF(AL0.LT.204.) THEN
         ILWHE2=2
       ELSE IF(AL0.LT.364.) THEN
         ILWHE2=3
       ELSE IF(AL0.LT.569.) THEN
         ILWHE2=4
       ELSE IF(AL0.LT.819.) THEN
         ILWHE2=5
       ELSE IF(AL0.LT.1116.) THEN
         ILWHE2=6
       ELSE IF(AL0.LT.1457.) THEN
         ILWHE2=7
       ELSE IF(AL0.LT.1844.) THEN
         ILWHE2=8
       ELSE IF(AL0.LT.2277.) THEN
         ILWHE2=9
       ELSE IF(AL0.LT.2756.) THEN
         ILWHE2=10
       ELSE IF(AL0.LT.3279.) THEN
         ILWHE2=11
       ELSE
         ILWHE2=12
      END IF
      FRION=FRHE(ILWHE2)
      FR1=FRION*ILWHE2*ILWHE2
      IF(FRION.GT.FREQ(2)) MHE10=SQRT(FR1/(FRION-FREQ(2)))
      IF(FRION.GT.FREQ(1)) MHE20=SQRT(FR1/(FRION-FREQ(1))) 
      WRITE(6,601) ILWHE2,MHE20+1
  601 FORMAT(1H0/ ' *** HE II LINES CONTRIBUTE'/
     * '     THE NEAREST LINE ON THE SHORT-WAVELENGTH SIDE IS',
     * I3,'  TO ',I3/)
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE HE2LIN(ID,I0,I1,ABSOH,EMISH)
C
C     opacity and emissivity of He II lines  (these which are not considered
C     explicitly)
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      PARAMETER (UN=1.,SIXTH=1./6.)
      PARAMETER (CPP=4.1412E-16,CPJ=631479.) 
      PARAMETER (C00=1.25E-9,CDOP=1.284523E12,CID=0.02654,TWO=2.)
      PARAMETER (CPJ4=CPJ/4.,AL10=2.3025851,CINV=UN/2.997925E18)
      PARAMETER (CID1=0.01497)
      DIMENSION PJ(80),SGF(12),FRHE(12),OSCHE2(19),PRF0(36),
     *          ABSO(MFREQ),EMIS(MFREQ),ABSOH(MFREQ),EMISH(MFREQ)
      COMMON/HHEPRF/IHYDPR,IHE1PR,IHE2PR
      COMMON/HE2PAR/IFHE2,IHE2L,ILWHE2,MHE10,MHE20
      COMMON/HE2PRF/PRFHE2(19,MDEPTH,36),WLHE2(19,36),NWLHE2(19),
     *              ILHE2(19),IUHE2(19)
      DATA FRHE /1.3158153D+16, 3.2895381D+15, 1.4624854D+15,
     *           8.2261878D+14, 5.2647201D+14, 3.6560459D+14,
     *           2.6860713D+14, 2.0565220D+14, 1.6249055D+14,
     *           1.3161730D+14, 1.0877460D+14, 9.1400851D+13/
      DATA SGF  /1.578e-18, 3.468e-18, 5.392e-18, 7.322e-18,
     *           9.262e-18, 1.121e-17, 1.316e-17, 1.511e-17, 
     *           1.708e-17, 1.904e-17, 2.178e-17, 2.376e-17/
      DATA OSCHE2/6.407E-1, 1.506E-1, 5.584E-2, 2.768E-2,
     *        1.604E-2, 1.023E-2, 6.980E-3,
     *        8.421E-1, 3.230E-2, 1.870E-2, 1.196E-2, 8.187E-3,
     *        5.886E-3, 4.393E-3, 3.375E-3, 2.656E-3,
     *        1.038,    1.793E-1, 6.549E-2/
C
      I=ILWHE2
      izz=2
      DO 1 IJ=I0,I1
         ABSO(IJ)=0.
         EMIS(IJ)=0.
         ABSOH(IJ)=0.
         EMISH(IJ)=0.
    1 CONTINUE
      T=TEMP(ID)
      T1=UN/T
      SQT=SQRT(T)
      ANE=ELEC(ID)
      ANES=EXP(SIXTH*LOG(ANE))
C
C     He III population (either LTE or NLTE, depending on input model)
C
      IF(IELHE2.GT.0) THEN
         ANP=POPUL(NNEXT(IELHE2),ID)
         NLHE2=NLAST(IELHE2)-NFIRST(IELHE2)+1
       ELSE
         ANP=RRR(ID,3,2)
         NLHE2=0
      END IF
C
C     populations of the first 60 levels of He II
C
      PP=CPP*ANE*ANP*T1/SQT
      DO 5 IL=1,60
         X=IL*IL
         IIL=NFIRST(IELHE2)+IL-1
         IF(IL.LE.NLHE2) PJ(IL)=POPUL(IIL,ID)/X
         IF(IL.GT.NLHE2) PJ(IL)=PP*EXP(CPJ/X*T1)*wnhe2(il,id)
    5 CONTINUE
C
C     Frequency- and line-independent parameters for evaluating the
C     asymptotic Stark profile
C
      F00=3.906e-11*ANES*ANES*ANES*ANES
      DOP0=1.E8*SQRT(4.12E7*T+VTURB(ID))
C
C -------------------------------------------------------------------
C     overall loop over spectral series (only in the infrared region)
C -------------------------------------------------------------------
C
      ISERU=ILWHE2
      IF(ILWHE2.LE.3) THEN
         ISERL=ILWHE2
       ELSE IF(ILWHE2.LE.5) THEN
         ISERL=ILWHE2-1
       ELSE IF(ILWHE2.LE.7) THEN
         ISERL=ILWHE2-2
       ELSE IF(ILWHE2.LE.9) THEN
         ISERL=ILWHE2-3
       ELSE
         ISERL=ILWHE2-4
      END IF
C
      DO 200 I=ISERL,ISERU
      II=I*I
      XII=UN/II
      PLTEI=PP*EXP(CPJ*T1*XII)*II
      POPI=PJ(I)*II
C
C     determination of which He II lines contribute in a current 
C     frequency region
C
      M1=MHE10
      IF(I.LT.ILWHE2.AND.FRHE(I).GT.FREQ(2)) THEN
         M1=SQRT(FRHE(I)*II/(FRHE(I)-FREQ(2)))
      END IF
      M2=M1+1
      IF(M1.LT.I+1) M1=I+1
      IF(grav.lt.6..and.M1.LE.6.AND.I.EQ.2) GO TO 10
      IF(grav.lt.6..and.M1.LE.4.AND.I.EQ.1) GO TO 10
      M1=M1-1
      M2=MHE20+3
      IF(M2.GT.60) M2=60
   10 CONTINUE
      if(grav.gt.6.) then
         m2=m2+5
         m1=m1-3
         if(m1.gt.i+6) m1=m1-3 
      end if
      IF(M1.LT.I+1) M1=I+1
      IF(M2.GT.60) M2=60
      A=0.
      E=0.
      DO 15 IJ=I0,I1
         ABSO(IJ)=0.
         EMIS(IJ)=0.
   15 CONTINUE
C
C     loop over lines which contribute at given wavelength region
C
      DO 100 J=M1,M2
         JJ=J*J
         IF(I.LE.2) THEN
            WLINE=227.838/(XII-1./JJ)
          ELSE 
            WLINE=227.7776/(XII-1./JJ)
         END IF
         ILINE=0   
         IF(I.EQ.2) THEN
            IF(J.EQ.3.AND.IHE2PR.GT.0) ILINE=1
          ELSE IF(I.EQ.3) THEN
            IF(J.EQ.4.AND.IHE2PR.GT.0) ILINE=8
            IF(J.GT.5.AND.J.LE.10.AND.IHE2PR.GT.0) ILINE=J-3
          ELSE IF(I.EQ.4) THEN
            IF(J.LE.7.AND.IHE2PR.GT.0) ILINE=J+12
            IF(J.GE.8.AND.J.LE.15.AND.IHE2PR.GT.0) ILINE=J+1
         END IF
         IF(ILINE.GT.0) THEN
	    NWL=NWLHE2(ILINE)
            DO 20 IWL=1,NWL
   20          PRF0(IWL)=PRFHE2(ILINE,ID,IWL)
            FID=CID*OSCHE2(ILINE)
            DO 50 IJ=I0,I1
               AL=ABS(WLAM(IJ)-WLINE)
               IF(AL.LT.1.E-4) AL=1.E-4
               AL=LOG10(AL)
               DO 30 IWL=1,NWL-1
                  IW0=IWL
                  IF(AL.LE.WLHE2(ILINE,IWL+1)) GO TO 40
   30          CONTINUE
   40          IW1=IW0+1
               PRF=(PRF0(IW0)*(WLHE2(ILINE,IW1)-AL)+PRF0(IW1)*
     *             (AL-WLHE2(ILINE,IW0)))/
     *             (WLHE2(ILINE,IW1)-WLHE2(ILINE,IW0))
               SG=EXP(PRF*AL10)*FID
               ABSO(IJ)=ABSO(IJ)+SG*wnhe2(j,id)
               EMIS(IJ)=EMIS(IJ)+SG*PJ(J)
   50       CONTINUE
          ELSE
            CALL STARK0(I,J,izz,XKIJ,WL0,FIJ,FIJ0)
            FXK=F00*XKIJ
            FXK1=UN/FXK
            DOP=DOP0/WL0
            DBETA=WL0*WL0*CINV*FXK1
            BETAD=DOP*DBETA
            FID=CID*FIJ*DBETA
            FID0=CID1*FIJ0/DOP
            CALL DIVHE2(BETAD,AD,DIV)
            DO 60 IJ=I0,I1
               BETA=ABS(WLAM(IJ)-WL0)*FXK1
               SG=STARKA(BETA,BETAD,AD,DIV,UN)*FID
               if(fid0.gt.0.) then
                  xd=beta/betad
                  if(xd.lt.5.) sg=sg+exp(-xd*xd)*fid0
               end if
               ABSO(IJ)=ABSO(IJ)+SG*wnhe2(j,id)
               EMIS(IJ)=EMIS(IJ)+SG*PJ(J)
   60       CONTINUE
         END IF
  100 CONTINUE
C
C     resulting absorption and emission coefficients
C
      DO 110 IJ=I0,I1
         EMIS(IJ)=EMIS(IJ)*II
         ABSO(IJ)=ABSO(IJ)*POPI-EMIS(IJ)
  110 CONTINUE
C
C     add contributions for different spectral series
C
      DO 160 IJ=I0,I1
         ABSOH(IJ)=ABSOH(IJ)+ABSO(IJ)
         EMISH(IJ)=EMISH(IJ)+EMIS(IJ)
  160 CONTINUE
  200 CONTINUE
C
C     finally, multiply EMISH by 2h nu^3/c^2
C
      DO 210 IJ=I0,I1
         F=FREQ(IJ)
         F15=F*1.E-15
         EMISH(IJ)=1.4743E-2*F15*F15*F15*EMISH(IJ)
  210 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE STARK0(I,J,IZZ,XKIJ,WL0,FIJ,FIJ0)
C
C     Auxiliary procedure for evaluating the approximate Stark profile
C     of hydrogen lines - sets up necessary frequency independent
C     parameters
C
C     Input:  I     - principal quantum number of the lower level
C             J     - principal quantum number of the upper level
C             IZZ   - ionic charge (IZZ=1 for hydrogen, etc.)
C     Output: XKIJ  - coefficients K(i,j) for the Hotzmark profile;
C                     exact up to j=6, asymptotic for higher j
C             WL0   - wavelength of the line i-j
C             FIJ   - Stark f-value for the line i-j
C             FIJ0  - f-value for the undisplaced component of the line
C
C
      INCLUDE 'PARAMS.FOR'
      PARAMETER (RYD1=911.763811,RYD2=911.495745,CXKIJ=5.5E-5)
      PARAMETER (WI1=911.753578, WI2=227.837832)
      PARAMETER (UN=1.,TEN=10.,TWEN=20.,HUND=100.)
      DIMENSION FSTARK(10,4),XKIJT(5,4),FOSC0(10,4),FADD(5,5)
      DATA XKIJT/3.56E-4,5.23E-4,1.09E-3,1.49E-3,2.25E-3,.0125,.0177,
     * .028,.0348,.0493,.124,.171,.223,.261,.342,.683,.866,1.02,1.19,
     * 1.46/
      DATA FSTARK/  .1387,    .0791,   .02126,   .01394,   .00642,
     *           4.814E-3, 2.779E-3, 2.216E-3, 1.443E-3, 1.201E-3,
     *              .3921,    .1193,   .03766,   .02209,   .01139,
     *           8.036E-3, 5.007E-3,  3.85E-3, 2.658E-3, 2.151E-3,
     *              .6103,    .1506,   .04931,   .02768,   .01485,
     *             .01023, 6.588E-3, 4.996E-3, 3.524E-3, 2.838E-3,
     *              .8163,    .1788,   .05985,   .03189,   .01762,
     *             .01196, 7.825E-3, 5.882E-3, 4.233E-3, 3.375E-3/
      DATA FOSC0 / 0.27746,  0., 0.00773,  0., 0.00134, 0., 
     *             0.000404, 0., 0.000162, 0.,
     *             0.24869,  0., 0.00701,  0., 0.00131, 0.,
     *             0.000422, 0., 0.000177, 0.,
     *             0.23175,  0., 0.00653,  0., 0.00118, 0.,
     *             0.000392, 0., 0.000169, 0.,
     *             0.22148,  0.0005, 0.00563, 0.0004, 0.00108, 0.,
     *             0.000362, 0., 0.000159, 0./ 
      DATA FADD /  1.231, 0.2069, 7.448E-2, 3.645E-2, 2.104E-2,
     *             1.424, 0.2340, 8.315E-2, 4.038E-2, 2.320E-2,
     *             1.616, 0.2609, 9.163E-2, 4.416E-2, 2.525E-2,
     *             1.807, 0.2876, 1.000E-1, 4.787E-2, 2.724E-2,
     *             1.999, 0.3143, 1.083E-1, 5.152E-2, 2.918E-2/
C
      II=I*I
      JJ=J*J
      JMIN=J-I
      IF(JMIN.LE.5.and.i.le.4) THEN
         XKIJ=XKIJT(JMIN,I)
       ELSE
         XKIJ=CXKIJ*(II*JJ)*(II*JJ)/(JJ-II)
      END IF
      IF(I.LE.4) THEN
         IF(JMIN.LE.10) THEN
            FIJ=FSTARK(JMIN,I)
            FIJ0=FOSC0(JMIN,I)
          ELSE 
            CFIJ=((TWEN*I+HUND)*J/(I+TEN)/(JJ-II))
            FIJ=FSTARK(10,I)*CFIJ*CFIJ*CFIJ
            FIJ0=0.
         END IF
       ELSE IF(I.LE.9) THEN
         IF(JMIN.LE.5) THEN
            FIJ=FADD(JMIN,I-4)
            FIJ0=0.
          ELSE 
            CFIJ=((TEN*I+25.)*J/(I+5.)/(JJ-II))
            FIJ=FADD(5,I-4)*CFIJ*CFIJ*CFIJ
            FIJ0=0.
         END IF
       ELSE
         CFIJ=UN*J/(JJ-II)
         FIJ=1.96*I*CFIJ*CFIJ*CFIJ
         FIJ0=0.
      END IF
C      if(i.eq.1) then
C         wl0=ryd1/(un/ii-un/jj)
C       else
C         WL0=RYD2/(UN/II-UN/JJ)
C      end if
C     wavelength with an explicit correction to the air wavalength
C
      w0=wi1
      if(izz.eq.2) w0=wi2
      WL0=W0/(UN/II-UN/JJ)
      IF(WL0.GT.2000.) THEN
         ALM=1.E8/(WL0*WL0) 
         XN1=64.328+29498.1/(146.-ALM)+255.4/(41.-ALM)
         WL0=WL0/(XN1*1.D-6+UN)
      END IF        
      RETURN
      END
C
C ********************************************************************
C
      FUNCTION STARKA(BETA,BETAD,A,DIV,FAC)
C
C     Approximate expressions for the hydrogen Stark profile
C
C     Input: BETA  - delta lambda in beta units,
C            BETAD - Doppler width in beta units
C            A     - auxiliary parameter
C                    A=1.5*LOG(BETAD)-1.671
C            DIV   - only for A > 1; division point between Doppler
C                    and asymptotic Stark wing, expressed in units
C                    of betad.
C                    DIV = solution of equation
C                    exp(-(beta/betad)**2)/betad/sqrt(pi)=
C                     = 1.5*FAC*beta**-5/2
C                    (ie. the point where Doppler profile is equal to
C                     the asymptotic Holtsmark)
C                    In order to save computer time, the division point
C                    DIV is calculated in advance by routine DIVSTR.
C            FAC   - factor by which the Holtsmark profile is to be
C                    multiplied to get total Stark Profile
C                    FAC should be taken to 2 for hydrogen, (and =1
C                    for He II)
C
      INCLUDE 'PARAMS.FOR'
      PARAMETER (F0=-0.5758228,F1=0.4796232,F2=0.07209481,AL=1.26)
      PARAMETER (SD=0.5641895,SLO=-2.5,TRHA=1.5,BL1=1.14,BL2=11.4)
      PARAMETER (SAC=0.08)
      XD=BETA/BETAD
C
C     for a > 1 Doppler core + asymptotic Holtzmark wing with division
C               point DIV
C
      IF(A.GT.AL) THEN
         IF(XD.LE.DIV) THEN
            STARKA=SD*EXP(-XD*XD)/BETAD
          ELSE
            STARKA=TRHA*FAC*EXP(SLO*LOG(BETA))
         END IF
       ELSE
C
C     empirical formula for a < 1
C
         IF(BETA.LE.BL1) THEN
            STARKA=SAC
          ELSE IF(BETA.LT.BL2) THEN
            XL=LOG(BETA)
            FL=(F0*XL+F1)*XL
            STARKA=F2*EXP(FL)
          ELSE
            STARKA=TRHA*FAC*EXP(SLO*LOG(BETA))
         END IF
      END IF
      RETURN
      END
C
C *******************************************************************
C *******************************************************************
C
      SUBROUTINE DIVSTR(BETAD,A,DIV)
C     ==============================
C
C     Auxiliary procedure for STARKA - determination of the division
C     point between Doppler and asymptotic Stark profiles
C
C     Input:  BETAD - Doppler width in beta units
C     Output: A     - auxiliary parameter
C                     A=1.5*LOG(BETAD)-1.671
C             DIV   - only for A > 1; division point between Doppler
C                     and asymptotic Stark wing, expressed in units
C                     of betad.
C                     DIV = solution of equation
C                     exp(-(beta/betad)**2)/betad/sqrt(pi)=3*beta**-5/2
C
      INCLUDE 'PARAMS.FOR'
      PARAMETER (UN=1.,TWO=2.,UNQ=1.25,UNH=1.5,TWH=2.5,FO=4.,FI=5.)
      PARAMETER (CA=1.671,BL=5.821,AL=1.26,CX=0.28,DX=0.0001)
C
      A=UNH*LOG(BETAD)-CA
      IF(BETAD.LT.BL) RETURN
      IF(A.GE.AL) THEN
         X=SQRT(A)*(UN+UNQ*LOG(A)/(FO*A-FI))
      ELSE
         X=SQRT(CX+A)
      ENDIF
      DO 10 I=1,5
         XN=X*(UN-(X*X-TWH*LOG(X)-A)/(TWO*X*X-TWH))
         IF(ABS(XN-X).LE.DX) GO TO 20
         X=XN
   10 CONTINUE
   20 DIV=X
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE HYDINI(IHYDPR)
C
C     Initializes necessary arrays for evaluating hydrogen line profiles
C     from the Schoening and Butler tables
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      DIMENSION WLINE(12)
      COMMON/HYDDAT/WL(36,12),XT(7,12),XNE(20,12),PRF(36,7,20),
     *              NWLH(12),NTH(12),NEH(12)
      COMMON/AUXHYD/XK,FXK,BETAD,DBETA
      COMMON/HYDPRF/PRFHYD(12,MDEPTH,36),WLHYD(12,36),NWLHYD(12)
      CHARACTER*1 CHAR
      DATA WLINE  /1215.67, 1025.72, 972.537, 949.743,
     *             6562.80, 4861.32, 4340.46, 4101.73,
     *             3970.07, 3889.05, 3835.38, 3797.90/
      DATA NLINE  /12/
C
c     OPEN(UNIT=IHYDPR,STATUS='OLD',READONLY)
C
      DO 5 I=1,12
         READ(IHYDPR,500)
    5 CONTINUE
      DO 100 ILINE=1,NLINE
         WL0=WLINE(ILINE)
C
C     read the tables, which have to be stored in file
C     unit IHYDPR (which is the input parameter in the progarm)
C
         READ(IHYDPR,501) JLINE,ILINE1
         READ(IHYDPR,*) CHAR,NWL,(WL(I,ILINE),I=1,NWL)
         READ(IHYDPR,*) CHAR,NT,(XT(I,ILINE),I=1,NT)
         READ(IHYDPR,*) CHAR,NE,(XNE(I,ILINE),I=1,NE)
	 READ(IHYDPR,500)
         NWLH(ILINE)=NWL
	 NWLHYD(ILINE)=NWL
         NTH(ILINE)=NT
	 NEH(ILINE)=NE
C
         DO 10 I=1,NWL
            IF(WL(I,ILINE).LT.1.E-4) WL(I,ILINE)=1.E-4
            WLHYD(ILINE,I)=LOG10(WL(I,ILINE))
   10    CONTINUE
C
         DO 20 IE=1,NE
            DO 20 IT=1,NT
               READ(IHYDPR,500)
               READ(IHYDPR,*) (PRF(IWL,IT,IE),IWL=1,NWL)
   20    CONTINUE
C
C        coefficient for the asymptotic profile is determined from
C        the input data
C
         XCLOG=PRF(NWL,1,1)+2.5*LOG10(WL(NWL,ILINE))+31.5304-
     *         XNE(1,ILINE)-2.*LOG10(WL0)
         XKLOG=0.6666667*(XCLOG-0.176)
         XK=EXP(XKLOG*2.3025851)
C
         DO 40 ID=1,ND
C
C           temperature is modified in order to account for the
C           effect of turbulent velocity on the Doppler width
C
            T=TEMP(ID)+6.06E-9*VTURB(ID)
            ANE=ELEC(ID)
            TL=LOG10(T)
            ANEL=LOG10(ANE)
            F00=1.25E-9*ANE**0.666666667
            FXK=F00*XK
            DOP=1.E8/WL0*SQRT(1.65E8*T)
            DBETA=WL0*WL0/2.997925E18/FXK
            BETAD=DBETA*DOP
C
C       interpolation to the actual values of temperature and electron
C       density. The result is stored at array PRFHYD, having indices
C       ILINE (line number: 1 for L-alpha,..., 4 for H-delta, etc.);
C                           5 for H-alpha,..., 8 for H-delta, etc.)
C       ID - depth index
C       IWL - wavelength index 
C
            DO 30 IWL=1,NWL
               CALL INTHYD(PROF,TL,ANEL,IWL,ILINE)
               PRFHYD(ILINE,ID,IWL)=PROF
   30       CONTINUE
   40   CONTINUE
  100 CONTINUE
C
  500 FORMAT(1X)
  501 FORMAT(12X,I1,9X,I1)
  502 FORMAT(2X,I4,2x,6E12.4/8X,6E12.4,4(/4X,6F12.4))
  503 FORMAT(2X,I4,F10.3,5F12.3,(/4X,6F12.3))
  504 FORMAT(2X,I4,F10.3,5F12.2,2(/4X,6F12.2))
  505 FORMAT(10F8.3)
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE INTHYD(W0,X0,Z0,IWL,ILINE)
C
C     Interpolation in temperature and electron density from the
C     Schoening and Butler tables for hydrogen lines to the actual valus of
C     temperature and electron density
C
      INCLUDE 'PARAMS.FOR'
      PARAMETER (TWO=2.)
      COMMON/AUXHYD/XK,FXK,BETAD,DBETA
      COMMON/HYDDAT/WL(36,12),XT(7,12),XNE(20,12),PRF(36,7,20),
     *              NWLH(12),NTH(12),NEH(12)
      DIMENSION ZZ(3),XX(3),WX(3),WZ(3)
C
      NX=3
      NZ=3
      NT=NTH(ILINE)
      NE=NEH(ILINE)
C
C     for values lower than the lowest grid value of electron density
C     the profiles are determined by the approximate expression
C     (see STARKA); not by an extrapolation in the HYD tables which may
C     be very inaccurate
C
      IF(Z0.LT.XNE(1,ILINE)*0.99.OR.Z0.GT.XNE(NE,ILINE)*1.01) THEN
         CALL DIVSTR(BETAD,A,DIV)
         W0=STARKA(WL(IWL,ILINE)/FXK,BETAD,A,DIV,TWO)*DBETA
         W0=LOG10(W0)
         GO TO 500
      END IF
C
C     Otherwise, one interpolates (or extrapolates for higher than the
C     highes grid value of electron density) in the HYD tables
C
      DO 10 IZZ=1,NE-1
         IPZ=IZZ
         IF(Z0.LE.XNE(IZZ+1,ILINE)) GO TO 20
   10 CONTINUE
   20 N0Z=IPZ-NZ/2+1
      IF(N0Z.LT.1) N0Z=1
      IF(N0Z.GT.NE-NZ+1) N0Z=NE-NZ+1
      N1Z=N0Z+NZ-1
C
      DO 300 IZZ=N0Z,N1Z
         I0Z=IZZ-N0Z+1
         ZZ(I0Z)=XNE(IZZ,ILINE)
C
C     Likewise, the approximate expression instead of extrapolation
C     is used for higher that the highest grid value of temperature,
C     if the Doppler width expressed in beta units (BETAD) is
C     sufficiently large (> 10)
C
         IF(X0.GT.1.01*XT(NT,ILINE).AND.BETAD.GT.10.) THEN
            CALL DIVSTR(BETAD,A,DIV)
            W0=STARKA(WL(IWL,ILINE)/FXK,BETAD,A,DIV,TWO)*DBETA
            W0=LOG10(W0)
            GO TO 500
         END IF
C
C     Otherwise, normal inter- or extrapolation
C
C     Both interpolations (in T as well as in electron density) are
C     by default the quadratic interpolations in logarithms
C
         DO 30 IX=1,NT-1
            IPX=IX
            IF(X0.LE.XT(IX+1,ILINE)) GO TO 40
   30    CONTINUE
   40    N0X=IPX-NX/2+1
         IF(N0X.LT.1) N0X=1
         IF(N0X.GT.NT-NX+1) N0X=NT-NX+1
         N1X=N0X+NX-1
         DO 200 IX=N0X,N1X
            I0=IX-N0X+1
            XX(I0)=XT(IX,ILINE)
            WX(I0)=PRF(IWL,IX,IZZ)
  200    CONTINUE
         IF(WX(1).LT.-99..OR.WX(2).LT.-99..OR.WX(3).LT.-99.) THEN
            CALL DIVSTR(BETAD,A,DIV)
            W0=STARKA(WL(IWL,ILINE)/FXK,BETAD,A,DIV,TWO)*DBETA
            W0=LOG10(W0)
            GO TO 500
          ELSE
            WZ(I0Z)=YINT(XX,WX,X0)
         END IF
  300 CONTINUE
      W0=YINT(ZZ,WZ,Z0)
  500 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
      FUNCTION YINT(XL,YL,XL0)
C
C     Quadratic interpolation routine
C
C     Input:  XL - array of x
C             YL - array of f(x)
C             XL0 - the point x(0) to which one interpolates
C
      INCLUDE 'PARAMS.FOR'
      DIMENSION XL(3),YL(3)
      A0=(XL(2)-XL(1))*(XL(3)-XL(2))*(XL(3)-XL(1))
      A1=(XL0-XL(2))*(XL0-XL(3))*(XL(3)-XL(2))
      A2=(XL0-XL(1))*(XL(3)-XL0)*(XL(3)-XL(1))
      A3=(XL0-XL(1))*(XL0-XL(2))*(XL(2)-XL(1))
      YINT=(YL(1)*A1+YL(2)*A2+YL(3)*A3)/A0
      RETURN
      END
C
C ********************************************************************
C
C
 
      SUBROUTINE HE1INI(IH)
C     ====================
C
C     Initializes necessary arrays for evaluating the He I line
C     absorption profiles using data calculated by Barnard, Cooper
C     and Smith JQSRT 14, 1025, 1974 (for 4471)
C     or Shamey, unpublished PhD thesis, 1969 (for other lines)
C
C     This procedure is quite analogous to HYDINI for hydrogen lines
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      COMMON/PROHE1/PRFHE1(50,4,8,3),DLMHE1(50,8,3),XNEHE1(8),
     *              NWLAM(8,4)
      COMMON/PRO447/PRF447(80,4,7),DLM447(80,7),XNE447(7)
      DATA NT /4/
C
c     OPEN(UNIT=IH,STATUS='OLD',READONLY)
C
C        read the Barnard, Cooper, Smith tables for He I 4471 line,
C        which have to be stored in file unit IH
C
         NE=7
         DO 10 IE=1,NE
            READ(IH,501) IL,WL0,IE1,XNE,NWL
	    NWLAM(IE,1)=NWL
	    XNE447(IE)=LOG10(XNE)
            DO 10 I=1,NWL
               READ(IH,502) DLM447(I,IE),
     *                   (PRF447(I,IT,IE),IT=1,NT)
   10    CONTINUE
C
C        read Shamey's tables for He I 4387, 4026, and 4922 lines
C        which have to be stored in file unit IH
C
         NE=8
         DO 20 ILN=1,3
            DO 20 IE=1,NE
               READ(IH,501) IL,WL0,IE1,XNE,NWL
	       NWLAM(IE,ILN+1)=NWL
	       XNEHE1(IE)=LOG10(XNE)
               DO 20 I=1,NWL
                  READ(IH,*) DLMHE1(I,IE,ILN),
     *                       (PRFHE1(I,IT,IE,ILN),IT=1,NT)
   20    CONTINUE
C
  501 FORMAT(/9X,I2,7X,F10.3,13X,I2,6X,E8.1,7X,I3/)
  502 FORMAT(5E10.2)
      RETURN
      END
C
C ********************************************************************
C
 
      FUNCTION WTOT(T,ANE,ID,ILINE)
C     =============================
C
C     Evaluates the total (electron + ion) impact Stark width
C     for four HeI lines
C     After Griem (1974); and Barnard, Cooper, Smith (1974) JQSRT 14,
C     1025 for the 4471 line
C
C     Input: T     - temperature
C            ANE   - electron density
C            ID    - depth index
C            ILINE - index of the line ( = 1  for 4471,
C                                        = 2  for 4387,
C                                        = 3  for 4026,
C                                        = 4  for 4922)
C     Output: WTOT - Stark width in Angstroms
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      DIMENSION ALPH0(4,4),W0(4,4),ALAM0(4)
      DATA ALPH0 / 0.107, 0.119, 0.134, 0.154,
     *             0.206, 0.235, 0.272, 0.317,
     *             0.172, 0.193, 0.218, 0.249,
     *             0.121, 0.136, 0.157, 0.184/
      DATA W0    / 1.460, 1.269, 1.079, 0.898,
     *             6.130, 5.150, 4.240, 3.450,
     *             4.040, 3.490, 2.960, 2.470,
     *             2.312, 1.963, 1.624, 1.315/
      DATA ALAM0 / 4471.50, 4387.93, 4026.20, 4921.93/
C
      I=JT(ID)
      ALPHA=(TI0(ID)*ALPH0(I,ILINE)+TI1(ID)*ALPH0(I-1,ILINE)+
     *      TI2(ID)*ALPH0(I-2,ILINE))*(ANE*1.E-13)**0.25
      WE=   (TI0(ID)*W0(I,ILINE)+TI1(ID)*W0(I-1,ILINE)+
     *      TI2(ID)*W0(I-2,ILINE))*ANE*1.E-16
      F0=1.884E19/ALAM0(ILINE)/ALAM0(ILINE)
      SIG=(4.32E-5*WE/SQRT(T)*F0/ANE**0.3333)**0.3333
      WTOT=WE*(1.+1.36/SIG*ALPHA**0.8889)
      RETURN
      END
 
C
C ********************************************************************
C
 
      FUNCTION EXTPRF(DLAM,IT,ILINE,ANEL,DLAST,PLAST)
C     ===============================================
C
C     Extrapolation in wavelengths in Shamey, or Barnard, Cooper,
C     Smith tables
C     Special formula suggested by Cooper
C
      INCLUDE 'PARAMS.FOR'
      DIMENSION W0(4,4)
      DATA W0    / 1.460, 1.269, 1.079, 0.898,
     *             6.130, 5.150, 4.240, 3.450,
     *             4.040, 3.490, 2.960, 2.470,
     *             2.312, 1.963, 1.624, 1.315/
C
      WE=W0(IT,ILINE)*EXP(ANEL*2.3025851)*1.E-16
      DLASTA=ABS(DLAST)
      D52=DLASTA*DLASTA*SQRT(DLASTA)
      F=D52*(PLAST-WE/3.14159/DLAST/DLAST)
      EXTPRF=(WE/3.14159+F/SQRT(ABS(DLAM)))/DLAM/DLAM
      RETURN
      END
 
C
C ********************************************************************
C
 
      FUNCTION PHE1(ID,FREQ,ILINE)
C     ============================
C
C     Absorption profile for four lines of He I, given by
C     Barnard, Cooper, Smith (1974) JQSRT 14, 1025 for the 4471 line;
C     Shamey (1969) PhD thesis, for other lines
C
C     Input: ID    - depth index
C            FREQ  - frequency
C            ILINE - index of the line ( = 1  for 4471,
C                                        = 2  for 4387,
C                                        = 3  for 4026,
C                                        = 4  for 4922)
C
C     Output: PHE1 - profile coefficient in frequency units,
C                    normalized to sqrt(pi) [not unity]
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      COMMON/PROHE1/PRFHE1(50,4,8,3),DLMHE1(50,8,3),XNEHE1(8),
     *              NWLAM(8,4)
      COMMON/PRO447/PRF447(80,4,7),DLM447(80,7),XNE447(7)
      DIMENSION WLAM0(4),XT(4),XX(3),WX(3),YY(2),PP(2),ZZ(3),WZ(3)
      DATA WLAM0 / 4471.50, 4387.93, 4026.20, 4921.93/
      DATA XT / 3.699, 4.000, 4.301, 4.602/
C
      T=TEMP(ID)
      TL=LOG10(T)
      ANE=ELEC(ID)
      ANEL=LOG10(ANE)
      ALAM=2.997925E18/FREQ
      DLAM=ALAM-WLAM0(ILINE)
      DOPL=SQRT(4.125E7*T+VTURB(ID))*WLAM0(ILINE)/2.997925E10
C
      IF(ILINE.EQ.1.AND.ANEL.GE.XNE447(1)) GO TO 10
      IF(ILINE.NE.1.AND.ANEL.GE.XNEHE1(1)) GO TO 10
C
C     isolated line approximation for low electron densities
C
      A=WTOT(T,ANE,ID,ILINE)/DOPL
      V=ABS(DLAM)/DOPL
      V1=ABS(ALAM-4471.682)/DOPL
c     PHE1=VOIGTE(A,V)
      PHE1=VOIGTK(A,V)
c     IF(ILINE.EQ.1) PHE1=(8.*PHE1+VOIGTE(A,V1))/9.
      IF(ILINE.EQ.1) PHE1=(8.*PHE1+VOIGTK(A,V1))/9.
      RETURN
C
C     otherwise, interpolation (or extrapolation) in tables
C
   10 NX=3
      NZ=3
      NY=2
      NT=4
      NE=8
      ILNE=ILINE-1
      IF(ILINE.EQ.1) NE=7
C
C     Interpolation in electron density
C
      DO 20 JZ=1,NE-1
         IPZ=JZ
	 IF(ILINE.EQ.1.AND.ANEL.LE.XNE447(JZ+1)) GO TO 30
	 IF(ILINE.NE.1.AND.ANEL.LE.XNEHE1(JZ+1)) GO TO 30
   20 CONTINUE
   30 N0Z=IPZ-NZ/2+1
      IF(N0Z.LT.1) N0Z=1
      IF(N0Z.GT.NE-NZ+1) N0Z=NE-NZ+1
      N1Z=N0Z+NZ-1
      DO 300 JZ=N0Z,N1Z
	 I0Z=JZ-N0Z+1
	 IF(ILINE.EQ.1) ZZ(I0Z)=XNE447(JZ)
	 IF(ILINE.NE.1) ZZ(I0Z)=XNEHE1(JZ)
C
C        Interpolation in temperature
C
	 DO 40 IX=1,NT-1
	    IPX=IX
	    IF(TL.LE.XT(IX+1)) GO TO 50
   40    CONTINUE
   50    N0X=IPX-NX/2+1
	 IF(N0X.LT.1) N0X=1
	 IF(N0X.GT.NT-NX+1) N0X=NT-NX+1
	 N1X=N0X+NX-1
	 DO 200 IX=N0X,N1X
	    I0X=IX-N0X+1
	    XX(I0X)=XT(IX)
C
C           Interpolation in wavelength
C
C           1. For delta lambda beyond tabulated values - special
C              extrapolation (Cooper's suggestion)
C
	    NLST=NWLAM(JZ,ILINE)
	    IF(ILINE.EQ.1) THEN
	       D1=DLM447(1,JZ)
	       D2=DLM447(NLST,JZ)
	       IF(DLAM.LT.D1) THEN
		  PRF=EXTPRF(DLAM,IX,ILINE,ZZ(I0Z),D1,PRF447(1,IX,JZ))
		  GO TO 150
                ELSE IF(DLAM.GT.D2) THEN
		  PRF=EXTPRF(DLAM,IX,ILINE,ZZ(I0Z),D2,
     *        	      PRF447(NLST,IX,JZ))
		  GO TO 150
               END IF
             ELSE
	       D1=DLMHE1(1,JZ,ILNE)
	       D2=DLMHE1(NLST,JZ,ILNE)
	       IF(DLAM.LT.D1) THEN
		  PRF=EXTPRF(DLAM,IX,ILINE,ZZ(I0Z),D1,
     *        	      PRFHE1(1,IX,JZ,ILNE))
		  GO TO 150
                ELSE IF(DLAM.GT.D2) THEN
		  PRF=EXTPRF(DLAM,IX,ILINE,ZZ(I0Z),D2,
     *        	      PRFHE1(NLST,IX,JZ,ILNE))
		  GO TO 150
               END IF
            END IF
C
C           normal linear interpolation in wavelength
C           (for 4471, linear interpolation in logarithms)
C
	    DO 60 IY=1,NLST-1
	       IPY=IY
	       IF(ILINE.EQ.1.AND.DLAM.LE.DLM447(IY+1,JZ)) GO TO 70
	       IF(ILINE.NE.1.AND.DLAM.LE.DLMHE1(IY+1,JZ,ILNE))
     *            GO TO 70
   60       CONTINUE
   70       N0Y=IPY-NY/2+1
	    IF(N0Y.LT.1) N0Y=1
	    IF(N0Y.GT.NLST-NY+1) N0Y=NLST-NY+1
	    N1Y=N0Y+NY-1
	    DO 100 IY=N0Y,N1Y
	       I0=IY-N0Y+1
	       IF(ILINE.EQ.1) YY(I0)=DLM447(IY,JZ)
	       IF(ILINE.EQ.1) PP(I0)=LOG(PRF447(IY,IX,JZ))
	       IF(ILINE.NE.1) YY(I0)=DLMHE1(IY,JZ,ILNE)
	       IF(ILINE.NE.1) PP(I0)=PRFHE1(IY,IX,JZ,ILNE)
  100      CONTINUE
	   IF(ILINE.NE.1) THEN
	      WX(I0X)=(PP(2)*(DLAM-YY(1))+PP(1)*(YY(2)-DLAM))/
     *                (YY(2)-YY(1))
	    ELSE
c             IF(YY(1).NE.0.) THEN
c                YY(1)=LOG(ABS(YY(1)))
c              ELSE
c                YY(1)=-8.
c             END IF
c             IF(YY(2).NE.0.) THEN
c                YY(2)=LOG(ABS(YY(2)))
c              ELSE
c                YY(2)=-8.
c             END IF
c             IF(DLAM.NE.0.) THEN
c                DLAM=LOG(ABS(DLAM))
c              ELSE
c                DLAM=-8.
c             END IF
             WX(I0X)=(PP(2)*(DLAM-YY(1))+PP(1)*(YY(2)-DLAM))/
     *                (YY(2)-YY(1))
             WX(I0X)=EXP(WX(I0X))
	   END IF
	   GO TO 200
  150      WX(I0X)=PRF
  200   CONTINUE
	WZ(I0Z)=YINT(XX,WX,TL)
  300 CONTINUE
      W0=YINT(ZZ,WZ,ANEL)
      PHE1=W0*DOPL*1.772454
      RETURN
      END
 
C
C ********************************************************************
C
 
      SUBROUTINE HE2INI(IH)
C     =====================
C
C     Initializes necessary arrays for evaluating the He II line
C     absorption profiles using data calculated by Schoening and
C     Butler
C
C     This procedure is quite analogous to HYDINI for hydrogen lines
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      COMMON/HE2PRF/PRFHE2(19,MDEPTH,36),WLHE2(19,36),NWLHE2(19),
     *              ILHE2(19),IUHE2(19)
      COMMON/HE2DAT/WL(36,19),XT(6),XNE(11,19),PRF(36,6,11),
     *              NWL,NT,NE
      COMMON/AUXHE2/XK,FXK,BETAD,DBETA
      DATA NLINE1 /19/
C
c      OPEN(UNIT=IH,STATUS='OLD',READONLY)
C
      DO 100 ILINE=1,NLINE1
C
C     read the Schoening and Butler tables, which have to be stored
C     in file unit IH
C
         READ(IH,501) ILHE2(ILINE),IUHE2(ILINE)
         IF(ILHE2(ILINE).LE.2) THEN
            WL00=227.838
          ELSE 
            WL00=227.7776
         END IF   
         WL0=WL00/(1./ILHE2(ILINE)**2-1./IUHE2(ILINE)**2)
         READ(IH,*) NWL,(WL(I,ILINE),I=1,NWL)
         READ(IH,503) NT,(XT(I),I=1,NT)
         READ(IH,504) NE,(XNE(I,ILINE),I=1,NE)
         READ(IH,500)
         NWLHE2(ILINE)=NWL
C
         DO 10 I=1,NWL
            IF(WL(I,ILINE).LT.1.E-4) WL(I,ILINE)=1.E-4
            WLHE2(ILINE,I)=LOG10(WL(I,ILINE))
   10    CONTINUE
C
         DO 20 IE=1,NE
            DO 20 IT=1,NT
               READ(IH,500)
               READ(IH,505) (PRF(IWL,IT,IE),IWL=1,NWL)
   20    CONTINUE
C
C        coefficient for the asymptotic profile is determined from
C        the input data
C
         XCLOG=PRF(NWL,1,1)+2.5*LOG10(WL(NWL,ILINE))+31.831-
     *         XNE(1,ILINE)-2.*LOG10(WL0)
         XKLOG=0.6666667*(XCLOG-0.176)
         XK=EXP(XKLOG*2.3025851)
         DO 50 ID=1,ND
            T=TEMP(ID)+2.42E-8*VTURB(ID)
            ANE=ELEC(ID)
            TL=LOG10(T)
            ANEL=LOG10(ANE)
            F00=1.25E-9*ANE**0.666666667
            FXK=F00*XK
            DOP=1.E8/WL0*SQRT(4.12E7*T)
            DBETA=WL0*WL0/2.997925E18/FXK
            BETAD=DBETA*DOP
C
C     interpolation to the actual values of temperature and electron
C     density. The result is stored at array PRFHE2, which has indices
C     ILINE  - index of line
C     ID     - depth index
C     IWL    - wavelength index (notice that the wavelength grid may
C              generally be different for different lines
C
            DO 30 IWL=1,NWL
               CALL INTHE2(PROF,TL,ANEL,IWL,ILINE)
               PRFHE2(ILINE,ID,IWL)=PROF
   30      CONTINUE
   50   CONTINUE
  100 CONTINUE
C
  500 FORMAT(1X)
  501 FORMAT(//14X,I2,9X,I2/)
  502 FORMAT(2X,I4,1P6E10.3,4(/5X,0P6F10.4)/5X,5F10.4)
  503 FORMAT(2X,I4,F10.3,5F12.3)
  504 FORMAT(2X,I4,F10.2,5F12.2/4X,5F12.2)
  505 FORMAT(10F8.3)
      RETURN
      END
C
C ********************************************************************
C
C
 
      SUBROUTINE INTHE2(W0,X0,Z0,IWL,ILINE)
C     =====================================
C
C     Interpolation in temperature and electron density from the
C     Schoening and Butler tables for He II lines to the actual
C     actual values of temperature and electron density
C
C     This procedure is quite analogous to INTHYD for hydrogen lines
C
      INCLUDE 'PARAMS.FOR'
      PARAMETER (UN=1.)
      COMMON/HE2DAT/WL(36,19),XT(6),XNE(11,19),PRF(36,6,11),
     *              NWL,NT,NE
      COMMON/AUXHE2/XK,FXK,BETAD,DBETA
      DIMENSION ZZ(3),XX(3),WX(3),WZ(3)
C
      NX=3
      NZ=3
C
C     for values lower than the lowest grid value of electron density
C     the profiles are determined by the approximate expression
C     (see STARKA); not by an extrapolation in the tables which may
C     be very inaccurate
C
      IF(Z0.LT.XNE(1,ILINE)*0.99.OR.Z0.GT.XNE(NE,ILINE)*1.01) THEN
         CALL DIVHE2(BETAD,A,DIV)
         W0=STARKA(WL(IWL,ILINE)/FXK,BETAD,A,DIV,UN)*DBETA
         W0=LOG10(W0)
         GO TO 500
      END IF
C
C     Otherwise, one interpolates (or extrapolates for higher than the
C     highes grid value of electron density) in the Schoening and
C     Butler tables
C
      DO 10 IZZ=1,NE-1
         IPZ=IZZ
         IF(Z0.LE.XNE(IZZ+1,ILINE)) GO TO 20
   10 CONTINUE
   20 N0Z=IPZ-NZ/2+1
      IF(N0Z.LT.1) N0Z=1
      IF(N0Z.GT.NE-NZ+1) N0Z=NE-NZ+1
      N1Z=N0Z+NZ-1
C
      DO 300 IZZ=N0Z,N1Z
         I0Z=IZZ-N0Z+1
         ZZ(I0Z)=XNE(IZZ,iline)
C
C     Likewise, the approximate expression instead of extrapolation
C     is used for higher that the highest grid value of temperature,
C     if the Doppler width expressed in beta units (BETAD) is
C     sufficiently large (> 10)
C
         IF(X0.GT.1.01*XT(NT).AND.BETAD.GT.10.) THEN
            W0=STARKA(WL(IWL,ILINE)/FXK,BETAD,A,DIV,UN)*DBETA
            W0=LOG10(W0)
            GO TO 500
         END IF
C
C     Otherwise, normal inter- or extrapolation
C
C     Both interpolations (in T as well as in electron density) are
C     by default the quadratic interpolations in logarithms
C
         DO 30 IX=1,NT-1
            IPX=IX
            IF(X0.LE.XT(IX+1)) GO TO 40
   30    CONTINUE
   40    N0X=IPX-NX/2+1
         IF(N0X.LT.1) N0X=1
         IF(N0X.GT.NT-NX+1) N0X=NT-NX+1
         N1X=N0X+NX-1
         DO 200 IX=N0X,N1X
            I0=IX-N0X+1
            XX(I0)=XT(IX)
            WX(I0)=PRF(IWL,IX,IZZ)
  200       CONTINUE
         WZ(I0Z)=YINT(XX,WX,X0)
  300 CONTINUE
      W0=YINT(ZZ,WZ,Z0)
  500 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
C
 
      SUBROUTINE DIVHE2(BETAD,A,DIV)
C     ==============================
C
C     Auxiliary procedure for evaluating approximate Stark profile
C     for He II lines
C     This procedure is quite analogous to DIVSTR for hydrogen;
C     the only difference is a somewhat different definition
C     of the parameter A ,ie. A for He II is equal to A for hydrogen
C     minus ln(2)
C
      PARAMETER (UN=1.,TWO=2.,UNQ=1.25,UNH=1.5,TWH=2.5,FO=4.,FI=5.)
      PARAMETER (CA=0.978,BL=5.821,AL=1.26,CX=0.28,DX=0.0001)
C
      INCLUDE 'PARAMS.FOR'
      A=UNH*LOG(BETAD)-CA
      IF(BETAD.LT.BL) RETURN
      IF(A.GE.AL) THEN
         X=SQRT(A)*(UN+UNQ*LOG(A)/(FO*A-FI))
      ELSE
         X=SQRT(CX+A)
      ENDIF
      DO 10 I=1,5
         XN=X*(UN-(X*X-TWH*LOG(X)-A)/(TWO*X*X-TWH))
         IF(ABS(XN-X).LE.DX) GO TO 20
         X=XN
   10 CONTINUE
   20 DIV=X
      RETURN
      END
C
C ********************************************************************
C
C
 
      SUBROUTINE PHE2(ISPEC,ID,ABLIN,EMLIN)
C     =====================================
C
C     Evaluation of the opacity and emissivity in a given He II line,
C     using profile coefficients calculated by Schoening and Butler.
C
C     Input: ISPEC - line index, defined in HE2INI
C            ID    - depth index
C     Output: ABLIN - absorption coefficient
C             EMLIN - emission coefficient
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      DIMENSION ABLIN(1),EMLIN(1),OSCHE2(19),PRF0(40),WLL(40)
      COMMON/HE2PRF/PRFHE2(19,MDEPTH,36),WLHE2(19,36),NWLHE2(19),
     *              ILHE2(19),IUHE2(19)
      DATA OSCHE2/6.407E-1, 1.506E-1, 5.584E-2, 2.768E-2,
     *        1.604E-2, 1.023E-2, 6.980E-3,
     *        8.421E-1, 3.230E-2, 1.870E-2, 1.196E-2, 8.187E-3,
     *        5.886E-3, 4.393E-3, 3.375E-3, 2.656E-3,
     *        1.038,    1.793E-1, 6.549E-2/
C
C     ILINE - line index 
C
      ILINE=ISPEC-5
C
      DO 10 IWL=1,NWLHE2(ILINE)
         PRF0(IWL)=PRFHE2(ILINE,ID,IWL)
         WLL(IWL)=WLHE2(ILINE,IWL)
   10 CONTINUE
C
      I=ILHE2(ILINE)
      J=IUHE2(ILINE)
      II=I*I
      JJ=J*J
      IF(I.LE.2) THEN
         WLINE=227.838/(1./II-1./JJ)
       ELSE 
         WLINE=227.7776/(1./II-1./JJ)
      END IF   
      T=TEMP(ID)
C
C     He III population (either LTE or NLTE, depending on input model)
C
      IF(IELHE2.GT.0.and.inlte.gt.0) THEN
         PP=POPUL(NNEXT(IELHE2),ID)
         NLHE2=NLAST(IELHE2)-NFIRST(IELHE2)+1
       ELSE
         PP=RRR(ID,3,2)
         NLHE2=0
      END IF
C
C     population of the lower level of the given transition
C     (again either LTE or NLTE)
C
      PP=PP*ELEC(ID)*4.1412E-16/T/SQRT(T)*II
      IF(I.LE.NLHE2.and.inlte.gt.0) THEN
         POPI=POPUL(NFIRST(IELHE2)+I-1,ID)
       ELSE
         POPI=PP*EXP(631479./T/II)
      END IF
C
C     population of the upper level of the given transition
C     (again either LTE or NLTE)
C
      IF(J.LE.NLHE2) THEN
         POPJ=POPUL(NFIRST(IELHE2)+J-1,ID)*II/JJ
       ELSE
         POPJ=PP*EXP(631479./T/JJ)
      END IF
 
C
C     loop over frequency points - opacity and emissivity in the given line
C     absorption coefficent is found by interpolating in previously
C     calculated tables, based on calculations of Schoening and Butler
C     (see procedure HE2INI)
C
      FID=0.02654*OSCHE2(ILINE)
      DO 50 IJ=3,NFREQ
         AL=ABS(WLAM(IJ)-WLINE)
         IF(AL.LT.1.E-4) AL=1.E-4
         AL=LOG10(AL)
         DO 20 IWL=1,NWLHE2(ILINE)-1
            IW0=IWL
            IF(AL.LE.WLL(IWL+1)) GO TO 30
   20    CONTINUE
   30    IW1=IW0+1
         PRF=(PRF0(IW0)*(WLL(IW1)-AL)+PRF0(IW1)*(AL-WLL(IW0)))/
     *       (WLL(IW1)-WLL(IW0))
         SG=EXP(PRF*2.3025851)*FID
         ABLIN(IJ)=ABLIN(IJ)+SG*(POPI-POPJ)
         EMLIN(IJ)=EMLIN(IJ)+SG*POPJ*1.4747E-2*(FREQ(IJ)*1.E-15)**3
   50 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
C
 
      FUNCTION ISPEC(IAT,ION,ALAM)
C     ============================
C
C     Auxiliary procedure for INISET
C
C     Input:  IAT  - atomic number
C             ION  - ion (=1 for neutrals, =2 for once ionized, etc.)
C             ALAM - wavelength in nanometers
C     Output: ISPEC - parameter specifying whether the given line
C                     is taken with a special (pretabulated) absorption
C                     profile - only for hydrogen and helium
C                   = 0  - profile is taken as an ordinary Voigt profile
C                   > 0  - special profile
C
      INCLUDE 'PARAMS.FOR'
      COMMON/HHEPRF/IHYDPR,IHE1PR,IHE2PR
C
      ISPEC=0
      IF(IAT.GT.2) RETURN
C
      IF(IAT.EQ.1) THEN
         ISPEC=1
         RETURN
       ELSE
         IF(ION.EQ.1) THEN
            IF(ABS(ALAM-447.1).LT.0.5.AND.IHE1PR.GT.0) ISPEC=2
            IF(ABS(ALAM-438.8).LT.0.2.AND.IHE1PR.GT.0) ISPEC=3
            IF(ABS(ALAM-402.6).LT.0.2.AND.IHE1PR.GT.0) ISPEC=4
            IF(ABS(ALAM-492.2).LT.0.2.AND.IHE1PR.GT.0) ISPEC=5
          ELSE
C
            IF(ALAM.LT.163..OR.ALAM.GT.1012.7) RETURN
            IF(ALAM.LT.321.) THEN
               IF(ABS(ALAM-164.0).LT.0.2.AND.IHE2PR.GT.0) ISPEC=6
               IF(ABS(ALAM-320.3).LT.0.2.AND.IHE2PR.GT.0) ISPEC=7
               IF(ABS(ALAM-273.3).LT.0.2.AND.IHE2PR.GT.0) ISPEC=8
               IF(ABS(ALAM-251.1).LT.0.2.AND.IHE2PR.GT.0) ISPEC=9
               IF(ABS(ALAM-238.5).LT.0.2.AND.IHE2PR.GT.0) ISPEC=10
               IF(ABS(ALAM-230.6).LT.0.2.AND.IHE2PR.GT.0) ISPEC=11
               IF(ABS(ALAM-225.3).LT.0.2.AND.IHE2PR.GT.0) ISPEC=12
             ELSE IF(ALAM.LT.541.) THEN
               IF(ALAM.LT.392.3) RETURN
               IF(ABS(ALAM-468.6).LT.0.2.AND.IHE2PR.GT.0) ISPEC=13
               IF(ABS(ALAM-485.9).LT.0.2.AND.IHE2PR.GT.0) ISPEC=14
               IF(ABS(ALAM-454.2).LT.0.2.AND.IHE2PR.GT.0) ISPEC=15
               IF(ABS(ALAM-433.9).LT.0.2.AND.IHE2PR.GT.0) ISPEC=16
               IF(ABS(ALAM-420.0).LT.0.2.AND.IHE2PR.GT.0) ISPEC=17
               IF(ABS(ALAM-410.0).LT.0.2.AND.IHE2PR.GT.0) ISPEC=18
               IF(ABS(ALAM-402.6).LT.0.2.AND.IHE2PR.GT.0) ISPEC=19
               IF(ABS(ALAM-396.8).LT.0.2.AND.IHE2PR.GT.0) ISPEC=20
               IF(ABS(ALAM-392.3).LT.0.2.AND.IHE2PR.GT.0) ISPEC=21
             ELSE
               IF(ABS(ALAM-1012.4).LT.0.2.AND.IHE2PR.GT.0) ISPEC=22
               IF(ABS(ALAM-656.0).LT.0.2.AND.IHE2PR.GT.0) ISPEC=23
               IF(ABS(ALAM-541.2).LT.0.2.AND.IHE2PR.GT.0) ISPEC=24
            END IF
         END IF
      END IF
      RETURN
      END
C
C
C     ******************************************************************
C
C

      SUBROUTINE HESET(IL,ALM,EXCL,EXCU,ION,IPRF0,ILWN,IUPN)
C     ======================================================
C     
C     Auxiliary procedure for INISET - set up quantities:
C     IPRF0      - index for the procedure evaluating standard absorption
C                  profile coefficient for He I lines - see GAMHE
C     ILWN,IUPN  - only in NLTE option is switched on;
C                  indices of the lower and upper level associated with
C                  the given line
C
C     Input: IL - line index
C            ALM - line wavelength in nm
C            EXCL - excitation potential of the lower level (in cm**-1)
C            EXCU - excitation potential of the upper level (in cm**-1)
C            ION  - ionisation degree (1=neutrals, 2=once ionized, etc.)
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      DIMENSION JU(23),NU(23),IT(23)
      DATA IT/1,1,0,1,0,0,0,1,0,0,0,1,1,0,0,0,1,0,1,0,0,0,0/
      DATA NU/6,6,9,3,8,4,7,5,6,6,5,4,4,4,3,4,3,3,5,5,7,8,10/
      DATA JU/15,3,5,9,5,3,5,3,5,1,1,15,3,5,3,1,15,5,15,5,1,1,1/
C
C ******* He I  ***********
C
      IF(ION.NE.1) GO TO 20
C
C     switch IPRF0 - see GAMHE
C
      ALAM=ALM*10.
      IPRF=0
      IF(ABS(ALAM-3819.60).LT.1.) IPRF=1
      IF(ABS(ALAM-3867.50).LT.1.) IPRF=2
      IF(ABS(ALAM-3871.79).LT.1.) IPRF=3
      IF(ABS(ALAM-3888.65).LT.1.) IPRF=4
      IF(ABS(ALAM-3926.53).LT.1.) IPRF=5
      IF(ABS(ALAM-3964.73).LT.1.) IPRF=6
      IF(ABS(ALAM-4009.27).LT.1.) IPRF=7
      IF(ABS(ALAM-4120.80).LT.1.) IPRF=8
      IF(ABS(ALAM-4143.76).LT.1.) IPRF=9
      IF(ABS(ALAM-4168.97).LT.1.) IPRF=10
      IF(ABS(ALAM-4437.55).LT.1.) IPRF=11
      IF(ABS(ALAM-4471.50).LT.1.) IPRF=12
      IF(ABS(ALAM-4713.20).LT.1.) IPRF=13
      IF(ABS(ALAM-4921.93).LT.1.) IPRF=14
      IF(ABS(ALAM-5015.68).LT.1.) IPRF=15
      IF(ABS(ALAM-5047.74).LT.1.) IPRF=16
      IF(ABS(ALAM-5875.70).LT.1.) IPRF=17
      IF(ABS(ALAM-6678.15).LT.1.) IPRF=18
      IF(ABS(ALAM-4026.20).LT.1.) IPRF=19
      IF(ABS(ALAM-4387.93).LT.1.) IPRF=20
      IF(ABS(ALAM-4023.97).LT.1.) IPRF=21
      IF(ABS(ALAM-3935.91).LT.1.) IPRF=22
      IF(ABS(ALAM-3833.55).LT.1.) IPRF=23
      IF(IPRF.GT.0.AND.IPRF.LE.20) IPRF0=IPRF
C
C     Indices of NLTE levels associated with the given line
C
      IF(INLTE.gt.5.OR.IELHE1.EQ.0) RETURN
      N0I=NFIRST(IELHE1)
      N1I=NLAST(IELHE1)
      HC=CL*H
      EION=ENION(N0I)/HC
      ILW=0
      IUN=0
      NQL=0
      IF(IPRF.GT.0) NQL=NU(IPRF)
      DO 10 I=N0I,N1I
	 NQ=NQUANT(I)
	 EX=EION-ENION(I)/HC
	 IF(ABS(EXCL-EX).LT.100.) THEN
	    ILW=I
	    IGL=INT(G(I)+0.001)
	 END IF
	 IF(NQ.EQ.NQL) THEN 
	    IG=INT(G(I)+0.001)
	    IF(IT(IPRF).EQ.0) THEN
	       IF(NQ.EQ.2.AND.IG.EQ.JU(IPRF)) IUN=I
	       IF(NQ.EQ.3) THEN
	          IF(IG.EQ.JU(IPRF)) THEN
	             IF(IG.EQ.1.OR.IG.EQ.5) IUN=I
	             IF(IG.EQ.3.AND.IGL.EQ.1) IUN=I
		   ELSE
		     IF(IG.EQ.9) IUN=I
                  END IF
	       END IF
	       IF(NQ.EQ.4) THEN
	          IF(IG.EQ.JU(IPRF)) THEN
	             IF(IG.EQ.1.OR.IG.EQ.5.OR.IG.EQ.7) IUN=I
	             IF(IG.EQ.3.AND.IGL.EQ.1) IUN=I
		   ELSE
		     IF(IG.EQ.16) IUN=I
                  END IF
	       END IF
	       IF(IG.EQ.25.OR.IG.EQ.36) IUN=I
	       IF(IG.EQ.49.OR.IG.EQ.64.OR.IG.EQ.81) IUN=I
	       IF(IG.EQ.100.OR.IG.EQ.121.OR.IG.EQ.144) IUN=I
             ELSE
	       IF(NQ.EQ.3) THEN
	          IF(IG.EQ.JU(IPRF)) THEN
	             IF(IG.EQ.9.OR.IG.EQ.15) IUN=I
	             IF(IG.EQ.3.AND.IGL.EQ.9) IUN=I
		   ELSE
		     IF(IG.EQ.27) IUN=I
                  END IF
	       END IF
	       IF(NQ.EQ.4) THEN
	          IF(IG.EQ.JU(IPRF)) THEN
	             IF(IG.EQ.9.OR.IG.EQ.15.OR.IG.EQ.21) IUN=I
	             IF(IG.EQ.3.AND.IGL.EQ.9) IUN=I
		   ELSE
		     IF(IG.EQ.48) IUN=I
                  END IF
	       END IF
	       IF(IG.EQ.75) IUN=I
	       IF(IG.EQ.108.OR.IG.EQ.147.OR.IG.EQ.192) IUN=I
	       IF(IG.EQ.243.OR.IG.EQ.300.OR.IG.EQ.363) IUN=I
	    END IF
	    IF(NQ.EQ.2.AND.IG.EQ.16) IUN=I
	    IF(NQ.EQ.3.AND.IG.EQ.36) IUN=I
	    IF(NQ.EQ.4.AND.IG.EQ.64) IUN=I
	    IF(NQ.EQ.5.AND.IG.EQ.100) IUN=I
	    IF(NQ.EQ.6.AND.IG.EQ.144) IUN=I
	    IF(NQ.EQ.7.AND.IG.EQ.196) IUN=I
	    IF(NQ.EQ.8.AND.IG.EQ.256) IUN=I
	    IF(NQ.EQ.9.AND.IG.EQ.324) IUN=I
	    IF(NQ.EQ.10.AND.IG.EQ.400) IUN=I
	 END IF 
   10 CONTINUE
      print *, 'il,iprof,ilw,iupn',il,iprf,ilw,iun
      ILWN=ILW
      IUPN=IUN
C
C ******* He II ***********
C
   20 IF(ION.NE.2.OR.IELHE2.LE.0) RETURN 
      N0I=NFIRST(IELHE2)
      NLHE2=NLAST(IELHE2)-N0I+1
      XL=SQRT(1./(1.-EXCL/438916.146))
      ILW=INT(XL)
      IF((FLOAT(ILW)-XL).LT.0.) ILW=ILW+1
      XU=SQRT(1./(1.-EXCU/438916.146))
      IUN=INT(XU)
      IF((FLOAT(IUN)-XU).LT.0.) IUN=IUN+1
      IF(ILW.LE.NLHE2) ILWN=ILW+N0I-1
      IF(IUN.LE.NLHE2) IUPN=IUN+N0I-1
      RETURN
      END
C
C
C ********************************************************************
C
      SUBROUTINE INISET
C     =================
C
C     SELECTION OF LINES THAT MAY CONTRIBUTE,
C     SET UP AUXILIARY FIELDS CONTAINING LINE PARAMETERS,
C     SET UP THE SET OF FREQUENCY POINTS
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INCLUDE 'LINDAT.FOR'
      COMMON/LIMPAR/ALAM0,ALAM1,FRMIN,FRLAST,FRLI0,FRLIM
      COMMON/BLAPAR/RELOP,SPACE0,CUTOF0,TSTD,DSTD,ALAMC
      COMMON/LBLANK/IBLANK,NBLANK
      COMMON/HE2PAR/IFHE2,IHE2L,ILWHE2,MHE10,MHE20
      COMMON/LICNTR/DFRCON,IJCNTR(MLIN)
      COMMON/NXTINI/ALM00,ALST00,NXTSET,INLIST
      COMMON/CTRFUN/CINT1(MDEPTH),CINT2(MDEPTH),
     *   CTRI(MDEPTH),CTRR(MDEPTH),XKAR(MDEPTH),
     *   ABXLI(MFREQ),EMXLI(MFREQ),IJCTR(MFREQ)
      SAVE ILLAST
C
      DATA CNM /2.997925D17/
      DATA C1,C2,C3 /2.3025851, 4.2014672, 1.4387886/
C
      DO 10 I=1,MFREQ
         W(I)=0.
         IJCTR(I)=0
   10 CONTINUE
C
      IJ=3
      IL0=0
      IPRSET=0
      NLIN=0
      IREADP=1
      IF(IBLANK.LE.1.OR.IMODE.EQ.1.OR.IMODE.EQ.-1) IREADP=0
      IF(IBLANK.LE.1) APREV=0.
      FRMIN=CNM/ALAM0
      FRM=FRMIN
      FREQ(3)=FRM
      SPACE=SPACE0
      IF(ALAMC.GT.0.) SPACE=SPACE0*ALAM0/ALAMC
      IF(SPACE0.LT.0.) SPACE=-SPACE0
      IF(IMODE.EQ.2) THEN
         NFRP=MFREQ+1
         W0=SPACE
         GO TO 105
      END IF
C
      ISTR=0
      IJMAX=0
      IMOD1L=0
      CUTOFF=CUTOF0
      DOPSTD=1.E7/ALAM0*DSTD
      DISTAN=0.15*DOPSTD
      SPAC=3.E16/ALAM0/ALAM0*SPACE
      DISTA0=0.14*SPAC
      IF(IBLANK.GE.2.AND.IMODE.EQ.-1) IL0=ILLAST
      FRLI0=FRMIN
      ASTD=0.01
      AVAB=ABSTD(IDSTD)*RELOP
C
   20 CONTINUE 
C
C     set up indices of lines
C     IL0 - is the current index of line in the numbering of all lines
C
      IF(IREADP.EQ.1) THEN
         IPRSET=IPRSET+1
         IL0=INDLIP(IPRSET)
         IF(FREQ0(IL0).LT.FRMIN) THEN
            IREADP=0
            IL0=INDLIP(IPRSET-1)+1
         END IF
       ELSE
         IL0=IL0+1
      END IF
      IF(IL0.GT.NLIN0) GO TO 210
      FRLIM=FRLI0
      FR0=FREQ0(IL0)
      ALAM=CNM/FR0
C
C     set up a different starting wavelength for IMODE=1
C
      IF(IMODE.NE.1) GO TO 45
      IF(ISTR.EQ.1.OR.IJ.NE.3) GO TO 45
      IF(ALAM.LT.ALAM0+2.*CUTOFF) GO TO 45
      ALAM0=ALAM-CUTOFF+0.0001
      FRMIN=CNM/ALAM0
      FRM=FRMIN
      IJ=3
      FREQ(3)=FRM
   45 CONTINUE
      IF(ALAM.LT.ALAM0-CUTOFF) GO TO 20
      IF(IJ.LT.MFREQ+1) GO TO 50
      IF(ALAM.GT.ALAM1+CUTOFF) GO TO 210
C
C     SECOND SELECTION : FOR LINE STRENGHTS
C
   50 CONTINUE
      ISTR=0
      IF(IMODE.GE.1) THEN
   	 ISTR=1
       ELSE
         EXT=EXTIN(IL0)
         FRLI0=FR0-EXT-SPAC
         IF(FRLI0.GT.FRLIM) FRLI0=FRLIM
         IF(ALAM.LT.ALAM0.AND.FR0-FRMIN.GT.EXT+SPAC) GO TO 20
         ISTR=1
         IF(IJ.GE.MFREQ+1.AND.FRMAX-FR0.GT.EXT+SPAC) GO TO 20
      END IF
C
      NLIN=NLIN+1
      if(nlin.gt.mlin) call quit(' too many lines in a set')
      INDLIN(NLIN)=IL0
      ALAMCU=ALAM+CUTOFF
C
C     FREQUENCY POINTS AND WEIGHTS
C
      IF(IJ.GE.MFREQ+1) GO TO 20
      IF(FR0.GT.FRMIN) GO TO 20
  100 DELT=ABS(FRM-FR0)
      IF(DELT.LT.DISTA0.AND.IMODE.NE.1) GO TO 20
      DFREL=CNM*(1.D0/FR0-1.D0/FRM)/SPACE
      NFRP=DFREL+1
      IF(NFRP.LE.2) NFRP=2
      W0=CNM*(1.D0/FR0-1.D0/FRM)/NFRP
      if(space0.lt.0) w0=-space0
      FRM=FR0
  105 FRACT=FREQ(IJ)
      ALACT=CNM/FRACT
C
      DO 110 K=1,NFRP
         FRACT=FRACT-W0
         ALACT=ALACT+W0
         IF(IMODE.GE.1.OR.NFRP.EQ.2) GO TO 107
         IF(FRACT.LT.FRLIM.AND.FRACT.GT.FR0+EXT+SPAC) GO TO 110
  107    IJ=IJ+1
         IF(IJ.GT.MFREQ) GO TO 130
	 FREQ(IJ)=CNM/ALACT
         W(IJ)=W(IJ)+(FREQ(IJ-1)-FREQ(IJ))*0.5
         W(IJ-1)=W(IJ-1)+(FREQ(IJ-1)-FREQ(IJ))*0.5
C        IF(FREQ(IJ).LT.FRLAST) GO TO 220
         IF(IMODE.EQ.1.AND.ALACT.GT.ALAMCU) GO TO 140
  110 CONTINUE
      IJCTR(IJ)=IL0
      IF(IMOD1L.EQ.1) GO TO 210
      DISTA0=DISTAN
      GO TO 20
C
  130 FRMAX=FREQ(MFREQ)
      ALAM1=CNM/FRMAX
      NFREQ=MFREQ
      IF(IMODE.EQ.2) GO TO 210
      IF(IMOD1L.EQ.1) GO TO 210
      GO TO 20
C
  140 IJMAX=IJ
      IJMAX=MIN(IJMAX,MFREQ)
      NFREQ=IJMAX
      IF(IL0.LT.NLIN0) THEN
         NBLANK=IBLANK+1
       ELSE
         NBLANK=IBLANK
      END IF
      GO TO 240
C
  210 NBLANK=IBLANK+1
      IF(IJ.GE.MFREQ+1) GO TO 230
  220 IJMAX=IJ
      IJMAX=MIN(IJMAX,MFREQ)
      NFREQ=IJMAX
      IF(IMODE.NE.1) GO TO 240
      IF(IMOD1L.EQ.1) GO TO 240
C     FR0=MAX(CNM/(ALAM+CUTOFF),FRLAST*0.99999999D0)
      FR0=FRLAST*0.99999999D0
      ALAM=CNM/FR0
      IMOD1L=1
      GO TO 100
C
  230 IJMAX=MFREQ
      NFREQ=MFREQ
  240 IF(FREQ(IJMAX).LE.FRLAST) NBLANK=IBLANK
      FREQ(1)=FREQ(3)
      FREQ(2)=FREQ(IJMAX)
      W(1)=0.5*(FREQ(1)-FREQ(2))
      W(2)=W(1)
C
C     truncate the interval if the required end is reached
C
      IF(FREQ(2).LT.FRLAST) THEN
         FREQ(2)=FRLAST
         W(1)=0.5*(FREQ(1)-FREQ(2))
         W(2)=W(1)
         DO 245 IJ=3,NFREQ
            IF(FREQ(IJ).LT.FRLAST) GO TO 247
            IJMAX=IJ
  245    CONTINUE
  247    NFREQ=IJMAX+1
         FREQ(NFREQ)=FRLAST
         W(NFREQ)=0.5*(FREQ(NFREQ-1)-FREQ(NFREQ))
         W(NFREQ-1)=W(NFREQ)+0.5*(FREQ(NFREQ-2)-FREQ(NFREQ-1))
      END IF
C
C     frequency interpolation coefficients
C
      IF(IMODE.NE.-1) THEN
      XX=FREQ(2)-FREQ(1)
      DO 250 IJ=1,NFREQ
         WLAM(IJ)=2.997925E18/FREQ(IJ)
         FRX1(IJ)=(FREQ(IJ)-FREQ(1))/XX
         FRX2(IJ)=(FREQ(2)-FREQ(IJ))/XX
  250 CONTINUE
c
c     frequency indices of the line centers
c
      DFRCON=NFREQ-3
      DFRCON=-DFRCON/XX
      IFRCON=DFRCON
      DO 255 IL=1,NLIN
         fr0=freq0(indlin(il))
         XJC=3.+DFRCON*(FREQ(1)-FR0)
         IJC=XJC
         IJCNTR(IL)=IJC
         if(ijc.le.3.or.ijc.ge.nfreq) go to 255
         if(fr0.lt.freq(ijc)) then
            ijc0=ijc
            dfr0=freq(ijc0)-fr0
  252       ijc0=ijc0+1
            dfr=abs(freq(ijc0)-fr0)
            if(dfr.lt.dfr0) then
               ijc=ijc0
               ijc0=ijc0+1
               dfr0=dfr
               go to 252
            end if
          else if(fr0.gt.freq(ijc)) then
            ijc0=ijc
            dfr0=fr0-freq(ijc0)
  254       ijc0=ijc0-1
            dfr=abs(freq(ijc0)-fr0)
            if(dfr.lt.dfr0) then
               ijc=ijc0
               ijc0=ijc0-1
               dfr0=dfr
               go to 254
            end if
         end if
         IJCNTR(IL)=IJC
  255 continue
      END IF
C
      NSP=0
      DO 260 IL=1,NLIN
         IL0=INDLIN(IL)
         ISP=ISPRF(IL0)
         IF(ISP.GT.5) THEN
            NSP=NSP+1
            ISP0(NSP)=ISP
         END IF
         INDLIP(IL)=INDLIN(IL)
  260 CONTINUE
      illast=0
      if(nlin.gt.0) ILLAST=INDLIN(NLIN)
C
      CALL READPH
C
      IF(ALAM0.LE.APREV+0.001) NBLANK=IBLANK
      APREV=ALAM0
      ALAM0=ALAM1
      ALM00=CNM/FREQ(NFREQ)
      RETURN
      END
C
C ********************************************************************
C
C
      SUBROUTINE READPH
C     =================
C
C     Auxiliary routine for LINSET - read table of detailed
C     photoinization cross-section from unit IPHT1, 
C     and interpolate to the set of current wavelengths (WLAM)
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INCLUDE 'LINDAT.FOR'
      COMMON/LBLANK/IBLANK,NBLANK
      COMMON/PHOTCS/PHOT(MFREQ,MPHOT),WPHT0,WPHT1,APHT(MPHOT),
     *              EPHT(MPHOT),GPHT(MPHOT),JPHT(MPHOT),
     *              NPHT
      DIMENSION PHT0(MPHOT),PHT1(MPHOT),IPHT(MPHOT),IEND(MPHOT),
     *          IFILE(MPHOT),NELEM(MPHOT),INDEX(MPHOT,MPHOT)
      PARAMETER (IPHT0=57)
      SAVE IPHT,IEND,NELEM,INDEX,NUMFIL
C
C     initialization - read basic information about files where the
C                      cross-sections are stored, 
C                      and basic parameters for starting levels
C
      IF(IBLANK.LE.1) THEN
         NPHT=0
         IPHT1=0
         NUMFIL=0
         DO 10 IJ=1,MFREQ
            DO 10 I=1,MPHOT
   10          PHOT(IJ,I)=0.
         READ(IPHT0,*,END=50,err=50) NPHT
         IF(NPHT.LE.0) RETURN
         npht1=npht
         READ(IPHT0,*,END=50) (IPHT(I),I=1,NPHT)
         READ(IPHT0,*,END=50) (APHT(I),I=1,NPHT)
         READ(IPHT0,*,END=50) (EPHT(I),I=1,NPHT)
         READ(IPHT0,*,END=50) (GPHT(I),I=1,NPHT)
         READ(IPHT0,*,END=50) (JPHT(I),I=1,NPHT)
C
C     determination of the number of files (NFILE) and the
C     partitioning of the individual cross-section to the corresponding
C     files
C
         NUMFIL=1
         IFILE(1)=1
         NELEM(1)=1
         INDEX(1,1)=1
         IF(NPHT.GT.1) THEN
            DO 30 I=2,NPHT
               DO 20 J=1,I-1
                  IF(IPHT(I).EQ.IPHT(J)) THEN
                     IFILE(I)=IFILE(J)
                     NELEM(IFILE(I))=NELEM(IFILE(I))+1
                     INDEX(IFILE(I),NELEM(IFILE(I)))=I
                     GO TO 30
                  END IF
   20          CONTINUE
               NUMFIL=NUMFIL+1
               IFILE(I)=NUMFIL
               NELEM(NUMFIL)=1
               INDEX(NUMFIL,1)=I
   30       CONTINUE
         END IF
         DO 40 IFIL=1,NUMFIL
            IEND(IFIL)=0
   40    CONTINUE
      END IF
   50 IF(NUMFIL.LE.0) RETURN
c
C     loop over individual files containing the photoionization data
C
      DO 300 IFIL=1,NUMFIL
         IF(IEND(IFIL).EQ.1) GO TO 200
         IF(IEND(IFIL).EQ.2) GO TO 300
         NPHT1=NELEM(IFIL)
         IPHT1=IPHT(INDEX(IFIL,1))
         IF(IBLANK.LE.1) THEN
  110       READ(IPHT1,*,END=200) WPHT1,(PHT1(I),I=1,NPHT1)
            IF(WPHT1.LT.WLAM(1)) GO TO 110
            BACKSPACE(IPHT1)
            BACKSPACE(IPHT1)
            READ(IPHT1,*,END=200) WPHT0,(PHT0(I),I=1,NPHT1)
          ELSE
            BACKSPACE(IPHT1)
            BACKSPACE(IPHT1)
            READ(IPHT1,*,END=200) WPHT0,(PHT0(I),I=1,NPHT1)
            READ(IPHT1,*,END=200) WPHT1,(PHT1(I),I=1,NPHT1)
         END IF
         DW=WPHT1-WPHT0
         A1=(WPHT1-WLAM(3))/DW
         A2=(WLAM(3)-WPHT0)/DW
         DO 130 I=1,NPHT1
            INDX=INDEX(IFIL,I)
            PHOT(1,INDX)=0.
            PHOT(2,INDX)=0.
            PHOT(3,INDX)=(A1*PHT0(I)+A2*PHT1(I))*1.E-18
            DO 130 IJ=4,MFREQ
               PHOT(IJ,INDX)=0.
  130    CONTINUE
         DO 190 IJ=4,MFREQ
            IF(WLAM(IJ).LE.WPHT1) THEN
               A1=(WPHT1-WLAM(IJ))/DW
               A2=(WLAM(IJ)-WPHT0)/DW
               DO 140 I=1,NPHT1
                  INDX=INDEX(IFIL,I)
                  PHOT(IJ,INDX)=(A1*PHT0(I)+A2*PHT1(I))*1.E-18
  140          CONTINUE
             ELSE
               WPHT0=WPHT1
               DO 150 I=1,NPHT1
  150             PHT0(I)=PHT1(I)
               IFSML=0
  160          READ(IPHT1,*,END=180) WPHT1,(PHT1(I),I=1,NPHT1)
               IF(WPHT1.LT.WLAM(IJ)) THEN
                  IFSML=1
                  GO TO 160
               END IF
               IF(IFSML.EQ.1) THEN
                  BACKSPACE(IPHT1)           
                  BACKSPACE(IPHT1)           
                  READ(IPHT1,*,END=180) WPHT0,(PHT0(I),I=1,NPHT1)
                  READ(IPHT1,*,END=180) WPHT1,(PHT1(I),I=1,NPHT1)
               END IF
               DW=WPHT1-WPHT0
               A1=(WPHT1-WLAM(IJ))/DW
               A2=(WLAM(IJ)-WPHT0)/DW
               DO 170 I=1,NPHT1
                  INDX=INDEX(IFIL,I)
                  PHOT(IJ,INDX)=(A1*PHT0(I)+A2*PHT1(I))*1.E-18
  170          CONTINUE
            END IF
            GO TO 190
  180       IEND(IFIL)=1      
            DO 185 I=1,NPHT1
               INDX=INDEX(IFIL,I)
               PHOT(IJ,INDX)=0.
  185       CONTINUE
  190    CONTINUE
         PHOT(1,INDX)=PHOT(3,INDX)
         PHOT(2,INDX)=PHOT(MFREQ,INDX)
         GO TO 300
  200    IEND(IFIL)=2
         DO 210 IJ=1,MFREQ
            DO 210 I=1,NELEM(IFIL)
               INDX=INDEX(IFIL,I)
               PHOT(IJ,INDX)=0.
  210    CONTINUE
  300 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
C
      SUBROUTINE INILIN
C     =================
C
C     read in the input line list,
C     selection of lines that may contribute,
C     set up auxiliary fields containing line parameters,
C
C     Input of line data - unit 19:
C
C     For each line, one (or two) records, containing:
C
C    ALAM    - wavelength (in nm)
C    ANUM    - code of the element and ion (as in Kurucz-Peytremann)
C              (eg. 2.00 = HeI; 26.00 = FeI; 26.01 = FeII; 6.03 = C IV)
C    GF      - log gf
C    EXCL    - excitation potential of the lower level (in cm*-1)
C    QL      - the J quantum number of the lower level
C    EXCU    - excitation potential of the upper level (in cm*-1)
C    QU      - the J quantum number of the upper level
C    AGAM    = 0. - radiation damping taken classical
C            > 0. - the value of Gamma(rad)
C
C     There are now two possibilities, called NEW and OLD, of the next
C     parameters:
C     a) NEW, next parameters are:
C    GS      = 0. - Stark broadening taken classical
C            > 0. - value of log gamma(Stark)
C    GW      = 0. - Van der Waals broadening taken classical
C            > 0. - value of log gamma(VdW)
C    INEXT   = 0  - no other record necessary for a given line
C            > 0  - next record is read, which contains:
C    WGR1,WGR2,WGR3,WGR4 - Stark broadening values from Griem (in Angst)
C                   for T=5000,10000,20000,40000 K, respectively;
C                   and n(el)=1e16 for neutrals, =1e17 for ions.
C    ILWN    = 0  - line taken in LTE (default)
C            > 0  - line taken in NLTE, ILWN is then index of the
C                   lower level
C            =-1  - line taken in approx. NLTE, with Doppler K2 function
C            =-2  - line taken in approx. NLTE, with Lorentz K2 function
C    IUN     = 0  - population of the upper level in LTE (default)
C            > 0  - index of the lower level
C    IPRF    = 0  - Stark broadening determined by GS
C            < 0  - Stark broadening determined by WGR1 - WGR4
C            > 0  - index for a special evaluation of the Stark
C                   broadening (in the present version inly for He I -
C                   see procedure GAMHE)
C      b) OLD, next parameters are
C     IPRF,ILWN,IUN - the same meaning as above
C     next record with WGR1-WGR4 - again the same meaning as above
C     (this record is automatically read if IPRF<0
C
C     The only differences between NEW and OLD is the occurence of
C     GS and GW in NEW, and slightly different format of reading.
C
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INCLUDE 'LINDAT.FOR'
      COMMON/LIMPAR/ALAM0,ALAM1,FRMIN,FRLAST,FRLI0,FRLIM
      COMMON/BLAPAR/RELOP,SPACE0,CUTOF0,TSTD,DSTD,ALAMC
      COMMON/HHEPRF/IHYDPR,IHE1PR,IHE2PR
      COMMON/LBLANK/IBLANK,NBLANK
      COMMON/HE2PAR/IFHE2,IHE2L,ILWHE2,MHE10,MHE20
      COMMON/NXTINI/ALM00,ALST00,NXTSET,INLIST
C
      PARAMETER (C1     = 2.3025851,
     *           C2     = 4.2014672,
     *           C3     = 1.4387886,
     *           CNM    = 2.997925D17,
     *           ANUMIN = 1.9,
     *           ANUMAX = 30.41,
     *           AHE2   = 2.01,
     *           EXT0   = 3.17,
     *           UN     = 1.0,
     *           TEN    = 10.,
     *           HUND   = 1.D2,
     *           TENM4  = 1.D-4,
     *           TENM8  = 1.D-8,
     *           OP4    = 0.4,
     *           AGR0=2.4734E-22, 
     *           XEH=13.595, XET=8067.6, XNF=25.,
     *           R02=2.5, R12=45., VW0=4.5E-9)
      DATA INLSET /0/
C
      IL=0
      INNLT0=0
      IGRIE0=0
      IF(NXTSET.EQ.1) THEN
          ALAM0=ALM00
          ALAST=ALST00
          FRLAST=CNM/ALAST
          NXTSET=0
          REWIND 19
      END IF
      ALAM00=ALAM0
      ALAST=CNM/FRLAST
      ALAST0=ALAST
      DOPSTD=1.E7/ALAM0*DSTD
      DOPLAM=ALAM0*ALAM0/CNM*DOPSTD
      AVAB=ABSTD(IDSTD)*RELOP
      ASTD=0.01
      IF(GRAV.GT.6.) ASTD=0.1
      CUTOFF=CUTOF0
      ALAST=CNM/FRLAST
      IF(INLTE.GE.1.AND.INLSET.EQ.0) THEN
         CALL NLTSET(0,IL,IAT,ION,EXCL,EXCU,QL,QU,IEVEN,INNLT0)
         INLSET=1
      END IF
C
C     first part of reading line list - read only lambda, and
C     skip all lines with wavelength below ALAM0-CUTOFF
C
      ALAM=0.
    7 READ(19,510) ALAM
  510 FORMAT(F10.4)
      IF(ALAM.LT.ALAM0-CUTOFF) GO TO 7
      BACKSPACE(19)
      GO TO 10
c
    8 write(6,688) alam
  688 format(' error in line list, lambda= ',f12.4/)
   10 ILWN=0
      IUN=0
      IPRF=0
      GS=0.
      GW=0.
      IF(INLIST.EQ.0) THEN
         READ(19,*,END=100,err=8) ALAM,ANUM,GF,EXCL,QL,EXCU,QU,AGAM,
     *                        GS,GW,INEXT
         IF(INEXT.NE.0) READ(19,*) WGR1,WGR2,WGR3,WGR4,ILWN,IUN,IPRF
       ELSE IF(INLIST.EQ.1) THEN
         READ(19,511,END=100) ALAM,ANUM,GF,EXCL,QL,EXCU,QU,AGAM,
     *                        IPRF,ILWN,IUN
         IF(IPRF.LT.0) READ(19,*) WGR1,WGR2,WGR3,WGR4
  511    FORMAT(F10.4,2F6.2,F11.3,F4.1,F12.3,F4.1,E10.3,3I3)
       ELSE IF(INLIST.EQ.2) THEN
         READ(19,521,END=100) ALAM,GF,ANUM,EXCL,QL,XLBL,EXCU,QU
  521    FORMAT(F10.4,F7.3,F6.2,F11.3,F5.1,A11,F11.3,F5.1)
         AGAM=0.
      END IF
C
C     first selection : for a given interval a atomic number
C
      IF(ALAM.GT.ALAST+CUTOFF) GO TO 100
      IF(ANUM.LT.ANUMIN.OR.ANUM.GT.ANUMAX) GO TO 10
      IF(ABS(ANUM-AHE2).LT.TENM4.AND.IFHE2.GT.0) GO TO 10
C
C     second selection : for line strenghts
C
      FR0=CNM/ALAM
      IAT=ANUM
      FRA=(ANUM-FLOAT(IAT)+TENM4)*HUND
      ION=INT(FRA)+1
      IF(ION.GT.IONIZ(IAT)) GO TO 10
      IEVEN=1
      EXCL=ABS(EXCL)
      EXCU=ABS(EXCU)
      IF(EXCL.GT.EXCU) THEN
         FRA=EXCL
         EXCL=EXCU
         EXCU=FRA
         FRA=QL
         QL=QU
         QU=FRA
         IEVEN=0
      END IF
      GFP=C1*GF-C2
      EPP=C3*EXCL
      gx=gfp-epp/tstd
      ab0=0.
      if(gx.gt.-30)
     *  AB0=EXP(GFP-EPP/TSTD)*RRR(IDSTD,ION,IAT)/DOPSTD/AVAB
      IF(AB0.LT.UN) GO TO 10
C
C     truncate line list if there are more lines than maximum allowable
C     (given by MLIN0 - see include file LINDAT.FOR)
C
      IL=IL+1
      IF(IL.GT.MLIN0) THEN
         WRITE(6,601) ALAM
         IL=MLIN0
         ALAST=CNM/FREQ0(IL)-CUTOFF
         FRLAST=CNM/ALAST
         NXTSET=1
         GO TO 100
      END IF
C
C     =============================================
C     line is selected, set up necessary parameters
C     =============================================
C
C     evaluation of EXTIN0 - the distance (in delta frequency) where
C     the line is supposed to contribute to the total opacity
C
      IF(IAT.LE.2) THEN
         EXT=SQRT(10.*AB0)
       ELSE IF(IAT.LE.14) THEN
         EX0=AB0*ASTD*10.
         EXT=EXT0
         IF(EX0.GT.TEN) EXT=SQRT(EX0)
       ELSE 
         EX0=AB0*ASTD
         EXT=EXT0
         IF(EX0.GT.TEN) EXT=SQRT(EX0)
      END IF
      EXTIN0=EXT*DOPSTD
C
C     store parameters for selected lines
C
      FREQ0(IL)=FR0
      EXCL0(IL)=EPP
      EXCU0(IL)=EXCU*C3
      GF0(IL)=GFP
      EXTIN(IL)=EXTIN0
      INDAT(IL)=100*IAT+ION
C
C     ****** line broadening parameters *****
C
C     1) natural broadening
C
      IF(AGAM.GT.0.) THEN
         GAMR0(IL)=EXP(C1*AGAM)
       ELSE
         GAMR0(IL)=AGR0*FR0*FR0
      END IF
C
C     if Stark or Van der Waals broadenig assumed classical,
C     evaluate the effective quantum number
C
      IF(GS.EQ.0..OR.GW.EQ.0) THEN
         Z=FLOAT(ION)
         XNEFF2=Z**2*(XEH/(ENEV(IAT,ION)-EXCU/XET))
         IF(XNEFF2.LE.0..OR.XNEFF2.GT.XNF) XNEFF2=XNF
      END IF
C
C     2) Stark broadening
C
      IF(GS.NE.0.) THEN
         GS0(IL)=EXP(C1*GS)
       ELSE
         GS0(IL)=TENM8*XNEFF2*XNEFF2*SQRT(XNEFF2)
      END IF
C
C     3) Van der Waals broadening
C
      IF(GW.NE.0.) THEN
         GW0(IL)=EXP(C1*GW)
       ELSE
         IF(IAT.LT.21) THEN
            R2=R02*(XNEFF2/Z)**2
          ELSE 
            R2=(R12-FLOAT(IAT))/Z
         END IF
         GW0(IL)=VW0*R2**OP4
      END IF
C
C     4) parameters for a special profile evaluation:
C
C     a) special He I and He II line broadening parameters
C
      ISPRFF=0
      IF(IAT.LE.2) ISPRFF=ISPEC(IAT,ION,ALAM)
      IF(IAT.EQ.2) CALL HESET(IL,ALAM,EXCL,EXCU,ION,IPRF,ILWN,IUN)
      ISPRF(IL)=ISPRFF
      IPRF0(IL)=IPRF
C
C     b) parameters for Griem values of Stark broadening
C
      IF(IPRF.LT.0) THEN
         IGRIE0=IGRIE0+1
         IGRIEM(IL)=IGRIE0
         IF(IGRIE0.GT.MGRIEM) THEN
            WRITE(6,603) ALAM
            GO TO 20
         END IF
         WGR0(1,IGRIE0)=WGR1
         WGR0(2,IGRIE0)=WGR2
         WGR0(3,IGRIE0)=WGR3
         WGR0(4,IGRIE0)=WGR4
      END IF
   20 CONTINUE
C
C     implied NLTE option
C
      if(inlte.eq.-2.or.inlte.eq.12) then
          if(iat.le.20.and.excl.le.1000.) qu=-abs(qu)
       else if(inlte.eq.-3) then
          if(excl.le.1000.) qu=-abs(qu)
       else if(inlte.eq.-4) then
          qu=-abs(qu)
      end if
C
C     NLTE lines initialization
C
      INDNLT(IL)=0
      IF(QU.LT.0..OR.QL.LT.0.) THEN
         ILWN=-1
         QU=ABS(QU)
         QL=ABS(QL)
      END IF
      IF(ILWN.LT.0.AND.INLTE.NE.0) THEN
         INNLT0=INNLT0+1
         INDNLT(IL)=INNLT0
         IF(INNLT0.GT.MNLT) THEN
            WRITE(6,604) ALAM
            GO TO 100
         END IF
         GI=2.*QL+UN
         GJ=2.*QU+UN
         CALL NLTE(IL,ILWN,IUN,GI,GJ)
         ILOWN(IL)=ILWN
         IUPN(IL)=IUN
      END IF
      IF(ILWN.GT.0.AND.INLTE.NE.0) THEN
         INNLT0=INNLT0+1
         INDNLT(IL)=INNLT0
         IF(INNLT0.GT.MNLT) THEN
            WRITE(6,604) ALAM
            GO TO 100
         END IF
         GI=2.*QL+UN
         GJ=2.*QU+UN
         CALL NLTE(IL,ILWN,IUN,GI,GJ)
         ILOWN(IL)=ILWN
         IUPN(IL)=IUN
      END IF
      IF(ILWN.EQ.0.AND.INLTE.GE.1) THEN
         CALL NLTSET(1,IL,IAT,ION,EXCL,EXCU,QL,QU,IEVEN,INNLT0)
         IF(INDNLT(IL).GT.0) THEN
            IF(INDNLT(IL).GT.MNLT) THEN
               WRITE(6,604) ALAM
               GO TO 100
            END IF
            GI=2.*QL+UN
            GJ=2.*QU+UN
            ILWN=ILOWN(IL)
            IUN=IUPN(IL)
            IF(ILWN.EQ.IUN.AND.GI.EQ.GJ) THEN
               INDNLT(IL)=0
               ILOWN(IL)=0
               IUPN(IL)=0
             ELSE
               CALL NLTE(IL,ILWN,IUN,GI,GJ)
            END IF
         END IF
      END IF
      GO TO 10
C
  100 NLIN0=IL
      NNLT=INNLT0
      NGRIEM=IGRIE0
      ALM1=CNM/FREQ0(1)
      IF(ALAM0.LT.ALM1.AND.IMODE.NE.1) THEN
         ALAM0=ALM1-4.*DOPLAM
         IF(ALAM0.LT.ALAM00) ALAM0=ALAM00
      END IF
      ALM2=CNM/FREQ0(NLIN0)
      IF(NLIN0.GT.1) ALM2=CNM/FREQ0(NLIN0-1)
      IF(ALAST.GT.ALM2.AND.IMODE.NE.1) THEN
         ALAST=ALM2-4.*DOPLAM
         IF(ALAST.GT.ALAST0) ALAST=ALAST0
         FRLAST=CNM/ALAST
      END IF
      IBLANK=0
C
      WRITE(6,611) NLIN0,NNLT,NGRIEM
  611 FORMAT(/' LINES - TOTAL        :',I10
     *       /' LINES - NLTE         :',I10
     *       /' LINES - GRIEM        :',I10/)
  601 FORMAT('0 **** MORE LINES THAN MLIN0, LINE LIST TRUNCATED '/
     *'       AT LAMBDA',F15.4,'  NM'/)
  602 FORMAT('0 **** MORE LINES WITH SPECIAL PROFILES THAN MPRF'/
     *'       FOR LINES WITH LAMBDA GREATER THAN',F15.4,'  NM'/)
  603 FORMAT('0 **** MORE LINES WITH GRIEM PROFILES THAN MGRIEM'/
     *'       FOR LINES WITH LAMBDA GREATER THAN',F15.4,'  NM'/)
  604 FORMAT('0 **** MORE LINES IN NLTE OPTION THAN MNLT'/
     *'       FOR LINES WITH LAMBDA GREATER THAN',F15.4,'  NM'/)
      RETURN
      END
C
C ********************************************************************
C
C

      SUBROUTINE INIBLA
C     =================
C
C     driving procedure for treating a partial line list for the
C     current wavelength region
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INCLUDE 'LINDAT.FOR'
      REAL*4 TYPION(30)
      COMMON/LBLANK/IBLANK,NBLANK
      COMMON/IPRNTR/IPRIN
      COMMON/PRFQUA/DOPA1(MATOM,MDEPTH),VDWC(MDEPTH)
      COMMON/HYLPAR/IHYL,ILOWH,M10,M20
C
      PARAMETER (DP0=3.33564E-11, DP1=1.651E8, 
     *           VW1=0.42, VW2=0.3, TENM4=1.E-4)
      PARAMETER (UN=1.) 
C
      IF(NLIN.EQ.0) RETURN
      XX=FREQ(1)
      IF(NFREQ.GE.2) XX=0.5*(FREQ(1)+FREQ(2))
      BNU=BN*(XX*1.E-15)**3
      HKF=HK*XX
      DO 20 ID=1,ND
         T=TEMP(ID)
         ANE=ELEC(ID)
         EXH=EXP(HKF/T)
         EXHK(ID)=UN/EXH
         PLAN(ID)=BNU/(EXH-UN)
         STIM(ID)=UN-EXHK(ID)
         if(iath.gt.0) then
            ANP=POPUL(NKH,ID)
            AH=DENS(ID)/WMM(ID)/YTOT(ID)-ANP
          else
            ah=rrr(id,1,1)
         end if
         AHE=RRR(ID,1,2)
         VDWC(ID)=(AH+VW1*AHE)*(T*TENM4)**VW2
         DO 10 IAT=1,30
            IF(AMAS(IAT).GT.0.)
     *      DOPA1(IAT,ID)=UN/(XX*DP0*SQRT(DP1*T/AMAS(IAT)+VTURB(ID)))
   10 CONTINUE
   20 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
C
      SUBROUTINE IDTAB
C     ================
C
C     output of selected line parameters (identification table)
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INCLUDE 'LINDAT.FOR'
      REAL*4 TYPION(30)
      COMMON/LBLANK/IBLANK,NBLANK
      COMMON/IPRNTR/IPRIN
      COMMON/PRFQUA/DOPA1(MATOM,MDEPTH),VDWC(MDEPTH)
      COMMON/HYLPAR/IHYL,ILOWH,M10,M20
      COMMON/LICNTR/DFRCON,IJCNTR(MLIN)
      COMMON/REFDEP/IREFD(MFREQ)
      PARAMETER (C1=2.3025851, C2=4.2014672, C3=1.4387886)
C
      DATA TYPION /4H I  ,4H II ,4H III,4H IV ,4H V  ,
     *             4H VI ,4H VII,4HVIII,4H IX ,4H X  ,
     *             4H XI ,4H XII,4HXIII,4H XIV,4H XV ,
     *             4H XVI,4HXVII,4H 18 ,4H XIX,4H XX ,
     *             4H XXI,4HXXII,4H 23 ,4HXXIV,4HXXV ,
     *             4HXXVI,4H 27 ,4H 28 ,4HXXIX,4H XXX/
      DATA APB,AP0,AP1,AP2,AP3,AP4 /4H    ,4H   .,4H   *,4H  **,4H ***,
     *                              4H****/
C
      IF(NLIN.EQ.0) GO TO 100
C
      ALM0=2.997925D18/FREQ(1)
      ALM1=2.997925D18/FREQ(2)
      IF(IMODE.GE.0) WRITE(6,601) IBLANK,ALM0,ALM1
      IF(IPRIN.LE.-2) RETURN
      if(iprin.ge.2) then
      IF(IMODE.GE.0.OR.(IMODE.EQ.-1.AND.IBLANK.EQ.1)) WRITE(6,602)
      end if
C
      DO 20 IL0=1,NLIN
         IL=INDLIN(IL0) 
         ALAM=2.997925D18/FREQ0(IL)
         ID=IDSTD
         IJCN=IJCNTR(IL0)
         IF(IJCN.GE.1.AND.IJCN.LE.MFREQ) ID0=IREFD(IJCN)
         IF(ID0.GT.0) ID=ID0
         IAT=INDAT(IL)/100
         ION=MOD(INDAT(IL),100)
         CALL PROFIL(IL,IAT,ID,AGAM)
         ABCNT=EXP(GF0(IL)-EXCL0(IL)/TEMP(ID))*RRR(ID,ION,IAT)*
     *          DOPA1(IAT,ID)*STIM(ID)
         STR0=ABCNT/ABSTD(ID)
         GF=(GF0(IL)+C2)/C1
         EXCL=EXCL0(IL)/C3
         IF(STR0.LE.1.2) THEN
            WW1=0.886*STR0*(1.-STR0*(0.707-STR0*0.577))
          ELSE 
            WW1=SQRT(LOG(STR0))
         END IF
         IF(STR0.GT.55.) THEN
            WW2=0.5*SQRT(3.14*AGAM*STR0)
            IF(WW2.GT.WW1) WW1=WW2
         END IF
         EQW=ALAM/FREQ0(IL)*1.E3/DOPA1(IAT,ID)*WW1
         STR=EQW*10.
         APR=APB
         IF(STR.GE.1.E0.AND.STR.LT.1.E1) APR=AP0
         IF(STR.GE.1.E1.AND.STR.LT.1.E2) APR=AP1
         IF(STR.GE.1.E2.AND.STR.LT.1.E3) APR=AP2
         IF(STR.GE.1.E3.AND.STR.LT.1.E4) APR=AP3
         IF(STR.GE.1.E4) APR=AP4
         if(iprin.ge.2) then
         WRITE(6,603) IL0,IL,ALAM,TYPAT(IAT),TYPION(ION),GF,EXCL,
     *                STR0,EQW,APR,ilown(il),iupn(il),id
         end if
         if(alam.ge.alm0.and.alam.lt.alm1) then
         WRITE(12,603) IL0,IL,ALAM,TYPAT(IAT),TYPION(ION),GF,EXCL,
     *                 STR0,EQW,APR,ilown(il),iupn(il),id
         end if
   20 CONTINUE
C
  601 FORMAT(/' ',I4,'. SET:',
     * ' INTERVAL  ',F9.3,' -',F9.3,' ANGSTROMS'/
     *        ' ------------')
  602 FORMAT(/1H ,13X,
     * 'LAMBDA    ATOM    LOG GF       ELO    LINE/CONT',2X,
     * 'EQ.WIDTH'/)
  603 FORMAT(1H ,I3,I7,F10.3,2X,2A4,F7.2,F12.3,1PE11.2,0PF8.1,1X,A4,
     *       4i3)
C
  100 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
C
      SUBROUTINE INIBLH
C     =================
C
C     output information about hydrogen lines
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INCLUDE 'LINDAT.FOR'
      REAL*4 TYPION(30)
      COMMON/LBLANK/IBLANK,NBLANK
      COMMON/IPRNTR/IPRIN
      COMMON/PRFQUA/DOPA1(MATOM,MDEPTH),VDWC(MDEPTH)
      COMMON/HYLPAR/IHYL,ILOWH,M10,M20
C
      PARAMETER (C1=2.3025851, C2=4.2014672, C3=1.4387886)
      PARAMETER (DP0=3.33564E-11, DP1=1.651E8, 
     *           VW1=0.42, VW2=0.3, TENM4=1.E-4)
      PARAMETER (UN=1.) 
      DATA TYPION /4H I  ,4H II ,4H III,4H IV ,4H V  ,
     *             4H VI ,4H VII,4HVIII,4H IX ,4H X  ,
     *             4H XI ,4H XII,4HXIII,4H XIV,4H XV ,
     *             4H XVI,4HXVII,4H 18 ,4H XIX,4H XX ,
     *             4H XXI,4HXXII,4H 23 ,4HXXIV,4HXXV ,
     *             4HXXVI,4H 27 ,4H 28 ,4HXXIX,4H XXX/
      DATA APB,AP0,AP1,AP2,AP3,AP4 /4H    ,4H   .,4H   *,4H  **,4H ***,
     *                              4H****/
C
      ALM0=2.997925D18/FREQ(1)
      ALM1=2.997925D18/FREQ(2)
      XX=FREQ(1)
      IF(NFREQ.GE.2) XX=0.5*(FREQ(1)+FREQ(2))
      BNU=BN*(XX*1.E-15)**3
      HKF=HK*XX
      IF(IMODE.GE.0) WRITE(6,601) IBLANK,ALM0,ALM1
      IF(IPRIN.LE.-2) RETURN
      if(iprin.ge.2) then
      IF(IMODE.GE.0.OR.(IMODE.EQ.-1.AND.IBLANK.EQ.1)) WRITE(6,602)
      end if
C
      IF(IHYL.LT.0) go to 200
      IAT=1
      ION=1
      IZZ=1
      ID=IDSTD
         T=TEMP(ID)
         ANE=ELEC(ID)
         EXH=EXP(HKF/T)
         EXHK(ID)=UN/EXH
         PLAN(ID)=BNU/(EXH-UN)
         STIM(ID)=UN-EXHK(ID)
         DOPA1(IAT,ID)=UN/(XX*DP0*SQRT(DP1*T/AMAS(IAT)+VTURB(ID)))
      ISERL=ILOWH
      ISERU=ILOWH
      IF(alm0.GT.17000..AND.alm1.LT.21000.) THEN
         ISERL=3
         ISERU=4
       ELSE IF(alm0.GT.22700.) THEN
         ISERL=4
         ISERU=5
         IF(alm0.GT.32800.) ISERU=6
         IF(alm0.GT.44660.) ISERU=7
      END IF
C
      DO 130 I=ISERL,ISERU
      II=I*I
      XII=UN/II
      M1=M10
      IF(I.LT.ILOWH) M1=ILOWH-1
      M2=M1+1
      IF(M1.LT.I+1) M1=I+1
      IF(grav.lt.3..and.M1.LE.6.AND.I.EQ.2) GO TO 110
      IF(grav.lt.3..and.M1.LE.4.AND.I.EQ.1) GO TO 110
      M1=M1-1
      M2=M20+3
      IF(M1.LT.I+1) M1=I+1
  110 CONTINUE
      if(grav.gt.3.) then
         m2=m2+5
         m1=m1-3
         if(m1.gt.i+6) m1=m1-3 
      end if
      if(grav.gt.6.) then
         m2=m2+2
         m1=m1-1
         if(m1.gt.i+6) m1=m1-1 
      end if
      IF(M1.LT.I+1) M1=I+1
      IF(M2.GT.20) M2=20
      ILINH=0
      DO 120 J=M2,M1,-1
         CALL STARK0(I,J,izz,XKIJ,WL0,FIJ,FIJ0)
         ALAM=WL0
C        if(alam.LT.alm0.OR.alam.GE.alm1) then
         if(alam.ge.alm0.and.alam.lt.alm1) then
         ILINH=ILINH+1
         GH=2.*II
         GF=LOG10(FIJ*GH)
         EXCL=109679.*(1.-XII)
         EXCL0H=EXCL*C3
         GF0H=GF*C1-C2
         ABCNT=EXP(GF0H-EXCL0H/TEMP(ID))*RRR(ID,ION,IAT)*
     *          DOPA1(IAT,ID)*STIM(ID)
         STR0=ABCNT/ABSTD(ID)
         IF(STR0.LE.1.2) THEN
            WW1=0.886*STR0*(1.-STR0*(0.707-STR0*0.577))
          ELSE 
            WW1=SQRT(LOG(STR0))
         END IF
         IF(STR0.GT.55.) THEN
            agam=0.01
            WW2=0.5*SQRT(3.14*AGAM*STR0)
            IF(WW2.GT.WW1) WW1=WW2
         END IF
         EQW=ALAM*ALAM/3.E18*1.E3/DOPA1(IAT,ID)*WW1
         STR=EQW*10.
         APR=APB
         IF(STR.GE.1.E0.AND.STR.LT.1.E1) APR=AP0
         IF(STR.GE.1.E1.AND.STR.LT.1.E2) APR=AP1
         IF(STR.GE.1.E2.AND.STR.LT.1.E3) APR=AP2
         IF(STR.GE.1.E3.AND.STR.LT.1.E4) APR=AP3
         IF(STR.GE.1.E4) APR=AP4
         if(iprin.ge.2) then
         WRITE(6,603) i,ilinh,ALAM,TYPAT(IAT),TYPION(ION),GF,EXCL,
     *                STR0,EQW,APR,i,j
         end if
         WRITE(14,603) i,ilinh,ALAM,TYPAT(IAT),TYPION(ION),GF,EXCL,
     *                 STR0,EQW,APR,i,j
         end if
  120    continue
  130 continue
  200 continue
C
  601 FORMAT(/' ',I4,'. SET:',
     * ' INTERVAL  ',F9.3,' -',F9.3,' ANGSTROMS'/
     *        ' ------------')
  602 FORMAT(/1H ,13X,
     * 'LAMBDA    ATOM    LOG GF       ELO    LINE/CONT',2X,
     * 'EQ.WIDTH'/)
  603 FORMAT(1H ,I3,I7,F10.3,2X,2A4,F7.2,F12.3,1PE11.2,0PF8.1,1X,A4,
     *2i3)
C
      RETURN
      END
C
C ********************************************************************
C
C

      SUBROUTINE NLTSET(MODE,IL,IAT,ION,EXCL,EXCU,QL,QU,IEVEN,INNLT0)
C     ===============================================================
C
C     NLTE option -  automatic assignement of level indices
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INCLUDE 'LINDAT.FOR'
      PARAMETER (MNION = 20,
     *           MNLEV = 450,
     *           ECONST=  5.03411142E15)
      PARAMETER (INLLEV = 13)
      COMMON/NL2PAR/ELIMEV(MNION,MNLEV),ELIMOD(MNION,MNLEV),
     *              ELIML(MNION,MNLEV),
     *              ENREV(MNION,MNLEV),ENROD(MNION,MNLEV),
     *              INDEV(MNION,MNLEV),INDOD(MNION,MNLEV),
     *              INDLV(MNION,MNLEV),
     *              NEVEN(MNION),NODD(MNION),NODD0,NLEVS(MNION),
     *              IATN(MNION),IONN(MNION),NNION
C
C     +++++++++++++++++++++++++++
C     MODE = 0  -  initialization
C     +++++++++++++++++++++++++++
C
      IF(MODE.EQ.0) THEN
         NNION=0
         READ(INLLEV,*,END=55,ERR=55) NNION    
         IF(NNION.LE.0) GO TO 55
         DO 50 I=1,NNION
            READ(INLLEV,*) IATN(I),IONN(I)
            READ(INLLEV,*) NEVEN(I)
            IF(NEVEN(I).GT.0) THEN
               DO 10 J=1,NEVEN(I)
                  READ(INLLEV,*) II,ELIMEV(I,J),ENREV(I,J)
   10          CONTINUE
c            END IF
            READ(INLLEV,*) NODD(I)
            NODD0=NODD(I)
            IF(NODD(I).GT.0) THEN
               DO 20 J=1,NODD(I)
                  READ(INLLEV,*) II,ELIMOD(I,J),ENROD(I,J)
   20          CONTINUE
             ELSE
               NODD(I)=NEVEN(I)
               DO 30 J=1,NODD(I)
                  ELIMOD(I,J)=ELIMEV(I,J)
   30          CONTINUE
            END IF
            INDION=0
            DO 40 IONEX=1,NION
               N0I=NFIRST(IONEX)
               IA=NUMAT(IATM(N0I))
               IF(IA.EQ.IATN(I).AND.IZ(IONEX)-1.EQ.IONN(I)) INDION=IONEX
   40       CONTINUE
            IF(INDION.LE.0) THEN
               call quit(' INCONSISTENCY IN UNIT 13 INPUT - NLTE')
            END IF
            NOFF=NFIRST(INDION)-1
c
            INT=0
            INE=1
            INO=1
   22       INT=INT+1
            IF(INT.GT.NEVEN(I)+NODD(I)) GO TO 24
            IF(ENREV(I,INE).LT.ENROD(I,INO)) THEN
                INDEV(I,INE)=INT+NOFF
                INE=INE+1
                IF(INE.GT.NEVEN(I)) GO TO 28
             ELSE
                INDOD(I,INO)=INT+NOFF
                INO=INO+1
                IF(INO.GT.NODD(I)) GO TO 26
            END IF
            GO TO 22
   24       CONTINUE 
            GO TO 50 
C
   26       IF(INE.LE.NEVEN(I)) THEN
               DO 27 INE1=INE,NEVEN(I)
                  INT=INT+1
                  INDEV(I,INE1)=INT+NOFF
   27          CONTINUE
            END IF
            GO TO 50        
   28       IF(INO.LE.NODD(I)) THEN
               DO 29 INO1=INO,NODD(I)
                  INT=INT+1
                  INDOD(I,INO1)=INT+NOFF
   29          CONTINUE
            END IF
C
           ELSE IF(NEVEN(I).LT.0) THEN
             NEV1=-NEVEN(I)
             IF(NEVEN(I).NE.0) THEN
               DO J=1,NEV1
                 READ(INLLEV,*) ENREV(I,J),ELIMEV(I,J),INDEV(I,J)
               END DO
             END IF
             READ(INLLEV,*) NODD(I)
             IF(NODD(I).GT.0) THEN
               DO J=1,NODD(I)
                 READ(INLLEV,*) ENROD(I,J),ELIMOD(I,J),INDOD(I,J)
               END DO
             END IF
             INDION=0
             DO IONEX=1,NION
               N0I=NFIRST(IONEX)
               IA=NUMAT(IATM(N0I))
               IF(IA.EQ.IATN(I).AND.IZ(IONEX)-1.EQ.IONN(I)) 
     .               INDION=IONEX
             END DO
             IF(INDION.LE.0) THEN
               call quit(' INCONSISTENCY IN UNIT 13 INPUT - NLTE')
             END IF
             NOFF=NFIRST(INDION)-1
             DO J=1,NEV1
               INDEV(I,J)=INDEV(I,J)+NOFF
             END DO
             DO J=1,NODD(I)
               INDOD(I,J)=INDOD(I,J)+NOFF
             END DO
           END IF
C
   50    CONTINUE
   55    CONTINUE
C
         INDION=NNION
         DO 90 IONEX=1,NION
            N0I=NFIRST(IONEX)
            IA=NUMAT(IATM(N0I))
            IONM1=IZ(IONEX)-1
            IF(IA.EQ.1.OR.IA.EQ.2) GO TO 90
            DO 60 I=1,NNION
               IF(IA.EQ.IATN(I).AND.IONM1.EQ.IONN(I)) GO TO 90
   60       CONTINUE
            IF(NFIRST(IONEX).EQ.NLAST(IONEX)) GO TO 90
            INDION=INDION+1
            EION=ENION(NFIRST(IONEX))
            NLEVS(INDION)=NLAST(IONEX)-NFIRST(IONEX)+1
            NEVEN(INDION)=0
            IATN(INDION)=IA
            IONN(INDION)=IONM1
            DELE=0.
            DO 70 II=NFIRST(IONEX),NLAST(IONEX)
               I=II-NFIRST(IONEX)+1
               E=(EION-ENION(II))*ECONST
               IF(II.LT.NLAST(IONEX)) THEN
                  E1=(EION-ENION(II+1))*ECONST
                  DELE=0.5*(E1-E)
                  ELIML(INDION,I)=E+DELE
                ELSE
                  IF(INLTE.GE.2) THEN
                     ELIML(INDION,I)=E+DELE
                   ELSE
                     ELIML(INDION,I)=EION*ECONST
                  END IF
               END IF
               INDLV(INDION,I)=II
   70       CONTINUE
   90    CONTINUE
         NNION=INDION
  100    RETURN
      END IF
C
C
C     ++++++++++++++++++++++++++++++++++++++++++
C     MODE > 0  -  level indices for the line IL
C     ++++++++++++++++++++++++++++++++++++++++++
C
      IF(NNION.LE.0) RETURN
      INION=0
      IONM1=ION-1
      DO 102 I=1,NNION
         IF(IAT.EQ.IATN(I).AND.IONM1.EQ.IONN(I)) INION=I
  102 CONTINUE
      IF(INION.LE.0) RETURN
      IF(NEVEN(INION).EQ.0) IEVEN=2
      IF(NEVEN(INION).LT.0) GOTO 400
C
      IF(IEVEN.EQ.1) THEN
         IND=0
         DO 110 J=1,NEVEN(INION)
            IF(EXCL.LE.ELIMEV(INION,J)) THEN
               IND=J
               GO TO 120
            END IF
  110    CONTINUE
         ILWN=0
         GO TO 200
  120    CONTINUE
         ILWN=INDEV(INION,IND)
C
         IND=0
         DO 130 J=1,NODD(INION)
            IF(EXCU.LE.ELIMOD(INION,J)) THEN
               IND=J
               GO TO 140
            END IF
  130    CONTINUE
         IUN=0
         GO TO 200
  140    CONTINUE
         IUN=INDOD(INION,IND)
C
       ELSE IF(IEVEN.EQ.0) THEN
         IND=0
         DO 150 J=1,NODD(INION)
            IF(EXCL.LE.ELIMOD(INION,J)) THEN
               IND=J
               GO TO 160
            END IF
  150    CONTINUE
         ILWN=0
         GO TO 200
  160    CONTINUE
         ILWN=INDOD(INION,IND)
C
         IND=0
         DO 170 J=1,NEVEN(INION)
            IF(EXCU.LE.ELIMEV(INION,J)) THEN
               IND=J
               GO TO 180
            END IF
  170    CONTINUE
         IUN=0
         GO TO 200
  180    CONTINUE
         IUN=INDEV(INION,IND)
  200    CONTINUE
c
c        transition between levels without a distinction in parity
c
       ELSE 
         IND=0
         DO 210 J=1,NLEVS(INION)
            IF(EXCL.LE.ELIML(INION,J)) THEN
               IND=J
               GO TO 220
            END IF
  210    CONTINUE
         ILWN=0
         IUN=0
         GO TO 300
  220    CONTINUE
         ILWN=INDLV(INION,IND)
C
         IND=0
         DO 230 J=1,NLEVS(INION)
            IF(EXCU.LE.ELIML(INION,J)) THEN
               IND=J
               GO TO 240
            END IF
  230    CONTINUE
         IUN=0
         GO TO 300
  240    CONTINUE
         IUN=INDLV(INION,IND)
  300    CONTINUE
      END IF
C
  400 IF(NEVEN(INION).LT.0) THEN
        NEV1=-NEVEN(INION)
        IF(IEVEN.EQ.1) THEN
          ILWN=0
          J=1
          DO WHILE (ILWN.EQ.0 .AND. J.LE.NEV1)
            IF(QL.EQ.ELIMEV(INION,J)) THEN
              DE=ENREV(INION,J)
              IF(EXCL.NE.0.) DE=(EXCL-DE)/EXCL
              IF(ABS(DE).LT.1.D-5) ILWN=INDEV(INION,J)
            END IF
            J=J+1
          END DO
          IUN=0
          J=1
          DO WHILE (IUN.EQ.0 .AND. J.LE.NODD(INION))
            IF(QU.EQ.ELIMOD(INION,J)) THEN
              DE=(EXCU-ENROD(INION,J))/EXCU
              IF(ABS(DE).LT.1.D-5) IUN=INDOD(INION,J)
            END IF
            J=J+1
          END DO
        ELSE IF(IEVEN.EQ.0) THEN
          ILWN=0
          J=1
          DO WHILE (ILWN.EQ.0 .AND. J.LE.NODD(INION))
            IF(QL.EQ.ELIMOD(INION,J)) THEN
              DE=ENROD(INION,J)
              IF(EXCL.NE.0.) DE=(EXCL-DE)/EXCL
              IF(ABS(DE).LT.1.D-5) ILWN=INDOD(INION,J)
            END IF
            J=J+1
          END DO
          IUN=0
          J=1
          DO WHILE (IUN.EQ.0 .AND. J.LE.NEV1)
            IF(QU.EQ.ELIMEV(INION,J)) THEN
              DE=(EXCU-ENREV(INION,J))/EXCU
              IF(ABS(DE).LT.1.D-5) IUN=INDEV(INION,J)
            END IF
            J=J+1
          END DO
        END IF
      END IF
C
      IF(INLTE.EQ.5) THEN
         INNLT0=INNLT0+1
         INDNLT(IL)=INNLT0
        ELSE IF(INLTE.EQ.4) THEN
         IF(ILWN.GT.0.AND.IUN.GT.0) THEN
            INDNLT(IL)=-1
         END IF
        ELSE IF(INLTE.EQ.3) THEN
         IF(ILWN.GT.0) THEN
            INDNLT(IL)=-1
         END IF
        ELSE
         INDNLT(IL)=-1
      END IF
      BNUL(IL)=BN*(FREQ0(IL)*1.E-15)**3
      ILOWN(IL)=ILWN
      IUPN(IL)=IUN
      RETURN
      END
C
C ********************************************************************
C ********************************************************************
C
C

      SUBROUTINE PHTION(ID,ABSO,EMIS)
C     ===============================
C
C     Opacity due to detailed photoionization (read from tables by
C     routine READPH)
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INCLUDE 'LINDAT.FOR'
      COMMON/PHOTCS/PHOT(MFREQ,MPHOT),WPHT0,WPHT1,APHT(MPHOT),
     *              EPHT(MPHOT),GPHT(MPHOT),JPHT(MPHOT),
     *              NPHT
       DIMENSION ABSO(MFREQ),EMIS(MFREQ),PLANF(MFREQ),STIMU(MFREQ)
       PARAMETER (C3=1.4387886)
C
      IF(NPHT.LE.0) RETURN
      T=TEMP(ID)
      DO 10 IJ=1,NFREQ
         XX=FREQ(IJ)
         X15=XX*1.E-15
         BNU=BN*X15*X15*X15
         HKF=HK*XX
         EXH=EXP(HKF/T)
         PLANF(IJ)=BNU/(EXH-1.)
         STIMU(IJ)=1.-1./EXH
   10 CONTINUE
      DO 30 I=1,NPHT
         IF(JPHT(I).LE.0) THEN
            IAT=APHT(I)
            X=(APHT(I)-FLOAT(IAT)+1.E-4)*1.E2
            ION=INT(X)+1
            POP=RRR(ID,ION,IAT)*GPHT(I)*EXP(-EPHT(I)*C3/T)
          ELSE
            JJ=JPHT(I)
            POP=POPUL(JJ,ID)
         END IF
         DO 20 IJ=1,NFREQ
            AB=PHOT(IJ,I)*POP*STIMU(IJ)
            ABSO(IJ)=ABSO(IJ)+AB
            EMIS(IJ)=EMIS(IJ)+AB*PLANF(IJ)
   20    CONTINUE
   30 CONTINUE
      RETURN
      END

C
C ********************************************************************
C ********************************************************************
C
      SUBROUTINE NLTE(IL,ILW,IUN,GI,GJ)
C     ===========================================
C
C     Control procedure for the NLTE option
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'LINDAT.FOR'
      COMMON/NLTPOP/PNLT(MATOM,MION,MDEPTH)
      PARAMETER (UN     = 1., 
     *           C3     = 1.4387886,
     *           XET    = 8067.6,
     *           XET3   = XET*C3)
C
C     CALCULATION OF THE 
C     CENTRAL OPACITY (ABCENT) AND THE LINE SOURCE FUNCTION  (SLIN)
C
      ILNLT=INDNLT(IL)
      IF(ILNLT.LE.0) RETURN
      IAT=INDAT(IL)/100
      ION=MOD(INDAT(IL),100)
      EGF=EXP(GF0(IL))
      BNU=BN*(FREQ0(IL)*1.E-15)**3
      DP0=3.33564E-11*FREQ0(IL)
      DP1=1.651E8/AMAS(IAT)
      IF(ILW.LE.0) GO TO 100
C
C     line is a transition between explicit levels of the
C     input model
C
      NKI=NNEXT(IEL(ILW))
      DO 60 ID=1,ND
         T=TEMP(ID)
         COR=1.
         PP=PNLT(IAT,ION,ID)
         IF(ILW.GT.0) THEN
	    PI=POPUL(ILW,ID)/G(ILW)
          ELSE
            PI=PP*EXP((ENEV(IAT,ION)*XET3-EXCL0(IL))/T)
         END IF
         IF(IUN.GT.0) THEN
            PJ=POPUL(IUN,ID)/G(IUN)
            cor=(excu0(il)-excl0(il)+
     *         (enion(iun)-enion(ilw))/1.38054e-16)/t
            cor=exp(cor)
          ELSE
            PJ=PP*EXP((ENEV(IAT,ION)*XET3-EXCU0(IL))/T)
         END IF
         if(pj.gt.0.) then
            X=PI/PJ*cor
          else
            x=un
         end if
         IF(X.EQ.UN) X=EXP(4.79928E-11*FREQ0(IL)/T)
         DOP=DP0*SQRT(DP1*T+VTURB(ID))
         SLIN(ILNLT,ID)=BNU/(X-UN)
         if(pi.gt.0.) ABCENT(ILNLT,ID)=PI*(UN-UN/X)*EGF/DOP
   60 CONTINUE
      RETURN
C
C     Approximate NLTE for resonance lines - second order escape
C     probablity theory form of the source function
C
C     Optical depth scale
C
  100 CONTINUE
      ALMIL=2.997925E17/FREQ0(IL)
      HKF=HK*FREQ0(IL)
      DO 110 ID=1,ND
         T=TEMP(ID)
         DOP=DP0*SQRT(DP1*T+VTURB(ID))
         X=EXP(HKF/T)
         ABCENT(ILNLT,ID)=EGF*EXP(-EXCL0(IL)/T)*RRR(ID,ION,IAT)/
     *                    DOP*(1.-1./X)
         AB=ABSTD(ID)+ABCENT(ILNLT,ID)*1.77245
         IF(ID.EQ.1) THEN
            ABM=AB/DENS(1)
            TAU=0.5*DM(1)*ABM
          ELSE
            AB0=AB/DENS(ID)
            TAU=TAU+0.5*(DM(ID)-DM(ID-1))*(AB0+ABM)
            ABM=AB0
         END IF
C
C        approximate epsilon after Kastner
C
         E=EPS(T,ELEC(ID),ALMIL,ION,IUN)
         XK2=XK2DOP(TAU)
         SLIN(ILNLT,ID)=SQRT(E/(E+(1.-E)*XK2))*BNU/(X-1.)
  110 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
C
 
      SUBROUTINE LINOP(ID,ABLIN,EMLIN,AVAB)
C     =====================================
C
C     TOTAL LINE OPACITY (ABLIN)  AND EMISSIVITY (EMLIN)
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INCLUDE 'LINDAT.FOR'
      LOGICAL LPR,lasdel
      PARAMETER (UN     = 1., 
     *           EXT0   = 3.17,
     *           TEN    = 10.,
     *           C3     = 1.4387886,
     *           XET    = 8067.6,
     *           XET3   = XET*C3)
      DIMENSION ABLIN(MFREQ),EMLIN(MFREQ),ABLINN(MFREQ)
      COMMON/LICNTR/DFRCON,IJCNTR(MLIN)
      COMMON/PRFQUA/DOPA1(MATOM,MDEPTH),VDWC(MDEPTH)
      COMMON/NLTPOP/PNLT(MATOM,MION,MDEPTH)
      common/lasers/lasdel
C
      DO 10 IJ=1,NFREQ
         ABLIN(IJ)=0.
         ABLINN(IJ)=0.
         EMLIN(IJ)=0.
   10 CONTINUE
C
      IF(NLIN.EQ.0) RETURN
C
C     overall loop over contributing lines
C
      TEM1=UN/TEMP(ID)
      DO 100 I=1,NLIN
         IL=INDLIN(I)
         INNLT=INDNLT(IL)
         IAT=INDAT(IL)/100
         ION=MOD(INDAT(IL),100)
         LPR=.TRUE.
         ISP=ISPRF(IL)
         IF(ISP.GT.1.AND.ISP.LE.5) LPR=.FALSE.
         IF (ISP.GE.6) GO TO 100
         CALL PROFIL(IL,IAT,ID,AGAM)
         DOP1=DOPA1(IAT,ID)
         FR0=FREQ0(IL)
         IF(INNLT.EQ.0) THEN
            AB0=EXP(GF0(IL)-EXCL0(IL)*TEM1)*RRR(ID,ION,IAT)*
     *          DOP1*STIM(ID)
          ELSE IF(INNLT.GT.0) THEN
            AB0=ABCENT(INNLT,ID)
            SL0=SLIN(INNLT,ID)
          ELSE
            ILW=ILOWN(IL)
            IUN=IUPN(IL)
            COR=1.
            PP=PNLT(IAT,ION,ID)
            IF(ILW.GT.0) THEN
	       PI=POPUL(ILW,ID)/G(ILW)
             ELSE
               PI=PP*EXP((ENEV(IAT,ION)*XET3-EXCL0(IL))*TEM1)
            END IF
            IF(IUN.GT.0) THEN
               PJ=POPUL(IUN,ID)/G(IUN)
               cor=(excu0(il)-excl0(il)+
     *             (enion(iun)-enion(ilw))/1.38054e-16)*tem1
               cor=exp(cor)
             ELSE
               PJ=PP*EXP((ENEV(IAT,ION)*XET3-EXCU0(IL))*TEM1)
            END IF
            if(pj.gt.0.) then
               X=PI/PJ*cor
             else
               x=un
            end if
            IF(X.EQ.UN) X=EXP(4.79928E-11*FREQ0(IL)*TEM1)
            SL0=BNUL(IL)/(X-UN)
            ab0=0.
            if(pi.gt.0.) AB0=PI*(UN-UN/X)*EXP(GF0(IL))*DOP1
         END IF
         if(ab0.le.0.and.lasdel) go to 100
C
C        set up limiting frequencies where the line I is supposed to
C        contribute to the opacity 
C
         EX0=AB0/AVAB*AGAM 
         EXT=EXT0
         IF(EX0.GT.TEN) EXT=SQRT(EX0)
         EXT=EXT/DOP1
         IJEXT=(DFRCON*EXT)+1.5
         IJ1=MAX(IJCNTR(I)-IJEXT,3)
         IJ2=MIN(IJCNTR(I)+IJEXT,MFREQ)
         IF(IJ1.GE.NFREQ.OR.IJ2.LE.2) GO TO 100
C
         IF(INNLT.EQ.0) THEN
C
C        *********
C        LTE lines
C        *********
C
	 IF(LPR) THEN
C
            DO 40 IJ=IJ1,IJ2
               XF=ABS(FREQ(IJ)-FR0)*DOP1
c               ABLIN(IJ)=ABLIN(IJ)+AB0*VOIGTE(AGAM,XF)
               ABLIN(IJ)=ABLIN(IJ)+AB0*VOIGTK(AGAM,XF)
   40       CONTINUE
C
C        special expressions for 4 selected He I lines
C
         ELSE
            DO 60 IJ=3,NFREQ
               FR=FREQ(IJ)
               ABL=AB0*PHE1(ID,FR,ISP-1)
               ABLIN(IJ)=ABLIN(IJ)+ABL
   60       CONTINUE
         END IF
C
C        **********
C        NLTE LINES
C        **********
C
       ELSE
	 IF(LPR) THEN
C
            DO 80 IJ=IJ1,IJ2
               XF=ABS(FREQ(IJ)-FR0)*DOP1
c               ABL=AB0*VOIGTE(AGAM,XF)
               ABL=AB0*VOIGTK(AGAM,XF)
               ABLINN(IJ)=ABLINN(IJ)+ABL
               EMLIN(IJ)=EMLIN(IJ)+ABL*SL0
   80       CONTINUE
C
C        again, special expressions for 4 selected He I lines
C
         ELSE
            DO 90 IJ=3,NFREQ
               FR=FREQ(IJ)
               ABL=AB0*PHE1(ID,FR,ISP-1)
               ABLINN(IJ)=ABLINN(IJ)+ABL
               EMLIN(IJ)=EMLIN(IJ)+ABL*SL0
   90       CONTINUE
         END IF
      END IF
  100 CONTINUE
C
      DO 110 IJ=3,NFREQ
         EMLIN(IJ)=EMLIN(IJ)+ABLIN(IJ)*PLAN(ID)
         ABLIN(IJ)=ABLIN(IJ)+ABLINN(IJ)
  110 CONTINUE
C
C     special routine for selected He II lines
C
      IF(NSP.EQ.0) RETURN
      DO 120 IS=1,NSP
         ISP=ISP0(IS)
         IF(ISP.GE.6.AND.ISP.LE.24) CALL PHE2(ISP,ID,ABLIN,EMLIN)
  120 CONTINUE
C
      RETURN
      END
C
C
C ********************************************************************
C
C
      SUBROUTINE PROFIL(IL,IAT,ID,AGAM)
C     =================================
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INCLUDE 'LINDAT.FOR'
      COMMON/PRFQUA/DOPA1(MATOM,MDEPTH),VDWC(MDEPTH)
      DIMENSION WGR(4)
      PARAMETER (PI4=7.95774715E-2)
C
      IPRF=IPRF0(IL)
      T=TEMP(ID)
      ANE=ELEC(ID)
C
C     radiative broadening (classical)
C
      AGAM=GAMR0(IL)
C
C     Stark broadening - standard (given in the line list or classical)
C
      IF(IPRF.EQ.0) THEN
         AGAM=AGAM+GS0(IL)*ANE
C
C     Stark broadening - special expressions for He I
C
       ELSE IF(IPRF.GT.0) THEN
         ANP=POPUL(NKH,ID)
         CALL GAMHE(IPRF,T,ANE,ANP,ID,GAM)
         AGAM=AGAM+GAM
C
C     Stark broadening - Griem
C
       ELSE 
         DO 10 I=1,4
   10       WGR(I)=WGR0(I,IGRIEM(IL))
         FR=FREQ0(IL)
         ION=MOD(INDAT(IL),100)
         CALL GRIEM(ID,T,ANE,ION,FR,WGR,GAM)
         AGAM=AGAM+GAM
      END IF
C
C     Van Der Waals broadening
C
      AGAM=AGAM+GW0(IL)*VDWC(ID)
C
C     final Voigt parameter a
C
      AGAM=AGAM*DOPA1(IAT,ID)*PI4
C
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE GRIEM(ID,T,ANE,ION,FR,WGR,GAM)
C     =========================================
C
C     STARK DAMPING PARAMETER (GAM) CALCULATED FROM INPUT VALUES
C     OF STARK WIDTHS FOR  T=5000, 10000, 20000, 40000 K,
C     AND FOR  NE=1.E16 (FOR NEUTRALS)  OR  NE = 1.E17 (FOR IONS)
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      DIMENSION WGR(4)
      J=JT(ID)
      GAM=(TI0(ID)*WGR(J)+TI1(ID)*WGR(J-1)+TI2(ID)*WGR(J-2))
     *    *ANE*1.E-10*FR*1.E-10*FR*4.2E-14
      IF(ION.GT.1) GAM=GAM*0.1
      IF(GAM.LT.0.) GAM=0.
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE GAMHE(IND,T,ANE,ANP,ID,GAM)
C     ======================================
C
C     NEUTRAL HELIUM STARK BROADENING PARAMETERS
C     AFTER DIMITRIJEVIC AND SAHAL-BRECHOT, 1984, J.Q.S.R.T. 31, 301
C     OR FREUDENSTEIN AND COOPER, 1978, AP.J. 224, 1079  (FOR C(IND).GT.0)
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      DIMENSION W(5,20),V(4,20),C(20)
C
C   ELECTRONS T= 5000   10000   20000   40000     LAMBDA
C
      DATA W /  5.990,  6.650,  6.610,  6.210,    3819.60,
     *          2.950,  3.130,  3.230,  3.300,    3867.50,
     *          0.000,  0.000,  0.000,  0.000,    3871.79,
     *          0.142,  0.166,  0.182,  0.190,    3888.65,
     *          0.000,  0.000,  0.000,  0.000,    3926.53,
     *          1.540,  1.480,  1.400,  1.290,    3964.73,
     *         41.600, 50.500, 57.400, 65.800,    4009.27,
     *          1.320,  1.350,  1.380,  1.460,    4120.80,
     *          7.830,  8.750,  8.690,  8.040,    4143.76,
     *          5.830,  6.370,  6.820,  6.990,    4168.97,
     *          0.000,  0.000,  0.000,  0.000,    4437.55,
     *          1.630,  1.610,  1.490,  1.350,    4471.50,
     *          0.588,  0.620,  0.641,  0.659,    4713.20,
     *          2.600,  2.480,  2.240,  1.960,    4921.93,
     *          0.627,  0.597,  0.568,  0.532,    5015.68,
     *          1.050,  1.090,  1.110,  1.140,    5047.74,
     *          0.277,  0.298,  0.296,  0.293,    5875.70,
     *          0.714,  0.666,  0.602,  0.538,    6678.15,
     *          3.490,  3.630,  3.470,  3.190,    4026.20,
     *          4.970,  5.100,  4.810,  4.310,    4387.93/
C
C   PROTONS   T= 5000   10000   20000   40000
C
      DATA V /  1.520,  4.540,  9.140, 10.200,
     *          0.607,  0.710,  0.802,  0.901,
     *          0.000,  0.000,  0.000,  0.000,
     *          0.0396, 0.0434, 0.0476, 0.0526,
     *          0.000,  0.000,  0.000,  0.000,
     *          0.507,  0.585,  0.665,  0.762,
     *          0.930,  1.710, 13.600, 27.200,
     *          0.288,  0.325,  0.365,  0.410,
     *          1.330,  6.800, 12.900, 14.300,
     *          1.100,  1.370,  1.560,  1.760,
     *          0.000,  0.000,  0.000,  0.000,
     *          1.340,  1.690,  1.820,  1.630,
     *          0.128,  0.143,  0.161,  0.181,
     *          2.040,  2.740,  2.950,  2.740,
     *          0.187,  0.210,  0.237,  0.270,
     *          0.231,  0.260,  0.291,  0.327,
     *          0.0591, 0.0650, 0.0719, 0.0799,
     *          0.231,  0.260,  0.295,  0.339,
     *          2.180,  3.760,  4.790,  4.560,
     *          1.860,  5.320,  7.070,  7.150/
      DATA C /2*0.,1.83E-4,0.,1.13E-4,5*0.,1.6E-4,9*0./
C
      IF(W(1,IND).EQ.0.) GO TO 10
      J=JT(ID)
      GAM=((TI0(ID)*W(J,IND)+TI1(ID)*W(J-1,IND)+TI2(ID)*W(J-2,IND))
     *     *ANE
     *    +(TI0(ID)*V(J,IND)+TI1(ID)*V(J-1,IND)+TI2(ID)*V(J-2,IND))
     *     *ANP)*1.884E3/W(5,IND)**2
      IF(GAM.LT.0.) GAM=0.
      RETURN
   10 GAM=C(IND)*T**0.16667*ANE
      RETURN
      END
C
C ********************************************************************
C
      FUNCTION EPS(T,ANE,ALAM,ION,N)
C     ==============================
C
C     NLTE PARAMETER EPSILON (COLLISIONAL/SPONTANEOUS DEEXCITATION)
C     AFTER  KASTNER, 1981, J.Q.S.R.T. 26, 377
C
      INCLUDE 'PARAMS.FOR'
      DATA CK0,CK1 /7.75E-8, 2.58E-8/
      X=1.438E8/ALAM/T
      XKT=12390./ALAM
      TT=0.75*X
      T1=TT+1.
      A=4.36E7*XKT*XKT/(1.-EXP(-X))
      IF(ION.EQ.1) GO TO 10
      B=1.1+LOG(T1/TT)-0.4/T1/T1
      C=X*B*SQRT(T)/XKT/XKT*ANE
      IF(N.EQ.0) C=CK0*C
      IF(N.NE.0) C=CK1*C
      GO TO 20
   10 C=2.16/T/SQRT(T)/X**1.68*ANE
   20 EPS=C/(C+A)
      RETURN
      END
C
C ********************************************************************
C
      FUNCTION XK2DOP(TAU)
C     ====================
C
C     KERNEL FUNCTION K2  (AUXILIARY PROCEDURE TO NLTE)
C     AFTER  HUMMER,  1981, J.Q.S.R.T. 26, 187
C
      INCLUDE 'PARAMS.FOR'
      DATA PI2SQ,PISQ /2.506628275D0,  1.772453851D0/
      DATA A0,A1,A2,A3,A4 /
     *  1.D0,  -1.117897000D-1,  -1.249099917D-1,  -9.136358767D-3,
     *         -3.370280896D-4/
      DATA B0,B1,B2,B3,B4,B5 /
     *  1.D0,   1.566124168D-1,   9.013261660D-3,   1.908481163D-4,
     *         -1.547417750D-7,  -6.657439727D-9/
      DATA C0,C1,C2,C3,C4 /
     *  1.0D0,   1.915049608D01,   1.007986843D02,   1.295307533D02,
     *         -3.143372468D01/
      DATA D0,D1,D2,D3,D4,D5/
     *  1.D0,   1.968910391D01,   1.102576321D02,   1.694911399D02,
     *         -1.669969409D01,  -3.666448000D01/
      XK2DOP=1.D0
      IF(TAU.LE.0.) RETURN
      IF(TAU.GT.11.) GO TO 10
      P=A0+TAU*(A1+TAU*(A2+TAU*(A3+TAU*A4)))
      Q=B0+TAU*(B1+TAU*(B2+TAU*(B3+TAU*(B4+TAU*B5))))
      XK2DOP=TAU/PI2SQ*LOG(TAU/PISQ)+P/Q
      RETURN
   10 X=1.D0/LOG(TAU/PISQ)
      P=C0+X*(C1+X*(C2+X*(C3+X*C4)))
      Q=D0+X*(D1+X*(D2+X*(D3+X*(D4+X*D5))))
      XK2DOP=P/Q/2.D0/TAU/SQRT(LOG(TAU/PISQ))
      RETURN
      END
C
C ********************************************************************
C
      SUBROUTINE INKUR
C     ================
C
C     Input of a Kurucz model atmosphere
C
C     Input values (extracted from the Kurucz files):
C      TEF, G  - effective temperature, log g (appears only in output)
C      ND      - number of depth points
C     and for each depth:
C      DM      - m, m is the mass depth coordinate
C      T       - temperature
C      P       - gass pressure
C      ANE     - electron density
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      DIMENSION POP(MLEVEL),ES(MLEVEL,MLEVEL),BS(MLEVEL)
      COMMON POP,ES,BS
C
      READ(8,501) TEF,GRAV
      READ(8,502) ND
      ND=ND-1
  501 FORMAT(4X,F8.0,9X,F8.5)
c  502 FORMAT(/////////////////////10X,I3)
  502 FORMAT(/////////////////////10X,I3/)
      WRITE(6,600) TEF,GRAV
      DO 10 ID=1,ND
         READ(8,*) DM(ID),TEMP(ID),P,ELEC(ID)
         AN=P/TEMP(ID)/BOLK
         DENS(ID)=WMM(ID)*(AN-ELEC(ID))
         WRITE(6,601) ID,DM(ID),TEMP(ID),ELEC(ID),DENS(ID)
         CALL WNSTOR(ID)
         CALL SABOLF(ID)
         CALL RATMAT(ID,ES,BS)
         CALL LINEQS(ES,BS,POP,NLEVEL,MLEVEL)
         DO 10 J=1,NLEVEL
            POPUL(J,ID)=POP(J)
   10 CONTINUE
  600 FORMAT(1H1,' INPUT KURUCZ MODEL FOR TEFF=',F7.0,'   LOG G =',
     *       F7.2//1H ,7X,'MASS',9X,'T',9X,'NE',9X,'DENS'//)
  601 FORMAT(1H ,I5,1PE10.3,0PF10.1,1P2D12.3)
      RETURN
      END
C
C ********************************************************************
C
C
C
      SUBROUTINE INPMOD
C     =================
C
C     Read an initial model atmosphere from unit 8
C     File 8 contains:
C      1. NDPTH -  number of depth points in which the initial model is
C                  given (if not equal to ND, routine interpolates
C                  automatically to the set DM by linear interpolation
C                  in log(DM)
C         NUMPAR - number of input model parameters in each depth
C                  = 3 for LTE model - ie. N, T, N(electron);
C                  > 3 for NLTE model)
C      2. DEPTH(ID),ID=1,NDPTH - mass-depth points for the input model
C      3. for each depth:
C                 T   - temperature
C                 ANE - electron density
C                 RHO - mass density
C                 level populations - only for NLTE input model
C                       Number of input level populations need not be
C                       equal to NLEVEL; in that case the procedure
C                       CHANGE is called from START to calculate the
C                       remaining level populations
C
C     Note: The output file 7, which is created by this program
C           (procedure OUTPUT) has the same structure as file 8
C           and may thus be used as input to another run of the
C           program
C     INTRPL - switch indicating whether (and, if so, how) interpolate
C              the initial model if the depth scales for the input model
C              and the present depth scale are different
C            = 0  -  no interpolation, i.e. scale DEPTH coincides with DM
C            > 0  -  polynomial interpolation of the (INTRPL-1)th order
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      PARAMETER (MINPUT=MLEVEL+4)
      DIMENSION ESEMAT(MLEVEL,MLEVEL),BESE(MLEVEL),POPLTE(MLEVEL)
      COMMON ESEMAT,BESE,POPLTE,POPUL0(MLEVEL,MDEPTH),X(MINPUT),
     *       TEMP0(MDEPTH),ELEC0(MDEPTH),DENS0(MDEPTH),PPL0(MDEPTH),
     *       PPL(MDEPTH),DEPTH(MDEPTH),DM0(MDEPTH),DP(MDEPTH)
      COMMON/NLTPOP/PNLT(MATOM,MION,MDEPTH)
C
      NUMP0=3
      IF(INMOD.EQ.2) NUMP0=4
      READ(8,*) NDPTH,NUMPAR
      READ(8,*) (DEPTH(I),I=1,NDPTH)
      DO 30 ID=1,NDPTH
         READ(8,*) (X(I),I=1,NUMPAR)
         TEMP0(ID)=X(1)
         ELEC0(ID)=X(2)
         DENS0(ID)=X(3)
         TEMP(ID)=X(1)
         ELEC(ID)=X(2)
         DENS(ID)=X(3)
         CALL SABOLF(ID)
         IF(NUMPAR.GT.NUMP0) THEN     
            NLEV0=NUMPAR-NUMP0
            DO 10 I=1,NLEV0
               POPUL0(I,ID)=X(NUMP0+I)*RELAB(IATM(I),ID)
   10       CONTINUE
            DO I=1,NLEV0
               if(popul0(i,id).eq.0.) then
                  IE=IEL(I)
                  N0I=NFIRST(IE)
                  NKI=NNEXT(IE)
                  POPUL0(I,ID)=ELEC(ID)*POPUL(NKI,ID)*SBF(I)
               end if
            END DO
          ELSE                    
            NLEV0=NLEVEL
            TEMP(ID)=X(1)
            ELEC(ID)=X(2)
            DENS(ID)=X(3)
            CALL WNSTOR(ID)
            CALL SABOLF(ID)
            CALL RATMAT(ID,ESEMAT,BESE)
            CALL LINEQS(ESEMAT,BESE,POPLTE,NLEV0,MLEVEL)
            DO 20 I=1,NLEV0
   20          POPUL0(I,ID)=POPLTE(I)
         END IF
   30 CONTINUE
C
C     if INTRPL = 0  -  no interpolation
C        i.e. scale DEPTH coincides with DM
C
      IF(INTRPL.EQ.0) THEN
         DO 40 ID=1,ND
            DM(ID)=DEPTH(ID)
            TEMP(ID)=TEMP0(ID)
            ELEC(ID)=ELEC0(ID)
            DENS(ID)=DENS0(ID)
            CALL WNSTOR(ID)
            DO 42 I=1,NLEVEL
               POPUL(I,ID)=POPUL0(I,ID)
   42       CONTINUE
   40    CONTINUE
       ELSE
C
C    if INTRPL > 0  - Interpolation from log(DEPTH) to log(DM)
C       INTRPL = 1 or 2 - linear interpolation,
C              = 3  -  parabolic interpoltaion,
C              = 4  -  cubic interpolation, etc.
C
         CALL INTERP(DM,TEMP0,DEPTH,TEMP,NDPTH,ND,INTRPL,1,0)
         CALL INTERP(DM,ELEC0,DEPTH,ELEC,NDPTH,ND,INTRPL,1,1)
         CALL INTERP(DM,DENS0,DEPTH,DENS,NDPTH,ND,INTRPL,1,1)
         DO 70 I=1,NLEV0
            DO 50 ID=1,NDPTH
   50          PPL0(ID)=POPUL0(I,ID)
            CALL INTERP(DM,PPL0,DEPTH,PPL,NDPTH,ND,INTRPL,1,1)
            DO 60 ID=1,ND
               CALL WNSTOR(ID)
               POPUL(I,ID)=PPL(ID)
   60    CONTINUE
   70    CONTINUE
      END IF
      DO 100 ID=1,ND
         BCON=ELEC(ID)/TEMP(ID)/SQRT(TEMP(ID))*2.0706E-16
         DO 100 IONE=1,NION
            ION=IZ(IONE)
            IAT=NUMAT(IATM(NFIRST(IONE)))
            NKI=NNEXT(IONE)
            IF(ION.GT.0) PNLT(IAT,ION,ID)=POPUL(NKI,ID)/G(NKI)*BCON
  100 CONTINUE
c
c     check abundances
c
      if(imode.ge.0) CALL CHCKAB
      RETURN
      END
C
C
C     ****************************************************************
C
C
 
      SUBROUTINE CHANGE
C     =================
C
C     This procedure controls an evaluation of initial level
C     populations in case where the system of explicit levels
C     (ie. the choice of explicit level, their numbering, or their
C     total number) is not consistent with that for the input level
C     populations read by procedure INPMOD.
C     Obviously, this procedure need be used only for NLTE input models.
C
C     Input from unit 5:
C     For each explicit level, II=1,NLEVEL, the following parameters:
C      IOLD   -  NE.0 - means that population of this level is
C                       contained in the set of input populations;
C                       IOLD is then its index in the "old" (i.e. input)
C                       numbering.
C                       All the subsequent parameters have no meaning
C                       in this case.
C             -  EQ.0 - means that this level has no equivalent in the
C                       set of "old" levels. Population of this level
C                       has thus to be evaluated.
C      MODE   -    indicates how the population is evaluated:
C             = 0  - population is equal to the population of the "old"
C                    level with index ISIOLD, multiplied by REL;
C             = 1  - population assumed to be LTE, with respect to the
C                    first state of the next ionization degree whose
C                    population must be contained in the set of "old"
C                    (ie. input) populations, with index NXTOLD in the
C                    "old" numbering.
C                    The population determined of this way may further
C                    be multiplied by REL.
C             = 2  - population determined assuming that the b-factor
C                    (defined as the ratio between the NLTE and
C                    LTE population) is the same as the b-factor of
C                    the level ISINEW (in the present numbering). The
C                    level ISINEW must have the equivalent in the "old"
C                    set; its index in the "old" set is ISIOLD, and the
C                    index of the first state of the next ionization
C                    degree, in the "old" numbering, is NXTSIO.
C                    The population determined of this way may further
C                    be multiplied by REL.
C             = 3  - level corresponds to an ion or atom which was not
C                    explicit in the old system; population is assumed
C                    to be LTE.
C      NXTOLD  -  see above
C      ISINEW  -  see above
C      ISIOLD  -  see above
C      NXTSIO  -  see above
C      REL     -  population multiplier - see above
C                 if REL=0, the program sets up REL=1
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      DIMENSION ESEMAT(MLEVEL,MLEVEL),BESE(MLEVEL),POPLTE(MLEVEL)
      COMMON ESEMAT,BESE,POPLTE,POPUL0(MLEVEL,MDEPTH),
     *       POPULL(MLEVEL,MDEPTH),POPL(MLEVEL)
C
      PARAMETER (S = 2.0706E-16)
      IFESE=0
      DO 100 II=1,NLEVEL
         READ(ICHANG,*) IOLD,MODE,NXTOLD,ISINEW,ISIOLD,NXTSIO,REL
	 IF(MODE.GE.3) IFESE=IFESE+1
         IF(REL.EQ.0.) REL=1.
         DO 90 ID=1,ND
            IF(IOLD.EQ.0) GO TO 10
            POPUL0(II,ID)=POPUL(IOLD,ID)
            GO TO 90
   10       IF(MODE.NE.0) GO TO 20
            POPUL0(II,ID)=POPUL(ISIOLD,ID)*REL
            GO TO 90
   20       T=TEMP(ID)
            ANE=ELEC(ID)
	    IF(MODE.GE.3) GO TO 40
            NXTNEW=NNEXT(IEL(II))
            SB=S/T/SQRT(T)*G(II)/G(NXTNEW)*EXP(ENION(II)/T/BOLK)
            IF(MODE.GT.1) GO TO 30
            POPUL0(II,ID)=SB*ANE*POPUL(NXTOLD,ID)*REL
            GO TO 90
   30       KK=ISINEW
            KNEXT=NNEXT(IEL(KK))
            SBK=S/T/SQRT(T)*G(KK)/G(KNEXT)*EXP(ENION(KK)/T/BOLK)
            POPUL0(II,ID)=SB/SBK*POPUL(NXTOLD,ID)/POPUL(NXTSIO,ID)*
     *                    POPUL(ISIOLD,ID)*REL
	    GO TO 90
   40       IF(IFESE.EQ.1) THEN
	       CALL SABOLF(ID)
               CALL RATMAT(ID,ESEMAT,BESE)
               CALL LINEQS(ESEMAT,BESE,POPLTE,NLEVEL,MLEVEL)
	       DO 50 III=1,NLEVEL
   50             POPULL(III,ID)=POPLTE(III)
	    END IF
	    POPUL0(II,ID)=POPULL(II,ID)
   90    CONTINUE
  100 CONTINUE
      DO 110 I=1,NLEVEL
         DO 110 ID=1,ND
            POPUL(I,ID)=POPUL0(I,ID)
  110 CONTINUE
      RETURN
      END
C
C
C ********************************************************************
C
C
      SUBROUTINE RATMAT(ID,A,B)
C
C     LTE RATE MATRIX  (SAHA-BOLTZMANN EQS. + CHARGE CONSERVATION EQ.)
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      parameter (un=1.)
      DIMENSION A(MLEVEL,MLEVEL),B(MLEVEL)
      LOGICAL LCHC
C
      LCHC=.FALSE.
      T=TEMP(ID)
      ANE=ELEC(ID)
      HKT=HK/T
      DO 10 I=1,NLEVEL
         B(I)=0.
         DO 10 J=1,NLEVEL
   10       A(J,I)=0.
C
      NKH=NKA(IATREF)
C
      DO 100 IAT=1,NATOM
         N0I=N0A(IAT)
         NKI=NKA(IAT)
         N1I=NKI-1
         NREFI=NKI
   50    DO 60 I=N0I,N1I
            A(I,I)=1.
            N=NNEXT(IEL(I))
   60       A(I,N)=-ANE*SBF(I)*WOP(I,ID)
         IF(IAT.EQ.IATREF) GO TO 100
         DO 80 I=N0I,NKI
            IL=ILK(I)
            A(NREFI,I)=UN
            IF(IL.NE.0) A(NREFI,I)=1.+ANE*USUM(IL)
   80    CONTINUE
            DO 90 I=N0A(IATREF),NKA(IATREF)
               IL=ILK(I)
               A(NREFI,I)=-ABUND(IAT,ID)
               IF(IL.GT.0) A(NREFI,I)=-ABUND(IAT,ID)*(UN+ANE*USUM(IL))
   90       CONTINUE
  100 CONTINUE
C
C     charge conservation equation, if LCHC=true
C
      IF(LCHC) THEN
C
C     here STATE determines Q, which is total charge due to
C     non-explicit atoms, relative to total hydrogen number density
C     density; and QM - contribution of the charge of H- if this
C     is not considered as an explicit ion
C
      CALL STATE(ID,T,ANE,Q)
C
C     QM - contribution of the charge of H- if this is not
C          considered as an explicit ion
C
      QM=0.
      IF(N0M.EQ.0) QM=1.0353E-16/T/SQRT(T)*EXP(8762.9/T)*ANE
      DO 120 IAT=1,NATOM
         NKI=NKA(IAT)
         IF(IAT.EQ.IATREF) GO TO 120
         DO 110 I=N0A(IAT),NKA(IAT) 
            IL=ILK(I)
            A(NKH,I)=IZ(IEL(I))-1
            IF(IL.NE.0) A(NKH,I)=IZ(IL)+(IZ(IL)-1)*USUM(IL)*ANE
  110    CONTINUE
  120 CONTINUE
         DO 130 I=N0A(IATREF),NKA(IATREF)
            IL=ILK(I)
            CH=IZ(IEL(I))-1
            IF(IL.GT.0) CH=IZ(IL)+(IZ(IL)-1)*ANE*USUM(IL)
            A(NKH,I)=CH+Q
  130    CONTINUE
         IF(IATREF.EQ.IATH) THEN
            A(NKH,NFIRST(IELH))=Q-QM
            IF(IELHM.NE.0) A(NKH,NFIRST(IELHM))=Q-1.
         END IF
         B(NKH)=ANE
      ELSE
C
C     particle conservation equation, if LCHC=false
C
         DO 140 I=N0A(IATREF),NKA(IATREF)
            IL=ILK(I)
            A(NKH,I)=1.
            IF(IL.GT.0) A(NKH,I)=1.+ANE*USUM(IL)
  140    CONTINUE
         B(NKH)=DENS(ID)/WMM(ID)/YTOT(ID)*ABUND(IATREF,ID)
      END IF
      RETURN
      END
C
C     ****************************************************************
C
      SUBROUTINE SABOLF(ID)
C     =====================
C
C     Saha-Boltzmann factors (SBF)
C     and "upper sums" - sum of Saha-Boltzmann factors for upper, LTE,
C     levels which are not included explicitly (USUM), and derivatives
C     wrt. temperature (T) and electron density (DUSUMN)
C
C     Input: ID  - depth index
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      PARAMETER (UH=1.5)
      PARAMETER (CMAX=2.154D4,CCON=2.0706D-16,TWO=2.D0)
C
C     DCHI - approximate lowering of ionization potential for neutrals
C      Actual lowering is DCHI*effective charge, and is considered only
C      if IUPSUM(ION).GT.0
C
      T=TEMP(ID)
      SQT=SQRT(T)
      ANE=ELEC(ID)
      STANE=SQRT(T/ANE)
      XMAX=CMAX*SQRT(STANE)
      TK=BOLK*T
      CON=CCON/T/SQT
C
C     Saha-Boltzmann factors
C
      DO 50 ION=1,NION
         QZ=IZ(ION)
         CFN=CON/G(NNEXT(ION))
         DCH=0.
         IUPS=IUPSUM(ION)
         SSBF=0.
         USUM(ION)=0.
         nlst=nlast(ion)
         if(ifwop(nlst).ge.0) then
             nl1up=nquant(nlst)+1
          else
             nl1up=nquant(nlst)
         end if
         DO 10 II=NFIRST(ION),NLAST(ION)
            if(ifwop(ii).lt.0) then
               E=EH*QZ*QZ/TK
               SUM=0.
               DO 5 J=nl1up,NLMX
                  XJ=J
                  XI=J*J
                  X=E/XI
                  FI=XI*EXP(X)*WNHINT(J,ID)
                  SUM=SUM+FI
    5          CONTINUE
               g(ii)=sum*two
               gmer(imrg(ii),id)=g(ii)
            end if
            SB=CFN*G(II)*EXP(ENION(II)/TK)
            SBF(II)=SB
            SSBF=SSBF+SB
   10    CONTINUE
C
C     Upper sums
C
         if(ifwop(nlst).lt.0) go to 50
         if(iups.eq.0) then
C
C     1. More exact approach - using (exact) partition functions
C
         IAT=NUMAT(IATM(NFIRST(ION)))
         XMX=XMAX*SQRT(QZ)
         CALL PARTF(IAT,IZ(ION),T,ANE,XMX,U,DUT,DUN)
         EE=ENION(NFIRST(ION))/TK
         CFE=CFN*EXP(EE)
         USUM(ION)=CFE*U-SSBF
         IF(USUM(ION).LT.0.) USUM(ION)=0.
C
C     2. Approximate approach - summation over fixed number of upper
C        levels, assumed hydrogenic (ie. their ionization energy and
C        statistical weight hydrogenic)
C
         else if(iups.gt.0) then
         SUM=0.
         DSUM=0.
         E=EH*QZ*QZ/TK
         DO 30 J=NQUANT(NLAST(ION))+1,IUPS
            XI=J*J
            X=E/XI
            FI=XI*EXP(X)
            SUM=SUM+FI
   30    CONTINUE
         USUM(ION)=SUM*CON*TWO
C
c        3. occupation probability form
c
         else 
         SUM=0.
         DSUM=0.
         E=EH*QZ*QZ/TK
         DO 40 J=NQUANT(NLAST(ION))+1,NLMX
            XJ=J
            XI=J*J
            X=E/XI
            FI=XI*EXP(X)*WNHINT(J,ID)
            SUM=SUM+FI
   40    CONTINUE
         USUM(ION)=SUM*CON*TWO
         end if
   50 CONTINUE
      RETURN
      END
C
C ********************************************************************
C
C

      FUNCTION SBFHMI(FR)
C     ===================
C
C     Bound-free cross-section for H- (negative hydrogen ion)
C
      INCLUDE 'PARAMS.FOR'
      SBFHMI=0.
      FR0=1.8259E14
      IF(FR.LT.FR0) RETURN
      IF(FR.LT.2.111E14) GO TO 10
      X=2.997925E15/FR
      SBFHMI=(6.80133E-3+X*(1.78708E-1+X*(1.6479E-1+X*(-2.04842E-2+X*
     1        5.95244E-4))))*1.E-17
      RETURN
   10 X=2.997925E15*(1./FR0-1./FR)
      SBFHMI=(2.69818E-1+X*(2.2019E-1+X*(-4.11288E-2+X*2.73236E-3)))
     1       *X*1.E-17
      RETURN
      END
C
C
C
C     ****************************************************************
C
C

      SUBROUTINE OPADD(MODE,IJ,ID,FR,CROSS,ABAD,EMAD,SCAD)
C     ====================================================
C
C     Additional opacities
C     This is basically user-supplied procedure; here are some more
C     important non-standard opacity sources, namely
C     Rayleigh scattering, H- opacity, H2+ opacity, and additional
C     opacity of He I and He II.
C     Inclusion of these opacities is contolled by switches transmitted
C     by COMMON/OPCPAR - see description in START.
C
C     Input parameters:
C     MODE  - controls the nature and the amount of calculations
C           = -1 - (OPADD called from START) evaluation of relevant
C                  depth-dependent quantities (usually photoionization
C                  cross-sections, but also possibly other), which are
C                  stored in array CROS
C           = 0  - evaluation of an additional opacity, emissivity, and
C                  scattering - for procedure OPAC0
C     IJ    - frequency index
C     ID    - depth index
C     FR    - frequency 
C     CROSS - array of photionization cross-section or other auxiliary
C             parameters for evaluating an additional opacity
C             Note: CROSS is output for MODE=-1, and input for other MODE
C
C     Output: 
C
C     ABAD  - absorption coefficient (at frequency point IJ and depth ID)
C     EMAD  - emission coefficient (at frequency point IJ and depth ID)
C     SCAD  - scattering coefficient (at frequency point IJ and depth ID)
C
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      DIMENSION CROSS(MCROSS,MFREQ)
      PARAMETER (FRRAY =  2.463E15)
C
      AB0=0.
      ABAD=0.
      EMAD=0.
      SCAD=0.
C
      if(iath.gt.0) then
      N0HN=NFIRST(IELH)
      NKH=NKA(IATH)
C
      IF(MODE.GE.0) THEN
         T=TEMP(ID)
         ANE=ELEC(ID)
         HKT=HK/T
         T32=1./T/SQRT(T)
      END IF
C
      IT=NLEVEL
C
C   -----------------------
C   HI  Rayleigh scattering
C   -----------------------
C
      IF(IRSCT.NE.0.AND.IOPHLI.NE.1.AND.IOPHLI.NE.2) THEN
      IT=IT+1
      IF(MODE.LT.0) THEN
         X=(2.997925E18/MIN(FR,FRRAY))**2
         CROSS(IT,IJ)=(5.799E-13+(1.422E-6+2.784/X)/X)/X/X
       ELSE
         ABAD=POPUL(N0HN,ID)*CROSS(IT,IJ)
         SCAD=ABAD
      END IF
      END IF
      IF(IOPHMI.NE.0) THEN
C
C   ----------------------------
C   H-  bound-free and free-free
C   ----------------------------
C     Note: IOPHMI must not by taken non-zero if H- is considered
C           explicitly, because H- opacity would be taken twice
C
      IT=IT+1
      IF(MODE.LT.0) THEN
         CROSS(IT,IJ)=SBFHMI(FR)
       ELSE
          XHM=8762.9/T
          SB=1.0353E-16*T32*EXP(XHM)*POPUL(N0HN,ID)*ANE*CROSS(IT,IJ)
          SF=SFFHMI(POPUL(N0HN,ID),FR,T)*ANE
          AB0=SB+SF
      END IF
      END IF

C
      IF(IOPH2P.GT.0) THEN
C
C   -----------------------------
C   H2+  bound-free and free-free
C   -----------------------------
C
      IT=IT+1
      IF(MODE.LT.0) THEN
         X=FR*1.E-15
         CROSS(IT,IJ)=(-7.342E-3+(-2.409+(1.028+(-4.23E-1+
     *        (1.224E-1-1.351E-2*X)*X)*X)*X)*X)*1.602E-12/BOLK
         IT=IT+1
         X=LOG(FR)
         CROSS(IT,IJ)=-3.0233E3+(3.7797E2+(-1.82496E1+(3.9207E-1-
     *                 3.1672E-3*X)*X)*X)*X
       ELSE
         X2=-CROSS(IT,IJ)/T+CROSS(IT+1,IJ)
         IT=IT+1
         SB=0.
         IF(X2.GT.-150.) SB=POPUL(N0HN,ID)*POPUL(NKH,ID)*EXP(X2)
         AB1=SB
      END IF
      END IF
      end if
C
C   ----------------------
C   neutral helium opacity
C   ----------------------
C     approximate, hydrogenic, opacity of neutral helium
C     given as a sum of bound-free transitions from averaged
C     levels with principal quantum numbers between that next
C     to the highest level considered explicitly and IOPHE1
C
      IF(IOPHE1.GT.0) THEN
      NHE2=NNEXT(IELHE1)
      I1=NQUANT(NLAST(IELHE1))+1
      IF(MODE.LT.0) THEN
         SG0=2.815E-16/(FR*1.E-15)**3
         DO 20 I=I1,IOPHE1
            IT=IT+1
            FRI=3.29E15/I/I
            SG=0.
            IF(FR.GE.FRI) SG=SG0*GAUNT(I,FR)/I**5
            CROSS(IT,IJ)=SG
   20    CONTINUE
       ELSE
         SB=4.1412E-16*T32
         DO 30 I=I1,IOPHE1
            IT=IT+1
            FRI=3.29E15/I/I
            IF(FR.LT.FRI) GO TO 30
            XI=HKT*FRI
            SG=SB*EXP(XI)*I*I*POPUL(NHE2,ID)*ANE*CROSS(IT,IJ)
            AB0=AB0+SG
   30    CONTINUE
      END IF
      END IF
C
C   --------------
C   ionized helium (analogously as for neutral helium)
C   --------------
C
      IF(IOPHE2.GT.0) THEN
      NHE3=NNEXT(IELHE2)
      I1=NQUANT(NLAST(IELHE2))+1
      IF(MODE.LT.0) THEN
         SG0=4.504E-15/(FR*1.E-15)**3
         DO 40 I=I1,IOPHE2
            IT=IT+1
            FRI=1.316E16/I/I
            SG=0.
            IF(FR.GE.FRI) SG=SG0*GAUNT(I,FR/4.E0)/I**5
            CROSS(IT,IJ)=SG
   40    CONTINUE
       ELSE
         SB=4.1412E-16*T32
         DO 50 I=I1,IOPHE2
            IT=IT+1
            FRI=1.316E16/I/I
            IF(FR.LT.FRI) GO TO 50
            XI=HKT*FRI
            SG=SB*EXP(XI)*I*I*POPUL(NHE3,ID)*ANE*CROSS(IT,IJ)
            AB0=AB0+SG
   50    CONTINUE
      END IF
      END IF
C
C     ----------------------------------------------
C     The user may supply more opacity sources here:
C     ----------------------------------------------
C
C     Finally, actual absorption and emission coefficients

      IF(MODE.LT.0) RETURN
      X=EXP(-HKT*FR)
      X1=1.-X
      BNX=BN*(FR*1.E-15)**3*X
      ABAD=ABAD+X1*(AB0+AB1)
      EMAD=EMAD+BNX*(AB0+AB1)
      RETURN
      END
C
C
C     ****************************************************************
C
C
      function wn(xn,a,ane,z)
C     =======================
c
c     evaluation of the occupation probablities for a hydrogenic ion
c     using eqs (4.26), and (4.39) of Hummer,Mihalas Ap.J. 331, 794, 1988.
c     approximate evaluation of Q(beta) - Hummer
c
c     Input: xn  - real number corresponding to quantum number n
c            a   - correlation parameter
c            ane - electron density
c            z   - ionic charge
c
      INCLUDE 'PARAMS.FOR'
      parameter (p1=0.1402,p2=0.1285,p3=1.,p4=3.15,p5=4.,un=1.)
      parameter (tkn=3.01,ckn=5.33333333,cb=8.3e14)
      parameter (f23=-2./3.)
c
c     evaluation of k(n)
c
      if(xn.ge.3.01) then
         xkn=un
       else
         xkn=ckn*xn/(xn+un)/(xn+un)
      end if
c
c     evaluation of beta
c
      beta=cb*z*z*z*xkn/xn/xn/xn/xn*exp(f23*log(ane))
c
c     approximate expression for Q(beta)
c
      x=exp(p4*log(un+p3*a))
c     c1=p1*(x+p5*z*a*a*a)    ! previous expression -ERROR !!!!!!
      c1=p1*(x+p5*(z-un)*a*a*a)
      c2=p2*x
      f=(c1*beta*beta*beta)/(un+c2*beta*sqrt(beta))
      wn=f/(un+f)
      return
      end
C
C
C ********************************************************************
C
C
      SUBROUTINE WNSTOR(ID)
C     =====================
C
C     Stores occupation probabilities for hydrogen levels
C     in common WNCOM for further use
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      PARAMETER (UN=1.,TWO=2.,SIXTH=1./6.,CCOR=0.09)
      parameter (p1=0.1402,p2=0.1285,p3=1.,p4=3.15,p5=4.)
      parameter (tkn=3.01,ckn=5.33333333,cb=8.3d14,f23=-2./3.)
C
      ANE=ELEC(ID)
      A=CCOR*EXP(SIXTH*LOG(ANE))/SQRT(TEMP(ID))
      DO 20 I=1,NLMX
         XN=I
         WNHINT(I,ID)=wn(xn,a,ane,un)
         WNHE2(I,ID)=wn(xn,a,ane,two)
   20 CONTINUE
C
C     array WOP - occupation probabilities for explicit levels
C
      do 30 ii=1,nlevel
         wop(ii,id)=un
         if(ifwop(ii).le.0) go to 30
         ie=iel(ii)
         nq=nquant(ii)
         if(iz(ie).eq.1) then
            wop(ii,id)=wnhint(nq,id)
          else if(iz(ie).eq.2) then
            wop(ii,id)=wnhe2(nq,id)
          else
            z=iz(ie)
            xn=nq
            wop(ii,id)=wn(xn,a,ane,z)
         end if
   30 continue
      RETURN
      END
C
C
C ********************************************************************
C
C
C
      SUBROUTINE TIMING(MOD,ITER)
C     ===========================
C
C     Timing procedure (call machine dependent routine!!)
C
C     INCLUDE 'PARAMS.FOR'
      CHARACTER ROUT*10
      DATA T0/0./
C
      TIME=SECOND()
      DT=TIME-T0
      T0=TIME
      IF(MOD.EQ.0) THEN
         IP=0
         ROUT=' INIT     '
      ELSE IF(MOD.EQ.1) THEN
         IP=ITER-1
         ROUT=' OPACITY  '
      ELSE IF(MOD.EQ.2) THEN
         IP=ITER
         ROUT='  TRANSFER'
      ENDIF
      WRITE(69,600) IP,MOD,TIME,DT,ROUT
  600 FORMAT(2I4,2F11.2,2X,A10)
      RETURN
      END
C
C
C ********************************************************************
C
C
      function second()
C     ==================
c
c this machine-dependent function returns elapsed CPU time in seconds.
c This version is for the DEC 5000/200 running Ultrix
c
c     INCLUDE 'PARAMS.FOR'
      dimension dummy(2)
      second=etime(dummy)
      return
      end
c
c
c
      subroutine quit(text)
C     =====================
c
c     stops the program and writes a text
c
      INCLUDE 'PARAMS.FOR'
      character*(*) text
      write(6,10) text
   10 format(1x,a)
      stop
      end
c
c

C
C *******************************************************************
C


      function voigte(a,vs)
c     =====================
c
c     computes a voigt function  h = h(a,v)
c     a=gamma/(4*pi*dnud)   and  v=(nu-nu0)/dnud.  this  is  done after
c     traving (landolt-b\rnstein, p. 449).
c
      INCLUDE 'PARAMS.FOR'
      dimension ak(19),a1(5)
      data ak      /-1.12470432, -0.15516677,  3.28867591, -2.34357915,
     ,  0.42139162, -4.48480194,  9.39456063, -6.61487486,  1.98919585,
     , -0.22041650, 0.554153432, 0.278711796,-0.188325687, 0.042991293,
     ,-0.003278278, 0.979895023,-0.962846325, 0.532770573,-0.122727278/
      data sqp/1.772453851/,sq2/1.414213562/
c
      v = abs(vs)
      u = a + v
      v2 = v*v
      if (a.eq.0.0) go to 140
      if (a.gt.0.2) go to 120
      if (v.ge.5.0) go to 121
c
      ex=0.
      if(v2.lt.100.)ex = exp(-v2)
      k = 1
c
  100 quo = 1.
      if (v.lt.2.4) go to 101
      quo = 1./(v2 - 1.5)
      m = 11
      go to 102
c
  101 m = 6
      if (v.lt.1.3) m = 1
  102 do 103 i=1,5
         a1(i) = ak(m)
         m = m + 1
  103 continue
      h1 = quo*(a1(1) + v*(a1(2) + v*(a1(3) + v*(a1(4) + v*a1(5)))))
      if (k.gt.1) go to 110
c
c a le 0.2  and v lt 5.
c
      hh = h1*a + ex*(1. + a*a*(1. - 2.*v2))
      voigte=hh
      return
c
  110 pqs = 2./sqp
      h1p = h1 + pqs*ex
      h2p = pqs*h1p - 2.*v2*ex
      h3p = (pqs*(1. - ex*(1. - 2.*v2)) - 2.*v2*h1p)/3. + pqs*h2p
      h4p = (2.*v2*v2*ex - pqs*h1p)/3. + pqs*h3p
      psi = ak(16) + a*(ak(17) + a*(ak(18) + a*ak(19)))
c
c 0.2 lt a le 1.4  and  a + v le 3.2
c
      hh = psi*(ex + a*(h1p + a*(h2p + a*(h3p + a*h4p))))
      voigte=hh
      return
c
  120 if (a.gt.1.4.or.u.gt.3.2) go to 130
      ex=0.
      if(v2.lt.100.)ex = exp(-v2)
      k = 2
      go to 100
c
c a le 0.2  and  v ge 5.
c
  121 hh = a*(15. + 6.*v2 + 4.*v2*v2)/(4.*v2*v2*v2*sqp)
      voigte=hh
      return
c
  130 a2 = a*a
      u = sq2*(a2 + v2)
      u2 = 1./(u*u)
c
c a gt 1.4  or  a + v gt 3.2
c
      hh = sq2/sqp*a/u*(1. + u2*(3.*v2 - a2) +
     ,        u2*u2*(15.*v2*v2 - 30.*v2*a2 + 3.*a2*a2))
      voigte=hh
      return
c
c a eq 0.
c
  140 hh=0.
      if(v2.lt.100.) hh=exp(-v2)
      voigte=hh
      return
      end
C
C
C ********************************************************************
C
C
      SUBROUTINE SIGAVS
C     =================
C
C     Read bound-free cross-sections for averaged levels
C     from the unit INSA (given by IFANCY), with increasing frequencies
C     It assumes that all continuum transitions for a given ion are
C     given in a successive order in the data (i.e. as in TLUSTY for
C     explicit levels. For other levels, additional input data in
C     unit 54 !!
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'SYNTHP.FOR'
      PARAMETER (HCCM=H*2.997925D10,BAM=1.D-18)
      LOGICAL LUV
      DIMENSION CRD(MFCRA),XIFE(6),FRD(MFCRA)
      CHARACTER*30 FIDATA(MION),FIODF1(MION),FIODF2(MION),FIBFCS(MION)
      COMMON/IONFIL/FIDATA,FIODF1,FIODF2,FIBFCS
C
      DATA XIFE/63480.,130563.,247220.,442000.,605000.,799000./
C
      FR1=FREQ(1)
      FR2=FREQ(2)
      NUNIT=0
      NQHT=0
      IF(IASV.EQ.0) GOTO 100
      WRITE(6,600)
  600 FORMAT(///,' DETAILED PHOTOIONIZATION CROSS-SECTIONS',
     * ' (EXPLICIT LEVELS)',/,
     * ' ---------------------------------------',/)
      DO 10 I=1,NION
        N1=NFIRST(I)
        N2=NLAST(I)
        INSA=0
        DO 11 II=N1,N2
          NFCR(II)=2
          FRECR(II,1)=FR1
          FRECR(II,2)=FR2
          CROSR(II,1)=0.
          CROSR(II,2)=0.
          INSB=IBF(II)
          IF(INSB.LT.50.OR.INSB.GT.100) GO TO 11
          IF(INSA.EQ.0) INSA=INSB
          IF(INSA.NE.INSB)
     *     call quit(' Incoherent file units in SIGAVS')
   11   CONTINUE
        IF(INSA.EQ.0) GOTO 10
        IF(FIBFCS(I).NE.' ') THEN
           INSA=INBFCS(I)
           OPEN(INSA,FILE=FIBFCS(I),STATUS='OLD')
        END IF
        READ(INSA,*,END=500,ERR=500) IIAT,IIZ,NSUP
        ATI=IIAT+0.01*(IIZ-1)
        IF(NSUP.GT.(N2-N1+1))
     *   call quit(' Too many bf-trans. in input file (SIGAVS)')
        WRITE(6,601) ATI,INSA
        DO 12 II=1,NSUP
          READ(INSA,*,END=500,ERR=500) IILO,EELO,GGLO,NFCRR
          IK=N1+IILO-1
          IF (IK.GT.N2 .OR. IK.LT.N1)
     *      call quit(' Inconsistent level numbering in SIGAVS')
          IF(IIAT.NE.26) GOTO 13
          ECMR=XIFE(IIZ)-EELO
c         DE=ABS((ENION(IK)-HCCM*ECMR)/ENION(IK))
c         IF(DE.GT.1.D-4) call quit(' Incorrect energy level in SIGAVS')
   13     READ(INSA,*,END=500,ERR=500) FR0,CR0
          NFD=1
          FRD(NFD)=FR0
          CRD(NFD)=CR0
          LUV=.FALSE.
          DO 14 IJ=1,NFCRR-1
            READ(INSA,*,END=500,ERR=500) FRIN,CRIN
            IF(LUV) GOTO 14
            IF(FRIN.GT.FR1) THEN
              IF(FR0.LE.FR2.AND.IJ.GT.1) THEN 
                NFD=NFD+1
                FRD(NFD)=FR0
                CRD(NFD)=CR0
              ENDIF
              NFD=NFD+1
              FRD(NFD)=FRIN
              CRD(NFD)=CRIN
              LUV=.TRUE.
            ELSE IF(FRIN.GT.FR2) THEN
              IF(FR0.LE.FR2.AND.IJ.GT.1) THEN 
                NFD=NFD+1
                FRD(NFD)=FR0
                CRD(NFD)=CR0
              ENDIF
              NFD=NFD+1
              FRD(NFD)=FRIN
              CRD(NFD)=CRIN
              FR0=FRIN
              CR0=CRIN
            ELSE
              FR0=FRIN
              CR0=CRIN
            ENDIF
            IF(NFD.GT.MFCRA)
     *        call quit(' Too many frequencies in SIGAVS')
   14     CONTINUE
          CRMX(IK)=0.
          DO 15 IJ=1,NFD
            CRMX(IK)=MAX(CRMX(IK),CRD(IJ))
   15     CONTINUE
          IF(CRMX(IK).GT.0.) THEN
            WRITE(6,601) ATI,IILO,EELO,NFD
  601       FORMAT(F7.2,I6,F13.3,I8)
            NFCR(IK)=NFD
            DO 16 IJ=1,NFD
              FRECR(IK,IJ)=FRD(NFD-IJ+1)
              CROSR(IK,IJ)=CRD(NFD-IJ+1)*BAM
   16       CONTINUE
          ENDIF
   12   CONTINUE
   10 CONTINUE
C
  100 READ(54,*,END=540,ERR=540) NUNIT
      IF(NUNIT.LE.0) RETURN
      WRITE(6,602)
  602 FORMAT(///,' DETAILED PHOTOIONIZATION CROSS-SECTIONS',
     * ' (NON-EXPLICIT LEVELS)',/,
     * ' ---------------------------------------',/)
      DO 110 IN=1,NUNIT
        READ(54,*,END=540,ERR=540) ATIR,INSA,NQHTR
        NQHT=NQHT+NQHTR
        IF(NQHT.GT.MPHOT)
     *    call quit(' Too many BF cross-sections in SIGAVS')
        READ(INSA,*,END=501,ERR=501) IIAT,IIZ,NSUP
C
c       check the total number of superlevels
c
        IF(NQHTR.GT.NSUP) THEN
           WRITE(6,603) NQHTR,NSUP
  603      FORMAT(' NQHTR=',i4,' in Unit 54 input greater than NSUP=',
     *              i4,/' program resets NQHTR to NSUP'/)
           NQHTR=NSUP
        END IF
c
C      loop over superlevels - read cross-sections
c
        DO 120 I=1,NQHTR
          IK=NQHT-NQHTR+I
          READ(INSA,*,END=501,ERR=501) IILO,EELO,GGLO,NFCRR
          AQHT(IK)=ATIR
          EQHT(IK)=EELO
          GQHT(IK)=GGLO
          READ(INSA,*) FR0,CR0
          NFD=1
          FRD(NFD)=FR0
          CRD(NFD)=CR0
          LUV=.FALSE.
          DO 130 IJ=1,NFCRR-1
            READ(INSA,*) FRIN,CRIN
            IF(LUV) GOTO 130
            IF(FRIN.GT.FR1) THEN
              IF(FR0.LE.FR2.AND.IJ.GT.1) THEN 
                NFD=NFD+1
                FRD(NFD)=FR0
                CRD(NFD)=CR0
              ENDIF
              NFD=NFD+1
              FRD(NFD)=FRIN
              CRD(NFD)=CRIN
              LUV=.TRUE.
            ELSE IF(FRIN.GT.FR2) THEN
              IF(FR0.LE.FR2.AND.IJ.GT.1) THEN 
                NFD=NFD+1
                FRD(NFD)=FR0
                CRD(NFD)=CR0
              ENDIF
              NFD=NFD+1
              FRD(NFD)=FRIN
              CRD(NFD)=CRIN
              FR0=FRIN
              CR0=CRIN
            ELSE
              FR0=FRIN
              CR0=CRIN
            ENDIF
  130     CONTINUE
          CRMY(IK)=0.
          DO 140 IJ=1,NFD
            CRMY(IK)=MAX(CRMY(IK),CRD(IJ))
  140     CONTINUE
          IF(CRMY(IK).GT.0.) THEN
            WRITE(6,611) ATIR,IILO,EELO,NFD
  611       FORMAT(F7.2,I6,F13.3,I8)
            NFQHT(IK)=NFD
            DO 150 IJ=1,NFD
              FRECQ(IK,IJ)=FRD(NFD-IJ+1)
              QHOT(IK,IJ)=CRD(NFD-IJ+1)*BAM
  150       CONTINUE
          ENDIF
  120   CONTINUE
  110 CONTINUE
  540 RETURN
C
  500 call quit(' ERROR IN DATA FILE FOR BF SIG OF AVERAGED LEVELS (1)')
  501 call quit(' ERROR IN DATA FILE FOR BF SIG OF AVERAGED LEVELS (2)')
C
      END
C
C
C ********************************************************************
C
C

      SUBROUTINE PHTX(ID,ABSO,EMIS)
C     =============================
C
C     Opacity due to detailed photoionization (read from tables by
C     routine SIGAVS)
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      INCLUDE 'LINDAT.FOR'
      DIMENSION ABSO(MFREQ),EMIS(MFREQ),PLANF(MFREQ),STIMU(MFREQ)
      DIMENSION PHOTI(MCROSS,MFREQ)
      DIMENSION IJP(MLEVEL),IJQ(MPHOT)
      PARAMETER (C3=1.4387886)
      SAVE PHOTI,IJP,IJQ
C
      IF(IASV.EQ.0 .AND. NQHT.EQ.0) RETURN
      T=TEMP(ID)
      DO 10 IJ=1,NFREQ
         XX=FREQ(IJ)
         X15=XX*1.E-15
         BNU=BN*X15*X15*X15
         HKF=HK*XX
         EXH=EXP(HKF/T)
         PLANF(IJ)=BNU/(EXH-1.)
         STIMU(IJ)=1.-1./EXH
   10 CONTINUE
C
      IF(IASV.EQ.0) GOTO 100
      IF(ID.EQ.1) THEN
        DO 40 I=1,NLEVEL
          IF(CRMX(I).EQ.0.) GOTO 40
          IK1=MAX0(2,IJP(I))
          DO 42 IJ=3,NFREQ
            DO 45 IK=IK1,NFCR(I)
              IF(FRECR(I,IK).LT.FREQ(IJ)) THEN
                IK2=IK
                GOTO 46
              ENDIF
   45       CONTINUE
   46       IK1=IK2
            IF(IJ.EQ.3) IJP(I)=IK1
            DFR=(FREQ(IJ)-FRECR(I,IK1))/(FRECR(I,IK1-1)-FRECR(I,IK1))
            PHOTI(I,IJ)=CROSR(I,IK1)+DFR*(CROSR(I,IK1-1)-CROSR(I,IK1))
   42     CONTINUE
          PHOTI(I,1)=PHOTI(I,3)
          PHOTI(I,2)=PHOTI(I,NFREQ)
   40   CONTINUE
      ENDIF
      DO 30 I=1,NLEVEL
        IF(CRMX(I).EQ.0.) GOTO 30
        POP=POPUL(I,ID)
        DO 20 IJ=1,NFREQ
          AB=PHOTI(I,IJ)*POP*STIMU(IJ)
          ABSO(IJ)=ABSO(IJ)+AB
          EMIS(IJ)=EMIS(IJ)+AB*PLANF(IJ)
   20   CONTINUE
   30 CONTINUE
C
  100 IF(NQHT.EQ.0) RETURN
      IF(ID.EQ.1) THEN
        DO 110 I=1,NQHT
          IF(CRMY(I).EQ.0.) GOTO 110
          IK1=MAX0(2,IJQ(I))
          DO 120 IJ=3,NFREQ
            DO 125 IK=IK1,NFQHT(I)
              IF(FRECQ(I,IK).LT.FREQ(IJ)) THEN
                IK2=IK
                GOTO 126
              ENDIF
  125       CONTINUE
  126       IK1=IK2
            IF(IJ.EQ.3) IJQ(I)=IK1
            DFR=(FREQ(IJ)-FRECQ(I,IK1))/(FRECQ(I,IK1-1)-FRECQ(I,IK1))
            PHOTI(I,IJ)=QHOT(I,IK1)+DFR*(QHOT(I,IK1-1)-QHOT(I,IK1))
  120     CONTINUE
  110   CONTINUE
      ENDIF
      DO 210 I=1,NQHT
        IF(CRMY(I).EQ.0.) GOTO 210
        IAT=AQHT(I)
        X=(AQHT(I)-FLOAT(IAT)+1.E-4)*100.
        ION=INT(X)+1
        POP=RRR(ID,ION,IAT)*GQHT(I)*EXP(-EQHT(I)*C3/T)
        DO 220 IJ=3,NFREQ
          AB=PHOTI(I,IJ)*POP*STIMU(IJ)
          ABSO(IJ)=ABSO(IJ)+AB
          EMIS(IJ)=EMIS(IJ)+AB*PLANF(IJ)
  220   CONTINUE
  210 CONTINUE
C
      RETURN
      END
C
C
C ********************************************************************
C
      subroutine getlal(nflall)
c     =========================
c
c     getlal reads in the profile functions for first and second
c            order in neutral and ionized H density
c
      INCLUDE 'PARAMS.FOR'
      parameter (NXMAX=700,NNMAX=5)
      common /callard/xlall(NXMAX),plall(NXMAX,NNMAX),stnneu,stncha,
     *     vneu,vcha
      common /iallard/nxall,iwarn
      read(nflall,*) nxall,stnneu,stncha,vneu,vcha
      do 10 i=1,nxall
         read(nflall,*) xlall(i),(plall(i,j),j=1,NNMAX)
   10 continue
      close(nflall)
      stnneu=10.0**stnneu
      stncha=10.0**stncha
      iwarn=0
      return
      end
c
C
C ********************************************************************
C
      subroutine allard(xl,hneutr,hcharg,prof)
c     ========================================
c
c     special routine for Lyman alpha in cool DA
c     Input:  xl  wavelength in [A]
c             hneutr  neutral H particle density [cm-3]
c             hcharg  ionized H particle density [cm-3]
c     Output: prof  Lyman alpha line profile, normalized to 1.0e8
c             if integrated over A
c
      INCLUDE 'PARAMS.FOR'
      parameter (NXMAX=700,NNMAX=5)
      common /callard/xlall(NXMAX),plall(NXMAX,NNMAX),stnneu,stncha,
     *     vneu,vcha
      common /iallard/nxall,iwarn
      if(xl.lt.xlall(1).or.xl.gt.xlall(nxall)) then
         prof=0.0
         return
      endif
      vn1=hneutr/stnneu
      vn2=hcharg/stncha
      vns=vn1*vneu+vn2*vcha
      if(iwarn.eq.0) then
         if(vn1*vneu.gt.0.3.or.vn2*vcha.gt.0.3) then
            write(*,*) '          warning: density too high for',
     *           ' Lyman alpha expansion'
            iwarn=1
         endif
      endif
      vn11=vn1*vn1
      vn22=vn2*vn2
      vn12=vn1*vn2
c      xnorm=1.0-vns+0.5*vns*vns
      xnorm=1.0/(1.0+vns+0.5*vns*vns)
c
      jl=0
      ju=nxall+1
 10   if(ju-jl.gt.1) then	
         jm=(ju+jl)/2
         if((xlall(nxall).gt.xlall(1)).eqv.(xl.gt.xlall(jm))) then
            jl=jm
         else
            ju=jm
         endif
         go to 10
      endif
      j=jl
c
      if(j.eq.0) j=1
      if(j.eq.nxall) j=j-1
      a1=(xl-xlall(j))/(xlall(j+1)-xlall(j))
      p1=  vn1*((1.0-a1)*plall(j,1)+a1*plall(j+1,1))
      p11=vn11*((1.0-a1)*plall(j,2)+a1*plall(j+1,2))
      p2=  vn2*((1.0-a1)*plall(j,3)+a1*plall(j+1,3))
      p22=vn22*((1.0-a1)*plall(j,4)+a1*plall(j+1,4))
      p12=vn12*((1.0-a1)*plall(j,5)+a1*plall(j+1,5))
      prof=(p1+p2+p11+p22+p12)*xnorm
      return
      end
C
C
C     **************************************************************
C
C
      subroutine readbf
c     =================
c
c     auxiliary subroutine for enabling reading of input data with
c     comments
c
c     lines beginning with ! or * are understood as comments
c
      INCLUDE 'PARAMS.FOR'
      character*80 buff
   10 continue
      read(5,501,end=20) buff
      if(buff(1:1).eq.'!'.or.buff(1:1).eq.'*') go to 10
      write(ibuff,501) buff
      go to 10
  501 format(a)
   20 continue
      rewind 15
      return 
      end
C
C
C     *******************************************************************
C
C

      SUBROUTINE PRETAB
C     =================
C
C     pretabulate expansion coefficients for the Voigt function
C     200 steps per doppler width - up to 10 Doppler widths
C
      INCLUDE 'PARAMS.FOR'
      PARAMETER (VSTEPS=200.,MVOI=2001)
      COMMON/VOITAB/H0TAB(MVOI),H1TAB(MVOI),H2TAB(MVOI)
      DIMENSION TABVI(81),TABH1(81)
      DATA TABVI/0.,.1,.2,.3,.4,.5,.6,.7,.8,.9,1.,1.1,1.2,1.3,1.4,1.5,
     11.6,1.7,1.8,1.9,2.,2.1,2.2,2.3,2.4,2.5,2.6,2.7,2.8,2.9,3.,3.1,3.2,
     2 3.3,3.4,3.5,3.6,3.7,3.8,3.9,4.0,4.2,4.4,4.6,4.8,5.0,5.2,5.4,5.6,
     3 5.8,6.0,6.2,6.4,6.6,6.8,7.0,7.2,7.4,7.6,7.8,8.0,8.2,8.4,8.6,8.8,
     4 9.0,9.2,9.4,9.6,9.8,10.0,10.2,10.4,10.6,10.8,11.0,11.2,11.4,11.6,
     5 11.8,12.0/
      DATA TABH1/-1.12838,-1.10596,-1.04048,-.93703,-.80346,-.64945,
     1-.48552,-.32192,-.16772,-.03012,.08594,.17789,.24537,.28981,
     2.31394,.32130,.31573,.30094,.28027,.25648,.231726,.207528,.184882,
     3.164341,.146128,.130236,.116515,.104739,.094653,.086005,.078565,
     4 .072129,.066526,.061615,.057281,.053430,.049988,.046894,.044098,
     5 .041561,.039250,.035195,.031762,.028824,.026288,.024081,.022146,
     6 .020441,.018929,.017582,.016375,.015291,.014312,.013426,.012620,
     7 .0118860,.0112145,.0105990,.0100332,.0095119,.0090306,.0085852,
     8 .0081722,.0077885,.0074314,.0070985,.0067875,.0064967,.0062243,
     9 .0059688,.0057287,.0055030,.0052903,.0050898,.0049006,.0047217,
     T .0045526,.0043924,.0042405,.0040964,.0039595/
C
      N=MVOI
      DO 10 I=1,N
   10    H0TAB(I)=FLOAT(I-1)/VSTEPS
      CALL INTERP(TABVI,TABH1,H0TAB,H1TAB,81,N,2,0,0)
      DO 20 I=1,N
         VV=(FLOAT(I-1)/VSTEPS)**2
         H0TAB(I)=EXP(-VV)
         H2TAB(I)=H0TAB(I)-(VV+VV)*H0TAB(I)
   20 CONTINUE
      RETURN
      END
C
C
C     *******************************************************************
C
C

      FUNCTION VOIGTK(A,V)
C     ====================
C
C     Voigt function after Kurucz (in Computational Astrophysics)
C
      INCLUDE 'PARAMS.FOR'
      PARAMETER (MVOI=2001)
      PARAMETER (ONE=1., THREE=3., TEN=10., FIFTN=15., TWOH=200.,
     *           C14142=1.4142, C11283=1.12838, C15=1.5,C32=3.2,
     *           C05642=0.5642,C79788=0.79788,C02=0.2,C14=1.4,
     *           C37613=0.37613,C23=2./3.,
     *           CV1=-.122727278,CV2=.532770573,CV3=-.96284325, 
     *           CV4=.979895032)
      COMMON/VOITAB/H0TAB(MVOI),H1TAB(MVOI),H2TAB(MVOI)
      IV=V*TWOH+C15
      IF(A.LT.C02) THEN
         IF(V.LE.TEN) THEN 
            VOIGTK=(H2TAB(IV)*A+H1TAB(IV))*A+H0TAB(IV)
          ELSE
            VOIGTK=C05642*A/(V*V)
         END IF
         RETURN
      END IF
      IF(A.GT.C14) GO TO 10
      IF(A+V.GT.C32) GO TO 10
      VV=V*V
      HH1=H1TAB(IV)+H0TAB(IV)*C11283
      HH2=H2TAB(IV)+HH1*C11283-H0TAB(IV)
      HH3=(ONE-H2TAB(IV))*C37613-HH1*C23*VV+HH2*C11283
      HH4=(THREE*HH3-HH1)*C37613+H0TAB(IV)*C23*VV*VV
      VOIGTK=((((HH4*A+HH3)*A+HH2)*A+HH1)*A+H0TAB(IV))*
     *       (((CV1*A+CV2)*A+CV3)*A+CV4)
      RETURN
   10 AA=A*A
      VV=V*V
      U=(AA+VV)*C14142
      UU=U*U
      VOIGTK=((((AA-TEN*VV)*AA*THREE+FIFTN*VV*VV)/UU+THREE*VV-AA)/UU+
     *       ONE)*A*C79788/U
      RETURN
      END
C
C
C     *******************************************************************
C
C
 
      SUBROUTINE RTECD
C     ================
C
C     solution of the radiative transfer equation by Feautrier method
C     for two continuum points 
C     used when one employs RTEDFE, ie. the DFE method for the
C     transfer equation for the inner frequency points
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      DIMENSION D(3,3,MDEPTH),ANU(3,MDEPTH),AANU(MDEPTH),DDD(MDEPTH),
     *       AA(3,3),BB(3,3),CC(3,3),VL(3),AMU(3),WTMU(3),
     *       DT(MDEPTH),TAU(MDEPTH),
     *       RDD(MDEPTH),FKK(MDEPTH),ST0(MDEPTH),SS0(MDEPTH),
     *       RINT(MDEPTH,MMU)
      INTEGER MSC(2,MDEPTH)
      COMMON CH(MFREQ,MDEPTH),ET(MFREQ,MDEPTH),SCAT(2,MDEPTH),MSC
      COMMON/EMFLUX/FLUX(MFREQ)
      COMMON/CONTLH/SCL1(2),ICONTL
      COMMON/CONSCA/SCC1(mdepth),SCC2(MDEPTH)
      COMMON/IPRNTR/IPRIN
c     PARAMETER (NMU = 3)
      PARAMETER (UN=1.D0, HALF=0.5D0)
      PARAMETER (THIRD=UN/3., QUART=UN/4., SIXTH=UN/6.D0)
      PARAMETER (TAUREF = 0.6666666666667)
      DATA AMU/.887298334620742D0,.5D0,.112701665379258D0/,
     1     WTMU/.277777777777778D0,.444444444444444D0,.277777777777778D0
     1         /
C
      NMU=3
      ND1=ND-1
C
C     loop over two continuum frequencies 
C
      DO 100 IJ=1,2       
      TAUMIN=CH(IJ,1)/DENS(1)*DM(1)*HALF
      TAU(1)=TAUMIN
      DO 10 I=1,ND1
         DT(I)=(DM(I+1)-DM(I))*(CH(IJ,I+1)/DENS(I+1)+CH(IJ,I)/DENS(I))*
     *         HALF
         ST0(I)=ET(IJ,I)/CH(IJ,I)
         SS0(I)=-SCAT(IJ,I)/CH(IJ,I)
         TAU(I+1)=TAU(I)+DT(I)
         IF(TAU(I).LE.TAUREF.AND.TAU(I+1).GT.TAUREF) IREF=I
   10 CONTINUE
      ST0(ND)=ET(IJ,ND)/CH(IJ,ND)
      SS0(ND)=-SCAT(IJ,ND)/CH(IJ,ND)
      FR=FREQ(IJ)
      IF(ICONTL.EQ.1) GO TO 17
      DO 15 I=1,ND
   15    SS0(I)=SS0(I)*MSC(IJ,I)*1.E-3
   17 CONTINUE
      BNU=BN*(FR*1.E-15)**3
      PLAND=BNU/(EXP(HK*FR/TEMP(ND  ))-UN)
      DPLAN=BNU/(EXP(HK*FR/TEMP(ND-1))-UN)
      DPLAN=(PLAND-DPLAN)/DT(ND1)
C
C   +++++++++++++++++++++++++++++++++++++++++
C   FIRST PART  -  VARIABLE EDDINGTON FACTORS
C   +++++++++++++++++++++++++++++++++++++++++
C
C   Allowance for wind blanketing
C
      ALB1=0.
c      IF(IWINDB.NE.0) ALB1=ALBEDO(IJ)/(UN+ALBEDO(IJ))/HALF
      DO 21 I=1,NMU
C
C   ************************
C   UPPER BOUNDARY CONDITION
C   ************************
C
         ID=1
         DTP1=DT(1)
         Q0=0.
         P0=0.
C
C        allowance for non-zero optical depth at the first depth point
C
         TAMM=TAUMIN/AMU(I)
         IF(TAMM.GT.0.01) THEN
            P0=UN-EXP(-TAMM)
          ELSE
            P0=TAMM*(UN-HALF*TAMM*(UN-TAMM*THIRD*(UN-QUART*TAMM)))
         END IF
         EX=UN-P0
         Q0=Q0+P0*AMU(I)*WTMU(I)
C
         DIV=DTP1/AMU(I)*THIRD
         VL(I)=DIV*(ST0(ID)+HALF*ST0(ID+1))+ST0(ID)*P0
         DO 20 J=1,NMU
            BB(I,J)=SS0(ID)*WTMU(J)*(DIV+P0)-ALB1*WTMU(J)
   20       CC(I,J)=-HALF*DIV*SS0(ID+1)*WTMU(J)
         BB(I,I)=BB(I,I)+AMU(I)/DTP1+UN+DIV
         CC(I,I)=CC(I,I)+AMU(I)/DTP1-HALF*DIV
         ANU(I,ID)=0.
   21 CONTINUE
C
C     Matrix inversion: instead of calling MATINV, a very fast inlined 
C     routine MINV3 for a specific 3 x 3 matrix inversion
C
C     CALL MATINV(BB,NMU,3)
C
C     ******************************
      BB(2,1)=BB(2,1)/BB(1,1)
      BB(2,2)=BB(2,2)-BB(2,1)*BB(1,2)
      BB(2,3)=BB(2,3)-BB(2,1)*BB(1,3)
      BB(3,1)=BB(3,1)/BB(1,1)
      BB(3,2)=(BB(3,2)-BB(3,1)*BB(1,2))/BB(2,2)
      BB(3,3)=BB(3,3)-BB(3,1)*BB(1,3)-BB(3,2)*BB(2,3)
C
      BB(3,2)=-BB(3,2)
      BB(3,1)=-BB(3,1)-BB(3,2)*BB(2,1)
      BB(2,1)=-BB(2,1)
C
      BB(3,3)=UN/BB(3,3)
      BB(2,3)=-BB(2,3)*BB(3,3)/BB(2,2)
      BB(2,2)=UN/BB(2,2)
      BB(1,3)=-(BB(1,2)*BB(2,3)+BB(1,3)*BB(3,3))/BB(1,1)
      BB(1,2)=-BB(1,2)*BB(2,2)/BB(1,1)
      BB(1,1)=UN/BB(1,1)
C
      BB(1,1)=BB(1,1)+BB(1,2)*BB(2,1)+BB(1,3)*BB(3,1)
      BB(1,2)=BB(1,2)+BB(1,3)*BB(3,2)
      BB(2,1)=BB(2,2)*BB(2,1)+BB(2,3)*BB(3,1)
      BB(2,2)=BB(2,2)+BB(2,3)*BB(3,2)
      BB(3,1)=BB(3,3)*BB(3,1)
      BB(3,2)=BB(3,3)*BB(3,2)
C     ******************************
C
      DO 22 I=1,NMU
         DO 22 J=1,NMU
            S=0.
            DO 23 K=1,NMU
   23          S=S+BB(I,K)*CC(K,J)
            D(I,J,ID)=S
            ANU(I,1)=ANU(I,1)+BB(I,J)*VL(J)
   22 CONTINUE
C
C   *******************
C   NORMAL DEPTH POINTS
C   *******************
C
      DO 34 ID=2,ND1
         DTM1=DTP1
         DTP1=DT(ID)
         DT0=HALF*(DTM1+DTP1)
         AL=UN/DTM1/DT0
         GA=UN/DTP1/DT0
         BE=AL+GA
         A=(UN-HALF*AL*DTP1*DTP1)*SIXTH
         C=(UN-HALF*GA*DTM1*DTM1)*SIXTH
         B=UN-A-C
         VL0=A*ST0(ID-1)+B*ST0(ID)+C*ST0(ID+1)
         DO 30 I=1,NMU
            DO 30 J=1,NMU
               AA(I,J)=-A*SS0(ID-1)*WTMU(J)
               CC(I,J)=-C*SS0(ID+1)*WTMU(J)
               BB(I,J)=B*SS0(ID)*WTMU(J)
   30    CONTINUE
         DO 31 I=1,NMU
            DIV=AMU(I)**2
            VL(I)=VL0
            AA(I,I)=AA(I,I)+DIV*AL-A
            CC(I,I)=CC(I,I)+DIV*GA-C
            BB(I,I)=BB(I,I)+DIV*BE+B
   31    CONTINUE
         DO 32 I=1,NMU
            S1=0.
            DO 36 J=1,NMU
               S=0.
               S1=S1+AA(I,J)*ANU(J,ID-1)
               DO 35 K=1,NMU
   35             S=S+AA(I,K)*D(K,J,ID-1)
   36          BB(I,J)=BB(I,J)-S
            VL(I)=VL(I)+S1
   32    CONTINUE
C
C     Matrix inversion: instead of calling MATINV, a very fast inlined 
C     routine MINV3 for a specific 3 x 3 matrix inversion
C
C     CALL MATINV(BB,NMU,3)
C
C     ******************************
      BB(2,1)=BB(2,1)/BB(1,1)
      BB(2,2)=BB(2,2)-BB(2,1)*BB(1,2)
      BB(2,3)=BB(2,3)-BB(2,1)*BB(1,3)
      BB(3,1)=BB(3,1)/BB(1,1)
      BB(3,2)=(BB(3,2)-BB(3,1)*BB(1,2))/BB(2,2)
      BB(3,3)=BB(3,3)-BB(3,1)*BB(1,3)-BB(3,2)*BB(2,3)
C
      BB(3,2)=-BB(3,2)
      BB(3,1)=-BB(3,1)-BB(3,2)*BB(2,1)
      BB(2,1)=-BB(2,1)
C
      BB(3,3)=UN/BB(3,3)
      BB(2,3)=-BB(2,3)*BB(3,3)/BB(2,2)
      BB(2,2)=UN/BB(2,2)
      BB(1,3)=-(BB(1,2)*BB(2,3)+BB(1,3)*BB(3,3))/BB(1,1)
      BB(1,2)=-BB(1,2)*BB(2,2)/BB(1,1)
      BB(1,1)=UN/BB(1,1)
C
      BB(1,1)=BB(1,1)+BB(1,2)*BB(2,1)+BB(1,3)*BB(3,1)
      BB(1,2)=BB(1,2)+BB(1,3)*BB(3,2)
      BB(2,1)=BB(2,2)*BB(2,1)+BB(2,3)*BB(3,1)
      BB(2,2)=BB(2,2)+BB(2,3)*BB(3,2)
      BB(3,1)=BB(3,3)*BB(3,1)
      BB(3,2)=BB(3,3)*BB(3,2)
C     ******************************
C
         DO 33 I=1,NMU
            ANU(I,ID)=0.
            DO 33 J=1,NMU
               S=0.
               DO 37 K=1,NMU
   37             S=S+BB(I,K)*CC(K,J)
               D(I,J,ID)=S
               ANU(I,ID)=ANU(I,ID)+BB(I,J)*VL(J)
   33    CONTINUE
   34 CONTINUE
C
C   ************
C   LOWER BOUNDARY CONDITION
C   ************
C
      ID=ND
      DO 41 I=1,NMU
         AA(I,I)=AMU(I)/DTP1
         VL(I)=PLAND+AMU(I)*DPLAN+AA(I,I)*ANU(I,ID-1)
         DO 40 J=1,NMU
   40       BB(I,J)=-AA(I,I)*D(I,J,ID-1)
         BB(I,I)=BB(I,I)+AA(I,I)+UN
   41 CONTINUE
C
C     Matrix inversion: instead of calling MATINV, a very fast inlined 
C     routine MINV3 for a specific 3 x 3 matrix inversion
C
C     CALL MATINV(BB,NMU,3)
C
C     ******************************
      BB(2,1)=BB(2,1)/BB(1,1)
      BB(2,2)=BB(2,2)-BB(2,1)*BB(1,2)
      BB(2,3)=BB(2,3)-BB(2,1)*BB(1,3)
      BB(3,1)=BB(3,1)/BB(1,1)
      BB(3,2)=(BB(3,2)-BB(3,1)*BB(1,2))/BB(2,2)
      BB(3,3)=BB(3,3)-BB(3,1)*BB(1,3)-BB(3,2)*BB(2,3)
C
      BB(3,2)=-BB(3,2)
      BB(3,1)=-BB(3,1)-BB(3,2)*BB(2,1)
      BB(2,1)=-BB(2,1)
C
      BB(3,3)=UN/BB(3,3)
      BB(2,3)=-BB(2,3)*BB(3,3)/BB(2,2)
      BB(2,2)=UN/BB(2,2)
      BB(1,3)=-(BB(1,2)*BB(2,3)+BB(1,3)*BB(3,3))/BB(1,1)
      BB(1,2)=-BB(1,2)*BB(2,2)/BB(1,1)
      BB(1,1)=UN/BB(1,1)
C
      BB(1,1)=BB(1,1)+BB(1,2)*BB(2,1)+BB(1,3)*BB(3,1)
      BB(1,2)=BB(1,2)+BB(1,3)*BB(3,2)
      BB(2,1)=BB(2,2)*BB(2,1)+BB(2,3)*BB(3,1)
      BB(2,2)=BB(2,2)+BB(2,3)*BB(3,2)
      BB(3,1)=BB(3,3)*BB(3,1)
      BB(3,2)=BB(3,3)*BB(3,2)
C     ******************************
C
      DO 42 I=1,NMU
         ANU(I,ID)=0.
         DO 42 J=1,NMU
            D(I,J,ID)=0.
            ANU(I,ID)=ANU(I,ID)+BB(I,J)*VL(J)
   42 CONTINUE
C
C   ************
C   BACKSOLUTION
C   ************
C
      DO 54 ID=ND-1,1,-1
         DO 50 I=1,NMU
            DO 50 J=1,NMU
               ANU(I,ID)=ANU(I,ID)+D(I,J,ID)*ANU(J,ID+1)
   50    CONTINUE
         AJ=0.
         AK=0.
         DO 52 I=1,NMU
            DIV=WTMU(I)*ANU(I,ID)
            AJ=AJ+DIV
            AK=AK+DIV*AMU(I)**2
   52    CONTINUE
         FKK(ID)=AK/AJ
   54 CONTINUE
C
C     surface Eddington actor
C
      AH=0.
      DO 53 I=1,NMU
   53    AH=AH+WTMU(I)*AMU(I)*ANU(I,1)
      FH=AH/AJ-HALF*ALB1
C
      FKK(ND)=THIRD
C
C
C   +++++++++++++++++++++++++++++++++++++++++
C   SECOND PART  -  DETERMINATION OF THE MEAN INTENSITIES
C   RECALCULATION OF THE TRANSFER EQUATION WITH GIVEN EDDINGTON FACTORS
C   +++++++++++++++++++++++++++++++++++++++++
C
      DTP1=DT(1)
      DIV=DTP1*THIRD
      BBB=FKK(1)/DTP1+FH+DIV+SS0(1)*(DIV+Q0)
      CCC=FKK(2)/DTP1-HALF*DIV*(UN+SS0(2))
      VLL=DIV*(ST0(1)+HALF*ST0(2))+ST0(1)*Q0
      AANU(1)=VLL/BBB
      DDD(1)=CCC/BBB
      DO 60 ID=2,ND1
         DTM1=DTP1
         DTP1=DT(ID)
         DT0=HALF*(DTP1+DTM1)
         AL=UN/DTM1/DT0
         GA=UN/DTP1/DT0
         A=(UN-HALF*DTP1*DTP1*AL)*SIXTH
         C=(UN-HALF*DTM1*DTM1*GA)*SIXTH
         AAA=AL*FKK(ID-1)-A*(UN+SS0(ID-1))
         CCC=GA*FKK(ID+1)-C*(UN+SS0(ID+1))
         BBB=(AL+GA)*FKK(ID)+(UN-A-C)*(UN+SS0(ID))
         VLL=A*ST0(ID-1)+C*ST0(ID+1)+(UN-A-C)*ST0(ID)
         BBB=BBB-AAA*DDD(ID-1)
         DDD(ID)=CCC/BBB
         AANU(ID)=(VLL+AAA*AANU(ID-1))/BBB
   60 CONTINUE
      BBB=FKK(ND)/DTP1+HALF
      AAA=FKK(ND1)/DTP1
      BBB=BBB-AAA*DDD(ND1)
      VLL=HALF*PLAND+DPLAN*THIRD
      RDD(ND)=(VLL+AAA*AANU(ND1))/BBB
      DO 70 IID=1,ND1
         ID=ND-IID
         RDD(ID)=AANU(ID)+DDD(ID)*RDD(ID+1)
   70 CONTINUE
      FLUX(IJ)=FH*RDD(1)
      if(ij.eq.1) then
         do 72 id=1,nd
   72       scc1(id)=-rdd(id)*ss0(id)*ch(1,id)
       else
         do 74 id=1,nd
   74       scc2(id)=-rdd(id)*ss0(id)*ch(2,id)
      end if
C
C     if needed (if iprin.ge.3), output of interesting physical
C     quantities at the monochromatic optical depth  tau(nu)=2/3
C
      IF(IPRIN.ge.3) THEN
      T0=LOG(TAU(IREF+1)/TAU(IREF))
      X0=LOG(TAU(IREF+1)/TAUREF)/T0
      X1=LOG(TAUREF/TAU(IREF))/T0
      DMREF=EXP(LOG(DM(IREF))*X0+LOG(DM(IREF+1))*X1)
      TREF=EXP(LOG(TEMP(IREF))*X0+LOG(TEMP(IREF+1))*X1)
      STREF=EXP(LOG(ST0(IREF))*X0+LOG(ST0(IREF+1))*X1)
      SCREF=EXP(LOG(-SS0(IREF))*X0+LOG(-SS0(IREF+1))*X1)
      SSREF=EXP(LOG(-SS0(IREF)*RDD(IREF))*X0+
     *           LOG(-SS0(IREF+1)*RDD(IREF+1))*X1)
      SREF=STREF+SSREF
      ALM=2.997925E18/FREQ(IJ)
      WRITE(36,636) IJ,ALM,IREF,DMREF,TREF,SCREF,STREF,SSREF,SREF
  636 FORMAT(1H ,I3,F10.3,I4,1PE10.3,0PF10.1,1X,1P3E10.3,E11.3)
      END IF
c
C   ********************************************************************
C
C   THIRD PART  -  DETERMINATION OF THE SPECIFIC INTENSITIES
C   RECALCULATION OF THE TRANSFER EQUATION WITH GIVEN SOURCE FUNCTION
C
      if(iflux.eq.0) go to 100
      DO 85 IMU=1,NMU0
      ANX=ANGL(IMU)
      DTP1=DT(1)
      DIV=DTP1*THIRD/ANX
C
      TAMM=TAUMIN/ANX
      IF(TAMM.LT.0.01) THEN
         P0=TAMM*(UN-HALF*TAMM*(UN-TAMM*THIRD*(UN-QUART*TAMM)))
       ELSE
         P0=UN-EXP(-TAMM)
      END IF
C
      BBB=ANX/DTP1+UN+DIV
      CCC=ANX/DTP1-HALF*DIV
      VLL=(DIV+P0)*(ST0(1)-SS0(1)*RDD(1))
     *    +HALF*DIV*(ST0(2)-SS0(2)*RDD(2))
      AANU(1)=VLL/BBB
      DDD(1)=CCC/BBB
      DIV=ANX*ANX
      DO 82 ID=2,ND1
         DTM1=DT(ID-1)
         DTP1=DT(ID)
         DT0=HALF*(DTP1+DTM1)
         AL=UN/DTM1/DT0
         GA=UN/DTP1/DT0
         A=(UN-HALF*DTP1*DTP1*AL)*SIXTH
         C=(UN-HALF*DTM1*DTM1*GA)*SIXTH
         AAA=DIV*AL-A
         CCC=DIV*GA-C
         BBB=DIV*(AL+GA)+UN-A-C
         VLL=A*(ST0(ID-1)-SS0(ID-1)*RDD(ID-1))+
     *       C*(ST0(ID+1)-SS0(ID+1)*RDD(ID+1))+
     *       (UN-A-C)*(ST0(ID)-SS0(ID)*RDD(ID))
         BBB=BBB-AAA*DDD(ID-1)
         DDD(ID)=CCC/BBB
         AANU(ID)=(VLL+AAA*AANU(ID-1))/BBB
   82 CONTINUE
C
C     Lower boundary condition
C
      AAA=ANX/DTP1
      BBB=AAA+UN
      VLL=PLAND+ANX*DPLAN
C
      RINT(ND,IMU)=(VLL+AAA*AANU(ND1))/(BBB-AAA*DDD(ND1))
      DO 84 IID=1,ND1
         ID=ND-IID
         RINT(ID,IMU)=AANU(ID)+DDD(ID)*RINT(ID+1,IMU)
   84 CONTINUE
   85 CONTINUE
c
      FLX=0.
      DO 86 IMU=1,NMU0
         RINT(1,IMU)=RINT(1,IMU)/HALF
         FLX=FLX+ANGL(IMU)*WANGL(IMU)*RINT(1,IMU)
   86 CONTINUE
      FLX=FLX*HALF
c     FLUX(IJ)=FLX
C
C     output of emergent specific intensities in continuum to Unit 18 
C
      if(iflux.ge.1) then
      WRITE(18,641) WLAM(IJ),FLX,(RINT(1,IMU),IMU=1,NMU0)
      end if
  100 CONTINUE
  641 FORMAT(1H ,f10.3,1pe15.5/(1P5E15.5))
c  
c     call rtedfe for the internal points
c
      CALL RTEDFE
c
      RETURN
      END
C
C
C     *******************************************************************
C
C
 
      SUBROUTINE RTEDFE
C     =================
C
C     Solution of the radiative transfer equation - frequency by
C     frequency - for the known source function.
C
C     The numerical method used:
c     Discontinuous Finite Element (DFE) method
c     Castor, Dykema, Klein, 1992, ApJ 387, 561.
C
C     Input through blank COMMON block:
C      CH     - two-dimensional array  absorption coefficient (frequency,
C               depth)
C      ET     - emission coefficient (frequency, depth)
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      INCLUDE 'SYNTHP.FOR'
      PARAMETER (ONE=1.,TWO=2.,HALF=0.5)
      PARAMETER (TAUREF = 0.6666666666667)
c      PARAMETER (TAUREF = 1.)
      DIMENSION DT(MDEPTH),ST0(MDEPTH),AB0(MDEPTH),DELDM(MDEPTH),
     *          dtau(mdepth),rip(mdepth),rim(mdepth),riup(mdepth),
     *          AMU(3),WTMU(3),RINT1(MMU),
     *          AMUI(MMU),AMUW(MMU),TAU(MDEPTH),SS0(MDEPTH)
      COMMON    CH(MFREQ,MDEPTH),ET(MFREQ,MDEPTH)
      COMMON/EMFLUX/FLUX(MFREQ)
      COMMON/CONTLH/SCL1(2),ICONTL
      COMMON/CONSCA/SCC1(mdepth),SCC2(MDEPTH)
      COMMON/IPRNTR/IPRIN
      COMMON/REFDEP/IREFD(MFREQ)
C
C     angle points (AMU) and angular integration weights (WTMU)
C
      DATA AMU/.887298334620742D0,.5D0,.112701665379258D0/,
     * WTMU/.277777777777778D0,.444444444444444D0,.277777777777778D0/
C
      DO 10 I=1,ND-1
         DELDM(I)=HALF*(DM(I+1)-DM(I))
   10 CONTINUE
C
c     angle points
C
      IF(IFLUX.EQ.0) THEN
         NMUS=NMU
         do 12 i=1,nmu
            amui(i)=amu(i)
            amuw(i)=amu(i)*wtmu(i)
   12    continue
       ELSE IF(IFLUX.EQ.1) THEN
         NMUS=NMU0
         do 14 i=1,nmus
            amui(i)=angl(i)
            amuw(i)=angl(i)*wangl(i)
   14    continue
      END IF
C
C     overall loop over frequencies
C
      DO 500 IJ=1,NFREQ
      FR=FREQ(IJ)
C
C     total source function
C  
      DO 20 ID=1,ND
         AB0(ID)=CH(IJ,ID)
         SCT=FRX1(IJ)*SCC2(ID)+FRX2(IJ)*SCC1(ID)
         ST0(ID)=(ET(IJ,ID)+SCT)/AB0(ID)
         SS0(ID)=-SCT/AB0(ID)
   20 CONTINUE
      AH=0.
C
C     optical depth scale
C
      TAU(1)=0.
      IREF=1
      DO 30 ID=1,ND-1
         DT(ID)=DELDM(ID)*(AB0(ID+1)/DENS(ID+1)+AB0(ID)/DENS(ID))
         TAU(ID+1)=TAU(ID)+DT(ID)
         IF(TAU(ID).LE.TAUREF.AND.TAU(ID+1).GT.TAUREF) IREF=ID
   30 CONTINUE
      IREFD(IJ)=IREF
C
C     quantities for the lower boundary condition
C
      FR15=FR*1.D-15
      BNU=BN*FR15*FR15*FR15
      PLAND=BNU/(EXP(HK*FR/TEMP(ND))-ONE)
      DPLAN=BNU/(EXP(HK*FR/TEMP(ND-1))-ONE)
      DPLAN=(PLAND-DPLAN)/DT(ND-1)
c
c     loop over angle poits
c
      DO 100 I=1,NMUS
         do id=1,nd-1
            dtau(id)=dt(id)/amui(i)
         enddo
C
c           outgoing intensity
c 
            rip(nd)=PLAND+AMUI(I)*DPLAN
            id=nd-1
            dt0=dtau(id)
            dtaup1=dt0+one
            dtau2=dt0*dt0
            bb=two*dtaup1
            cc=dt0*dtaup1
            aa=dtau2+bb
            rim(id+1)=(aa*rip(id+1)-cc*st0(id+1)+dt0*st0(id))/bb
            do id=nd-1,1,-1
               dt0=dtau(id)
               dtaup1=dt0+one
               dtau2=dt0*dt0
               bb=two*dtaup1
               cc=dt0*dtaup1
               aa=one/(dtau2+bb)
               rim(id)=(two*rim(id+1)+dt0*st0(id+1)+cc*st0(id))*aa
               rip(id+1)=(bb*rim(id+1)+cc*st0(id+1)-dt0*st0(id))*aa
            enddo
            do id=2,nd-1
               riup(id)=(rim(id)*dtau(id-1)+rip(id)*dtau(id))/
     *                  (dtau(id-1)+dtau(id))
            enddo
            riup(1)=rim(1)
            riup(nd)=rip(nd)
c
         AH=AH+AMUW(I)*RIUP(1)
         RINT1(I)=RIUP(1)
c
c     end of the loop over angle points
c
  100 CONTINUE
      FLUX(IJ)=AH*HALF
      if(iflux.ge.1) then
C
C     output of emergent specific intensities to Unit 10 (line points)
C     or 18 (two continuum points)
C
      IF(IJ.GT.2) THEN
      WRITE(10,618) WLAM(IJ),FLUX(IJ),(RINT1(IMU),IMU=1,NMUS)
      ELSE
      WRITE(18,618) WLAM(IJ),FLUX(IJ),(RINT1(IMU),IMU=1,NMUS)
      END IF
      end if
  618 FORMAT(1H ,f10.3,1pe15.5/(1P5E15.5))
C
C     if needed (if iprin.ge.3), output of interesting physical
C     quantities at the monochromatic optical depth  tau(nu)=2/3
C
      IF(IPRIN.GE.3) THEN
      T0=LOG(TAU(IREF+1)/TAU(IREF))
      X0=LOG(TAU(IREF+1)/TAUREF)/T0
      X1=LOG(TAUREF/TAU(IREF))/T0
      DMREF=EXP(LOG(DM(IREF))*X0+LOG(DM(IREF+1))*X1)
      TREF=EXP(LOG(TEMP(IREF))*X0+LOG(TEMP(IREF+1))*X1)
      STREF=EXP(LOG(ST0(IREF))*X0+LOG(ST0(IREF+1))*X1)
      SSREF=EXP(LOG(-SS0(IREF))*X0+LOG(-SS0(IREF+1))*X1)
      SREF=STREF+SSREF
      ALM=2.997925E18/FREQ(IJ)
      WRITE(36,636) IJ,ALM,IREF,DMREF,TREF,STREF,SSREF,SREF
  636 FORMAT(1H ,I3,F10.3,I4,1PE10.3,0PF10.1,1X,1P3E10.3)
      END IF
c
C
C     end of the loop over frequencies
C
  500 CONTINUE
      RETURN
      END
C
C
C    *******************************************************************
C
C
      SUBROUTINE PARTF(IAT,IZI,T,ANE,XMAXN,U)
C     =======================================
C
C     Partition functions 
C     The standard evaluation is for hydrogen through zinc, for
C     neutrals and first four ionization degrees.
C     Basically after Traving, Baschek, and Holweger, Abhand. Hamburg.
C     Sternwarte. Band VIII, Nr. 1 (1966)
C
C     The routine calls special procedures for Fe and Ni; or
C     the values based on the tabulated Opacity Project ionization
C     fractions
C
C     Input:
C      IAT   - atomic number
C      IZI   - ionic charge (=1 for neutrals, =2 for once ionized, etc)
C      T     - temperature
C      ANE   - electron density
C      XMAXN - principal quantum number of the last bound level
C
C     Output:
C      U     - partition function
C
      INCLUDE 'PARAMS.FOR'
      PARAMETER (NIONS=123, NSS=222)
      PARAMETER (UN=1.D0, HALF=0.5D0, TWO=2.D0, TRHA=1.5D0,
     *           THIRD=UN/3.D0, SIXTH=UN/6.D0)
      REAL*4 AHH( 6),  ALB(12),  AB (11),  AC (19),  AN (30),  AO (49),
     *       AF (34),  ANN(23),  ANA(19),  AMG(15),  AAL(17),  ASI(23),
     *       AP (19),  AS (29),  ACL(28),  AAR(25),  AK (30),  ACA(17),
     *       ASC(24),  ATI(33),  AV (33),  ACR(29),  AMN(28),  AFE(35),
     *       ACO(29),  ANI(23),  ACU(20),  AZN(18)
      REAL*4 GHH( 6),  GLB(12),  GB (11),  GC (19),  GN (30),  GO (49),
     *       GF (34),  GNN(23),  GNA(19),  GMG(15),  GAL(17),  GSI(23),
     *       GP (19),  GS (29),  GCL(28),  GAR(25),  GK (30),  GCA(17),
     *       GSC(24),  GTI(33),  GV (33),  GCR(29),  GMN(28),  GFE(35),
     *       GCO(29),  GNI(23),  GCU(20),  GZN(18)
      REAL*4 XL1(99), XL2(123),  XL(222),
     *       CH1(66),  CH2(72),  CH3(55),  CH4(29),  CHION(222)
      REAL*4 ALF(678), GAM(678), MAX,      MAX2   
      INTEGER*2 II1(5,15),II2(5,15),INDEX0(5,30),
     *          IS1(53),IS2(70),IS(123),INDEXS(123),
     *          IM1(99),IM2(123),IM(222),INDEXM(222),
     *          IGP1(99),IGP2(123),IGPR(222),
     *          IG01(53),IG02(70),IG0(123)
      EQUIVALENCE   ( AHH(1), ALF(  1)),( ALB(1), ALF(  7)),
     *              ( AB (1), ALF( 19)),
     *              ( AC (1), ALF( 30)),( AN (1), ALF( 49)),
     *              ( AO (1), ALF( 79)),( AF (1), ALF(128)),
     *              ( ANN(1), ALF(162)),( ANA(1), ALF(185)),
     *              ( AMG(1), ALF(204)),( AAL(1), ALF(219)),
     *              ( ASI(1), ALF(236)),( AP (1), ALF(259)),
     *              ( AS (1), ALF(278)),( ACL(1), ALF(307)),
     *              ( AAR(1), ALF(335)),( AK (1), ALF(360)),
     *              ( ACA(1), ALF(390)),( ASC(1), ALF(407)),
     *              ( ATI(1), ALF(431)),( AV (1), ALF(464)),
     *              ( ACR(1), ALF(497)),( AMN(1), ALF(526)),
     *              ( AFE(1), ALF(554)),( ACO(1), ALF(589)),
     *              ( ANI(1), ALF(618)),( ACU(1), ALF(641)),
     *              ( AZN(1), ALF(661))
      EQUIVALENCE   ( GHH(1), GAM(  1)),( GLB(1), GAM(  7)),
     *              ( GB (1), GAM( 19)),
     *              ( GC (1), GAM( 30)),( GN (1), GAM( 49)),
     *              ( GO (1), GAM( 79)),( GF (1), GAM(128)),
     *              ( GNN(1), GAM(162)),( GNA(1), GAM(185)),
     *              ( GMG(1), GAM(204)),( GAL(1), GAM(219)),
     *              ( GSI(1), GAM(236)),( GP (1), GAM(259)),
     *              ( GS (1), GAM(278)),( GCL(1), GAM(307)),
     *              ( GAR(1), GAM(335)),( GK (1), GAM(360)),
     *              ( GCA(1), GAM(390)),( GSC(1), GAM(407)),
     *              ( GTI(1), GAM(431)),( GV (1), GAM(464)),
     *              ( GCR(1), GAM(497)),( GMN(1), GAM(526)),
     *              ( GFE(1), GAM(554)),( GCO(1), GAM(589)),
     *              ( GNI(1), GAM(618)),( GCU(1), GAM(641)),
     *              ( GZN(1), GAM(661))
      EQUIVALENCE   ( CH1(1), CHION(  1)),
     *              ( CH2(1), CHION( 67)),
     *              ( CH3(1), CHION(139)),
     *              ( CH4(1), CHION(194)),
     *              ( XL1(1),    XL(  1)),
     *              ( XL2(1),    XL(100))
      EQUIVALENCE   ( IS1(1),  IS(1)),   ( IS2(1),  IS( 54)),
     *              ( IM1(1),  IM(1)),   ( IM2(1),  IM(100)),
     *              (IGP1(1),IGPR(1)),   (IGP2(1),IGPR(100)),
     *              (IG01(1), IG0(1)),   (IG02(1), IG0( 54)),
     *              (II1(1,1),INDEX0(1,1)),(II2(1,1),INDEX0(1,16))
C
      DATA II1      /   1,  -1,   0,   0,   0,
     *                  2,   3,  -1,   0,   0,
     *                  4,   5,  -2,  -1,   0,
     *                  6,   7,  -1,  -2,  -1,
     *                  8,   9,  10,  -1,  -2,
     *                 11,  12,  13,  14,  -1,
     *                 15,  16,  17,  18,  19,
     *                 20,  21,  22,  23,  24,
     *                 25,  26,  27,  28,  -6,
     *                 29,  30,  31,  32,  -9,
     *                 33,  34,  35,  36,  -4,
     *                 37,  38,  39,  40,  -9,
     *                 41,  42,  43,  44,  -6,
     *                 45,  46,  47,  48,  -1,
     *                 49,  50,  51,  52,  53                         /
      DATA II2      /  54,  55,  56,  57,  58,
     *                 59,  60,  61,  62,  63,
     *                 64,  65,  66,  67,  68,
     *                 69,  70,  71,  72,  73,
     *                 74,  75,  76,  77,  -9,
     *                 78,  76,  80,  81,  82,
     *                 83,  84,  85,  86,  87,
     *                 88,  89,  90,  91,  92,
     *                 93,  94,  95,  96,  97,
     *                 98,  99, 100, 101, 102,
     *                103, 104, 105, 106, 107,
     *                108, 109, 110, 111, -25,
     *                112, 113, 114, 115,  -1,
     *                116, 117, 118, 119,  -1,
     *                120, 121, 122, 123,  -1                         /
C
      DATA IG01     /   2,
     *                  1,   2,
     *                  2,   1,
     *                  1,   2,
     *                  2,   1,   2,
     *                  1,   2,   1,   2,
     *                  4,   1,   2,   1,   2,
     *                  5,   4,   1,   2,   1,
     *                  4,   5,   4,   1,
     *                  1,   4,   5,   4,
     *                  2,   1,   4,   5,
     *                  1,   2,   1,   4,
     *                  2,   1,   2,   1,
     *                  1,   2,   1,   2,
     *                  4,   1,   2,   1,   2                         /
      DATA  IG02    /   5,   4,   1,   2,   1,
     *                  4,   5,   4,   1,   2,
     *                  1,   4,   5,   4,   1,
     *                  2,   1,   4,   5,   4,
     *                  1,   2,   1,   4,
     *                  4,   3,   4,   1,   4,
     *                  5,   4,   5,   4,   1,
     *                  4,   1,   4,   5,   4,
     *                  7,   6,   1,   4,   5,
     *                  6,   7,   6,   1,   4,
     *                  9,  10,   9,   6,   1,
     *                 10,   9,  10,  20,
     *                  9,   6,   9,  28,
     *                  2,   1,   6,  21,
     *                  1,   2,   1,  10                              /
C
      DATA IS1      /   1,
     *                  1,   1,
     *                  1,   1,
     *                  2,   1,
     *                  1,   2,   1,
     *                  1,   2,   2,   1,
     *                  2,   2,   3,   2,   1,
     *                  3,   4,   3,   5,   2,
     *                  2,   3,   4,   3,
     *                  2,   2,   3,   2,
     *                  1,   2,   2,   3,
     *                  1,   1,   2,   2,
     *                  2,   2,   1,   2,
     *                  1,   2,   2,   1,
     *                  2,   1,   1,   1,   1                         /
      DATA  IS2     /   3,   2,   1,   2,   2,
     *                  2,   3,   2,   1,   1,
     *                  2,   2,   3,   1,   1,
     *                  1,   2,   3,   3,   2,
     *                  2,   1,   2,   2,
     *                  3,   1,   1,   1,   1,
     *                  3,   2,   1,   1,   1,
     *                  2,   3,   1,   1,   1,
     *                  3,   2,   1,   1,   1,
     *                  3,   2,   1,   1,   1,
     *                  3,   2,   2,   1,   1,
     *                  4,   2,   1,   1,
     *                  2,   2,   1,   1,
     *                  3,   2,   1,   1,
     *                  3,   3,   1,   1                              /
C
      DATA IM1      /   2,
     *                  2,   2,
     *                  2,   2,
     *                  3,   2,   3,
     *                  3,   3,   2,   3,
     *                  4,   3,   3,   3,   3,   3,
     *                  3,   3,   4,   3,   3,   4,   2,   3,   2,   3,
     *                  4,   2,   2,   4,   2,   3,   3,   4,   4,   2,
     *                  3,   4,   2,   2,   2,   3,   3,
     *                  3,   3,   4,   2,   2,
     *                  4,   2,   3,   2,   5,   2,   2,
     *                  2,   2,   3,   2,   4,   2,   2,   4,   2,
     *                  2,   2,   2,   3,   2,   4,   2,   2,
     *                  3,   3,   2,   2,   3,   2,
     *                  3,   2,   3,   2,   3,   2,   2,
     *                  5,   4,   4,   4,   3,   3,
     *                  3,   2,   4,   4,   3,   3                    /
      DATA  IM2     /   4,   2,   2,   4,   2,   5,   4,   2,   3,   1,
     *                  3,   2,   5,   2,   2,   4,   2,   4,   4,
     *                  2,   2,   3,   2,   4,   2,   2,   4,   4,
     *                  3,   2,   3,   3,   2,   3,
     *                  4,   2,   2,   4,   2,
     *                  3,   2,   3,   2,   2,   3,   2,
     *                  4,   3,   3,   5,   4,   2,   3,
     *                  6,   4,   3,   6,   3,   5,   4,   2,
     *                  5,   3,   5,   4,   4,   4,   4,   4,
     *                  3,   3,   3,   4,   4,   4,   4,   4,
     *                  3,   2,   3,   4,   4,   4,   4,   4,
     *                  4,   4,   3,   5,   3,   4,   4,   4,   4,
     *                  5,   3,   3,   3,   5,   4,   5,   1,
     *                  6,   3,   5,   3,   5,   1,
     *                  2,   3,   3,   4,   3,   4,   1,
     *                  2,   2,   2,   3,   3,   2,   3,   1          /
C
      DATA IGP1     /   2,
     *                  4,   2,
     *                  2,   4,
     *                  4,  12,   2,
     *                  2,   4,  12,   2,
     *                 12,   2,  18,   4,  12,   2,
     *                 18,  10,  12,  24,   2,  18,   6,   4,  12,   2,
     *                  8,  20,  12,  18,  10,   2,  10,  12,  24,  20,
     *                  2,  18,   6,  18,  10,   4,  12,
     *                 18,  10,   8,  20,  12,
     *                 18,  10,   2,  10,  12,  24,  20,
     *                  8,   4,  18,  10,   8,  20,  12,  18,  10,
     *                  2,   8,   4,  18,  10,   8,  20,  12,
     *                  4,   2,   8,   4,  18,  10,
     *                  2,  18,   4,  12,   2,   8,   4,
     *                 12,   2,  18,   4,  12,   2,
     *                 18,  10,  12,   2,   4,   2                    /
      DATA  IGP2    /   8,  20,  12,  18,  10,  12,   2,  18,   4,  12,
     *                 18,  10,   8,  20,  12,  18,  10,  12,   2,
     *                  8,   4,  18,  10,   8,  20,  12,  18,  12,
     *                  2,   8,   4,  18,  10,   2,
     *                  8,  20,  12,  18,  10,
     *                  4,  20,   2,   8,   4,  18,  10,
     *                 30,  42,  18,  20,   2,  12,  18,
     *                 56,  56,  28,  42,  10,  20,   2,  12,
     *                 50,  70,  56,  72,  64,  42,  20,   2,
     *                 12,  60,  40,  50,  18,  56,  42,  20,
     *                 14,  10,  50,  12,  72,  50,  56,  42,
     *                 60,  56,  40,  50,  18,  12,  72,  50,  56,
     *                 42,  70,  42,  18,  56,  24,  50,  12,
     *                 20,  56,  42,  18,  56,  50,
     *                  2,  30,  10,  20,  56,  42,  56,
     *                  4,   8,  12,   2,  30,  10,  20,  42          /
C
      DATA XL1      /11.0,
     *                8.0,12.0,
     *                6.0, 6.0,
     *                6.0, 4.0, 8.0,
     *                9.0, 6.0, 4.0, 6.0,
     *                6.0, 6.0, 5.0, 6.1, 5.0, 6.0,
     *                6.1, 4.0, 5.0, 3.9, 6.0, 5.0, 4.0, 6.0, 6.3, 6.0,
     *                8.0, 6.0, 3.4, 6.0, 5.0, 3.9, 3.9, 6.0, 4.9, 4.0,
     *                5.9, 5.0, 4.9, 4.0, 4.0, 6.0, 6.0,
     *                4.0, 4.0, 5.0, 4.0, 4.0,
     *                5.0, 4.0, 3.9, 4.0, 5.0, 5.0, 4.0,
     *                6.0, 6.0, 5.0, 4.0, 3.9, 4.0, 4.0, 5.0, 5.0,
     *                7.0, 4.0, 4.0, 4.0, 4.0, 5.0, 5.0, 5.0,
     *                7.0, 7.0, 5.0, 5.0, 5.0, 5.0,
     *                7.0, 4.0, 7.0, 4.0, 7.0, 5.0, 5.0,
     *                6.1, 5.9, 5.0, 5.0, 5.0, 7.0,
     *                5.0, 5.0, 5.0, 7.0, 8.6, 8.0                    /
      DATA  XL2     / 6.0, 5.0, 5.0, 5.0, 5.0, 3.5, 5.0,14.4, 5.0, 4.0,
     *                6.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.2,
     *                6.0, 6.0, 5.1, 5.0, 5.0, 5.0, 5.0, 5.0, 4.0,
     *                7.0, 5.0, 5.0, 6.0, 6.0, 5.0,
     *                6.0, 5.0, 5.0, 3.6, 4.0,
     *                5.9, 6.0, 7.0, 5.0, 4.9, 5.0, 4.3,
     *                4.9, 4.9, 5.0, 5.0, 6.0, 4.6, 3.8,
     *                5.0, 4.7, 5.0, 5.0, 5.0, 5.0, 6.0, 4.8,
     *                5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0,11.2,
     *                5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.2,
     *                6.0, 5.0, 6.0, 7.0, 5.0, 5.0, 5.0, 5.0,
     *                5.0, 5.0, 5.0, 5.0, 5.0, 6.0, 5.0, 3.6, 3.8,
     *                5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 3.0,
     *                5.4, 5.0, 9.0, 5.0, 5.0, 3.0,
     *                8.0, 6.0, 5.0, 7.0, 5.0, 5.0, 2.9,
     *                8.0, 5.0, 5.0, 8.0, 5.0, 5.0, 5.0, 2.8          /
C
C
      DATA CH1      /  13.595 ,
     *                 24.580 ,  54.403 ,
     *                  5.390 , 75.619 ,
     *                  9.320 ,  13.278 ,  18.206 ,
     *                  8.296 ,  25.149 ,  31.146 ,  37.920 ,
     *                 11.256 ,  24.376 ,  30.868 ,  47.871 ,  55.873 ,
     *                 64.476 ,
     *                 14.529 ,  16.428 ,  29.593 ,  36.693 ,
     *                 47.426 ,  55.765 ,  63.626 ,  77.450 ,  87.445 ,
     *                 97.863 ,
     *                 13.614 ,  16.938 ,  18.630 ,
     *                 35.108 ,  37.621 ,  40.461 ,  42.584 ,
     *                 54.886 ,  63.733 ,  70.556 ,
     *                 77.394 ,  87.609 ,  97.077 , 103.911 , 106.116 ,
     *                113.873 , 125.863 ,
     *                 17.418 ,  20.009 ,  34.977 ,  39.204 ,  41.368 ,
     *                 62.646 ,  65.774 ,  69.282 ,  71.882 ,
     *                 87.139 ,  97.852 , 106.089 ,
     *                 21.559 ,  21.656 ,  41.071 ,  44.274 ,
     *                 63.729 ,  68.806 ,  71.434 ,  97.162 , 100.917 /
      DATA CH2      /   5.138 ,  47.290 ,  47.459 ,  71.647 ,  75.504 ,
     *                 98.880 , 104.778 , 107.864 ,
     *                  7.644 ,  15.031 ,  80.117 ,  80.393 ,
     *                109.294 , 113.799 ,
     *                  5.984 ,  10.634 ,  18.823 ,  25.496 ,
     *                 28.441 , 119.957 , 120.383 ,
     *                  8.149 ,  16.339 ,  22.894 ,
     *                 33.459 ,  42.333 ,  45.130 ,
     *                 10.474 ,  11.585 ,  19.720 ,
     *                 30.156 ,  51.354 ,  65.007 ,
     *                 10.357 ,  12.200 ,  13.401 ,  23.405 ,  24.807 ,
     *                 35.047 ,  47.292 ,  57.681 ,  72.474 ,  85.701 ,
     *                 13.014 ,  14.458 ,  23.798 ,  26.041 ,  27.501 ,
     *                 39.904 ,  41.610 ,  53.450 ,  67.801 ,
     *                 15.755 ,  15.933 ,  27.619 ,  29.355 ,
     *                 40.899 ,  42.407 ,  45.234 ,  59.793 ,  75.002 ,
     *                  4.339 ,  31.810 ,  32.079 ,
     *                 45.738 ,  47.768 ,  50.515 ,
     *                 60.897 ,  63.890 ,  65.849 ,  82.799 ,  85.150 /
      DATA CH3      /   6.111 ,   7.808 ,  11.868 ,
     *                 51.207 ,  51.596 ,  67.181 ,  69.536 ,
     *                  6.538 ,   7.147 ,   8.042 ,
     *                 12.891 ,  24.752 ,  74.090 ,  91.847 ,
     *                  6.818 ,  6.953 ,  7.411 ,
     *                 13.635 ,  14.685 ,  28.137 ,  43.236 , 100.083 ,
     *                  6.738 ,   7.101 ,  14.205 ,  15.670 ,  16.277 ,
     *                 29.748 ,  48.464 ,  65.198 ,
     *                  6.763 ,   8.285 ,   9.221 ,
     *                 16.493 ,  18.662 ,  30.950 ,  49.580 ,  73.093 ,
     *                  7.432 ,   8.606 ,   9.240 ,  15.636 ,  18.963 ,
     *                 33.690 ,  53.001 ,  76.006 ,
     *                  7.896 ,   8.195 ,   8.927 ,  16.178 ,  18.662 ,
     *                 30.640 ,  34.607 ,  56.001 ,  79.001           /
      DATA CH4      /   7.863 ,   8.378 ,   9.160 ,   9.519 ,
     *                 17.052 ,  18.958 ,  33.491 ,  53.001 ,
     *                  7.633 ,   8.793 ,  18.147 ,  20.233 ,  35.161 ,
     *                 56.025 ,
     *                  7.724 ,  10.532 ,  10.980 ,
     *                 20.286 ,  27.985 ,  36.826 ,  61.975 ,
     *                  9.391 ,  17.503 ,  17.166 ,
     *                 17.959 ,  27.757 ,  28.310 ,  39.701 ,  65.074 /
C
      DATA AHH      /  20.4976, 747.5023,
     *                 28.1703, 527.8296,  22.2809, 987.7189          /
      DATA GHH      /  10.853 ,  13.342 ,
     *                 21.170 ,  24.125 ,  43.708 ,  53.542           /
C
      DATA ALB      /   8.4915,  97.5015,  23.3299, 192.6701,
     *                  9.1849,  32.9263, 183.8887,  19.9563,  88.0437,
     *                  6.0478,  35.9723, 233.9798                    /
      DATA GLB      /   2.022 ,   4.604 ,  62.032 ,  72.624 ,
     *                  2.735 ,   6.774 ,   8.569 ,  10.750 ,  11.672 ,
     *                  3.967 ,  12.758 ,  16.692                     /
C
      DATA AB       /   4.0086,  19.6741, 402.3110,
     *                  9.7257,  30.9262, 186.3466,  44.1629,  60.8371,
     *                  6.0084,  23.5767,  76.4149                    /
      DATA GB       /   0.002 ,   3.971 ,   7.882 ,
     *                  4.720 ,  13.477 ,  22.103 ,  23.056 ,  24.734 ,
     *                  6.000 ,  24.540 ,  32.300                     /
C
      DATA AC       /   8.0158,   5.8833,  33.7521, 595.3432,
     *                  4.0003,  17.0841,  82.9154,
     *                 15.9808,  48.2044, 435.8093,
     *                 10.0281,  15.7574, 186.2109,
     *                 15.4127,  55.9559, 243.6311,
     *                  6.0057,  23.5757,  76.4185                    /
      DATA GC       /   0.004 ,   1.359 ,   6.454 ,  10.376 ,
     *                  0.008 ,  16.546 ,  21.614 ,
     *                  5.688 ,  15.801 ,  26.269 ,
     *                  6.691 ,  25.034 ,  40.975 ,
     *                 17.604 ,  36.180 ,  47.133 ,
     *                  8.005 ,  40.804 ,  54.492                     /
C
      DATA AN       /  14.0499,  30.8008, 883.1443,
     *                 10.0000,  16.0000,  64.0000,
     *                  8.0462,   6.2669,  17.8696, 282.8084,
     *                  7.3751,  33.1390, 215.4829,
     *                  4.0003,  19.3533,  80.6462,
     *                 13.0998,  19.6425,  94.3035, 370.9539,
     *                 16.0000,  38.0000,
     *                 10.3289,  14.5021, 187.1624, 108.1615, 191.8383,
     *                  6.0044,  23.5612,  76.4344                    /
      DATA GN       /   2.554 ,   9.169 ,  13.651 ,
     *                 12.353 ,  13.784 ,  14.874 ,
     *                  0.014 ,   2.131 ,  15.745 ,  24.949 ,
     *                  6.376 ,  14.246 ,  29.465 ,
     *                  0.022 ,  31.259 ,  41.428 ,
     *                  7.212 ,  15.228 ,  34.387 ,  46.708 ,
     *                 46.475 ,  49.468 ,
     *                  8.693 ,  37.650 ,  65.479 ,  61.155 ,  79.196 ,
     *                  9.999 ,  60.991 ,  82.262                     /
C
      DATA AO       /   4.0029,   5.3656,  36.2853,1044.3447,
     *                131.0217, 868.9779,  14.8533,  93.1466,
     *                 12.7843,   5.6828,  98.0919, 829.4396,
     *                 50.9878, 199.0120,   2.0000,   6.0000,  10.0000,
     *                 10.0000,  30.0000,  50.0000,
     *                  8.0703,   5.7144,  84.1156, 529.0927,
     *                  5.6609,  28.9355, 111.3620, 494.0413,
     *                 45.5249, 134.4751,
     *                  4.0003,  21.2937,  78.7058,
     *                 12.8293,  16.2730, 123.6578, 327.2396,
     *                 48.7883, 102.2117,  20.0060, 161.9903,
     *                 28.4184,  61.5816,
     *                 10.5563,  13.2950, 188.1390,
     *                 14.6560, 129.4922, 470.8512                    /
      DATA GO       /   0.022 ,   2.019 ,   9.812 ,  13.087 ,
     *                 13.804 ,  16.061 ,  14.293 ,  16.114 ,
     *                  3.472 ,   7.437 ,  22.579 ,  32.035 ,
     *                 27.774 ,  33.678 ,  28.118 ,  31.019 ,  34.204 ,
     *                 30.892 ,  33.189 ,  36.181 ,
     *                  0.032 ,   2.760 ,  35.328 ,  48.277 ,
     *                  7.662 ,  16.786 ,  42.657 ,  54.522 ,
     *                 50.204 ,  56.044 ,
     *                  0.048 ,  50.089 ,  66.604 ,
     *                  8.954 ,  18.031 ,  57.755 ,  72.594 ,
     *                 68.388 ,  82.397 ,  31.960 ,  76.876 ,
     *                 75.686 ,  80.388 ,
     *                 10.747 ,  52.323 ,  94.976 ,
     *                 27.405 ,  86.350 , 109.917                     /
C
      DATA AF       /   2.0001,  39.9012, 122.0986,
     *                 10.0000,  30.0000,  50.0000,
     *                  4.0199,   5.5741,  22.1839, 190.2179,
     *                 53.0383, 126.9616,  31.6894,  75.3105,
     *                 13.5014,   7.9936,  55.7981, 298.7039,
     *                 26.2496,  63.7503,   2.0000,   6.0000,  10.0000,
     *                 28.7150,  71.2850,
     *                  8.0153,   6.1931,  21.7287,  48.7780, 278.2782,
     *                178.5560, 421.4435,  51.7632,  95.2368          /
      DATA GF       /   0.050 ,  13.317 ,  15.692 ,
     *                 15.361 ,  17.128 ,  18.498 ,
     *                  0.048 ,   2.735 ,  20.079 ,  30.277 ,
     *                 27.548 ,  32.532 ,  30.391 ,  34.707 ,
     *                  4.479 ,  12.072 ,  31.662 ,  51.432 ,
     *                 44.283 ,  50.964 ,  46.193 ,  50.436 ,  54.880 ,
     *                 50.816 ,  57.479 ,
     *                  0.058 ,   3.434 ,  14.892 ,  37.472 ,  69.883 ,
     *                 67.810 ,  83.105 ,  72.435 ,  79.747           /
C
      DATA ANN      /  34.5080, 365.4919,  16.5768, 183.4231,
     *                  2.0007,  89.5607, 380.4381,  26.4473,  63.5527,
     *                  4.0342,   5.6162,  11.5176,  72.8273,
     *                 48.5684, 131.4315,  31.1710,  76.8290,
     *                 14.0482,  13.3077,  52.7897, 467.8487,
     *                 54.2196, 195.7800                              /
      DATA GNN      /  17.796 ,  20.730 ,  17.879 ,  20.855 ,
     *                  0.097 ,  29.878 ,  37.221 ,  31.913 ,  37.551 ,
     *                  0.092 ,   3.424 ,  24.806 ,  46.616 ,
     *                 45.643 ,  54.147 ,  48.359 ,  57.420 ,
     *                  5.453 ,  18.560 ,  46.583 ,  80.101 ,
     *                 70.337 ,  85.789                               /
C
      DATA ANA      /  11.6348, 158.3593,
     *                 21.0453,  50.9546,  10.1389,  25.8611,
     *                  2.0019,  38.0569, 137.9398,  28.3106,  61.6893,
     *                  4.0334,   5.8560,  18.1786, 208.9142,
     *                 93.6895, 406.3095,  60.4276, 239.5719          /
      DATA GNA      /   2.400 ,   4.552 ,
     *                 34.367 ,  40.566 ,  34.676 ,  40.764 ,
     *                  0.170 ,  44.554 ,  57.142 ,  51.689 ,  60.576 ,
     *                  0.152 ,   4.260 ,  36.635 ,  83.254 ,
     *                 72.561 ,  89.475 ,  75.839 ,  92.582           /
C
      DATA AMG      /  10.7445, 291.5057,  53.7488,
     *                  6.2270,  31.1291, 132.6438,
     *                 40.4379, 159.5618,  20.3845,  79.6154,
     *                  2.0007, 106.8977, 343.1010,  10.1326, 237.8581/
      DATA GMG      /   2.805 ,   6.777 ,   9.254 ,
     *                  4.459 ,   9.789 ,  13.137 ,
     *                 57.413 ,  71.252 ,  58.010 ,  71.660 ,
     *                  0.276 ,  74.440 ,  94.447 ,  54.472 ,  95.858 /
C
      DATA AAL      /   4.0009,  11.7804, 142.2179,  13.6585,  96.3371,
     *                 10.0807,  49.5843, 285.3343,  14.6872,  59.3122,
     *                  6.3277,  29.5086, 134.1634,
     *                 46.3164, 153.6833,  22.9896,  77.0103          /
      DATA GAL      /   0.014 ,   3.841 ,   5.420 ,   3.727 ,   8.833 ,
     *                  4.749 ,  11.902 ,  16.719 ,  11.310 ,  18.268 ,
     *                  6.751 ,  16.681 ,  24.151 ,
     *                 83.551 , 104.787 ,  84.293 , 105.171           /
C
      DATA ASI      /   7.9658,   4.6762,   1.3512, 123.2267, 443.7797,
     *                  4.0000,   7.4186,  24.1754, 60.4060,
     *                 14.4695,  11.9721,  26.5062, 269.0521,
     *                  9.1793,   4.8766,  29.1442,  52.7998,
     *                 13.2674,  36.0417, 180.6910,
     *                  6.4839,  27.6851, 135.8301                    /
      DATA GSI      /   0.020 ,   0.752 ,   1.614 ,   5.831 ,   7.431 ,
     *                  0.036 ,   8.795 ,  11.208 ,  13.835 ,
     *                  5.418 ,   7.825 ,  14.440 ,  19.412 ,
     *                  6.572 ,  11.449 ,  18.424 ,  25.457 ,
     *                 15.682 ,  27.010 ,  34.599 ,
     *                  9.042 ,  24.101 ,  37.445                     /
C
      DATA AP       /  13.5211,  22.2130, 353.2583,  10.0000, 150.0000,
     *                  8.0241,   5.8085,  51.7542, 252.4002,
     *                  4.0021,  20.7985,  62.4194, 200.7786,
     *                 11.7414,  63.5124, 179.7420,
     *                  6.8835,  32.7777, 228.3366                    /
      DATA GP       /   1.514 ,   5.575 ,   9.247 ,   8.076 ,  10.735 ,
     *                  0.043 ,   1.212 ,   8.545 ,  15.525 ,
     *                  0.074 ,   7.674 ,  16.639 ,  25.118 ,
     *                  8.992 ,  24.473 ,  40.704 ,
     *                 11.464 ,  33.732 ,  55.455                     /
C
      DATA AS       /   3.9615,   5.0780,  15.0944, 362.8588,
     *                 51.5995, 268.4002,  12.0000, 276.0000,
     *                 11.4377,   5.5126, 141.0009, 254.0478,
     *                 33.0518, 126.9479,
     *                  4.0707,   4.0637,   5.7245, 144.6376, 106.4909,
     *                  4.0011,  19.2813,  27.5990,  35.1179,
     *                 94.7454, 283.2486,
     *                 10.5474,  28.7137,  65.7378,  24.0000          /
      DATA GS       /   0.053 ,   1.121 ,   5.812 ,   9.425 ,
     *                  8.936 ,  11.277 ,   9.600 ,  12.551 ,
     *                  1.892 ,   3.646 ,  13.550 ,  19.376 ,
     *                 16.253 ,  21.062 ,
     *                  0.043 ,   0.123 ,   1.590 ,  13.712 ,  22.050 ,
     *                  0.118 ,   9.545 ,  18.179 ,  31.441 ,
     *                 30.664 ,  56.150 ,
     *                 10.704 ,  27.075 ,  50.599 ,  43.034           /
C
      DATA ACL      /   2.0007,  62.5048, 669.4942,  29.0259, 130.9740,
     *                  3.9064,   0.3993,   5.3570,  60.3424, 119.9913,
     *                138.1567, 278.8418, 102.3681, 158.6314,
     *                 12.6089,   5.9527, 110.5635, 262.8715,
     *                 69.2035, 100.7960,
     *                  7.3458,   5.6638,  44.1256, 202.7846,
     *                  4.0037,  21.8663,  40.5363,  57.5919          /
      DATA GCL      /   0.110 ,   9.919 ,  12.280 ,  11.017 ,  13.532 ,
     *                  0.092 ,   0.581 ,   1.620 ,  13.121 ,  19.787 ,
     *                 16.365 ,  21.988 ,  18.065 ,  23.594 ,
     *                  2.358 ,   5.708 ,  19.084 ,  30.683 ,
     *                 24.880 ,  33.229 ,
     *                  0.102 ,   1.391 ,  14.709 ,  36.968 ,
     *                  0.185 ,  11.783 ,  25.653 ,  44.698           /
C
      DATA AAR      /  43.6623, 324.3375,  20.8298, 163.1701,
     *                  2.0026, 137.4515, 258.5445,  62.8129, 149.1867,
     *                  4.0495,  14.4466,  46.8234, 124.6651,
     *                151.9828, 268.0157, 101.1302, 150.8691,
     *                 13.3718,   8.6528,  60.4614, 285.5072,
     *                  6.7655,   4.7684,  12.8631,  54.5260          /
      DATA GAR      /  12.638 ,  14.958 ,  12.833 ,  15.139 ,
     *                  0.178 ,  17.522 ,  23.584 ,  20.464 ,  25.150 ,
     *                  0.151 ,   1.561 ,  17.399 ,  30.871 ,
     *                 24.684 ,  33.978 ,  27.091 ,  36.481 ,
     *                  2.810 ,   8.877 ,  24.351 ,  44.489 ,
     *                  0.144 ,   1.160 ,  10.210 ,  27.178           /
C
      DATA AK       /  12.9782, 148.6673,   6.3493,
     *                 66.3444, 101.6553,   4.0001,  13.4465,  46.5534,
     *                  2.0171, 116.4767, 713.4965,  63.5907, 396.4079,
     *                  2.0000,  10.0000,  30.0000,
     *                  4.0702,   5.7791,  52.6795, 327.4539,
     *                 62.8604, 357.1331,  55.9337, 196.0646,
     *                 10.9275,   5.5398,  43.2761,  76.2560,
     *                 42.0000,  18.0000                              /
      DATA GK       /   1.871 ,   3.713 ,  18.172 ,
     *                 21.185 ,  27.705 ,   2.059 ,  23.709 ,  28.542 ,
     *                  0.273 ,  26.709 ,  39.640 ,  31.220 ,  41.865 ,
     *                 29.955 ,  37.557 ,  42.862 ,
     *                  0.228 ,   2.274 ,  21.703 ,  50.191 ,
     *                 32.145 ,  49.262 ,  34.155 ,  51.718 ,
     *                  3.043 ,   5.479 ,  20.547 ,  30.680 ,
     *                 36.275 ,  47.345                               /
C
      DATA ACA      /  18.2366,  27.5012, 149.2617,  94.5242, 705.4711,
     *                 11.8706,  14.0710, 106.0547,
     *                 57.2414, 110.7567,  29.8121,  54.1874,
     *                  2.0184,  97.5784, 282.3939, 209.1871, 252.8129/
      DATA GCA      /   2.050 ,   3.349 ,   5.321 ,   4.873 ,   7.017 ,
     *                  1.769 ,   5.109 ,   9.524 ,
     *                 27.271 ,  41.561 ,  29.172 ,  42.140 ,
     *                  0.394 ,  28.930 ,  52.618 ,  38.593 ,  49.646 /
C
      DATA ASC      /   6.0014,  83.1958,  67.3666, 329.4354,
     *                 44.0793, 169.9969, 533.9195,
     *                 34.1642, 124.8475, 228.9879,
     *                 11.9979,  16.9280,  28.4778,  82.0418, 234.5360,
     *                  6.0042,   2.7101,  13.9801,  65.3039,
     *                 12.0000,  12.0000,
     *                  2.0051,   2.9621,  29.0306                    /
      DATA GSC      /   0.021 ,   2.056 ,   3.551 ,   5.465 ,
     *                  1.535 ,   3.797 ,   6.203 ,
     *                  2.389 ,   4.858 ,   7.141 ,
     *                  0.011 ,   0.430 ,   1.156 ,   3.711 ,   8.863 ,
     *                  0.025 ,   3.499 ,  10.463 ,  18.606 ,
     *                 41.779 ,  57.217 ,
     *                  0.539 ,  24.442 ,  51.079                     /
C
      DATA ATI      /   7.0887,   8.9186,  17.5633, 206.6832, 438.5735,
     *                654.1721,
     *                 38.0462,  69.6271, 364.2845, 832.0408,
     *                 98.8562,  57.9934, 442.1498,
     *                 19.7843,  32.0637,  37.0895, 110.6682, 288.4946,
     *                521.8837,
     *                 10.0000,  34.0000, 120.0000,
     *                 16.1691,  22.3550,  24.1646,  83.5128, 222.7963,
     *                  6.0020,   4.6177,  25.2636,  52.1162,
     *                 12.0000,   8.0000                              /
      DATA GTI      /   0.021 ,   0.048 ,   1.029 ,   2.183 ,   4.109 ,
     *                  5.785 ,
     *                  0.846 ,   1.792 ,   3.836 ,   5.787 ,
     *                  2.561 ,   4.869 ,   6.340 ,
     *                  0.023 ,   0.124 ,   0.774 ,   1.810 ,   4.980 ,
     *                  9.585 ,
     *                  1.082 ,   4.928 ,  11.279 ,
     *                  0.041 ,   1.375 ,   4.768 ,  10.985 ,  19.769 ,
     *                  0.048 ,  11.577 ,  24.531 ,  36.489 ,
     *                 54.436 ,  75.373                               /
C
      DATA AV       /  15.2627,  23.9869,  51.3053, 570.3384,1650.9417,
     *                162.2829, 298.8303, 908.8852,
     *                 23.6736,  37.1624,  86.8011, 300.7440, 864.5880,
     *                 57.8961,  79.4605, 214.9007, 864.7425,
     *                 61.8508,  64.0845, 192.8298, 718.2349,
     *                 23.8116,  68.2495, 135.0613, 536.7632,
     *                 15.9543,  22.5542,  71.4921, 248.9544,
     *                  6.0006,   5.8785,  50.5077,  97.6129          /
      DATA GV       /   0.026 ,   0.145 ,   0.718 ,   2.586 ,   5.458 ,
     *                  2.171 ,   4.153 ,   6.097 ,
     *                  0.009 ,   0.366 ,   1.504 ,   5.294 ,  10.126 ,
     *                  1.796 ,   2.353 ,   6.068 ,  12.269 ,
     *                  2.560 ,   3.674 ,   6.593 ,  12.880 ,
     *                  0.045 ,   1.684 ,   8.162 ,  21.262 ,
     *                  0.065 ,   1.746 ,  15.158 ,  33.141 ,
     *                  0.077 ,  21.229 ,  44.134 ,  60.203           /
C
      DATA ACR      /  30.1842,  79.2847, 149.5293,
     *                215.3696, 119.1974, 741.4321,
     *                184.9946,1352.5038, 784.4937,
     *                 46.6191, 160.1361, 488.0449, 657.1928,
     *                 47.1742, 267.0275, 441.1324, 150.6650,
     *                 24.3768, 122.8359, 285.5092, 794.1654,
     *                 24.2296,  75.0258, 172.9452, 543.6511,
     *                 15.9819,  17.6800,  95.2003, 225.0947          /
      DATA GCR      /   0.993 ,   3.070 ,   5.673 ,
     *                  3.339 ,   4.801 ,   7.198 ,
     *                  2.829 ,   4.990 ,   7.643 ,
     *                  1.645 ,   3.727 ,   7.181 ,  12.299 ,
     *                  2.902 ,   4.273 ,   8.569 ,  14.912 ,
     *                  0.047 ,   2.566 ,   9.441 ,  21.198 ,
     *                  0.078 ,   2.242 ,  15.638 ,  32.725 ,
     *                  0.103 ,   2.146 ,  26.153 ,  49.381           /
C
      DATA AMN      /  53.9107,  81.3931, 546.6945 ,
     *                144.1893, 407.8029,  45.6177, 298.4423,2410.9335,
     *                 22.6382,  93.8419, 183.9367, 907.5765,
     *                137.0409, 168.6783, 329.0287, 773.2513,
     *                 70.1925,  72.3372, 213.9512, 539.5165,
     *                 24.2373,  93.5415, 456.6167, 506.5484,
     *                 24.7687,  66.9896, 264.1853, 484.0161          /
      DATA GMN      /   2.527 ,   4.204 ,   6.602 ,
     *                  4.155 ,   7.321 ,   2.285 ,   5.631 ,   8.448 ,
     *                  1.496 ,   3.839 ,   7.751 ,  13.484 ,
     *                  3.681 ,   6.054 ,   9.934 ,  14.936 ,
     *                  3.531 ,   6.967 ,  15.222 ,  25.069 ,
     *                  0.071 ,   2.896 ,  20.725 ,  37.383 ,
     *                  0.126 ,   2.660 ,  28.528 ,  53.413           /
C
      DATA AFE      /  14.4102,   2.7050, 421.6612, 940.1484,
     *                 36.2187,  22.8883, 239.5997, 825.2919,
     *                110.0242, 992.3040, 640.6715,
     *                 17.0494,  32.3783,  34.3184, 420.9626,1067.2064,
     *                154.0059, 462.1117, 329.8618,
     *                 15.7906,  47.1186, 279.9292, 692.1005,
     *                 91.0206, 206.3082, 706.9927, 836.6689,
     *                 40.0790,  27.6965,  28.2243,  18.0001,
     *                 24.0899,  89.6340,  51.5756, 241.6980          /
      DATA GFE      /   0.066 ,   0.339 ,   2.897 ,   6.585 ,
     *                  0.923 ,   1.679 ,   4.620 ,   7.053 ,
     *                  4.249 ,   5.875 ,   7.781 ,
     *                  0.062 ,   0.283 ,   1.504 ,   5.430 ,  11.210 ,
     *                  2.792 ,   7.627 ,  13.623 ,
     *                  0.077 ,   3.723 ,  12.137 ,  23.700 ,
     *                  2.688 ,   7.595 ,  15.444 ,  25.587 ,
     *                  3.982 ,   4.677 ,   6.453 ,  23.561 ,
     *                  0.102 ,   3.354 ,  22.954 ,  33.796           /
C
      DATA ACO      /  11.9120,  20.4424,  28.3863, 132.5038, 600.7461,
     *                 33.3092, 237.4331, 977.2502,
     *                 55.5396, 318.8169, 619.6366,
     *                 32.6900,  83.8694, 107.4378,
     *                 11.2593,  38.2239,  22.9964, 261.3486, 637.1485,
     *                 23.0233,  41.6599, 264.6460, 181.6699,
     *                 16.0356,   7.8633,  70.3158, 423.3512, 742.3553,
     *                  0.                                            /
      DATA GCO      /   0.112 ,   0.341 ,   0.809 ,   3.808 ,   6.723 ,
     *                  2.057 ,   3.484 ,   7.210 ,
     *                  2.405 ,   5.133 ,   8.097 ,
     *                  2.084 ,   5.291 ,   8.426 ,
     *                  0.135 ,   0.517 ,   1.606 ,   6.772 ,  12.622 ,
     *                  2.512 ,   4.348 ,   8.253 ,  15.377 ,
     *                  0.132 ,   0.863 ,   3.086 ,  11.789 ,  23.263 ,
     *                  0.                                            /
C
      DATA ANI      /   7.1268,  12.4486,  11.9953,  10.0546, 114.1658,
     *                391.2064,
     *                 26.3908, 213.8081, 938.7927,
     *                  4.1421,  37.3781,  25.9712, 333.3397, 311.1633,
     *                 33.1031, 184.1854, 136.7072,
     *                 11.1915,   5.4174,  53.6793, 460.6781, 380.0056,
     *                  0.                                            /
      DATA GNI      /   0.026 ,   0.137 ,   0.315 ,   1.778 ,   4.029 ,
     *                  6.621 ,
     *                  2.249 ,   4.042 ,   7.621 ,
     *                  0.191 ,   1.235 ,   3.358 ,   8.429 ,  17.096 ,
     *                  3.472 ,   9.065 ,  16.556 ,
     *                  0.194 ,   1.305 ,   5.813 ,  14.172 ,  26.169 ,
     *                  0.                                            /
C
      DATA ACU      /  11.0549, 238.9423,  10.3077, 126.2990,1073.3876,
     *                 30.0000,  50.0000,  60.0000,
     *                 19.2984,  50.5974, 240.2021,1216.9016,
     *                 48.3048, 583.2011, 320.4931,
     *                  4.0155,  70.3264, 313.1213, 536.5331,
     *                  0.                                            /
      DATA GCU      /   4.212 ,   7.227 ,   1.493 ,   5.859 ,   9.709 ,
     *                  7.081 ,   9.362 ,  10.130 ,
     *                  2.865 ,   8.260 ,  14.431 ,  18.292 ,
     *                  9.650 ,  14.640 ,  24.320 ,
     *                  0.337 ,   8.520 ,  16.925 ,  28.342 ,
     *                  0.                                            /
C
      DATA AZN      /  15.9880, 484.0042,  18.5863, 123.4134,
     *                  3.0000, 189.0000,
     *                  6.1902,  38.9317, 204.8780,
     *                 10.2588,  89.3771, 370.3640,  30.0000, 128.0000,
     *                 24.6904, 106.7491, 439.5586,
     *                  0.                                            /
      DATA GZN      /   4.546 ,   8.840 ,  10.247 ,  16.620 ,
     *                 11.175 ,  16.321 ,
     *                  6.113 ,  12.964 ,  16.444 ,
     *                  7.926 ,  13.633 ,  24.353 ,  16.286 ,  24.910 ,
     *                 10.291 ,  20.689 ,  32.077 ,
     *                  0.                                            /
C
C
      DATA ICOMP /0/
C
C
      EXP10(X)=EXP(2.3025851*X)
C
      IF(ICOMP.NE.0) GO TO 5
      IND=1
      DO 1 K=1,NIONS
         INDEXS(K)=IND
         IND=IND+IS(K)
    1 CONTINUE
      IND=1
      DO 2 K=1,NSS
         INDEXM(K)=IND
         IND=IND+IM(K)
    2 CONTINUE
      ICOMP=1
    5 CONTINUE
      IF((IAT.EQ.26.or.iat.eq.28)
     *  .AND.IZI.GE.4.AND.IZI.LE.9) GO TO 70
      IF(IZI.LE.0.OR.IZI.GT.5.OR.IAT.LE.0.OR.IAT.GT.30) GO TO 50
      MODE=MODPF(IAT)
      IF(MODE.LT.0) GO TO 50
      IF(MODE.GT.0) GO TO 60
      I0=INDEX0(IZI,IAT)
      IF(I0) 40,50,10
   10 QZ=IZI
C     MAX=XMAXN*SQRT(QZ)
      XMAX=XMAXN
      THET=5040.4/T
      A=31.321*QZ*QZ*THET
      XMAX2=XMAX*XMAX
      QAS1=XMAX*THIRD*(XMAX2+TRHA*XMAX+HALF)
      IS0=INDEXS(I0)
      ISS=IS0+IS(I0)-1
      SU1=0.
      SQA=0.
      DO 30 K=IS0,ISS
         XXL=XL(K)
         GPR=IGPR(K)
         X=CHION(K)*THET
         EX=0.
         IF(X.LT.30) EX=EXP10(-X)
         QAS=(QAS1-XXL*THIRD*(XXL*XXL+TRHA*XXL+HALF)+(XMAX-XXL)*
     *       (UN+A*HALF/XXL/XMAX)*A)*GPR*EX
         SQA=SQA+QAS
         M0=INDEXM(K)
         M1=M0+IM(K)-1
         AL1=0.
         DO 20 M=M0,M1
            XG=GAM(M)*THET
            IF(XG.GT.20.) GO TO 20
            XM=EXP10(-XG)*ALF(M)
            AL1=AL1+XM
   20    CONTINUE
         SU1=SU1+AL1
   30 CONTINUE
      U=IG0(I0)
      U=U+SU1+SQA
      IF(U.LT.0.) U=IG0(I0)
      RETURN
   40 U=FLOAT(-I0)
      RETURN
   50 CALL PFSPEC(IAT,IZI,T,ANE,XMAXN,U)
      RETURN
   60 U=PFSTD(IZI,IAT)
      RETURN
   70 if(iat.eq.26) call pffe(IZI,T,ANE,U)
      if(iat.eq.28) call pfni(izi,t,ane,u,dut,dun)
      RETURN
      END
C
C ********************************************************************
C
C
      subroutine pffe(ion,t,ane,pf)
c     =============================
c
c     partition functions for Fe IV to Fe IX
c     after Fischel and Sparks, 1971, NASA SP-3066
c
c     Output:  PF   partition function
c
      INCLUDE 'PARAMS.FOR'
      dimension tt(50),pn(10),nca(9)
      dimension p4a(22),p4b(10,28), 
     *          p5a(30),p5b(10,20),
     *          p6a(37),p6b(10,13),
     *          p7a(40),p7b(10,10),
     *          p8a(41),p8b(10,9),
     *          p9a(45),p9b(10,5)
c
      parameter (xen=2.302585093,xmil=0.001,xmilen=xmil*xen)
      parameter (xbtz=1.38054d-16)
c
c
      data nca /3*0,22,30,37,40,41,45/
     *     nne /10/
c
      data tt /
     * 3.,4.,5.,6.,7.,8.,9.,10.,11.,12.,13.,14.,15.,16.,17.,18.,19.,
     * 20.,21.,22.,23.,24.,25.,26.,27.,28.,29.,30.,
     * 32.,34.,36.,38.,40.,42.,44.,46.,48.,
     * 50.,55.,60.,65.,70.,75.,80.,85.,90.,95.,100.,125.,150./
c
      data pn /-2.,-1.,0.,1.,2.,3.,4.,5.,6.,7./
c
      data p4a /
     * 0.778, 0.778, 0.778, 0.779, 0.783, 0.789, 0.801, 0.818,
     * 0.842, 0.871, 0.906, 0.945, 0.987, 1.030, 1.074, 1.117,
     * 1.160, 1.201, 1.242, 1.280, 1.317, 1.353/
c
      data p4b /
     * 1.406,1.393,1.389,7*1.387,
     * 1.464,1.434,1.424,1.421,1.420,5*1.419,
     * 1.546,1.483,1.461,1.454,1.451,1.451,4*1.450,
     * 1.665,1.547,1.503,1.488,1.482,1.481,4*1.480,
     * 1.826,1.636,1.553,1.524,1.514,1.510,4*1.509,
     * 2.024,1.755,1.618,1.564,1.546,1.540,1.538,3*1.537,
     * 2.480,2.087,1.814,1.674,1.619,1.599,1.593,1.591,1.590,1.590,
     * 2.945,2.489,2.105,1.846,1.717,1.667,1.649,1.643,1.641,1.640,
     * 3.379,2.897,2.452,2.089,1.859,1.751,1.710,1.696,1.691,1.689,
     * 3.774,3.283,2.808,2.381,2.054,1.864,1.782,1.751,1.741,1.738,
     * 4.133,3.637,3.150,2.688,2.292,2.015,1.871,1.814,1.793,1.786,
     * 4.460,3.962,3.468,2.989,2.549,2.199,1.984,1.886,1.848,1.835,
     * 4.757,4.258,3.762,3.274,2.809,2.406,2.121,1.972,1.908,1.886,
     * 5.029,4.530,4.032,3.539,3.061,2.624,2.279,2.073,1.976,1.939,
     * 5.279,4.780,4.281,3.785,3.299,2.840,2.450,2.189,2.051,1.996,
     * 5.510,5.010,4.511,4.013,3.522,3.050,2.628,2.318,2.136,2.057,
     * 6.014,5.514,5.014,4.515,4.018,3.530,3.065,2.666,2.381,2.228,
     * 6.435,5.935,5.435,4.936,4.437,3.943,3.460,3.022,2.658,2.422,
     * 6.794,6.294,5.794,5.294,4.794,4.297,3.807,3.343,2.939,2.631,
     * 7.102,6.602,6.102,5.602,5.102,4.604,4.110,3.638,3.194,2.845,
     * 7.370,6.870,6.370,5.870,5.370,4.871,4.375,3.892,3.439,3.052,
     * 7.606,7.106,6.606,6.106,5.605,5.106,4.608,4.125,3.661,3.249,
     * 7.815,7.315,6.814,6.314,5.814,5.314,4.816,4.333,3.851,3.418,
     * 8.001,7.501,7.001,6.500,6.000,5.500,5.001,4.511,4.032,3.586,
     * 8.168,7.668,7.168,6.668,6.168,5.667,5.168,4.680,4.197,3.741,
     * 8.319,7.819,7.319,6.819,6.319,5.818,5.319,4.832,4.347,3.884,
     * 8.900,8.399,7.899,7.399,6.899,6.398,5.898,5.405,4.917,4.431,
     * 9.294,8.794,8.294,7.793,7.293,6.793,6.292,5.799,5.306,4.824/
c
      data p5a /
     * 1.235, 1.276, 1.301, 1.321, 1.339, 1.359, 1.381, 1.405,
     * 1.432, 1.460, 1.489, 1.518, 1.546, 1.574, 1.601, 1.627,
     * 1.652, 1.675, 1.697, 1.718, 1.738, 1.757, 1.775, 1.792,
     * 1.808, 1.823, 1.838, 1.851, 1.877, 1.900/
c
      data p5b /
     * 1.943,1.928,1.923,7*1.921,
     * 2.011,1.964,1.947,1.942,1.941,5*1.940,
     * 2.144,2.025,1.980,1.965,1.960,1.958,4*1.957,
     * 2.361,2.137,2.032,1.993,1.980,1.976,1.975,3*1.974,
     * 2.646,2.315,2.121,2.035,2.004,1.994,1.991,1.990,1.989,1.989,
     * 2.960,2.553,2.260,2.102,2.037,2.015,2.007,2.005,2.004,2.004,
     * 3.274,2.823,2.450,2.205,2.086,2.040,2.025,2.020,2.018,2.018,
     * 3.575,3.101,2.674,2.348,2.158,2.075,2.045,2.036,2.032,2.031,
     * 4.251,3.757,3.275,2.829,2.466,2.234,2.124,2.083,2.069,2.064,
     * 4.822,4.324,3.829,3.346,2.895,2.522,2.278,2.161,2.116,2.100,
     * 5.308,4.808,4.310,3.816,3.334,2.888,2.525,2.297,2.187,2.145,
     * 5.725,5.225,4.726,4.228,3.736,3.260,2.828,2.496,2.294,2.206,
     * 6.088,5.589,5.089,4.590,4.093,3.604,3.139,2.733,2.447,2.291,
     * 6.407,5.907,5.407,4.908,4.409,3.915,3.433,2.988,2.629,2.399,
     * 6.689,6.189,5.689,5.189,4.690,4.193,3.704,3.236,2.832,2.535,
     * 6.940,6.440,5.940,5.440,4.941,4.443,3.949,3.469,3.038,2.687,
     * 7.166,6.666,6.166,5.666,5.166,4.667,4.171,3.684,3.237,2.847,
     * 7.370,6.870,6.369,5.869,5.369,4.870,4.373,3.882,3.417,3.008,
     * 8.150,7.649,7.149,6.649,6.149,5.649,5.149,4.651,4.167,3.700,
     * 8.677,8.177,7.676,7.176,6.676,6.176,5.676,5.176,4.687,4.203/
c
      data p6a /
     * 1.218, 1.273, 1.309, 1.335, 1.358, 1.379, 1.400, 1.421,
     * 1.442, 1.463, 1.484, 1.504, 1.523, 1.542, 1.560, 1.577,
     * 1.594, 1.609, 1.624, 1.638, 1.652, 1.664, 1.677, 1.688,
     * 1.699, 1.709, 1.719, 1.729, 1.746, 1.762, 1.777, 1.790,
     * 1.803, 1.814, 1.825, 1.834, 1.843/
c
      data p6b /
     * 1.862,1.855,1.853,7*1.852,
     * 1.958,1.900,1.880,1.874,1.872,5*1.871,
     * 2.264,2.045,1.944,1.906,1.894,1.890,4*1.888,
     * 2.776,2.386,2.119,1.984,1.930,1.912,1.906,1.904,2*1.903,
     * 3.321,2.856,2.453,2.165,2.012,1.949,1.927,1.920,1.918,1.917,
     * 3.821,3.333,2.868,2.465,2.178,2.025,1.963,1.941,1.934,1.932,
     * 4.266,3.771,3.285,2.825,2.434,2.164,2.027,1.972,1.953,1.947,
     * 4.662,4.164,3.670,3.187,2.739,2.372,2.135,2.022,1.980,1.965,
     * 5.015,4.516,4.019,3.527,3.052,2.624,2.295,2.102,2.019,1.988,
     * 5.332,4.832,4.344,3.838,3.351,2.889,2.493,2.217,2.075,2.017,
     * 5.618,5.118,4.619,4.121,3.628,3.149,2.711,2.364,2.155,2.058,
     * 6.710,6.210,5.710,5.210,4.711,4.213,3.719,3.241,2.807,2.462,
     * 7.446,6.946,6.446,5.946,5.446,4.946,4.447,3.952,3.474,3.022/
c
      data p7a /
     * 1.074,1.130,1.167,1.194,1.215,1.234,1.250,1.266,1.280,1.293,
     * 1.306,1.318,1.329,1.340,1.350,1.360,1.369,1.378,1.386,1.394,
     * 1.401,1.408,1.415,1.421,1.427,1.433,1.439,1.444,1.454,1.463,
     * 1.471,1.479,1.486,1.492,1.498,1.504,1.509,1.514,1.525,1.534/
c
      data p7b /
     * 1.555,1.546,1.544,1.543,6*1.542,
     * 1.617,1.572,1.557,1.552,1.550,1.550,4*1.549,
     * 1.798,1.648,1.587,1.566,1.559,1.557,4*1.556,
     * 2.134,1.832,1.666,1.597,1.573,1.565,1.563,1.562,2*1.561,
     * 2.550,2.138,1.836,1.671,1.602,1.578,1.570,1.568,2*1.567,
     * 2.968,2.504,2.102,1.816,1.665,1.603,1.582,1.575,2*1.572,
     * 3.359,2.875,2.419,2.037,1.779,1.651,1.601,1.584,1.579,1.577,
     * 3.718,3.224,2.745,2.305,1.953,1.736,1.636,1.599,1.586,1.582,
     * 5.097,4.598,4.098,3.601,3.110,2.638,2.217,1.899,1.719,1.643,
     * 6.026,5.526,5.026,4.527,4.028,3.531,3.042,2.576,2.170,1.885/
c
      data p8a /
     * 0.809,0.849,0.875,0.894,0.908,0.918,0.927,0.934,0.939,0.944,
     * 0.948,0.952,0.955,0.958,0.960,0.962,0.964,0.966,0.967,0.969,
     * 0.970,0.971,0.973,0.974,0.975,0.975,0.976,0.977,0.978,0.980,
     * 0.981,0.982,0.983,0.984,0.984,0.985,0.986,0.986,0.987,0.988,
     * 0.989/
c
      data p8b /
     * 0.992,0.991,8*0.990,
     * 1.000,0.994,0.992,7*0.991,
     * 1.032,1.005,0.996,0.993,0.992,5*0.991,
     * 1.129,1.040,1.008,0.997,0.993,5*0.992,
     * 1.335,1.132,1.042,1.009,0.998,0.994,0.993,0.993,2*0.992,
     * 1.640,1.312,1.121,1.038,1.007,0.998,0.994,3*0.993,
     * 1.987,1.573,1.269,1.101,1.030,1.005,0.997,2*0.994,0.993,
     * 3.514,3.017,2.526,2.053,1.628,1.305,1.119,1.039,1.010,1.000,
     * 4.569,4.069,3.569,3.072,2.580,2.103,1.671,1.336,1.136,1.048/
c
      data p9a /39*0.000,0.001,0.002,0.005,0.008,0.014,0.021/
c
      data p9b /
     * 2*0.032,8*0.031,
     * 0.048,0.045,8*0.044,
     * 0.076,0.065,0.061,0.060,6*0.059,
     * 1.128,0.722,0.429,0.271,0.207,0.184,0.177,0.174,2*0.173,
     * 2.696,2.200,1.712,1.249,0.848,0.564,0.415,0.354,0.333,0.327/
c
      na=nca(ion)
      nb=50-na
      pne=log10(ane*xbtz*t)
      t0=xmil*t
      j=1
      if(pne.lt.pn(1)) go to 15
      if(pne.gt.pn(nne)) then
        j1=nne
        j2=nne
        goto 16
      endif
      do 10 j=1,nne-1      
        if(pne.ge.pn(j).and.pne.lt.pn(j+1)) go to 15
   10 continue
   15 j1=j
      j2=j1+1
      if(pne.lt.pn(1)) j2=1
   16 do 20 i=1,49
         if(t0.ge.tt(i).and.t0.lt.tt(i+1)) go to 25
   20 continue
   25 i1=i
      i2=i+1
      if(t0.gt.tt(50)) then
        i1=50
        i2=50
      endif
      if(i2.le.na) then
         if(ion.eq.4) then
           px1=p4a(i1)
           px2=p4a(i1)
           py1=p4a(i2)
           py2=p4a(i2)
         else if(ion.eq.5) then
           px1=p5a(i1)
           px2=p5a(i1)
           py1=p5a(i2)
           py2=p5a(i2)
         else if(ion.eq.6) then
           px1=p6a(i1)
           px2=p6a(i1)
           py1=p6a(i2)
           py2=p6a(i2)
         else if(ion.eq.7) then
           px1=p7a(i1)
           px2=p7a(i1)
           py1=p7a(i2)
           py2=p7a(i2)
         else if(ion.eq.8) then
           px1=p8a(i1)
           px2=p8a(i1)
           py1=p8a(i2)
           py2=p8a(i2)
         else if(ion.eq.9) then
           px1=p9a(i1)
           px2=p9a(i1)
           py1=p9a(i2)
           py2=p9a(i2)
         endif
       else if(i1.eq.na) then
         if(ion.eq.4) then
           px1=p4a(i1)
           px2=p4a(i1)
           py1=p4b(j1,i2-na)
           py2=p4b(j2,i2-na)
         else if(ion.eq.5) then
           px1=p5a(i1)
           px2=p5a(i1)
           py1=p5b(j1,i2-na)
           py2=p5b(j2,i2-na)
         else if(ion.eq.6) then
           px1=p6a(i1)
           px2=p6a(i1)
           py1=p6b(j1,i2-na)
           py2=p6b(j2,i2-na)
         else if(ion.eq.7) then
           px1=p7a(i1)
           px2=p7a(i1)
           py1=p7b(j1,i2-na)
           py2=p7b(j2,i2-na)
         else if(ion.eq.8) then
           px1=p8a(i1)
           px2=p8a(i1)
           py1=p8b(j1,i2-na)
           py2=p8b(j2,i2-na)
         else if(ion.eq.9) then
           px1=p9a(i1)
           px2=p9a(i1)
           py1=p9b(j1,i2-na)
           py2=p9b(j2,i2-na)
         endif
      else
         if(ion.eq.4) then
           px1=p4b(j1,i1-na)
           px2=p4b(j2,i1-na)
           py1=p4b(j1,i2-na)
           py2=p4b(j2,i2-na)
         else if(ion.eq.5) then
           px1=p5b(j1,i1-na)
           px2=p5b(j2,i1-na)
           py1=p5b(j1,i2-na)
           py2=p5b(j2,i2-na)
         else if(ion.eq.6) then
           px1=p6b(j1,i1-na)
           px2=p6b(j2,i1-na)
           py1=p6b(j1,i2-na)
           py2=p6b(j2,i2-na)
         else if(ion.eq.7) then
           px1=p7b(j1,i1-na)
           px2=p7b(j2,i1-na)
           py1=p7b(j1,i2-na)
           py2=p7b(j2,i2-na)
         else if(ion.eq.8) then
           px1=p8b(j1,i1-na)
           px2=p8b(j2,i1-na)
           py1=p8b(j1,i2-na)
           py2=p8b(j2,i2-na)
         else if(ion.eq.9) then
           px1=p9b(j1,i1-na)
           px2=p9b(j2,i1-na)
           py1=p9b(j1,i2-na)
           py2=p9b(j2,i2-na)
         endif
      end if
      dlgunx=px2-px1
      px=px1+(pne-pn(j1))*dlgunx
      dlguny=py2-py1
      py=py1+(pne-pn(j1))*dlguny
      delt=tt(i2)-tt(i1)
      if(delt.ne.0.) then
        dlgut=(py-px)/delt
        pf=px+(t0-tt(i1))*dlgut
      else
        pf=px
      endif
      pf=exp(xen*pf)
      return
      end
         
C
C ********************************************************************
C ********************************************************************
C

      SUBROUTINE MATINV(A,N,NR)
C     =========================
C
C     Matrix inversion
C      by LU decomposition
C
C      A  -  matrix of actual size (N x N) and maximum size (NR x NR)
C            to be inverted;
C      Inversion is accomplished in place and the original matrix is
C      replaced by its inverse
C
      INCLUDE 'PARAMS.FOR'
      DIMENSION A(NR,NR)
      IF(N.EQ.1) GO TO 250
      DO 50 I=2,N
         IM1=I-1
         DO 20 J=1,IM1
            JM1=J-1
            DIV=A(J,J)
            SUM=0.
            IF(JM1.LT.1) GO TO 20
            DO 10 K=1,JM1
   10          SUM=SUM+A(I,K)*A(K,J)
   20       A(I,J)=(A(I,J)-SUM)/DIV
         DO 40 J=I,N
            SUM=0.
            DO 30 K=1,IM1
   30          SUM=SUM+A(I,K)*A(K,J)
   40       A(I,J)=A(I,J)-SUM
   50 CONTINUE
      DO 80 II=2,N
         I=N+2-II
         IM1=I-1
         IF(IM1.LT.1) GO TO 80
         DO 70 JJ=1,IM1
            J=I-JJ
            JP1=J+1
            SUM=0.
            IF(JP1.GT.IM1) GO TO 70
            DO 60 K=JP1,IM1
   60          SUM=SUM+A(I,K)*A(K,J)
   70       A(I,J)=-A(I,J)-SUM
   80 CONTINUE
      DO 110 II=1,N
         I=N+1-II
         DIV=A(I,I)
         IP1=I+1
         IF(IP1.GT.N) GO TO 110
         DO 100 JJ=IP1,N
            J=N+IP1-JJ
            SUM=0.
            DO 90 K=IP1,J
   90          SUM=SUM+A(I,K)*A(K,J)
            A(I,J)=-SUM/DIV
  100    CONTINUE
  110 A(I,I)=1.0D0/A(I,I)
C
      DO 240 I=1,N
         DO 230 J=1,N
            K0=I
            IF(J.GE.I) GO TO 220
            SUM=0.
  200       DO 210 K=K0,N
  210          SUM=SUM+A(I,K)*A(K,J)
            GO TO 230
  220       K0=J
            SUM=A(I,K0)
            IF(K0.EQ.N) GO TO 230
            K0=K0+1
            GO TO 200
  230    A(I,J)=SUM
  240 CONTINUE
      RETURN
  250 A(1,1)=1.0D0/A(1,1)
      RETURN
      END
C
C
C     ****************************************************************
C
C

      SUBROUTINE LINEQS(A,B,X,N,NR)
C     =============================
C
C     Solution of the linear system A*X=B
C     by Gaussian elimination with partial pivoting
C
C     Input: A  - matrix of the linear system, with actual size (N x N),
C                and maximum size (NR x NR)
C            B  - the rhs vector
C     Output: X - solution vector
C     Note that matrix A and vector B are destroyed here !
C
      INCLUDE 'PARAMS.FOR'
      DIMENSION A(NR,NR),B(NR),X(NR),D(MLEVEL)
      DIMENSION IP(MLEVEL)
      DO 70 I=1,N
         DO 10 J=1,N
   10       D(J)=A(J,I)
         IM1=I-1
         IF(IM1.LT.1) GO TO 40
         DO 30 J=1,IM1
            IT=IP(J)
            A(J,I)=D(IT)
            D(IT)=D(J)
            JP1=J+1
            DO 20 K=JP1,N
   20          D(K)=D(K)-A(K,J)*A(J,I)
   30    CONTINUE
   40    AM=ABS(D(I))
         IP(I)=I
         DO 50 K=I,N
            IF(AM.GE.ABS(D(K))) GO TO 50
            IP(I)=K
            AM=ABS(D(K))
   50    CONTINUE
         IT=IP(I)
         A(I,I)=D(IT)
         D(IT)=D(I)
         IP1=I+1
         IF(IP1.GT.N) GO TO 80
         DO 60 K=IP1,N
   60       A(K,I)=D(K)/A(I,I)
   70 CONTINUE
   80 DO 100 I=1,N
         IT=IP(I)
         X(I)=B(IT)
         B(IT)=B(I)
         IP1=I+1
         IF(IP1.GT.N) GO TO 110
         DO 90 J=IP1,N
   90       B(J)=B(J)-A(J,I)*X(I)
  100 CONTINUE
  110 DO 140 I=1,N
         K=N-I+1
         SUM=0.
         KP1=K+1
         IF(KP1.GT.N) GO TO 130
         DO 120 J=KP1,N
  120       SUM=SUM+A(K,J)*X(J)
  130    X(K)=(X(K)-SUM)/A(K,K)
  140 CONTINUE
      RETURN
      END
C
C
C     ****************************************************************
C
C

      FUNCTION EXPINT(X)
C     ==================
C
C     First exponential integral function E1(X)
C
      
      INCLUDE 'PARAMS.FOR'
      IF(X.GT.1.0) GO TO 10
      EXPINT=-LOG(X)-0.57721566+X*(0.99999193+X*(-0.24991055
     1        +X*(0.05519968+X*(-0.00976004+X*0.00107857))))
      RETURN
   10 EXPINT=EXP(-X)*((0.2677734343+X*(8.6347608925+X*
     1       (18.059016973+X*(8.5733287401+X))))/
     2       (3.9584969228+X*(21.0996530827+X*
     3       (25.6329561486+X*(9.5733223454+X)))))/X
      RETURN
      END
C
C
C     ****************************************************************
C
C

      SUBROUTINE INTERP(X,Y,XX,YY,NX,NXX,NPOL,ILOGX,ILOGY)
C     ====================================================
C
C     General interpolation procedure of the (NPOL-1)-th order
C
C     for  ILOGX = 1  logarithmic interpolation in X
C     for  ILOGY = 1  logarithmic interpolation in Y
C
C     Input:
C      X    - array of original x-coordinates
C      Y    - array of corresponding functional values Y=y(X)
C      NX   - number of elements in arrays X or Y
C      XX   - array of new x-coordinates (to which is to be 
C             interpolated
C      NXX  - number of elements in array XX
C     Output:
C      YY   - interpolated functional values YY=y(XX)
C
      INCLUDE 'PARAMS.FOR'
      DIMENSION X(1),Y(1),XX(1),YY(1)
      EXP10(X0)=EXP(X0*2.30258509299405D0)
      IF(NPOL.LE.0.OR.NX.LE.0) GO TO 200
      IF(ILOGX.EQ.0) GO TO 30
      DO 10 I=1,NX
   10    X(I)=LOG10(X(I))
      DO 20 I=1,NXX
   20    XX(I)=LOG10(XX(I))
   30 IF(ILOGY.EQ.0) GO TO 50
      DO 40 I=1,NX
   40    Y(I)=LOG10(Y(I))
   50 NM=(NPOL+1)/2
      NM1=NM+1
      NUP=NX+NM1-NPOL
      DO 100 ID=1,NXX
         XXX=XX(ID)
         DO 60 I=NM1,NUP
            IF(XXX.LE.X(I)) GO TO 70
   60    CONTINUE
         I=NUP
   70    J=I-NM
         JJ=J+NPOL-1
         YYY=0.
         DO 90 K=J,JJ
            T=1.
            DO 80 M=J,JJ
               IF(K.EQ.M) GO TO 80
               T=T*(XXX-X(M))/(X(K)-X(M))
   80       CONTINUE
   90    YYY=Y(K)*T+YYY
         YY(ID)=YYY
  100 CONTINUE
      IF(ILOGX.EQ.0) GO TO 130
      DO 110 I=1,NX
  110    X(I)=EXP10(X(I))
      DO 120 I=1,NXX
  120    XX(I)=EXP10(XX(I))
  130 IF(ILOGY.EQ.0) RETURN
      DO 140 I=1,NX
  140    Y(I)=EXP10(Y(I))
      DO 150 I=1,NXX
  150    YY(I)=EXP10(YY(I))
      RETURN
  200    N=NX
         IF(NXX.GE.NX) N=NXX
      DO 210 I=1,N
         XX(I)=X(I)
  210    YY(I)=Y(I)
      RETURN
      END
C
C ********************************************************************
C ********************************************************************
C
      SUBROUTINE PFSPEC(IAT,IZI,T,ANE,XMAX,U)
C     =======================================
                                                                                
C     Non-standard evaluation of the partition function
C     user supplied procedure
C
C     Input:
C      IAT   - atomic number
C      IZI   - ionic charge (=1 for neutrals, =1 for once ionized, etc)
C      T     - temperature
C      ANE   - electron density
C      XMAX  - principal quantum number of the last bound level
C
C     Output:
C      U     - partition function
C
*
* Modified from the ATMOS related programme 5-April-1990
* as an addition to TLUSTY to allow high ionisation states
* of C, N and O
*
* M.A.Barstow - University of Leicester, Dept of Physics & Astronomy
*
      INCLUDE 'PARAMS.FOR'
      PARAMETER (MH=100,MHEI=100,MHEII=100,MCI=135,
     +     MCII=157,MCIII=156,MCIV=55,MCV=15,MCVI=100,MNI=228,MNII=122,
     +     MNIII=133,MNIV=73,MNV=51,MNVI=8,MNVII=100,MOI=174,MOII=191,
     +     MOIII=168,MOIV=166,MOV=115,MOVI=52,MOVII=16,MOVIII=100)
      DIMENSION GHYD(MH),SHYD(MH),ENHYD(MH),
     +     GHEL(MH),ENHEL(MH),SHEL(MH),
     +     GCI(MCI),ENCI(MCI),SCI(MCI),
     +     GCII(MCII),ENCII(MCII),SCII(MCII),
     +     GCIII(MCIII),ENCIII(MCIII),SCIII(MCIII),
     +     GCIV(MCIV),ENCIV(MCIV),SCIV(MCIV),
     +     GCV(MCV),ENCV(MCV),SCV(MCV),
     +     GNI(MNI),ENNI(MNI),SNI(MNI),
     +     GNII(MNII),ENNII(MNII),SNII(MNII),
     +     GNIII(MNIII),ENNIII(MNIII),SNIII(MNIII),
     +     GNIV(MNIV),ENNIV(MNIV),SNIV(MNIV),
     +     GNV(MNV),ENNV(MNV),SNV(MNV),
     +     GNVI(MNVI),ENNVI(MNVI),SNVI(MNVI),
     +     GOI(MOI),ENOI(MOI),SOI(MOI),
     +     GOII(MOII),ENOII(MOII),SOII(MOII),
     +     GOIII(MOIII),ENOIII(MOIII),SOIII(MOIII),
     +     GOIV(MOIV),ENOIV(MOIV),SOIV(MOIV),
     +     GOV(MOV),ENOV(MOV),SOV(MOV),
     +     GOVI(MOVI),ENOVI(MOVI),SOVI(MOVI),
     +     GOVII(MOVII),ENOVII(MOVII),SOVII(MOVII)
      INTEGER NHYD(MH),NHEL(MHEI),NCI(MCI),NCII(MCII),
     +     NCIII(MCIII),NCIV(MCIV),NCV(MCV),NNI(MNI),NNII(MNII),
     +     NNIII(MNIII),NNIV(MNIV),NNV(MNV),NNVI(MNVI),NOI(MOI),
     +     NOII(MOII),NOIII(MOIII),NOIV(MOIV),NOV(MOV),NOVI(MOVI),
     +     NOVII(MOVII)
      PARAMETER (HI=13.5878,HEI=24.587,HEII=54.416,CVI=489.84,
     +     NVII=666.83,OVIII=871.12)
      PARAMETER (ZH=1.0,ZHE=2.0,ZC=6.0,ZN=7.0,ZO=8.0)
C                           N***=QUANTUM NO. OF LEVEL
C      DATA FOR IONS        G***=STATISTICAL WEIGHT OF LEVEL
C                           EN***=ENERGY OF LEVEL
C                           S*=SCREENING NO. OF LEVEL
	DATA NHYD/ 1, 2, 3, 4, 5, 6,
     +	 	7, 8, 9,10,11,12,
     +		13,14,15,16,17,18,
     +		19,20,21,22,23,24,
     +		25,26,27,28,29,30,
     +		31,32,33,34,35,36,
     +		37,38,39,40,41,42,
     +		43,44,45,46,47,48,
     +		49,50,51,52,53,54,
     +		55,56,57,58,59,60,
     +		61,62,63,64,65,66,
     +		67,68,69,70,71,72,
     +		73,74,75,76,77,78,
     +		79,80,81,82,83,84,
     +		85,86,87,88,89,90,
     +		91,92,93,94,95,96,
     +		97,98,99, 100 /
	DATA GHYD/ 2.000000000000000, 8.000000000000000, 18.00000000000000,
     +		 32.00000000000000, 50.00000000000000, 72.00000000000000,
     +		 98.00000000000000, 128.0000000000000, 162.0000000000000,
     +		 200.0000000000000, 242.0000000000000, 288.0000000000000,
     +		 338.0000000000000, 392.0000000000000, 450.0000000000000,
     +		 512.0000000000000, 578.0000000000000, 648.0000000000000,
     +		 722.0000000000000, 800.0000000000000, 882.0000000000000,
     +		 968.0000000000000, 1058.000000000000, 1152.000000000000,
     +		 1250.000000000000, 1352.000000000000, 1458.000000000000,
     +		 1568.000000000000, 1682.000000000000, 1800.000000000000,
     +		 1922.000000000000, 2048.000000000000, 2178.000000000000,
     +		 2312.000000000000, 2450.000000000000, 2592.000000000000,
     +		 2738.000000000000, 2888.000000000000, 3042.000000000000,
     +		 3200.000000000000, 3362.000000000000, 3528.000000000000,
     +		 3698.000000000000, 3872.000000000000, 4050.000000000000,
     +		 4232.000000000000, 4418.000000000000, 4608.000000000000,
     +		 4802.000000000000, 5000.000000000000, 5202.000000000000,
     +		 5408.000000000000, 5618.000000000000, 5832.000000000000,
     +		 6050.000000000000, 6272.000000000000, 6498.000000000000,
     +		 6728.000000000000, 6962.000000000000, 7200.000000000000,
     +		 7442.000000000000, 7688.000000000000, 7938.000000000000,
     +		 8192.000000000000, 8450.000000000000, 8712.000000000000,
     +		 8978.000000000000, 9248.000000000000, 9522.000000000000,
     +		 9800.000000000000, 10082.00000000000, 10368.00000000000,
     +		 10658.00000000000, 10952.00000000000, 11250.00000000000,
     +		 11552.00000000000, 11858.00000000000, 12168.00000000000,
     +		 12482.00000000000, 12800.00000000000, 13122.00000000000,
     +		 13448.00000000000, 13778.00000000000, 14112.00000000000,
     +		 14450.00000000000, 14792.00000000000, 15138.00000000000,
     +		 15488.00000000000, 15842.00000000000, 16200.00000000000,
     +		 16562.00000000000, 16928.00000000000, 17298.00000000000,
     +		 17672.00000000000, 18050.00000000000, 18432.00000000000,
     +		 18818.00000000000, 19208.00000000000, 19602.00000000000,
     +		 20000.00000000000/
	DATA ENHYD /0.0000000000000000E+00,10.19085000000000,12.07804444444444,
     +		 12.73856250000000, 13.04428800000000, 13.21036111111111,
     +		 13.31049795918367, 13.37549062500000, 13.42004938271605,
     +		 13.45192200000000, 13.47550413223140, 13.49344027777778,
     +		 13.50739881656805, 13.51847448979592, 13.52740977777778,
     +		 13.53472265625000, 13.54078339100346, 13.54586234567901,
     +		 13.55016066481994, 13.55383050000000, 13.55698866213152,
     +		 13.55972603305785, 13.56211417769376, 13.56421006944444,
     +		 13.56605952000000, 13.56769970414201, 13.56916104252401,
     +		 13.57046862244898, 13.57164328180737, 13.57270244444444,
     +		 13.57366077003122, 13.57453066406250, 13.57532268135905,
     +		 13.57604584775087, 13.57670791836735, 13.57731558641975,
     +		 13.57787465303141, 13.57839016620499, 13.57886653517423,
     +		 13.57930762500000, 13.57971683521713, 13.58009716553288,
     +		 13.58045127095727, 13.58078150826446, 13.58108997530864,
     +		 13.58137854442344, 13.58164889090086, 13.58190251736111,
     +		 13.58214077467722, 13.58236488000000, 13.58257593233372,
     +		 13.58277492603550, 13.58296276254895, 13.58314026063100,
     +		 13.58330816528926, 13.58346715561225, 13.58361785164666,
     +		 13.58376082045184, 13.58389658144211, 13.58402561111111,
     +		 13.58414834721849, 13.58426519250780, 13.58437651801461,
     +		 13.58448266601563, 13.58458395266272, 13.58468067033976,
     +		 13.58477308977501, 13.58486146193772, 13.58494601974375,
     +		 13.58502697959184, 13.58510454274945, 13.58517889660494,
     +		 13.58525021580034, 13.58531866325785, 13.58538439111111,
     +		 13.58544754155125, 13.58550824759656, 13.58556663379356,
     +		 13.58562281685627, 13.58567690625000, 13.58572900472489,
     +		 13.58577920880428, 13.58582760923211, 13.58587429138322,
     +		 13.58591933564014, 13.58596281773932, 13.58600480908971,
     +		 13.58604537706612, 13.58608458527964, 13.58612249382716,
     +		 13.58615915952180, 13.58619463610586, 13.58622897444791,
     +		 13.58626222272522, 13.58629442659280, 13.58632562934028,
     +		 13.58635587203741, 13.58638519366930, 13.58641363126212,
     +		 13.58644122000000/
	DATA SHYD/100*0.0D0/
      DATA NHEL/1,2,2,2,2,2,2,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,
     +        5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,
     +        23,24,25,26,27,
     +		28,29,30,31,32,33,
     +		34,35,36,37,38,39,
     +		40,41,42,43,44,45,
     +		46,47,48,49,50,51,
     +		52,53,54,55,56,57,
     +		58,59,60,61,62,63,
     +		64,65,66,67,68,69,
     +		70,71,72,73,74,75,
     +		76,77,78,79,80,81/
      DATA GHEL/1.0D0,3.0D0,1.0D0,5.0D0,3.0D0,1.0D0,3.0D0,
     +          3.0D0,1.0D0,5.0D0,3.0D0,
     +         1.0D0,15.0D0,5.0D0,3.0D0,3.0D0,1.0D0,9.0D0,
     +         15.0D0,5.0D0,21.0D0,7.0D0,
     +         3.0D0,100.0D0,144.0D0,196.0D0,256.0D0,324.0D0,
     +         400.0D0,484.0D0,
     +         576.0D0,676.0D0,784.0D0,900.0D0,1024.0D0,1156.0D0,
     +         1296.0D0,1444.0D0,1600.0D0,1764.0D0,1936.0D0,
     +         2116.0D0,2304.0D0,2500.0D0,2704.0D0,3136.0D0,
     +		3136.000000000000,3364.000000000000,3600.000000000000,
     +		3844.000000000000,4096.000000000000,4356.000000000000,
     +		4624.000000000000,4900.000000000000,5184.000000000000,
     +		5476.000000000000,5776.000000000000,6084.000000000000,
     +		6400.000000000000,6724.000000000000,7056.000000000000,
     +		7396.000000000000,7744.000000000000,8100.000000000000,
     +		8464.000000000000,8836.000000000000,9216.000000000000,
     +		9604.000000000000,10000.00000000000,10404.00000000000,
     +		10816.00000000000,11236.00000000000,11664.00000000000,
     +		12100.00000000000,12544.00000000000,12996.00000000000,
     +		13456.00000000000,13924.00000000000,14400.00000000000,
     +		14884.00000000000,15376.00000000000,15876.00000000000,
     +		16384.00000000000,16900.00000000000,17424.00000000000,
     +		17956.00000000000,18496.00000000000,19044.00000000000,
     +		19600.00000000000,20164.00000000000,20736.00000000000,
     +		21316.00000000000,21904.00000000000,22500.00000000000,
     +		23104.00000000000,23716.00000000000,24336.00000000000,
     +		24964.00000000000,25600.00000000000,26244.00000000000/
      DATA ENHEL/0.0D0,19.819D0,20.615D0,20.964D0,
     +           20.964D0,20.964D0,21.218D0,
     +           22.718D0,22.920D0,23.007D0,23.007D0,
     +           23.007D0,23.073D0,23.074D0,
     +           23.087D0,23.593D0,23.673D0,23.707D0,
     +           23.736D0,23.736D0,23.737D0,
     +           23.737D0,23.742D0,24.028D0,24.201D0,
     +           24.304D0,24.371D0,24.417D0,
     +           24.449D0,24.473D0,24.491D0,24.506D0,
     +           24.517D0,24.526D0,24.534D0,
     +           24.540D0,24.545D0,24.549D0,24.553D0,
     +           24.556D0,24.559D0,24.562D0,
     +           24.564D0,24.566D0,24.568D0,24.570D0,
     +		24.57131951530612,24.57238228299643,24.57334055555556,
     +		24.57420759625390,24.57499462890625,24.57571120293848,
     +		24.57636548442907,24.57696448979592,24.57751427469136,
     +		24.57802008765522,24.57848649584488,24.57891748849441,
     +		24.57931656250000,24.57968679357525,24.58003089569161,
     +		24.58035127095727,24.58065005165289,24.58092913580247,
     +		24.58119021739130,24.58143481213219,24.58166427951389,
     +		24.58187984173261,24.58208260000000,24.58227354863514,
     +		24.58245358727811,24.58262353150587,24.58278412208505,
     +		24.58293603305785,24.58307987882653,24.58321622037550,
     +		24.58334557074911,24.58346839988509,24.58358513888889,
     +		24.58369618382155,24.58380189906348,24.58390262030738,
     +		24.58399865722656,24.58409029585799,24.58417780073462,
     +		24.58426141679661,24.58434137110727,24.58441787439614,
     +		24.58449112244898,24.58456129736163,24.58462856867284,
     +		24.58469309438919,24.58475502191381,24.58481448888889,
     +		24.58487162396122,24.58492654747850,24.58497937212360,
     +		24.58503020349303,24.58507914062500,24.58512627648224/
      DATA SHEL/0.375D0,0.622D0,0.622D0,0.842D0,
     +          0.842D0,0.842D0,0.842D0,0.747D0,
     +          0.747D0,0.912D0,0.912D0,0.912D0,
     +          0.993D0,0.993D0,0.912D0,0.810D0,
     +          0.810D0,0.937D0,0.995D0,0.995D0,
     +          1.000D0,1.000D0,0.937D0,0.949D0,
     +          0.958D0,75*1.000D0/
	DATA NCI/2,2,2,2,2,2,3,3,3,3,2,2,2,3,3,3,3,3,
     +		3,3,3,3,3,2,3,4,4,4,3,3,3,3,3,3,4,3,
     +		3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,
     +		4,4,4,5,4,4,4,4,4,5,5,5,5,5,5,5,5,5,
     +		5,5,5,5,6,5,5,5,5,5,6,6,6,6,6,6,6,7,
     +		6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,8,8,
     +		8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,10,10,
     +		10,11,11,11,2,3,3,3,2,2/
	DATA GCI/1.0D0,3.0D0,5.0D0,5.0D0,1.0D0,    
     +		5.0D0,1.0D0,3.0D0,5.0D0,3.0D0,    
     +		7.0D0,5.0D0,3.0D0,3.0D0,3.0D0,    
     +		5.0D0,7.0D0,3.0D0,1.0D0,3.0D0,    
     +		5.0D0,5.0D0,1.0D0,9.0D0,5.0D0,    
     +		1.0D0,3.0D0,5.0D0,5.0D0,7.0D0,    
     +		9.0D0,3.0D0,5.0D0,7.0D0,3.0D0,    
     +		3.0D0,3.0D0,5.0D0,3.0D0,1.0D0,    
     +		3.0D0,5.0D0,7.0D0,3.0D0,3.0D0,    
     +		1.0D0,3.0D0,5.0D0,5.0D0,1.0D0,    
     +		5.0D0,5.0D0,7.0D0,9.0D0,3.0D0,    
     +		5.0D0,7.0D0,3.0D0,7.0D0,3.0D0,	 
     +		5.0D0,3.0D0,1.0D0,3.0D0,3.0D0,	 
     +		5.0D0,7.0D0,5.0D0,1.0D0,5.0D0,	 
     +		5.0D0,7.0D0,9.0D0,3.0D0,5.0D0,	 
     +		7.0D0,3.0D0,7.0D0,3.0D0,5.0D0,	 
     +		3.0D0,1.0D0,5.0D0,5.0D0,7.0D0,	 
     +		9.0D0,3.0D0,5.0D0,7.0D0,3.0D0,	 
     +		7.0D0,5.0D0,3.0D0,1.0D0,3.0D0,	 
     +		5.0D0,7.0D0,9.0D0,3.0D0,5.0D0,	 
     +		7.0D0,7.0D0,3.0D0,5.0D0,3.0D0,	 
     +		1.0D0,9.0D0,7.0D0,5.0D0,3.0D0,	 
     +		5.0D0,7.0D0,7.0D0,5.0D0,3.0D0,	 
     +		1.0D0,9.0D0,7.0D0,5.0D0,3.0D0,	 
     +		5.0D0,7.0D0,7.0D0,3.0D0,5.0D0,	 
     +		7.0D0,3.0D0,5.0D0,7.0D0,5.0D0,	 
     +		3.0D0,5.0D0,7.0D0,3.0D0,3.0D0/
	DATA ENCI/0.0D0,2.0333605D-03,5.3933649D-03,1.263870,2.684086,
     +		4.182672,7.480511,7.482891,7.487915,7.684888,
     +		7.946046,7.946620,7.946474,8.537387,8.640516,
     +		8.643146,8.647287,8.771255,8.846707,8.848247,
     +		8.850785,9.002712,9.171972,9.330682,9.631248,
     +		9.683908,9.685375,9.689256,9.695577,9.697620,
     +		9.701885,9.708156,9.708925,9.710041,9.712769,
     +		9.714380,9.761111,9.833419,9.834406,9.834934,
     +		9.940317,9.942698,9.946449,9.988707,10.05592,
     +		10.08144,10.08328,10.08553,10.13833,10.19809,
     +		10.35278,10.38514,10.38514,10.38514,10.39370,
     +		10.39456,10.39580,10.40021,10.40845,10.41874,
     +		10.42750,10.42990,10.42990,10.52043,10.52041,
     +		10.52041,10.53705,10.58840,10.61635,10.67973,
     +		10.70230,10.70328,10.70328,10.70878,10.70878,
     +		10.71184,10.71407,10.71854,10.72362,10.72523,
     +		10.72684,10.72684,10.86509,10.87426,10.87513,
     +		10.87513,10.87997,10.87997,10.88257,10.88533,
     +		10.88679,10.88964,10.89075,10.89075,10.88980,
     +		10.97789,10.97854,10.97854,10.98597,10.98597,
     +		10.98597,10.98808,10.98913,10.98994,10.98994,
     +		10.98994,11.04474,11.04474,11.04487,11.05280,
     +		11.05280,11.05280,11.05392,11.05429,11.05429,
     +		11.05429,11.09049,11.09049,11.09049,11.09843,
     +		11.09843,11.09843,11.09880,11.13129,11.13129,
     +		11.13129,11.15477,11.15477,11.15477,12.13544,
     +		12.83767,12.84024,12.84331,13.11772,14.86312/
	DATA NCII/2,2,2,2,2,2,2,2,2,2,3,3,3,2,3,3,2,2,4,4,4,3,3,3,
     +		4,4,2,2,4,4,5,5,5,3,3,5,5,5,5,6,3,3,3,3,3,3,6,6,
     +		6,6,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,
     +		3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,
     +		4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,
     +		4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,
     +		5,5,5,5,5,5,6,6,6,6,6,6,6/
	DATA GCII/2.0D0,4.0D0,2.0D0,4.0D0,6.0D0,
     +		6.0D0,4.0D0,2.0D0,2.0D0,4.0D0,
     +		2.0D0,2.0D0,4.0D0,4.0D0,4.0D0,
     +		6.0D0,6.0D0,4.0D0,2.0D0,2.0D0,
     +		4.0D0,2.0D0,4.0D0,6.0D0,4.0D0,
     +		6.0D0,2.0D0,4.0D0,6.0D0,8.0D0,
     +		2.0D0,2.0D0,4.0D0,2.0D0,4.0D0,
     +		4.0D0,6.0D0,6.0D0,8.0D0,2.0D0,
     +		2.0D0,4.0D0,6.0D0,8.0D0,2.0D0,
     +		4.0D0,4.0D0,6.0D0,6.0D0,8.0D0,
     +		4.0D0,2.0D0,4.0D0,6.0D0,4.0D0,
     +		6.0D0,2.0D0,4.0D0,6.0D0,8.0D0,
     +		10.0D0,2.0D0,4.0D0,6.0D0,8.0D0,
     +		4.0D0,6.0D0,6.0D0,4.0D0,2.0D0,
     +		6.0D0,8.0D0,4.0D0,2.0D0,2.0D0,
     +		4.0D0,6.0D0,2.0D0,4.0D0,2.0D0,
     +		4.0D0,6.0D0,8.0D0,4.0D0,2.0D0,
     +		4.0D0,6.0D0,4.0D0,6.0D0,4.0D0,
     +		6.0D0,8.0D0,10.0D0,2.0D0,4.0D0,
     +		6.0D0,8.0D0,4.0D0,6.0D0,6.0D0,
     +		4.0D0,2.0D0,6.0D0,8.0D0,4.0D0,
     +		6.0D0,8.0D0,10.0D0,6.0D0,8.0D0,
     +		6.0D0,8.0D0,10.0D0,12.0D0,8.0D0,
     +		10.0D0,8.0D0,6.0D0,4.0D0,2.0D0,
     +		6.0D0,4.0D0,4.0D0,2.0D0,2.0D0,
     +		4.0D0,6.0D0,2.0D0,4.0D0,2.0D0,
     +		4.0D0,6.0D0,8.0D0,6.0D0,4.0D0,
     +		2.0D0,6.0D0,8.0D0,4.0D0,6.0D0,
     +		8.0D0,10.0D0,6.0D0,8.0D0,10.0D0,
     +		12.0D0,8.0D0,6.0D0,4.0D0,2.0D0,
     +		2.0D0,4.0D0,6.0D0,8.0D0,6.0D0,
     +		4.0D0,2.0D0/
	DATA ENCII/0.0D0,7.9350658D-03,5.331397,5.334075,5.337658,
     +		9.290338,9.290624,11.96386,13.71590,13.72101,
     +		14.44900,16.33194,16.33332,17.60895,18.04607,
     +		18.04625,18.65519,18.65582,19.49478,20.14995,
     +		20.15068,20.70119,20.70413,20.70971,20.84491,
     +		20.84496,20.92025,20.92256,20.95094,20.95094,
     +		21.49265,21.73314,21.73405,22.09347,22.13075,
     +		22.13075,22.13075,22.18799,22.18799,22.47211,
     +		22.52747,22.52929,22.53239,22.53689,22.56844,
     +		22.57086,22.82136,22.82136,22.85996,22.85996,
     +		22.89870,23.11398,23.11600,23.11878,23.38108,
     +		23.38522,24.12408,24.27024,24.27201,24.27444,
     +		24.27787,24.37010,24.37079,24.37187,24.37315,
     +		24.60198,24.60332,24.65351,24.65617,24.65793,
     +		24.78982,24.79512,25.06741,25.07039,25.98117,
     +		25.98415,25.98986,26.58329,26.58615,26.62689,
     +		26.62867,26.63139,26.63554,26.75178,26.82771,
     +		26.82771,26.83016,26.89454,26.89578,27.22147,
     +		27.22329,27.22585,27.22930,27.29263,27.29263,
     +		27.29378,27.29509,27.35131,27.35294,27.37703,
     +		27.37957,27.38104,27.41188,27.41302,27.41395,
     +		27.41395,27.41395,27.41409,27.46301,27.46301,
     +		27.46810,27.46936,27.47200,27.47561,27.47330,
     +		27.47864,27.48713,27.49096,27.49330,27.49330,
     +		27.48854,27.49412,27.55688,27.56022,27.99752,
     +		27.99752,27.99752,28.25640,28.25640,28.61124,
     +		28.61124,28.61124,28.61124,28.64683,28.64683,
     +		28.64683,28.66803,26.43629,28.66875,28.66875,
     +		28.66875,28.66875,28.70253,28.70253,28.70253,
     +		28.70253,28.70515,28.70515,28.70515,28.70515,
     +		29.31561,29.31561,29.31561,29.31561,29.33557,
     +		29.33557,29.33557/
	DATA NCIII/2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,4,
     +		3,4,4,4,4,3,4,4,4,4,4,4,4,4,3,3,3,4,3,3,3,3,3,3,
     +		3,3,3,3,3,3,5,3,3,3,3,5,5,5,5,3,5,5,5,5,5,5,5,5,
     +		5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,
     +		7,8,8,8,8,9,9,9,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,
     +		4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,
     +		6,6,6,6,6,6,7,7,7,7,7,7/
	DATA GCIII/1.0D0,1.0D0,3.0D0,5.0D0,3.0D0,
     +		1.0D0,3.0D0,5.0D0,5.0D0,1.0D0,
     +		3.0D0,1.0D0,3.0D0,1.0D0,3.0D0,
     +		5.0D0,3.0D0,5.0D0,7.0D0,5.0D0,
     +		1.0D0,3.0D0,5.0D0,3.0D0,3.0D0,
     +		1.0D0,1.0D0,3.0D0,5.0D0,3.0D0,
     +		3.0D0,5.0D0,7.0D0,5.0D0,7.0D0,
     +		9.0D0,3.0D0,7.0D0,3.0D0,5.0D0,
     +		7.0D0,5.0D0,3.0D0,1.0D0,3.0D0,
     +		5.0D0,5.0D0,5.0D0,5.0D0,7.0D0,
     +		9.0D0,3.0D0,5.0D0,7.0D0,3.0D0,
     +		5.0D0,3.0D0,1.0D0,7.0D0,3.0D0,
     +		1.0D0,3.0D0,5.0D0,1.0D0,3.0D0,
     +		5.0D0,7.0D0,7.0D0,9.0D0,11.0D0,
     +		9.0D0,5.0D0,3.0D0,5.0D0,7.0D0,
     +		9.0D0,7.0D0,3.0D0,3.0D0,3.0D0,
     +		5.0D0,7.0D0,7.0D0,9.0D0,11.0D0,
     +		9.0D0,5.0D0,5.0D0,7.0D0,9.0D0,
     +		7.0D0,3.0D0,3.0D0,3.0D0,5.0D0,
     +		7.0D0,5.0D0,3.0D0,3.0D0,5.0D0,
     +		7.0D0,3.0D0,5.0D0,7.0D0,1.0D0,
     +		3.0D0,5.0D0,3.0D0,3.0D0,5.0D0,
     +		7.0D0,1.0D0,3.0D0,5.0D0,5.0D0,
     +		5.0D0,3.0D0,5.0D0,7.0D0,5.0D0,
     +		3.0D0,1.0D0,7.0D0,3.0D0,3.0D0,
     +		5.0D0,7.0D0,1.0D0,3.0D0,5.0D0,
     +		5.0D0,5.0D0,3.0D0,5.0D0,7.0D0,
     +		5.0D0,3.0D0,1.0D0,3.0D0,5.0D0,
     +		7.0D0,1.0D0,3.0D0,5.0D0,3.0D0,
     +		5.0D0,7.0D0,5.0D0,3.0D0,1.0D0,
     +		3.0D0,5.0D0,7.0D0,1.0D0,3.0D0,5.0D0/
	DATA ENCIII/0.0D0,6.486296,6.489148,6.496191,12.69008,
     +		17.03237,17.03602,17.04185,18.08638,22.62984,
     +		29.52845,30.64541,32.10371,32.19328,32.19396,
     +		32.19555,33.47080,33.45866,33.47146,34.27982,
     +		38.20770,38.21183,38.22034,38.36164,38.43612,
     +		38.64882,39.39549,39.39549,39.39611,39.64054,
     +		39.84380,39.84582,39.84874,39.91699,39.91782,
     +		39.91892,39.97328,40.01022,40.05026,40.05341,
     +		40.05822,40.19756,40.57121,40.86969,40.87231,
     +		40.87686,41.24874,41.30157,41.32848,41.33158,
     +		41.33611,41.85783,41.80309,41.86202,42.14028,
     +		42.16117,42.16444,42.16623,42.32471,42.55869,
     +		42.67342,42.67342,42.67342,42.78661,42.83001,
     +		42.83001,42.83001,42.96405,42.96405,42.96416,
     +		42.96405,42.98029,42.98736,43.03527,43.03550,
     +		43.03579,43.25349,43.98952,44.27370,44.39248,
     +		44.39248,44.39248,44.46592,44.46592,44.46600,
     +		44.47219,44.47673,44.48596,44.48596,44.48596,
     +		44.52591,45.07626,45.24178,45.32720,45.32720,
     +		45.32720,45.38200,45.86543,45.92891,45.92891,
     +		45.92891,46.33929,46.33929,46.33929,46.69749,
     +		46.69749,46.69749,47.25143,47.35238,47.35238,
     +		47.35722,47.64920,47.64920,47.65379,47.81342,
     +		47.83558,48.06245,48.06245,48.06245,48.16114,
     +		48.16114,48.16114,48.20208,50.51542,50.55803,
     +		50.55803,50.55803,50.69428,50.69428,50.69428,
     +		50.77264,50.79460,50.90022,50.90022,50.90022,
     +		50.93829,50.93829,50.93829,52.24497,52.24497,
     +		52.24497,52.31775,52.31775,52.31775,52.43107,
     +		52.43107,52.43107,52.45302,52.45302,52.45302,
     +		53.23251,53.23251,53.23251,53.27802,53.27802,
     +		53.27802/
	DATA NCIV/2,2,2,3,3,3,3,3,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,
     +		6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,8,8,
     +		8,8,8,8,8,8,8/
	DATA GCIV/2.0D0,2.0D0,4.0D0,2.0D0,2.0D0,
     +		4.0D0,4.0D0,6.0D0,2.0D0,2.0D0,
     +		4.0D0,4.0D0,6.0D0,6.0D0,8.0D0,
     +		2.0D0,2.0D0,4.0D0,4.0D0,6.0D0,
     +		6.0D0,8.0D0,8.0D0,10.0D0,2.0D0,
     +		2.0D0,4.0D0,4.0D0,6.0D0,6.0D0,
     +		8.0D0,8.0D0,10.0D0,10.0D0,12.0D0,
     +		2.0D0,2.0D0,4.0D0,4.0D0,6.0D0,
     +		6.0D0,8.0D0,8.0D0,10.0D0,10.0D0,
     +		12.0D0,2.0D0,4.0D0,6.0D0,8.0D0,
     +		8.0D0,10.0D0,12.0D0,14.0D0,16.0D0/
	DATA ENCIV/0.0D0,7.995100,8.008378,37.54872,39.68134,
     +		39.68525,40.28040,40.28173,49.76113,50.62434,
     +		50.62599,50.87540,50.87595,50.88784,50.88784,
     +		55.21889,55.65134,55.65221,55.77947,55.77947,
     +		55.78577,55.78578,55.78703,55.78703,58.12002,
     +		58.36774,58.36774,58.44275,58.44275,58.44709,
     +		58.44709,58.44764,58.44764,58.44770,58.44770,
     +		59.84267,60.00038,60.00038,60.04725,60.04725,
     +		60.05156,60.05156,60.05191,60.05191,60.05194,
     +		60.05194,61.05946,61.05946,61.09294,61.09294,
     +		61.09319,61.09319,61.09319,61.09319,61.09319/
	DATA NCV/1,2,2,2,2,2,3,3,3,3,4,5,6,7,8/
	DATA GCV/1.0D0,3.0D0,1.0D0,3.0D0,5.0D0,
     +		3.0D0,3.0D0,5.0D0,7.0D0,3.0D0,
     +		3.0D0,3.0D0,3.0D0,3.0D0,3.0D0/
	DATA ENCV/0.0D0,298.9618,304.4046,304.4030,304.4199,
     +		307.8855,354.2645,354.2645,354.2645,354.5177,
     +		370.9247,378.5349,382.6710,385.1917,386.6807/
	DATA NNI/2,2,2,2,2,3,3,3,3,3,2,2,2,3,3,3,3,3,3,3,3,3,3,3,
     +		3,3,3,3,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,
     +		3,3,4,4,4,4,4,4,4,4,4,5,5,5,5,5,4,4,4,4,4,4,4,4,
     +		4,4,4,4,4,4,4,4,4,3,3,3,3,6,6,6,6,6,5,5,5,5,5,5,
     +		5,5,5,5,5,5,5,5,5,5,5,7,7,7,7,7,6,6,6,6,6,6,6,6,
     +		6,6,6,6,6,6,6,6,6,8,8,8,8,8,7,7,7,7,7,7,7,7,7,7,
     +		7,7,7,9,9,9,9,9,8,8,8,8,8,8,8,8,8,8,8,8,8,10,10,10,
     +		10,10,9,9,9,9,9,9,9,9,9,9,9,9,9,11,11,11,11,11,10,
     +		10,10,10,10,10,10,10,10,10,10,10,10,12,12,12,12,12,
     +		11,11,11,11,11,11,11,11,11,11,11,11,11,13,13,12,12,
     +		12,12,12,12,12/
	DATA GNI/4.0D0,6.0D0,4.0D0,4.0D0,2.0D0,
     +		2.0D0,4.0D0,6.0D0,2.0D0,4.0D0,
     +		6.0D0,4.0D0,2.0D0,2.0D0,2.0D0,
     +		4.0D0,6.0D0,8.0D0,2.0D0,4.0D0,
     +		6.0D0,4.0D0,4.0D0,6.0D0,2.0D0,
     +		4.0D0,6.0D0,4.0D0,2.0D0,4.0D0,
     +		6.0D0,2.0D0,4.0D0,4.0D0,2.0D0,
     +		4.0D0,6.0D0,8.0D0,10.0D0,6.0D0,
     +		8.0D0,2.0D0,4.0D0,6.0D0,2.0D0,
     +		4.0D0,6.0D0,8.0D0,4.0D0,6.0D0,
     +		2.0D0,2.0D0,4.0D0,6.0D0,8.0D0,
     +		2.0D0,4.0D0,6.0D0,4.0D0,2.0D0,
     +		4.0D0,6.0D0,2.0D0,4.0D0,4.0D0,
     +		6.0D0,8.0D0,10.0D0,2.0D0,4.0D0,
     +		6.0D0,8.0D0,4.0D0,2.0D0,6.0D0,
     +		8.0D0,2.0D0,4.0D0,6.0D0,4.0D0,
     +		6.0D0,4.0D0,6.0D0,2.0D0,4.0D0,
     +		2.0D0,4.0D0,6.0D0,2.0D0,4.0D0,
     +		4.0D0,6.0D0,8.0D0,10.0D0,4.0D0,
     +		2.0D0,6.0D0,8.0D0,2.0D0,4.0D0,
     +		6.0D0,8.0D0,2.0D0,4.0D0,6.0D0,
     +		4.0D0,6.0D0,2.0D0,4.0D0,6.0D0,
     +		2.0D0,4.0D0,4.0D0,6.0D0,8.0D0,
     +		10.0D0,2.0D0,4.0D0,6.0D0,8.0D0,
     +		4.0D0,2.0D0,6.0D0,8.0D0,4.0D0,
     +		6.0D0,2.0D0,4.0D0,6.0D0,2.0D0,
     +		4.0D0,6.0D0,2.0D0,4.0D0,2.0D0,
     +		4.0D0,6.0D0,8.0D0,6.0D0,8.0D0,
     +		4.0D0,2.0D0,4.0D0,6.0D0,2.0D0,
     +		4.0D0,6.0D0,2.0D0,4.0D0,2.0D0,
     +		4.0D0,6.0D0,2.0D0,4.0D0,6.0D0,
     +		8.0D0,4.0D0,2.0D0,6.0D0,8.0D0,
     +		4.0D0,6.0D0,2.0D0,4.0D0,6.0D0,
     +		2.0D0,4.0D0,2.0D0,4.0D0,6.0D0,
     +		2.0D0,4.0D0,6.0D0,8.0D0,4.0D0,
     +		2.0D0,6.0D0,8.0D0,4.0D0,6.0D0,
     +		2.0D0,4.0D0,6.0D0,2.0D0,4.0D0,
     +		2.0D0,4.0D0,6.0D0,4.0D0,2.0D0,
     +		6.0D0,8.0D0,2.0D0,4.0D0,6.0D0,
     +		8.0D0,4.0D0,6.0D0,2.0D0,4.0D0,
     +		6.0D0,2.0D0,4.0D0,2.0D0,4.0D0,
     +		6.0D0,4.0D0,2.0D0,6.0D0,8.0D0,
     +		2.0D0,4.0D0,6.0D0,8.0D0,4.0D0,
     +		6.0D0,2.0D0,4.0D0,6.0D0,2.0D0,
     +		4.0D0,4.0D0,2.0D0,2.0D0,4.0D0,
     +		6.0D0,4.0D0,6.0D0/
	DATA ENNI/0.0D0,2.383371,2.384363,3.575739,3.575739,
     +		10.32619,10.33038,10.33617,10.67904,10.69042,
     +		10.92429,10.92973,10.93217,11.60284,11.75037,
     +		11.75317,11.75780,11.76412,11.83769,11.83997,
     +		11.84472,11.99580,12.00032,12.00975,12.12207,
     +		12.12649,12.35701,12.35614,12.84713,12.85333,
     +		12.86185,12.91211,12.92268,12.97078,12.97568,
     +		12.97693,12.97929,12.98350,12.98958,12.99502,
     +		13.00392,13.00161,13.00483,13.00074,13.01686,
     +		13.01822,13.01983,13.02095,13.03344,13.03636,
     +		13.20179,13.23674,13.23917,13.24364,13.25041,
     +		13.26429,13.26623,13.27127,13.32189,13.61527,
     +		13.62076,13.62945,13.64202,13.65185,13.66270,
     +		13.66493,13.66914,13.67609,13.66580,13.67249,
     +		13.67410,13.68043,13.66588,13.66872,13.67695,
     +		13.68464,13.67869,13.68191,13.68836,13.69398,
     +		13.69673,13.70310,13.70607,13.92292,13.92614,
     +		13.95653,13.96207,13.97100,13.97749,13.98841,
     +		13.97948,13.98097,13.98543,13.99324,13.98568,
     +		13.98754,13.98803,13.99674,13.98865,13.98865,
     +		13.98865,13.99696,13.99237,13.99473,13.99944,
     +		14.00155,14.00384,14.13620,14.14326,14.15244,
     +		14.15045,14.15455,14.15417,14.15417,14.15417,
     +		14.15417,14.15690,14.15690,14.15690,14.16508,
     +		14.15827,14.16025,14.15864,14.16843,14.16313,
     +		14.17035,14.16645,14.16645,14.16831,14.23464,
     +		14.24468,14.25113,14.25212,14.25212,14.25683,
     +		14.25683,14.25683,14.25683,14.25882,14.25882,
     +		14.26043,14.26043,14.26545,14.27073,14.27109,
     +		14.27109,14.27109,14.36247,14.36247,14.31821,
     +		14.31821,14.31821,14.32329,14.32329,14.32329,
     +		14.32329,14.32403,14.32403,14.32465,14.32465,
     +		14.33234,14.33544,14.33494,14.33494,14.33494,
     +		14.36272,14.36272,14.36433,14.36433,14.36433,
     +		14.36830,14.36830,14.36830,14.36830,14.36854,
     +		14.36854,14.37016,14.37016,14.37896,14.38119,
     +		14.38107,14.38107,14.38107,14.39557,14.39557,
     +		14.39768,14.39768,14.39768,14.40152,14.40152,
     +		14.40202,14.40202,14.40264,14.40264,14.40264,
     +		14.40264,14.41206,14.41206,14.41442,14.41442,
     +		14.41442,14.42012,14.42012,14.42099,14.42099,
     +		14.42099,14.42583,14.42583,14.42682,14.42682,
     +		14.42781,14.42781,14.42781,14.42781,14.43636,
     +		14.43636,14.43698,14.43698,14.43698,14.46253,
     +		14.44021,14.44455,14.44455,14.45434,14.45434,
     +		14.45434,14.45980,14.45980/
	DATA NNII/2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,2,3,3,3,3,2,3,
     +		3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,3,4,4,4,
     +		4,4,4,4,4,4,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,
     +		4,4,4,4,4,4,4,4,4,4,3,3,3,5,5,5,5,5,5,5,5,5,5,5,
     +		5,5,5,5,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3/
	DATA GNII/1.0D0,3.0D0,5.0D0,5.0D0,1.0D0,
     +		5.0D0,7.0D0,5.0D0,3.0D0,5.0D0,
     +		3.0D0,1.0D0,5.0D0,1.0D0,3.0D0,
     +		5.0D0,3.0D0,3.0D0,3.0D0,3.0D0,
     +		5.0D0,7.0D0,3.0D0,3.0D0,1.0D0,
     +		3.0D0,5.0D0,5.0D0,1.0D0,5.0D0,
     +		7.0D0,9.0D0,5.0D0,3.0D0,5.0D0,
     +		7.0D0,5.0D0,3.0D0,1.0D0,7.0D0,
     +		3.0D0,1.0D0,3.0D0,5.0D0,3.0D0,
     +		3.0D0,3.0D0,5.0D0,7.0D0,1.0D0,
     +		3.0D0,5.0D0,3.0D0,5.0D0,3.0D0,
     +		5.0D0,7.0D0,1.0D0,5.0D0,7.0D0,
     +		9.0D0,5.0D0,3.0D0,5.0D0,7.0D0,
     +		5.0D0,3.0D0,1.0D0,7.0D0,5.0D0,
     +		7.0D0,9.0D0,7.0D0,7.0D0,9.0D0,
     +		11.0D0,3.0D0,9.0D0,7.0D0,5.0D0,
     +		3.0D0,5.0D0,1.0D0,3.0D0,5.0D0,
     +		1.0D0,3.0D0,5.0D0,3.0D0,3.0D0,
     +		5.0D0,7.0D0,5.0D0,7.0D0,9.0D0,
     +		7.0D0,7.0D0,9.0D0,11.0D0,9.0D0,
     +		1.0D0,3.0D0,5.0D0,7.0D0,9.0D0,
     +		3.0D0,5.0D0,7.0D0,5.0D0,3.0D0,
     +		5.0D0,7.0D0,9.0D0,11.0D0,7.0D0,
     +		5.0D0,3.0D0,1.0D0,3.0D0,5.0D0,
     +		7.0D0,9.0D0/
	DATA ENNII/0.0D0,6.0876831D-03,1.6279284D-02,1.898923,4.052723,
     +		5.848106,11.43604,11.43781,11.43801,13.54146,
     +		13.54146,13.54228,17.87734,18.46259,18.46651,
     +		18.48341,18.49722,19.23384,20.40944,20.64636,
     +		20.65389,20.66582,20.67651,20.94027,21.14861,
     +		21.15298,21.16022,21.59986,22.10340,23.12481,
     +		23.13218,23.14229,23.19670,23.23962,23.24260,
     +		23.24636,23.41565,23.42207,23.42555,23.47490,
     +		23.57225,24.36823,24.37465,24.38944,24.53166,
     +		25.06612,25.13369,25.14001,25.15193,25.18946,
     +		25.19245,25.20124,25.23510,25.46049,25.53877,
     +		25.54572,25.55447,25.58160,25.99668,26.00464,
     +		26.01527,26.02787,26.06667,26.06994,26.07548,
     +		26.12440,26.13011,26.13327,26.16475,26.16510,
     +		26.16800,26.16849,26.17391,26.19663,26.19758,
     +		26.20937,26.20252,26.21087,26.21191,26.21252,
     +		26.22134,26.22182,26.25393,26.25770,26.26368,
     +		26.55921,26.56489,26.58065,26.63554,27.36569,
     +		27.36569,27.36569,27.40948,27.40948,27.40999,
     +		27.41783,27.42901,27.42963,27.43824,27.43947,
     +		27.77609,27.77805,27.78169,27.78704,27.79372,
     +		28.01910,28.02209,28.02755,28.54429,30.17253,
     +		30.17448,30.17763,30.18179,30.18682,30.34387,
     +		30.34864,30.35188,30.41607,30.41652,30.41750,
     +		30.41894,30.42068/
	DATA NNIII/2,2,2,2,2,2,2,2,2,2,2,2,2,3,2,2,3,3,3,3,3,3,3,3,
     +		3,4,3,3,3,3,3,3,4,4,3,3,3,3,4,4,4,4,3,3,3,3,3,3,
     +		3,3,3,3,3,5,3,3,3,3,3,3,3,5,5,3,3,5,5,5,5,6,6,6,
     +		6,6,6,4,4,4,3,3,4,4,4,4,4,4,3,3,4,4,4,4,4,4,4,4,
     +		4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,
     +		4,4,4,4,4,4,4,3,3,5,5,5,5/
	DATA GNIII/2.0D0,4.0D0,2.0D0,4.0D0,6.0D0,
     +		6.0D0,4.0D0,2.0D0,2.0D0,4.0D0,
     +		4.0D0,6.0D0,4.0D0,2.0D0,2.0D0,
     +		4.0D0,2.0D0,4.0D0,4.0D0,6.0D0,
     +		2.0D0,4.0D0,6.0D0,2.0D0,4.0D0,
     +		2.0D0,2.0D0,4.0D0,2.0D0,4.0D0,
     +		6.0D0,8.0D0,2.0D0,4.0D0,4.0D0,
     +		2.0D0,4.0D0,6.0D0,4.0D0,6.0D0,
     +		6.0D0,8.0D0,4.0D0,6.0D0,2.0D0,
     +		4.0D0,6.0D0,8.0D0,10.0D0,2.0D0,
     +		4.0D0,6.0D0,8.0D0,2.0D0,4.0D0,
     +		6.0D0,6.0D0,4.0D0,2.0D0,6.0D0,
     +		8.0D0,4.0D0,6.0D0,4.0D0,2.0D0,
     +		6.0D0,8.0D0,8.0D0,10.0D0,4.0D0,
     +		6.0D0,6.0D0,8.0D0,8.0D0,10.0D0,
     +		2.0D0,4.0D0,6.0D0,4.0D0,6.0D0,
     +		2.0D0,4.0D0,2.0D0,4.0D0,6.0D0,
     +		8.0D0,2.0D0,4.0D0,4.0D0,6.0D0,
     +		4.0D0,2.0D0,4.0D0,6.0D0,4.0D0,
     +		6.0D0,8.0D0,10.0D0,4.0D0,6.0D0,
     +		2.0D0,4.0D0,6.0D0,8.0D0,6.0D0,
     +		4.0D0,2.0D0,6.0D0,8.0D0,4.0D0,
     +		6.0D0,8.0D0,10.0D0,6.0D0,8.0D0,
     +		6.0D0,8.0D0,10.0D0,12.0D0,8.0D0,
     +		10.0D0,8.0D0,6.0D0,4.0D0,2.0D0,
     +		6.0D0,4.0D0,4.0D0,6.0D0,2.0D0,
     +		4.0D0,6.0D0,8.0D0/
	DATA ENNIII/0.0D0,2.1635452D-02,7.180255,7.098413,7.108480,
     +		12.52548,12.52643,16.24252,18.08651,18.10019,
     +		23.16076,25.17799,25.18006,27.43827,28.56680,
     +		28.56730,30.45896,30.46342,33.13367,33.13441,
     +		35.65022,35.65797,35.67233,36.84229,36.85629,
     +		38.44641,38.32793,38.33453,38.39367,38.39807,
     +		38.40689,38.41771,38.64517,38.64825,38.95919,
     +		39.34056,39.34595,39.35325,39.39646,39.40031,
     +		39.71098,39.71098,39.79651,39.80747,40.55027,
     +		40.94474,40.94909,40.95552,40.96437,41.26192,
     +		41.26358,41.26631,41.26982,41.37555,41.47835,
     +		41.48166,41.68555,41.69232,41.69667,42.12335,
     +		42.13715,42.39634,42.39655,42.48893,42.49769,
     +		42.49625,42.49625,42.54757,42.54757,43.95493,
     +		43.95493,44.00932,44.00932,44.04135,44.04135,
     +		45.69180,45.69957,45.71402,46.28896,46.29317,
     +		46.46321,46.47039,46.71232,46.71811,46.72555,
     +		46.73671,46.81577,46.81788,46.85206,46.86286,
     +		46.92110,47.02857,47.03412,47.04068,47.61238,
     +		47.61238,47.61845,47.62763,47.75000,47.75000,
     +		47.77108,47.77108,49.01428,47.77802,47.88887,
     +		47.88887,47.88887,47.97657,47.97913,47.98245,
     +		47.98245,47.98363,47.98760,48.07270,48.08297,
     +		48.11119,48.11662,48.12305,48.13089,48.12993,
     +		48.14229,48.14024,48.14488,48.15087,48.15427,
     +		48.15307,48.16119,49.16950,49.17073,50.71214,
     +		50.71214,50.71214,50.71214/
	DATA NNIV/2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,
     +		3,3,3,3,3,3,4,3,3,3,3,3,4,4,4,3,3,3,3,4,4,4,4,3,
     +		3,3,4,4,4,4,3,4,5,5,5,5,5,5,5,6,6,6,4,4,4,4,5,5,4/
	DATA GNIV/1.0D0,1.0D0,3.0D0,7.0D0,3.0D0,
     +		1.0D0,3.0D0,5.0D0,5.0D0,1.0D0,
     +		3.0D0,1.0D0,1.0D0,3.0D0,5.0D0,
     +		3.0D0,5.0D0,7.0D0,5.0D0,1.0D0,
     +		3.0D0,5.0D0,3.0D0,3.0D0,3.0D0,
     +		5.0D0,7.0D0,3.0D0,1.0D0,3.0D0,
     +		5.0D0,5.0D0,5.0D0,5.0D0,7.0D0,
     +		9.0D0,1.0D0,3.0D0,5.0D0,3.0D0,
     +		5.0D0,7.0D0,7.0D0,3.0D0,3.0D0,
     +		5.0D0,7.0D0,5.0D0,3.0D0,1.0D0,
     +		5.0D0,5.0D0,7.0D0,9.0D0,3.0D0,
     +		7.0D0,3.0D0,3.0D0,5.0D0,7.0D0,
     +		7.0D0,9.0D0,11.0D0,3.0D0,5.0D0,
     +		7.0D0,5.0D0,3.0D0,5.0D0,7.0D0,
     +		3.0D0,5.0D0,7.0D0/
	DATA ENNIV/0.0D0,8.323934,8.331770,8.349648,16.20427,
     +		21.75491,21.76399,21.77946,23.41898,29.18244,
     +		46.76804,50.15470,50.32483,50.32679,50.33118,
     +		52.06988,52.07031,52.07132,53.20933,57.68086,
     +		57.69048,57.71067,58.64906,59.62210,60.05779,
     +		60.05779,60.07403,60.44809,61.27855,61.27855,
     +		61.29070,61.78379,61.95650,61.97423,61.97423,
     +		61.97423,62.44215,62.44215,62.44215,62.67301,
     +		62.67685,62.68218,62.77282,62.86333,63.40415,
     +		63.40415,63.40415,63.41109,63.41767,63.41767,
     +		63.80760,64.05482,64.05569,64.05706,64.39976,
     +		64.70402,68.21900,68.53058,68.53058,68.53058,
     +		68.73986,68.73986,68.73986,71.28416,71.28416,
     +		71.28416,73.28070,73.60580,73.60580,73.61063,
     +		78.63129,78.63129,78.63129/
	DATA NNV/2,2,2,3,3,3,3,3,4,4,4,4,4,5,5,5,5,5,6,6,6,6,6,6,
     +		6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8/
	DATA GNV/2.0D0,2.0D0,4.0D0,2.0D0,2.0D0,
     +		4.0D0,4.0D0,6.0D0,2.0D0,2.0D0,
     +		4.0D0,4.0D0,6.0D0,2.0D0,2.0D0,
     +		4.0D0,4.0D0,6.0D0,2.0D0,2.0D0,
     +		4.0D0,4.0D0,6.0D0,6.0D0,8.0D0,
     +		8.0D0,10.0D0,12.0D0,2.0D0,2.0D0,
     +		4.0D0,4.0D0,6.0D0,6.0D0,8.0D0,
     +		8.0D0,10.0D0,12.0D0,14.0D0,2.0D0,
     +		2.0D0,4.0D0,4.0D0,6.0D0,6.0D0,
     +		8.0D0,8.0D0,10.0D0,12.0D0,14.0D0,16.0D0/
	DATA ENNV/0.0D0,9.976473,10.00851,56.55396,59.23740,
     +		59.24660,60.05890,60.06188,75.17694,76.26962,
     +		76.26962,76.61120,76.61120,83.55153,84.09893,
     +		84.09893,84.27598,84.27598,88.02306,88.33514,
     +		88.33514,88.43854,88.43742,88.44214,88.44214,
     +		88.44313,88.44313,88.44313,90.68689,90.88043,
     +		90.88043,90.94527,90.94527,90.94912,90.94912,
     +		90.94974,90.94974,90.94974,90.94974,92.40136,
     +		92.53167,92.53167,92.57358,92.57358,92.57618,
     +		92.57618,92.57668,92.57668,92.57668,92.57668,
     +		92.57668/
	DATA NNVI/1,2,2,2,2,2,3,4/
	DATA GNVI/1.0D0,3.0D0,1.0D0,3.0D0,5.0D0,3.0D0,3.0D0,3.0D0/
	DATA ENNVI/0.0D0,419.8009,426.2953,426.2965,426.3325,
     +		425.7398,497.9737,521.5830/
	DATA NOI/2,2,2,2,2,3,3,3,3,3,3,3,3,4,4,3,3,3,3,3,3,3,3,3,
     +		4,4,4,4,4,4,3,3,3,5,5,3,4,4,4,4,4,4,4,4,5,5,5,6,
     +		6,5,5,5,5,5,5,5,5,6,6,6,7,7,6,6,6,6,6,6,6,6,8,8,
     +		7,7,7,7,7,7,7,7,9,9,8,8,8,8,8,8,8,8,10,10,9,9,9,9,
     +		9,9,9,9,11,11,10,10,10,10,10,10,10,10,3,3,3,3,3,3,
     +		3,3,3,3,3,3,4,3,3,3,3,3,3,3,3,3,3,3,4,4,4,2,2,2,3,
     +		3,3,3,3,5,4,4,4,4,4,4,4,4,4,4,4,3,6,5,5,5,5,5,5,5,
     +		5,5,5,7,6,6,6,2/
	DATA GOI/5.0D0,3.0D0,1.0D0,5.0D0,1.0D0,
     +		5.0D0,3.0D0,3.0D0,5.0D0,7.0D0,
     +		5.0D0,3.0D0,1.0D0,5.0D0,3.0D0,
     +		9.0D0,7.0D0,5.0D0,5.0D0,3.0D0,
     +		1.0D0,7.0D0,5.0D0,3.0D0,3.0D0,
     +		5.0D0,7.0D0,5.0D0,3.0D0,1.0D0,
     +		7.0D0,5.0D0,3.0D0,5.0D0,3.0D0,
     +		5.0D0,9.0D0,7.0D0,5.0D0,3.0D0,
     +		1.0D0,7.0D0,5.0D0,3.0D0,5.0D0,
     +		3.0D0,1.0D0,5.0D0,3.0D0,9.0D0,
     +		7.0D0,5.0D0,3.0D0,1.0D0,7.0D0,
     +		5.0D0,3.0D0,5.0D0,3.0D0,1.0D0,
     +		5.0D0,3.0D0,9.0D0,7.0D0,5.0D0,
     +		3.0D0,1.0D0,7.0D0,5.0D0,3.0D0,
     +		5.0D0,3.0D0,9.0D0,7.0D0,5.0D0,
     +		3.0D0,1.0D0,7.0D0,5.0D0,3.0D0,
     +		5.0D0,3.0D0,9.0D0,7.0D0,5.0D0,
     +		3.0D0,1.0D0,7.0D0,5.0D0,3.0D0,
     +		5.0D0,3.0D0,9.0D0,7.0D0,5.0D0,
     +		3.0D0,1.0D0,7.0D0,5.0D0,3.0D0,
     +		5.0D0,3.0D0,9.0D0,7.0D0,5.0D0,
     +		3.0D0,1.0D0,7.0D0,5.0D0,3.0D0,
     +		7.0D0,5.0D0,3.0D0,9.0D0,7.0D0,
     +		5.0D0,5.0D0,3.0D0,1.0D0,7.0D0,
     +		3.0D0,5.0D0,5.0D0,5.0D0,3.0D0,
     +		1.0D0,9.0D0,7.0D0,5.0D0,9.0D0,
     +		11.0D0,9.0D0,7.0D0,7.0D0,7.0D0,
     +		5.0D0,3.0D0,5.0D0,3.0D0,1.0D0,
     +		7.0D0,5.0D0,3.0D0,3.0D0,5.0D0,
     +		5.0D0,9.0D0,7.0D0,5.0D0,9.0D0,
     +		11.0D0,9.0D0,7.0D0,7.0D0,5.0D0,
     +		3.0D0,1.0D0,1.0D0,5.0D0,9.0D0,
     +		7.0D0,5.0D0,9.0D0,11.0D0,9.0D0,
     +		7.0D0,5.0D0,3.0D0,1.0D0,5.0D0,
     +		5.0D0,3.0D0,1.0D0,3.0D0/
	DATA ENOI/0.0D0,01.9651687D-02,2.8082693D-02,1.967363,0.4206081,
     +		9.146132,9.521420,10.74028,10.74053,10.74098,
     +		10.98893,10.98886,10.98895,11.83768,11.93056,
     +		12.07869,12.07870,12.07870,12.07872,12.07872,
     +		12.07872,12.08711,12.08711,12.08711,12.28604,
     +		12.28612,12.28627,12.35891,12.35891,12.35891,
     +		12.53927,12.54078,12.54176,12.66092,12.69755,
     +		12.72854,12.75377,12.75377,12.75377,12.75377,
     +		12.75377,12.75911,12.75911,12.75911,12.87829,
     +		12.87829,12.87829,13.02082,13.03891,13.06624,
     +		13.06624,13.06624,13.06624,13.06624,13.06913,
     +		13.06913,13.06913,13.13145,13.13145,13.13145,
     +		13.21004,13.22030,13.23559,13.23559,13.23559,
     +		13.23559,13.23559,13.23740,13.23740,13.23740,
     +		13.32166,13.32807,13.33749,13.33749,13.33749,
     +		13.33749,13.33749,13.33869,13.33869,13.33869,
     +		13.39308,13.39756,13.40353,385.3597,13.40353,
     +		13.40353,13.40353,13.40488,13.40488,13.40488,
     +		13.44262,13.44449,13.44872,13.44872,13.44872,
     +		13.44872,13.44872,13.44966,13.44966,13.44966,
     +		13.47577,13.47812,13.48112,13.48112,13.48112,
     +		13.48112,13.48112,13.48148,13.48148,13.48148,
     +		14.04685,14.04687,14.04730,14.09888,14.09975,
     +		14.10046,14.12320,14.12450,14.12526,14.13382,
     +		14.37218,14.46048,15.22525,15.28698,15.29424,
     +		15.29817,15.40062,15.40062,15.40062,15.40372,
     +		15.40390,15.40622,15.40550,15.41465,15.59420,
     +		15.59514,15.59577,15.65520,15.66431,15.66970,
     +		15.78109,15.78181,15.78222,15.82895,15.94391,
     +		16.01073,16.07676,16.07676,16.07676,16.07836,
     +		16.07844,16.08080,16.08005,16.08545,16.11433,
     +		16.11550,16.11614,16.23505,16.35702,16.35702,
     +		16.35702,16.35702,16.39057,16.39063,16.39308,
     +		16.39308,16.40451,16.40451,16.40451,16.54127,
     +		16.56668,16.56668,16.56668,23.53702/
	DATA NOII/2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,2,3,3,3,3,3,3,3,3,
     +		3,3,3,3,3,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,
     +		3,3,3,3,3,3,3,3,3,4,4,4,4,4,3,4,4,4,4,4,4,4,4,3,
     +		3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,3,4,4,4,4,4,4,
     +		4,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,
     +		5,5,5,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,
     +		5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,3,3,3,4,4,4,4,
     +		4,4,4,4,4,4,3,3,4,4,4,4,4,4,4,5,5,3,3,3,3,3,4/
	DATA GOII/4.0D0,6.0D0,4.0D0,4.0D0,2.0D0,
     +		6.0D0,4.0D0,2.0D0,6.0D0,4.0D0,
     +		2.0D0,4.0D0,6.0D0,2.0D0,4.0D0,
     +		2.0D0,2.0D0,2.0D0,4.0D0,6.0D0,
     +		8.0D0,6.0D0,4.0D0,2.0D0,4.0D0,
     +		6.0D0,4.0D0,6.0D0,4.0D0,4.0D0,
     +		2.0D0,2.0D0,4.0D0,2.0D0,6.0D0,
     +		8.0D0,6.0D0,4.0D0,4.0D0,6.0D0,
     +		8.0D0,10.0D0,6.0D0,4.0D0,2.0D0,
     +		2.0D0,4.0D0,2.0D0,4.0D0,6.0D0,
     +		8.0D0,6.0D0,8.0D0,4.0D0,2.0D0,
     +		4.0D0,6.0D0,2.0D0,4.0D0,6.0D0,
     +		2.0D0,4.0D0,6.0D0,2.0D0,4.0D0,
     +		6.0D0,8.0D0,4.0D0,6.0D0,2.0D0,
     +		4.0D0,2.0D0,4.0D0,8.0D0,6.0D0,
     +		10.0D0,8.0D0,4.0D0,6.0D0,2.0D0,
     +		4.0D0,4.0D0,6.0D0,8.0D0,10.0D0,
     +		2.0D0,4.0D0,6.0D0,8.0D0,4.0D0,
     +		6.0D0,4.0D0,2.0D0,4.0D0,2.0D0,
     +		6.0D0,8.0D0,2.0D0,6.0D0,4.0D0,
     +		8.0D0,5.80D0,4.0D0,2.0D0,6.0D0,
     +		8.0D0,10.0D0,12.0D0,8.0D0,10.0D0,
     +		4.0D0,6.0D0,4.0D0,6.0D0,8.0D0,
     +		10.0D0,6.0D0,8.0D0,2.0D0,4.0D0,
     +		6.0D0,2.0D0,4.0D0,6.0D0,4.0D0,
     +		2.0D0,4.0D0,6.0D0,8.0D0,2.0D0,
     +		4.0D0,6.0D0,4.0D0,6.0D0,2.0D0,
     +		4.0D0,6.0D0,8.0D0,6.0D0,4.0D0,
     +		2.0D0,6.0D0,8.0D0,8.0D0,6.0D0,
     +		4.0D0,2.0D0,6.0D0,8.0D0,10.0D0,
     +		12.0D0,8.0D0,10.0D0,4.0D0,6.0D0,
     +		4.0D0,6.0D0,8.0D0,10.0D0,6.0D0,
     +		8.0D0,4.0D0,6.0D0,8.0D0,6.0D0,
     +		8.0D0,4.0D0,6.0D0,2.0D0,4.0D0,
     +		8.0D0,10.0D0,6.0D0,8.0D0,6.0D0,
     +		4.0D0,2.0D0,4.0D0,6.0D0,10.0D0,
     +		12.0D0,2.0D0,4.0D0,4.0D0,6.20D0,
     +		10.0D0,8.0D0,6.0D0,4.0D0,2.0D0,
     +		6.0D0/
	DATA ENOII/0.0D0,3.323850,3.326454,5.017305,5.017491,
     +		14.85813,14.87838,14.88860,20.58005,20.57736,
     +		22.96648,22.97954,23.001876,23.41940,23.44172,
     +		24.26523,25.28586,25.63160,25.63849,25.64984,
     +		25.66529,25.66142,25.66154,25.83188,25.83760,
     +		25.84900,26.22564,26.24928,26.30498,26.35845,
     +		26.37943,26.55392,26.56133,28.12621,28.35835,
     +		28.36128,28.51330,28.51270,28.67733,28.68403,
     +		28.69369,28.70637,28.82200,28.83108,28.83932,
     +		28.82414,28.82992,28.85285,28.85711,28.85729,
     +		28.85808,28.86334,28.88355,28.94193,28.95606,
     +		29.06249,29.06893,29.58618,29.59923,29.61924,
     +		29.79726,29.82051,30.42546,30.47162,30.47763,
     +		30.48836,30.50400,30.74951,30.77135,30.80112,
     +		30.81214,31.02747,31.02747,31.14773,31.14812,
     +		31.31967,31.31982,31.37404,31.37430,31.46620,
     +		31.46649,31.55199,31.55199,31.55199,31.56553,
     +		31.61407,31.61407,31.61407,31.61407,31.61407,
     +		31.62925,31.63375,31.63644,31.63766,31.65117,
     +		31.65364,31.67396,31.69345,31.70178,31.71699,
     +		31.70200,31.71709,31.72948,31.72935,31.70999,
     +		31.71043,31.71889,31.73747,31.71911,31.73823,
     +		31.72081,31.72752,31.75062,31.75112,31.75553,
     +		31.75715,31.75586,31.75803,31.95026,31.96318,
     +		31.98375,32.03889,32.06284,32.14771,32.14780,
     +		32.35511,32.35511,32.36540,32.38251,32.39264,
     +		32.39264,32.40412,32.44667,32.46798,32.88345,
     +		32.88345,32.88345,32.88345,32.90963,32.91418,
     +		32.91418,32.92780,32.92780,32.93536,32.94354,
     +		32.95061,32.96264,32.93858,32.94181,32.95049,
     +		32.97082,32.95073,32.97146,32.96227,32.96227,
     +		32.97119,32.97528,32.97826,32.97999,32.97863,
     +		32.97999,33.19875,33.19968,33.20123,34.06365,
     +		34.06901,34.08607,34.08607,34.17174,34.17174,
     +		34.20029,34.20029,34.20504,34.20504,34.21390,
     +		34.21390,34.21960,34.22819,34.22819,34.23350,
     +		34.23350,34.25269,34.25269,34.48530,34.48530,
     +		36.19083,36.18759,36.19109,36.19123,36.19131,37.05294/
	DATA NOIII/2,2,2,2,2,2,2,3,3,2,2,2,2,2,2,3,3,3,3,2,2,2,3,3,
     +		3,3,3,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,
     +		2,3,3,3,4,4,4,4,3,3,3,3,3,3,4,4,4,4,4,3,3,3,4,4,
     +		4,4,4,3,3,3,3,4,4,4,4,3,3,3,4,4,4,4,4,4,4,4,5,5,
     +		5,5,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,
     +		5,5,5,5,5,5,5,5,5,3,3,3,6,6,6,6,7,3,3,4,4,4,3,4,
     +		4,4,4,4,4,4,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,5/
	DATA GOIII/1.0D0,3.0D0,5.0D0,5.0D0,1.0D0,
     +		5.0D0,7.0D0,5.0D0,3.0D0,5.0D0,
     +		3.0D0,1.0D0,5.0D0,3.0D0,3.0D0,
     +		1.0D0,3.0D0,5.0D0,3.0D0,5.0D0,
     +		3.0D0,1.0D0,3.0D0,3.0D0,5.0D0,
     +		7.0D0,3.0D0,5.0D0,1.0D0,3.0D0,
     +		5.0D0,5.0D0,1.0D0,5.0D0,7.0D0,
     +		9.0D0,5.0D0,3.0D0,5.0D0,7.0D0,
     +		5.0D0,3.0D0,1.0D0,7.0D0,3.0D0,
     +		3.0D0,5.0D0,7.0D0,1.0D0,1.0D0,
     +		3.0D0,5.0D0,1.0D0,3.0D0,5.0D0,
     +		3.0D0,3.0D0,1.0D0,3.0D0,5.0D0,
     +		7.0D0,9.0D0,3.0D0,3.0D0,5.0D0,
     +		7.0D0,3.0D0,3.0D0,5.0D0,7.0D0,
     +		1.0D0,3.0D0,5.0D0,5.0D0,1.0D0,
     +		3.0D0,5.0D0,7.0D0,5.0D0,5.0D0,
     +		7.0D0,9.0D0,5.0D0,5.0D0,3.0D0,
     +		1.0D0,3.0D0,5.0D0,7.0D0,5.0D0,
     +		3.0D0,1.0D0,7.0D0,3.0D0,1.0D0,
     +		3.0D0,5.0D0,3.0D0,3.0D0,5.0D0,
     +		7.0D0,3.0D0,5.0D0,7.0D0,9.0D0,
     +		11.0D0,1.0D0,3.0D0,5.0D0,7.0D0,
     +		9.0D0,7.0D0,5.0D0,3.0D0,5.0D0,
     +		3.0D0,1.0D0,5.0D0,7.0D0,9.0D0,
     +		5.0D0,7.0D0,9.0D0,5.0D0,3.0D0,
     +		5.0D0,7.0D0,7.0D0,3.0D0,3.0D0,
     +		5.0D0,7.0D0,5.0D0,3.0D0,5.0D0,
     +		7.0D0,7.0D0,7.0D0,5.0D0,3.0D0,
     +		5.0D0,7.0D0,3.0D0,3.0D0,1.0D0,
     +		3.0D0,5.0D0,7.0D0,9.0D0,3.0D0,
     +		5.0D0,7.0D0,3.0D0,5.0D0,7.0D0,
     +		7.0D0,5.0D0,3.0D0,5.0D0,7.0D0,
     +		9.0D0,3.0D0,5.0D0,7.0D0,1.0D0,
     +		3.0D0,5.0D0,3.0D0/
	DATA ENOIII/0.0D0,1.4059945D-02,3.8038719D-02,2.513308,5.354124,
     +		7.477820,14.88140,14.88477,14.88550,17.65325,
     +		17.65339,17.65514,23.19140,24.43587,26.09378,
     +		33.13600,33.15068,33.18253,33.85794,35.18196,
     +		35.20895,35.22094,36.07438,36.43500,36.45190,
     +		36.47919,36.89279,36.98353,37.22392,37.23410,
     +		37.25028,38.01204,38.90675,40.22861,40.25288,
     +		40.27497,40.26230,40.57149,40.57759,40.58673,
     +		40.84922,40.86335,40.87098,41.14086,41.25951,
     +		41.97723,41.99266,42.14902,42.56451,43.39812,
     +		43.41013,43.43237,44.22956,44.24270,44.27655,
     +		44.46952,45.03978,45.31862,45.32294,45.33144,
     +		45.34384,45.35962,45.34443,45.43903,45.45230,
     +		45.47797,45.62070,45.69189,45.69899,45.71153,
     +		45.91510,45.92614,45.93959,45.98626,46.25228,
     +		46.44183,45.21283,46.46955,46.62690,46.78899,
     +		46.78899,46.78899,46.82767,46.91713,46.91867,
     +		46.92080,47.01923,47.02679,47.03461,47.20199,
     +		47.20199,47.20199,47.21141,47.24910,48.62968,
     +		48.62968,48.62968,48.69874,48.86141,48.86587,
     +		48.87442,48.91428,48.91908,48.92621,48.93560,
     +		48.94701,49.36293,49.36248,49.36198,49.36323,
     +		49.37332,49.40500,49.41368,49.41845,49.63815,
     +		49.65178,49.65844,49.76514,49.77709,49.79367,
     +		49.78386,49.78386,49.78386,49.81572,49.78386,
     +		49.78386,49.78386,50.01249,50.03133,50.31391,
     +		50.31750,50.32357,51.41365,51.47638,51.47638,
     +		51.47638,52.44297,52.69355,52.85969,53.12613,
     +		53.14089,53.16110,53.31682,54.18348,54.33549,
     +		54.33549,54.34320,54.35460,54.36977,54.46407,
     +		54.47044,54.48261,54.88958,54.88958,54.88958,
     +		55.81414,55.82281,55.82951,56.14741,56.14741,
     +		56.14741,56.31095,56.31095,56.31095,56.73994,
     +		56.73994,56.73994,58.73808/
	DATA NOIV/2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,
     +		3,3,3,3,3,3,3,3,3,3,3,4,3,3,3,3,3,3,3,3,3,3,3,3,
     +		3,3,4,4,3,3,3,3,3,3,5,3,3,3,3,5,5,5,5,3,4,4,4,3,
     +		3,4,4,6,6,4,4,3,3,3,3,3,3,3,4,4,7,7,4,4,4,4,4,4,
     +		4,4,4,4,4,4,4,4,4,4,3,8,8,4,4,3,3,3,3,3,3,3,3,3,
     +		3,3,3,3,3,5,5,3,3,5,5,3,3,5,5,5,5,5,5,5,5,5,5,5,
     +		3,3,3,3,3,3,3,3,3,6,6,6,6,4,4,3,4,4,7,7,7,7/
	DATA GOIV/2.0D0,4.0D0,2.0D0,4.0D0,6.0D0,
     +		6.0D0,4.0D0,2.0D0,2.0D0,6.0D0,
     +		4.0D0,6.0D0,4.0D0,2.0D0,4.0D0,
     +		2.0D0,2.0D0,4.0D0,2.0D0,4.0D0,
     +		6.0D0,2.0D0,4.0D0,2.0D0,4.0D0,
     +		2.0D0,4.0D0,6.0D0,8.0D0,4.0D0,
     +		2.0D0,4.0D0,6.0D0,4.0D0,6.0D0,
     +		2.0D0,2.0D0,4.0D0,6.0D0,8.0D0,
     +		10.0D0,2.0D0,4.0D0,6.0D0,8.0D0,
     +		4.0D0,6.0D0,6.0D0,4.0D0,2.0D0,
     +		4.0D0,6.0D0,6.0D0,8.0D0,4.0D0,
     +		2.0D0,2.0D0,4.0D0,2.0D0,4.0D0,
     +		6.0D0,2.0D0,4.0D0,4.0D0,6.0D0,
     +		6.0D0,8.0D0,2.0D0,2.0D0,4.0D0,
     +		6.0D0,6.0D0,8.0D0,2.0D0,4.0D0,
     +		4.0D0,6.0D0,2.0D0,4.0D0,4.0D0,
     +		6.0D0,2.0D0,4.0D0,6.0D0,2.0D0,
     +		4.0D0,4.0D0,6.0D0,6.0D0,8.0D0,
     +		2.0D0,2.0D0,4.0D0,6.0D0,8.0D0,
     +		6.0D0,4.0D0,2.0D0,4.0D0,6.0D0,
     +		6.0D0,8.0D0,4.0D0,6.0D0,6.0D0,
     +		8.0D0,2.0D0,6.0D0,8.0D0,4.0D0,
     +		2.0D0,4.0D0,6.0D0,2.0D0,4.0D0,
     +		6.0D0,8.0D0,2.0D0,4.0D0,6.0D0,
     +		6.0D0,4.0D0,4.0D0,6.0D0,8.0D0,
     +		2.0D0,4.0D0,6.0D0,8.0D0,4.0D0,
     +		6.0D0,6.0D0,4.0D0,2.0D0,4.0D0,
     +		6.0D0,8.0D0,6.0D0,4.0D0,2.0D0,
     +		6.0D0,8.0D0,4.0D0,2.0D0,6.0D0,
     +		4.0D0,2.0D0,4.0D0,6.0D0,6.0D0,
     +		8.0D0,4.0D0,2.0D0,2.0D0,4.0D0,
     +		6.0D0,8.0D0,4.0D0,6.0D0,2.0D0,
     +		4.0D0,6.0D0,2.0D0,4.0D0,6.0D0,8.0D0/
	DATA ENOIV/0.0D0,4.7920357D-02,8.824909,8.841201,8.864076,
     +		15.73825,15.73998,20.37910,22.37705,22.40721,
     +		28.67474,31.63571,31.63934,35.83378,35.83476,
     +		44.33902,48.37428,48.38508,54.37857,54.39532,
     +		54.42593,56.14158,56.17444,57.92984,57.94415,
     +		58.03452,58.04428,58.06108,58.08709,58.79609,
     +		59.33789,59.34961,59.36561,59.84372,59.87542,
     +		60.23497,61.10992,61.36131,61.37108,61.38501,
     +		61.40412,61.93150,61.93509,61.94088,61.94888,
     +		62.18008,62.18691,62.46812,62.48219,62.49133,
     +		63.30199,63.30286,63.32506,63.35387,63.75540,
     +		63.77412,64.30924,64.30999,66.87376,67.85857,
     +		67.86167,68.16618,68.17400,68.44416,68.44416,
     +		68.50069,68.50069,68.74507,70.50282,70.51955,
     +		70.55017,70.76975,70.76975,71.12993,71.15609,
     +		71.21387,71.21387,71.31690,71.33785,71.39315,
     +		71.39737,71.48887,71.50672,71.53300,72.12492,
     +		72.12764,72.47591,72.50269,72.88482,72.88482,
     +		73.16019,73.37047,73.37047,73.37047,73.37047,
     +		73.52322,73.52322,73.52322,73.60108,73.61112,
     +		73.64819,73.65725,73.68911,73.71453,73.93237,
     +		73.95444,74.05078,74.06293,74.06293,74.10930,
     +		74.12628,74.40265,74.40438,74.76035,74.76035,
     +		74.76035,74.76035,75.18896,75.18896,75.18896,
     +		76.30446,76.30806,76.44791,77.47625,77.47625,
     +		77.92433,77.92433,78.12258,78.12258,78.19797,
     +		78.21979,78.41159,78.43242,78.59385,78.59385,
     +		78.59385,78.59385,78.63718,78.63718,78.63718,
     +		78.85769,78.88398,78.91572,78.91572,78.96023,
     +		78.97250,78.98019,80.20107,80.20107,80.72665,
     +		80.72900,81.00314,81.01343,81.37509,81.37509,
     +		81.37509,81.37509,81.42716,81.42716,81.83012,
     +		82.88895,82.88895,83.03365,83.03365,83.03365,83.03365/
	DATA NOV/2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,
     +		3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,
     +		4,4,4,4,4,4,5,5,5,5,5,5,4,4,4,4,4,4,4,4,4,4,4,6,
     +		6,6,6,6,4,4,4,6,4,4,4,4,4,7,7,7,7,7,8,8,8,8,5,5,
     +		5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6/
	DATA GOV/1.0D0,1.0D0,3.0D0,5.0D0,3.0D0,
     +		1.0D0,3.0D0,5.0D0,5.0D0,1.0D0,
     +		3.0D0,1.0D0,3.0D0,1.0D0,3.0D0,
     +		5.0D0,3.0D0,5.0D0,7.0D0,5.0D0,
     +		1.0D0,3.0D0,5.0D0,3.0D0,3.0D0,
     +		3.0D0,5.0D0,7.0D0,3.0D0,1.0D0,
     +		3.0D0,5.0D0,5.0D0,5.0D0,3.0D0,
     +		5.0D0,7.0D0,1.0D0,5.0D0,3.0D0,
     +		1.0D0,7.0D0,3.0D0,3.0D0,1.0D0,
     +		1.0D0,3.0D0,5.0D0,3.0D0,3.0D0,
     +		5.0D0,7.0D0,5.0D0,7.0D0,3.0D0,
     +		3.0D0,3.0D0,5.0D0,7.0D0,5.0D0,
     +		3.0D0,3.0D0,3.0D0,5.0D0,7.0D0,
     +		3.0D0,1.0D0,3.0D0,5.0D0,5.0D0,
     +		5.0D0,3.0D0,7.0D0,3.0D0,5.0D0,
     +		7.0D0,3.0D0,5.0D0,7.0D0,5.0D0,
     +		5.0D0,3.0D0,1.0D0,7.0D0,3.0D0,
     +		3.0D0,3.0D0,5.0D0,7.0D0,5.0D0,
     +		3.0D0,3.0D0,5.0D0,7.0D0,3.0D0,
     +		3.0D0,5.0D0,7.0D0,1.0D0,3.0D0,
     +		5.0D0,5.0D0,5.0D0,3.0D0,5.0D0,
     +		7.0D0,7.0D0,3.0D0,3.0D0,5.0D0,
     +		7.0D0,1.0D0,3.0D0,5.0D0,5.0D0/
	DATA ENOV/0.0D0,10.18183,10.19878,10.23674,19.68863,
     +		26.48845,26.50776,26.54108,28.73015,35.69651,
     +		67.83862,69.59028,72.01395,72.28146,72.28596,
     +		72.29554,74.50599,74.50733,74.50979,75.95557,
     +		80.97483,80.99497,81.03748,82.38657,83.40436,
     +		83.97941,84.00407,84.04314,84.82139,85.49855,
     +		85.51269,85.53633,86.12596,86.43890,87.33036,
     +		87.33829,87.35107,87.73579,87.80076,87.81837,
     +		87.82866,88.39750,89.17985,89.60004,90.71603,
     +		91.26665,91.26665,91.26888,91.48672,92.04689,
     +		92.04763,92.04937,92.59937,92.97132,98.72523,
     +		99.49233,106.7049,106.7049,106.7049,100.2237,
     +		102.1987,102.8568,103.0377,103.0583,103.0944,
     +		103.1870,103.5465,103.5465,103.5676,103.8792,
     +		103.8829,104.1001,104.2509,104.2990,104.2990,
     +		104.2990,104.3064,104.3181,104.3333,104.4087,
     +		104.5556,104.5689,104.5754,105.0316,105.0733,
     +		106.7358,106.9963,106.9963,106.9963,106.9274,
     +		108.4187,108.5325,108.5325,108.5325,111.4108,
     +		111.5461,111.5461,111.5461,111.7535,111.7535,
     +		111.7535,111.8898,111.9082,112.1444,112.1444,
     +		112.1444,112.3809,115.9379,116.0435,116.0435,
     +		116.0435,116.1501,116.1501,116.1501,116.2166/
	DATA NOVI/2,2,2,3,3,3,3,3,4,4,4,4,4,4,4,5,5,5,5,5,6,6,6,6,
     +		6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8/
	DATA GOVI/2.0D0,2.0D0,4.0D0,2.0D0,2.0D0,
     +		4.0D0,4.0D0,6.0D0,2.0D0,2.0D0,
     +		4.0D0,4.0D0,6.0D0,6.0D0,8.0D0,
     +		2.0D0,2.0D0,4.0D0,4.0D0,6.0D0,
     +		2.0D0,4.0D0,4.0D0,6.0D0,6.0D0,
     +		8.0D0,8.0D0,10.0D0,12.0D0,2.0D0,
     +		2.0D0,4.0D0,4.0D0,6.0D0,6.0D0,
     +		8.0D0,8.0D0,10.0D0,12.0D0,14.0D0,
     +		2.0D0,2.0D0,4.0D0,6.0D0,8.0D0,
     +		8.0D0,10.0D0,12.0D0,14.0D0,16.0D0,4.0D0,6.0D0/
	DATA ENOVI/0.0D0,11.94909,12.01505,79.35559,82.58831,
     +		82.60773,83.64374,83.65008,105.7219,107.0408,
     +		107.0487,107.4805,107.4831,107.5050,107.5062,
     +		117.6237,118.2920,118.2920,118.5122,118.5122,
     +		124.3735,124.3735,124.5034,124.5034,124.5142,
     +		124.5142,124.5156,124.5156,124.5156,127.8017,
     +		128.0311,128.0311,128.1171,128.1171,128.1243,
     +		128.1243,128.1252,128.1252,128.1252,128.1252,
     +		130.2520,130.3984,130.3984,130.4674,130.4674,
     +		130.4680,130.4680,130.4680,130.4680,130.4680,
     +		130.4693,130.4693/
	DATA NOVII/1,2,2,2,2,2,3,3,3,3,3,3,3,4,5,6/
	DATA GOVII/1.0D0,3.0D0,1.0D0,3.0D0,5.0D0,
     +		3.0D0,1.0D0,3.0D0,5.0D0,7.0D0,
     +		5.0D0,3.0D0,3.0D0,3.0D0,3.0D0,3.0D0/
	DATA ENOVII/0.0D0,561.0761,568.6182,568.6255,568.6938,
     +		573.9532,664.1129,664.1129,664.1129,665.1804,
     +		665.1804,665.1804,665.6218,697.8022,712.7239,720.8449/
	DATA SCI/4.179704,4.179868,4.180140,4.284864,4.411317, 
     +		4.556712,4.417538,4.418036,4.419087,4.460873,
     +		5.012059,5.012145,5.012123,4.656621,4.682271,
     +		4.682931,4.683973,4.715525,4.735114,4.735517, 
     +		4.736181,4.776610,4.823287,5.245868,4.960446, 
     +		4.636463,4.637096,4.638772,4.981131,4.981795, 
     +		4.983181,4.985224,4.985476,4.985839,4.648973, 
     +		4.987257,5.002644,5.026932,5.027268,5.027448, 
     +		4.751991,4.753114,4.754886,4.775015,4.807735, 
     +		4.820394,4.821310,4.822433,4.849118,4.880081, 
     +		4.964531,4.983084,4.983084,4.983084,4.988046, 
     +		4.988550,4.989272,4.739796,4.996660,5.002712, 
     +		5.007890,5.009317,5.009317,4.830776,4.830763, 
     +		4.830763,4.843919,4.885500,4.908801,4.963564, 
     +		4.983777,4.984663,4.984663,4.989659,4.989659, 
     +		4.992449,4.793379,4.998577,5.003253,5.004741, 
     +		5.006231,5.006231,4.972326,4.984214,4.985345, 
     +		4.985345,4.991673,4.991673,4.995098,4.831870, 
     +		5.000666,5.004451,5.005935,5.005935,5.004665, 
     +		4.984616,4.985763,4.985763,4.999064,4.999064, 
     +		4.999064,5.002865,5.004758,5.006233,5.006233, 
     +		5.006233,4.984145,4.984145,4.984432,5.002990, 
     +		5.002990,5.002990,5.005628,5.006508,5.006508, 
     +		5.006508,4.983365,4.983365,4.983365,5.006886, 
     +		5.006886,5.006886,5.008002,5.012074,5.012074, 
     +		5.012074,5.014099,5.014099,5.014099,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000/ 
	DATA SCII/3.322208,3.322644,3.633090,3.633257,3.633480,
     +		3.893420,3.893440,4.089184,4.229172,4.229597, 
     +		3.436720,3.692591,3.692789,4.589103,3.953149, 
     +		3.953178,4.702748,4.702820,3.603431,3.770060, 
     +		3.770254,4.440431,4.441056,4.442240,3.961645, 
     +		3.961659,4.991754,4.992091,3.992479,3.992479, 
     +		3.697579,3.795690,3.796068,4.770876,4.780956, 
     +		3.968260,3.968260,3.994325,3.994325,3.754887, 
     +		4.893884,4.894430,4.895358,4.896706,4.906213, 
     +		4.906944,3.971236,3.971236,3.996578,3.996578, 
     +		5.011171,5.086056,5.086787,5.087796,5.188515, 
     +		5.190205,5.591661,5.735427,5.737656,5.740739, 
     +		5.745144,5.937513,5.941305,5.947732,5.956571, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000,
     +		6.000000,6.000000,6.000000,6.000000,6.000000,
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000,6.000000,6.000000,6.000000, 
     +		6.000000,6.000000/
	DATA SCIII/2.247678,2.511178,2.511298,2.511595,2.783334,
     +		2.988424,2.988601,2.988887,3.040348,3.275480,
     +		2.516355,2.624130,2.770250,2.779440,2.779510,
     +		2.779673,2.913505,2.912204,2.913576,3.001503,
     +		3.471912,3.472452,3.473566,2.656192,3.501991,
     +		2.707107,2.843331,2.843331,2.843447,3.667003,
     +		2.928022,2.928408,2.928967,2.942070,2.942230,
     +		2.942442,2.952919,2.960061,3.725865,3.726323,
     +		3.727023,2.996535,3.802981,3.848412,3.848814,
     +		3.849514,3.907525,3.915897,3.920174,3.920667,
     +		3.921389,4.006182,3.997117,4.006877,2.756046,
     +		4.057183,4.057739,4.058045,4.085242,2.876864,
     +		2.910818,2.910818,2.910818,4.166811,2.957773,
     +		2.957773,2.957773,2.998549,2.998549,2.998583,
     +		2.998549,3.003525,3.005696,3.020441,3.020510,
     +		3.020601,3.088544,2.797248,2.916939,2.968366,
     +		2.968366,2.968366,3.000603,3.000603,3.000640,
     +		3.003372,3.005378,3.009464,3.009464,3.009464,
     +		3.027199,2.830505,2.926040,2.976524,2.976524,
     +		2.976524,3.009360,2.932986,2.982088,2.982088,
     +		2.982088,2.986294,2.986294,2.986294,4.828427,
     +		4.828427,4.828427,5.151012,5.224114,5.224114,
     +		5.227788,5.497263,5.497263,5.502663,5.756044,
     +		5.817122,6.000000,6.000000,6.000000,6.000000,
     +		6.000000,6.000000,6.000000,6.000000,6.000000,
     +		6.000000,6.000000,6.000000,6.000000,6.000000,
     +		6.000000,6.000000,6.000000,6.000000,6.000000,
     +		6.000000,6.000000,6.000000,6.000000,6.000000,
     +		6.000000,6.000000,6.000000,6.000000,6.000000,
     +		6.000000,6.000000,6.000000,6.000000,6.000000,
     +		6.000000,6.000000,6.000000,6.000000,6.000000,
     +		6.000000/
	DATA SCIV/1.644934,1.923884,1.924364,1.778341,1.948965,
     +		1.949284,1.998202,1.998312,1.838941,1.962835,
     +		1.963075,1.999589,1.999669,2.001418,2.001418,
     +		1.874532,1.972046,1.972243,2.001394,2.001394,
     +		2.002842,2.002845,2.003133,2.003133,1.897882,
     +		1.978616,1.978616,2.003384,2.003384,2.004821,
     +		2.004821,2.005002,2.005002,2.005023,2.005023,
     +		1.913888,1.984033,1.984033,2.005113,2.005113,
     +		2.007061,2.007061,2.007217,2.007217,2.007234,
     +		2.007234,1.989961,1.989961,2.009654,2.009654,
     +		2.009800,2.009800,2.009800,2.009800,2.009800/
	DATASCV/0.6309066,0.7688928,0.9242349,0.9241881,0.9246764,
     +		1.026124,1.003322,1.003322,1.003322,1.020118,
     +		1.021842,1.027042,1.033988,1.051912,1.003001/
	DATA SNI/4.931870,5.108953,5.109031,5.204087,5.204087,
     +		5.329969,5.330800,5.331948,5.401419,5.403777,
     +		5.968683,5.969459,5.969806,5.605717,5.641185,
     +		5.641868,5.642995,5.644538,5.662621,5.663186,
     +		5.664362,5.702335,5.703489,5.705897,5.734946,
     +		5.736104,5.797976,5.797737,5.588642,5.591228,
     +		5.594790,5.615995,5.620492,5.980873,5.982464,
     +		5.982872,5.983638,5.985012,5.986994,5.988774,
     +		5.991692,5.990931,5.991989,5.990646,5.995945,
     +		5.996395,5.996926,5.997295,6.001428,6.002394,
     +		5.745163,5.761658,5.762813,5.764937,5.768167,
     +		5.774817,5.775745,5.778173,5.802792,5.696104,
     +		5.699982,5.706142,5.715098,5.722151,5.983984,
     +		5.985277,5.987724,5.991767,5.985780,5.989671,
     +		5.990610,5.994303,5.985830,5.987479,5.992273,
     +		5.996771,5.993288,5.995173,5.998955,6.002261,
     +		6.003886,6.255743,6.257061,6.360914,6.362586,
     +		5.757127,5.763044,5.772635,5.779661,5.791555,
     +		5.984846,5.986194,5.990250,5.997386,5.990476,
     +		5.992170,5.992623,6.000597,5.993189,5.993189,
     +		5.993189,6.000802,5.996590,5.998751,6.003087,
     +		6.005032,6.007153,5.793718,5.804320,5.818227,
     +		5.815205,5.821445,5.989322,5.989322,5.989322,
     +		5.989322,5.992901,5.992901,5.992901,6.003714,
     +		5.994695,5.997311,5.995185,6.008173,6.001116,
     +		6.010741,6.005529,6.005529,6.008008,5.801159,
     +		5.821038,5.833978,5.835981,5.835981,5.989852,
     +		5.989852,5.989852,5.989852,5.993398,5.993398,
     +		5.996287,5.996287,6.005342,6.014956,6.015613,
     +		6.015613,6.015613,5.971639,5.971639,5.850568,
     +		5.850568,5.850568,5.990061,5.990061,5.990061,
     +		5.990061,5.991796,5.991796,5.993244,5.993244,
     +		6.011374,6.018783,6.017594,6.017594,6.017594,
     +		5.858175,5.858175,5.863377,5.863377,5.863377,
     +		5.988659,5.988659,5.988659,5.988659,5.989390,
     +		5.989390,5.994151,5.994151,6.020563,6.027375,
     +		6.026996,6.026996,6.026996,5.866343,5.866343,
     +		5.874646,5.874646,5.874646,5.990859,5.990859,
     +		5.992667,5.992667,5.994933,5.994933,5.994933,
     +		5.994933,6.030020,6.030020,6.038991,6.038991,
     +		6.038991,5.873279,5.873279,5.877365,5.877365,
     +		5.877365,5.992039,5.992039,5.996431,5.996431,
     +		6.000838,6.000838,6.000838,6.000838,6.039686,
     +		6.039686,6.042562,6.042562,6.042562,6.018730,
     +		5.886326,5.994597,5.994597,6.047575,6.047575,
     +		6.047575,6.078406,6.078406/
	DATA SNII/4.048939,4.049242,4.049750,4.145151,4.258360,
     +		4.356432,4.688145,4.688257,4.688270,4.826217,
     +		4.826217,4.826272,5.142618,4.284333,4.284811,
     +		4.286872,4.288557,5.253337,4.532960,4.564950,
     +		4.565974,4.567596,5.379367,4.605227,4.634192,
     +		4.634804,4.635817,4.698180,4.771750,4.928997,
     +		4.930175,4.931792,4.940517,4.947424,4.947905,
     +		4.948512,4.976005,4.977055,4.977624,4.985716,
     +		5.001774,4.517682,4.519204,4.522714,5.167543,
     +		4.688999,4.706267,4.707887,4.710950,4.720615,
     +		4.721386,4.723658,4.732426,4.791679,5.359476,
     +		5.360877,5.362645,4.824183,4.939473,4.941747,
     +		4.944790,4.948400,4.959554,4.960499,4.962098,
     +		4.976268,4.977930,4.978850,4.988034,4.988136,
     +		4.988983,4.989127,4.990716,4.997378,4.997656,
     +		5.001124,4.999108,5.001566,5.001872,5.002052,
     +		5.004650,5.004791,5.510713,5.511550,5.512880,
     +		4.633615,4.635821,4.641956,4.663452,4.970949,
     +		4.970949,4.970949,4.990886,4.990886,4.991119,
     +		4.994713,4.999842,5.000126,5.004091,5.004655,
     +		5.899771,5.900361,5.901458,5.903069,5.905087,
     +		5.975470,5.976437,5.978201,6.162114,7.000000,
     +		7.000000,7.000000,7.000000,7.000000,7.000000,
     +		7.000000,7.000000,7.000000,7.000000,7.000000,
     +		7.000000,7.000000/
	DATA SNIII/3.264886,3.265738,3.559230,3.555733,3.556163,
     +		3.795859,3.795903,3.971288,4.062202,4.062887,
     +		4.328298,4.441761,4.441879,3.362787,4.644640,
     +		4.644671,3.648880,3.649321,3.924340,3.924418,
     +		4.208216,4.209135,4.210838,4.353292,4.355043,
     +		3.749472,4.546074,4.546964,4.554955,4.555551,
     +		4.556746,4.558211,3.785649,3.786211,4.632736,
     +		4.686664,4.687436,4.688480,3.926233,3.926969,
     +		3.987034,3.987034,4.752837,4.754452,4.866728,
     +		4.928826,4.929522,4.930549,4.931964,4.980142,
     +		4.980413,4.980860,4.981436,3.664742,5.015918,
     +		5.016470,5.050785,5.051935,5.052674,5.126587,
     +		5.129026,3.959079,3.959144,5.192320,5.193925,
     +		3.989434,3.989434,4.005147,4.005147,3.968565,
     +		3.968565,3.992409,3.992409,4.006539,4.006539,
     +		5.571515,5.574721,5.580696,6.132490,6.134099,
     +		5.935632,5.939608,6.083616,6.087341,6.092149,
     +		6.099411,6.364476,6.365573,6.178216,6.185985,
     +		6.229222,6.316157,6.320952,6.326658,7.000000,
     +		7.000000,7.000000,7.000000,7.000000,7.000000,
     +		7.000000,7.000000,7.000000,7.000000,7.000000,
     +		7.000000,7.000000,7.000000,7.000000,7.000000,
     +		7.000000,7.000000,7.000000,7.000000,7.000000,
     +		7.000000,7.000000,7.000000,7.000000,7.000000,
     +		7.000000,7.000000,7.000000,7.000000,7.000000,
     +		7.000000,7.000000,7.000000,7.000000,7.000000,
     +		7.000000,7.000000,7.000000/
	DATA SNIV/2.226836,2.490623,2.490878,2.491461,2.755431,
     +		2.952339,2.952669,2.953231,3.013266,3.231892,
     +		2.493613,2.749589,2.762857,2.763010,2.763353,
     +		2.901417,2.901452,2.901533,2.994477,3.382731,
     +		3.383611,3.385459,3.472422,3.564919,3.607152,
     +		3.607152,3.608737,3.645438,3.728391,3.728391,
     +		2.639493,3.779903,3.797702,3.799535,3.799535,
     +		3.799535,2.797721,2.797721,2.797721,3.872625,
     +		3.873032,3.873596,3.883205,2.857107,2.934635,
     +		2.934635,2.934635,3.951730,3.952443,3.952443,
     +		2.993446,3.029914,3.030044,3.030246,4.061023,
     +		3.127314,2.880353,2.950477,2.950477,2.950477,
     +		2.998267,2.998267,2.998267,2.959708,2.959708,
     +		2.959708,4.785085,4.873190,4.873190,4.874527,
     +		7.000000,7.000000,7.000000/
	DATA SNV/1.634565,1.915400,1.916327,1.771111,1.943796,
     +		1.944398,1.997854,1.998051,1.833396,1.959357,
     +		1.959357,1.999384,1.999384,1.870467,1.969524,
     +		1.969524,2.001982,2.001982,1.895972,1.977561,
     +		1.977561,2.004889,2.004593,2.005843,2.005843,
     +		2.006106,2.006106,2.006106,1.914798,1.983841,
     +		1.983841,2.007186,2.007186,2.008574,2.008574,
     +		2.008797,2.008797,2.008797,2.008797,1.929893,
     +		1.990742,1.990742,2.010469,2.010469,2.011696,
     +		2.011696,2.011930,2.011930,2.011930,2.011930,
     +		2.011930/
	DATA SNVI/0.6290283,0.7657156,0.9208641,0.9208946,0.9217644,
     +		0.9074407,1.024314,1.024867/
	DATA SOI/5.998809,6.000254,6.000874,6.149045,6.029965,
     +		6.280362,6.354168,6.620857,6.620917,6.621027,
     +		6.681873,6.681856,6.681878,6.554275,6.592577,
     +		6.991942,6.991948,6.991948,6.991953,6.991953,
     +		6.991953,6.994710,6.994710,6.994710,6.749977,
     +		6.750016,6.750087,6.784759,6.784759,6.784759,
     +		7.156593,7.157186,7.157570,6.676266,6.701954,
     +		7.234456,6.993919,6.993919,6.993919,6.993919,
     +		6.993919,6.997045,6.997045,6.997045,6.836974,
     +		6.836974,6.836974,6.746833,6.766088,6.996467,
     +		6.996467,6.996467,6.996467,6.996467,6.999115,
     +		6.999115,6.999115,6.869720,6.869720,6.869720,
     +		6.793480,6.808908,6.999084,6.999084,6.999084,
     +		6.999084,6.999084,7.001479,7.001479,7.001479,
     +		6.826997,6.839929,7.001803,7.001803,7.001803,
     +		7.001803,7.001803,7.003955,7.003955,7.003955,
     +		6.852827,6.864539,7.004705,8.000000,7.004705,
     +		7.004705,7.004705,7.007905,7.007905,7.007905,
     +		6.877349,6.883498,7.007761,7.007761,7.007761,
     +		7.007761,7.007761,7.010591,7.010591,7.010591,
     +		6.890946,6.900387,7.011453,7.011453,7.011453,
     +		7.011453,7.011453,7.012788,7.012788,7.012788,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000/
	DATA SOII/4.784610,4.940430,4.940555,5.022952,5.022962,
     +		5.557054,5.558274,5.558889,5.930025,5.929834,
     +		5.160761,5.162283,5.164577,5.214052,5.216705,
     +		6.210938,5.445367,5.490556,5.491464,5.492962,
     +		5.495002,5.494491,5.494507,5.517109,5.517870,
     +		5.519391,5.570158,5.573380,5.580988,6.392210,
     +		6.394130,5.615287,5.616316,5.844496,5.880436,
     +		5.880893,5.904250,5.904674,5.930839,5.931911,
     +		5.933457,5.935489,5.954107,5.955576,5.956912,
     +		5.954453,5.955388,5.959104,5.959794,5.959825,
     +		5.959952,5.960805,5.964087,5.973599,5.975908,
     +		5.993385,5.994448,5.442262,5.445265,5.449878,
     +		5.491284,5.496742,6.232405,5.654758,5.656267,
     +		5.658962,5.662895,5.725537,5.731195,5.738926,
     +		5.741796,6.348958,6.348958,6.373241,6.373322,
     +		6.408604,6.408635,6.419951,6.420006,6.439373,
     +		6.439435,5.943564,5.943564,5.943564,5.947441,
     +		5.961402,5.961402,5.961402,5.961402,6.471051,
     +		5.965786,5.967088,5.967867,5.968222,5.972136,
     +		5.972852,5.978758,6.488330,5.986873,5.991322,
     +		5.986938,5.991353,5.994984,5.994948,5.989273,
     +		5.989404,5.991879,5.997332,5.991945,5.997554,
     +		5.992443,5.994410,6.001196,6.001346,6.002642,
     +		6.003121,6.002740,6.003380,5.576062,5.580966,
     +		5.588796,5.609913,5.619139,6.121709,6.121740,
     +		5.734796,5.734796,5.738977,5.745944,5.750079,
     +		5.750079,5.754774,5.772264,5.781077,5.960446,
     +		5.960446,5.960446,5.960446,5.972282,5.974347,
     +		5.974347,5.980535,5.980535,5.983981,5.987715,
     +		5.990945,5.996456,5.985451,5.986923,5.990890,
     +		6.000214,5.991003,6.000511,5.996286,5.996286,
     +		6.000386,6.002267,6.003636,6.004436,6.003808,
     +		6.004436,6.864734,6.865004,6.865458,6.871479,
     +		6.874276,6.883227,6.883227,6.929313,6.929313,
     +		6.945119,6.945119,6.947771,6.947771,7.214550,
     +		7.214550,6.955942,6.960794,6.960794,6.963802,
     +		6.963802,6.974759,6.974759,6.897856,6.897856,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000/
	DATA SOIII/3.980091,3.980605,3.981483,4.073126,4.181011,
     +		4.263698,4.567496,2.851461,2.851508,4.688399,
     +		4.688406,4.688483,4.944256,5.004756,5.087306,
     +		4.201648,4.202927,4.205704,4.265077,5.589531,
     +		5.591178,5.591910,4.466920,4.500863,4.502461,
     +		4.505044,4.544430,5.702087,4.576288,4.577272,
     +		4.578837,4.653335,4.743010,4.880211,4.882788,
     +		4.885133,4.883788,4.916797,4.917453,4.918434,
     +		4.946753,4.948285,4.949112,4.978528,4.991553,
     +		5.071567,5.073311,5.091046,6.092469,5.236801,
     +		5.238239,5.240906,4.450987,4.453166,4.458786,
     +		4.490992,5.440957,5.477274,5.477840,5.478956,
     +		5.480584,5.482658,4.640882,4.657492,4.659830,
     +		4.664354,4.689624,5.526725,5.527675,5.529354,
     +		4.742366,4.744359,4.746791,4.755242,4.803841,
     +		5.629193,5.463434,5.633066,5.655169,4.904211,
     +		4.904211,4.904211,4.911571,5.696494,5.696715,
     +		5.697021,4.948280,4.949739,4.951245,4.983719,
     +		4.983719,4.983719,4.985557,4.992922,4.595488,
     +		4.595488,4.595488,4.614187,5.995187,5.995924,
     +		5.997336,6.003933,6.004729,6.005913,6.007472,
     +		6.009368,6.079757,6.079680,6.079593,6.079808,
     +		6.081549,6.087021,6.088523,6.089349,6.127790,
     +		6.130199,6.131379,6.150372,6.152512,6.155484,
     +		4.922875,4.922875,4.922875,4.932409,4.922875,
     +		4.922875,4.922875,4.991952,4.997716,6.251313,
     +		6.251994,6.253141,4.947119,4.974443,4.974443,
     +		4.974443,5.003925,6.782259,6.828280,6.541492,
     +		6.547457,6.555665,6.965416,7.060263,7.160808,
     +		7.160808,7.166230,7.174317,7.185196,7.256399,
     +		7.261456,7.271212,7.771374,7.771374,7.771374,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000/
	DATA SOIV/3.228562,3.230039,3.508826,3.509360,3.510109,
     +		3.741247,3.741307,3.904661,3.977057,3.978160,
     +		4.214302,4.331145,4.331291,4.503491,4.503533,
     +		3.322590,3.617383,3.618198,4.097019,4.098440,
     +		4.101037,4.249484,4.252384,4.410741,4.412061,
     +		4.420406,4.421309,4.422863,4.425270,4.491520,
     +		4.543003,4.544125,4.545658,4.591770,4.594849,
     +		3.506632,4.717019,4.742457,4.743450,4.744866,
     +		4.746809,4.800908,4.801279,4.801878,4.802707,
     +		4.826727,4.827440,4.856910,4.858391,4.859354,
     +		3.927959,3.928085,4.948471,4.951597,4.995503,
     +		4.997566,5.057139,5.057223,3.602068,5.487784,
     +		5.488193,5.528638,5.529685,3.943577,3.943577,
     +		3.956409,3.956409,5.607411,5.152442,5.155901,
     +		5.162243,5.906104,5.906104,5.285100,5.290775,
     +		3.955026,3.955026,5.325924,5.330538,6.007065,
     +		6.007765,6.023023,6.026014,6.030425,6.132527,
     +		6.133009,5.594399,5.600957,3.969004,3.969004,
     +		5.768017,5.824149,5.824149,5.824149,5.824149,
     +		5.865850,5.865850,5.865850,5.887424,5.890223,
     +		5.900586,5.903125,5.912084,5.919259,5.981793,
     +		5.988238,6.512458,4.040435,4.040435,6.034046,
     +		6.039135,6.592915,6.593322,6.679720,6.679720,
     +		6.679720,6.679720,6.791924,6.791924,6.791924,
     +		7.150804,7.152208,7.208681,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000,
     +		8.000000/
	DATA SOV/2.212299,2.477108,2.477559,2.478570,2.736373,
     +		2.929941,2.930501,2.931468,2.995396,3.204502,
     +		2.480139,2.586177,2.736415,2.753261,2.753545,
     +		2.754149,2.895501,2.895588,2.895747,2.990361,
     +		3.333698,3.335127,3.338143,3.434917,3.509306,
     +		3.551885,3.553720,3.556629,3.614975,3.666382,
     +		3.667461,3.669268,3.714561,3.738797,3.808601,
     +		3.809227,3.810236,3.840735,3.845908,3.847311,
     +		3.848131,3.893723,3.957266,2.655746,2.780047,
     +		2.842480,2.842480,2.842734,2.867645,2.932266,
     +		2.932352,2.932553,2.996815,3.040747,2.722722,
     +		2.858081,4.369750,4.369750,4.369750,2.990545,
     +		4.293693,4.399677,4.429359,4.432752,4.438707,
     +		4.454041,4.514207,4.514207,4.517767,4.570812,
     +		4.571450,2.913395,2.952782,2.965416,2.965416,
     +		2.965416,4.644915,4.646958,4.649636,2.994349,
     +		4.688903,4.691261,4.692408,4.774586,4.782194,
     +		2.928606,3.022013,3.022013,3.022013,2.997125,
     +		2.933282,2.986425,2.986425,2.986425,5.872365,
     +		5.931636,5.931636,5.931636,6.025977,6.025977,
     +		6.025977,6.090481,6.099398,6.217293,6.217293,
     +		6.217293,6.343698,8.000000,8.000000,8.000000,
     +		8.000000,8.000000,8.000000,8.000000,8.000000/
	DATA SOVI/1.626749,1.908750,1.910343,1.765577,1.939605,
     +		1.940666,1.997515,1.997865,1.829541,1.956604,
     +		1.957376,1.999562,1.999822,2.001964,2.002083,
     +		1.867336,1.968342,1.968342,2.001995,2.001995,
     +		1.976059,1.976059,2.004681,2.004681,2.007063,
     +		2.007063,2.007365,2.007365,2.007365,1.914098,
     +		1.982390,1.982390,2.008208,2.008208,2.010369,
     +		2.010369,2.010631,2.010631,2.010631,2.010631,
     +		1.930105,1.987143,1.987143,2.014184,2.014184,
     +		2.014431,2.014431,2.014431,2.014431,2.014431,
     +		2.014965,2.014965/
	DATA SOVII/0.6273875,0.7631111,0.9180546,0.9182081,0.9196253,
     +		1.029738,0.9543552,0.9543552,0.9543552,1.004676,
     +		1.004676,1.004676,1.025589,1.027917,1.034432,
     +		1.045346/
*
*	Find index for atom and ion, 10*IAT+IZI
*
c       IF(IAT.EQ.26.AND.IZI.GE.6.AND.IZI.LE.9) GO TO 260
	IF(IAT.GT.2.AND.IAT.LT.6)GO TO 9999
	IF(IAT.LT.1.OR.IAT.GT.8)GO TO 9999
	IND=10*IAT+IZI
	IF(IND.EQ.11) GO TO 11
	IF(IND.EQ.21) GO TO 21
	IF(IND.EQ.22) GO TO 22
	IF(IND.EQ.61) GO TO 61
	IF(IND.EQ.61) GO TO 62
	IF(IND.EQ.63) GO TO 63
	IF(IND.EQ.64) GO TO 64
	IF(IND.EQ.65) GO TO 65
	IF(IND.EQ.66) GO TO 66
	IF(IND.EQ.71) GO TO 71
	IF(IND.EQ.72) GO TO 72
	IF(IND.EQ.73) GO TO 73
	IF(IND.EQ.74) GO TO 74
	IF(IND.EQ.75) GO TO 75
	IF(IND.EQ.76) GO TO 76
	IF(IND.EQ.77) GO TO 77
	IF(IND.EQ.81) GO TO 81
	IF(IND.EQ.82) GO TO 82
	IF(IND.EQ.83) GO TO 83
	IF(IND.EQ.84) GO TO 84
	IF(IND.EQ.85) GO TO 85
	IF(IND.EQ.86) GO TO 86
	IF(IND.EQ.87) GO TO 87
	IF(IND.EQ.88) GO TO 88
* 
*	CALCULATING PARTITION FUNCTIONS FOR HYDROGEN
* 
 11	CALL PARTDV(T,ANE,ZH,MH,NHYD,GHYD,ENHYD,SHYD,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR HEI
* 
 21	CALL PARTDV(T,ANE,ZHE,MHEI,NHEL,GHEL,ENHEL,SHEL,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR HEII
* 
 22	CALL PARTDV(T,ANE,ZHE,MHEII,NHYD,GHYD,ENHYD,SHYD,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR CI
* 
 61	CALL PARTDV(T,ANE,ZC,MCI,NCI,GCI,ENCI,SCI,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR CII
* 
 62	CALL PARTDV(T,ANE,ZC,MCII,NCII,GCII,ENCII,SCII,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR CIII
* 
 63	CALL PARTDV(T,ANE,ZC,MCIII,NCIII,GCIII,ENCIII,SCIII,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR CIV
* 
 64	CALL PARTDV(T,ANE,ZC,MCIV,NCIV,GCIV,ENCIV,SCIV,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR CV
* 
 65	CALL PARTDV(T,ANE,ZC,MCV,NCV,GCV,ENCV,SCV,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR CVI
* 
 66	CALL PARTDV(T,ANE,ZC,MH,NHYD,GHYD,ENHYD,SHYD,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR NI
* 
 71	CALL PARTDV(T,ANE,ZN,MNI,NNI,GNI,ENNI,SNI,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR NII
* 
 72	CALL PARTDV(T,ANE,ZN,MNII,NNII,GNII,ENNII,SNII,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR NIII
* 
 73	CALL PARTDV(T,ANE,ZN,MNIII,NNIII,GNIII,ENNIII,SNIII,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR NIV
* 
 74	CALL PARTDV(T,ANE,ZN,MNIV,NNIV,GNIV,ENNIV,SNIV,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR NV
* 
 75	CALL PARTDV(T,ANE,ZN,MNV,NNV,GNV,ENNV,SNV,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR NVI
* 
 76	CALL PARTDV(T,ANE,ZN,MNVI,NNVI,GNVI,ENNVI,SNVI,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR NVII
* 
 77	CALL PARTDV(T,ANE,ZN,MH,NHYD,GHYD,ENHYD,SHYD,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR OI
* 
 81	CALL PARTDV(T,ANE,ZO,MOI,NOI,GOI,ENOI,SOI,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR OII
* 
 82	CALL PARTDV(T,ANE,ZO,MOII,NOII,GOII,ENOII,SOII,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR OIII
* 
 83	CALL PARTDV(T,ANE,ZO,MOIII,NOIII,GOIII,ENOIII,SOIII,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR OIV
* 
 84	CALL PARTDV(T,ANE,ZO,MOIV,NOIV,GOIV,ENOIV,SOIV,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR OV
* 
 85	CALL PARTDV(T,ANE,ZO,MOV,NOV,GOV,ENOV,SOV,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR OVI
* 
 86	CALL PARTDV(T,ANE,ZO,MOVI,NOVI,GOVI,ENOVI,SOVI,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR OVII
* 
 87	CALL PARTDV(T,ANE,ZO,MOVII,NOVII,GOVII,ENOVII,SOVII,U)
	GO TO 8888
* 
*	CALCULATING PARTITION FUNCTIONS FOR OVIII
* 
 88	CALL PARTDV(T,ANE,ZO,MH,NHYD,GHYD,ENHYD,SHYD,U)
	GO TO 8888
C
C 
C	CALCULATING PARTITION FUNCTIONS FOR FE VI - FE IX
C 
C260    CALL PFFE(IZI,T,ANE,U)
 8888	CONTINUE
	RETURN
 9999	U=0
	WRITE(*,*)!! INVALID ATOM IN USER SUPPLIED ROUTINE PARTFUN !!
	STOP
	END
C
C     **************************************************************
C
C 
	SUBROUTINE PARTDV(TEMP,DNE,Z,NLEV,NE,GEE,ENRGY,S,U)
C       ===================================================
C 
        INCLUDE 'PARAMS.FOR'
	DIMENSION GEE(*),ENRGY(*),S(*)
	INTEGER NE(*)
	U=0.0
	ET=TEMP/11604.8
	P=(14.69D0-0.20-0.6667*LOG10(DNE))
C 
	DO 10 I=1,NLEV
	   U1=FLOAT(NE(I))
	   ZSTAR=Z-S(I)
	   IF (ZSTAR.GT.0)THEN
	       W=P+4.*LOG10(ZSTAR)-4.*LOG10(U1)
	    ELSE
	       W=0.0
	   ENDIF
	   IF (W.GT.1.) W=1.
C 
	   IF ((ENRGY(I)/ET).LT.65.0) THEN
		U1=GEE(I)*W*EXP(-ENRGY(I)/ET)
	    ELSE
		U1=0.0
	   ENDIF
	   U=U+U1
 10	CONTINUE
 	RETURN
	END
C
C     **************************************************************
C
      subroutine pfni(ion,t,ane,pf,dut,dun)
c     =====================================
c
c     partition functions for Ni IV to Ni IX
c
c     this routine interpolates within a grid
c     calculated from all levels predicted by
c     Kurucz (1992), i.e. over 12,000 levels per ion.
c     the partition functions depend only on T !
c     (i.e. no level dissolution with increasing density)
c     TL  27-DEC-1994, 23-JAN-1995
c
c     Output:  PF   partition function
c              DUT  d(PF)/dT
c              DUN  d(PF)/d(ANE) (=0 in this version)
c
      implicit double precision (a-h,o-z)
c
      dimension g0(6)
      dimension p4a(190),p4b(170)
      dimension p5a(190),p5b(170)
      dimension p6a(190),p6b(170)
      dimension p7a(190),p7b(170)
      dimension p8a(190),p8b(170)
      dimension p9a(190),p9b(170)
      parameter (xen=2.302585093,xmil=0.001)
c
      data g0/28.,25.,6.,25.,28.,21./
c
      data p4a/
     .    1.447,1.464,1.482,1.501,1.518,1.535,1.551,1.567,1.582,1.596,
     .    1.610,1.623,1.636,1.648,1.659,1.671,1.681,1.692,1.702,1.711,
     .    1.721,1.730,1.739,1.748,1.757,1.765,1.774,1.782,1.791,1.799,
     .    1.808,1.816,1.824,1.833,1.841,1.850,1.859,1.868,1.877,1.886,
     .    1.895,1.905,1.914,1.924,1.934,1.945,1.955,1.966,1.977,1.989,
     .    2.000,2.012,2.025,2.037,2.050,2.063,2.077,2.091,2.105,2.119,
     .    2.134,2.149,2.164,2.179,2.195,2.211,2.227,2.243,2.260,2.276,
     .    2.293,2.310,2.327,2.344,2.362,2.379,2.397,2.414,2.432,2.449,
     .    2.467,2.484,2.502,2.519,2.537,2.554,2.571,2.588,2.606,2.623,
     .    2.640,2.657,2.674,2.690,2.707,2.723,2.740,2.756,2.772,2.788,
     .    2.804,2.819,2.835,2.850,2.866,2.881,2.896,2.911,2.925,2.940,
     .    2.954,2.969,2.983,2.997,3.010,3.024,3.038,3.051,3.064,3.077,
     .    3.090,3.103,3.116,3.128,3.141,3.153,3.165,3.177,3.189,3.201,
     .    3.213,3.224,3.235,3.247,3.258,3.269,3.280,3.291,3.301,3.312,
     .    3.322,3.332,3.343,3.353,3.363,3.373,3.382,3.392,3.402,3.411,
     .    3.421,3.430,3.439,3.448,3.457,3.466,3.475,3.484,3.492,3.501,
     .    3.509,3.518,3.526,3.534,3.542,3.550,3.558,3.566,3.574,3.582,
     .    3.589,3.597,3.604,3.612,3.619,3.626,3.634,3.641,3.648,3.655,
     .    3.662,3.669,3.676,3.682,3.689,3.696,3.702,3.709,3.715,3.722/
      data p4b/
     .    3.589,3.597,3.604,3.612,3.619,3.626,3.634,3.641,3.648,3.655,
     .    3.662,3.669,3.676,3.682,3.689,3.696,3.702,3.709,3.715,3.722,
     .    3.728,3.734,3.740,3.747,3.753,3.759,3.765,3.771,3.777,3.782,
     .    3.788,3.794,3.800,3.805,3.811,3.816,3.822,3.827,3.833,3.838,
     .    3.843,3.849,3.854,3.859,3.864,3.869,3.874,3.879,3.884,3.889,
     .    3.894,3.899,3.904,3.909,3.913,3.918,3.923,3.927,3.932,3.936,
     .    3.941,3.945,3.950,3.954,3.959,3.963,3.967,3.972,3.976,3.980,
     .    3.984,3.988,3.993,3.997,4.001,4.005,4.009,4.013,4.017,4.021,
     .    4.024,4.028,4.032,4.036,4.040,4.043,4.047,4.051,4.055,4.058,
     .    4.062,4.065,4.069,4.072,4.076,4.079,4.083,4.086,4.090,4.093,
     .    4.097,4.100,4.103,4.107,4.110,4.113,4.116,4.120,4.123,4.126,
     .    4.129,4.132,4.135,4.138,4.141,4.144,4.148,4.151,4.154,4.157,
     .    4.159,4.162,4.165,4.168,4.171,4.174,4.177,4.180,4.182,4.185,
     .    4.188,4.191,4.193,4.196,4.199,4.202,4.204,4.207,4.210,4.212,
     .    4.215,4.217,4.220,4.223,4.225,4.228,4.230,4.233,4.235,4.238,
     .    4.240,4.243,4.245,4.247,4.250,4.252,4.255,4.257,4.259,4.262,
     .    4.264,4.266,4.268,4.271,4.273,4.275,4.278,4.280,4.282,4.284/
      data p5a/
     .    1.398,1.408,1.427,1.446,1.466,1.486,1.506,1.526,1.545,1.564,
     .    1.583,1.601,1.619,1.636,1.652,1.668,1.683,1.698,1.712,1.725,
     .    1.738,1.751,1.763,1.775,1.786,1.797,1.808,1.818,1.828,1.837,
     .    1.846,1.855,1.864,1.873,1.881,1.889,1.897,1.904,1.912,1.919,
     .    1.926,1.933,1.940,1.946,1.953,1.960,1.966,1.972,1.979,1.985,
     .    1.991,1.997,2.003,2.009,2.016,2.022,2.028,2.034,2.040,2.046,
     .    2.052,2.058,2.065,2.071,2.077,2.084,2.090,2.097,2.103,2.110,
     .    2.117,2.124,2.131,2.138,2.145,2.152,2.160,2.167,2.175,2.183,
     .    2.191,2.199,2.207,2.216,2.224,2.233,2.241,2.250,2.259,2.268,
     .    2.278,2.287,2.297,2.306,2.316,2.326,2.336,2.346,2.356,2.367,
     .    2.377,2.387,2.398,2.409,2.419,2.430,2.441,2.452,2.463,2.474,
     .    2.485,2.497,2.508,2.519,2.530,2.542,2.553,2.564,2.576,2.587,
     .    2.599,2.610,2.621,2.633,2.644,2.655,2.667,2.678,2.689,2.701,
     .    2.712,2.723,2.734,2.745,2.757,2.768,2.779,2.790,2.801,2.812,
     .    2.822,2.833,2.844,2.855,2.865,2.876,2.886,2.897,2.907,2.918,
     .    2.928,2.938,2.948,2.958,2.968,2.978,2.988,2.998,3.008,3.018,
     .    3.027,3.037,3.046,3.056,3.065,3.075,3.084,3.093,3.102,3.111,
     .    3.120,3.129,3.138,3.147,3.156,3.164,3.173,3.182,3.190,3.198,
     .    3.207,3.215,3.223,3.232,3.240,3.248,3.256,3.264,3.272,3.279/
      data p5b/
     .    3.120,3.129,3.138,3.147,3.156,3.164,3.173,3.182,3.190,3.198,
     .    3.207,3.215,3.223,3.232,3.240,3.248,3.256,3.264,3.272,3.279,
     .    3.287,3.295,3.303,3.310,3.318,3.325,3.333,3.340,3.347,3.355,
     .    3.362,3.369,3.376,3.383,3.390,3.397,3.404,3.411,3.417,3.424,
     .    3.431,3.438,3.444,3.451,3.457,3.464,3.470,3.476,3.483,3.489,
     .    3.495,3.501,3.507,3.514,3.520,3.526,3.531,3.537,3.543,3.549,
     .    3.555,3.561,3.566,3.572,3.578,3.583,3.589,3.594,3.600,3.605,
     .    3.610,3.616,3.621,3.626,3.632,3.637,3.642,3.647,3.652,3.657,
     .    3.662,3.667,3.672,3.677,3.682,3.687,3.692,3.697,3.701,3.706,
     .    3.711,3.716,3.720,3.725,3.729,3.734,3.738,3.743,3.747,3.752,
     .    3.756,3.761,3.765,3.769,3.774,3.778,3.782,3.786,3.790,3.795,
     .    3.799,3.803,3.807,3.811,3.815,3.819,3.823,3.827,3.831,3.835,
     .    3.839,3.843,3.846,3.850,3.854,3.858,3.862,3.865,3.869,3.873,
     .    3.876,3.880,3.884,3.887,3.891,3.894,3.898,3.901,3.905,3.908,
     .    3.912,3.915,3.918,3.922,3.925,3.929,3.932,3.935,3.939,3.942,
     .    3.945,3.948,3.951,3.955,3.958,3.961,3.964,3.967,3.970,3.974,
     .    3.977,3.980,3.983,3.986,3.989,3.992,3.995,3.998,4.001,4.004/
      data p6a/
     .    0.778,0.804,0.817,0.834,0.854,0.876,0.901,0.928,0.957,0.987,
     .    1.017,1.048,1.079,1.109,1.139,1.169,1.197,1.225,1.253,1.279,
     .    1.304,1.329,1.353,1.376,1.398,1.419,1.440,1.459,1.478,1.497,
     .    1.515,1.532,1.548,1.564,1.580,1.594,1.609,1.623,1.636,1.649,
     .    1.662,1.674,1.686,1.698,1.709,1.720,1.730,1.740,1.750,1.760,
     .    1.769,1.779,1.788,1.796,1.805,1.813,1.821,1.829,1.837,1.845,
     .    1.852,1.860,1.867,1.874,1.881,1.888,1.894,1.901,1.907,1.914,
     .    1.920,1.926,1.932,1.938,1.944,1.950,1.956,1.962,1.968,1.974,
     .    1.979,1.985,1.991,1.996,2.002,2.007,2.013,2.018,2.024,2.029,
     .    2.035,2.041,2.046,2.052,2.057,2.063,2.068,2.074,2.080,2.086,
     .    2.091,2.097,2.103,2.109,2.115,2.121,2.127,2.133,2.139,2.145,
     .    2.152,2.158,2.164,2.171,2.177,2.184,2.190,2.197,2.204,2.211,
     .    2.218,2.225,2.232,2.239,2.246,2.253,2.261,2.268,2.276,2.283,
     .    2.291,2.298,2.306,2.314,2.322,2.330,2.338,2.346,2.354,2.362,
     .    2.370,2.379,2.387,2.395,2.404,2.412,2.420,2.429,2.438,2.446,
     .    2.455,2.463,2.472,2.481,2.489,2.498,2.507,2.516,2.524,2.533,
     .    2.542,2.551,2.560,2.569,2.577,2.586,2.595,2.604,2.613,2.622,
     .    2.631,2.639,2.648,2.657,2.666,2.675,2.683,2.692,2.701,2.710,
     .    2.718,2.727,2.736,2.744,2.753,2.761,2.770,2.779,2.787,2.796/
      data p6b/
     .    2.631,2.639,2.648,2.657,2.666,2.675,2.683,2.692,2.701,2.710,
     .    2.718,2.727,2.736,2.744,2.753,2.761,2.770,2.779,2.787,2.796,
     .    2.804,2.812,2.821,2.829,2.838,2.846,2.854,2.862,2.871,2.879,
     .    2.887,2.895,2.903,2.911,2.919,2.927,2.935,2.943,2.951,2.958,
     .    2.966,2.974,2.982,2.989,2.997,3.005,3.012,3.020,3.027,3.035,
     .    3.042,3.049,3.057,3.064,3.071,3.078,3.086,3.093,3.100,3.107,
     .    3.114,3.121,3.128,3.135,3.141,3.148,3.155,3.162,3.169,3.175,
     .    3.182,3.188,3.195,3.202,3.208,3.214,3.221,3.227,3.234,3.240,
     .    3.246,3.252,3.259,3.265,3.271,3.277,3.283,3.289,3.295,3.301,
     .    3.307,3.313,3.319,3.325,3.330,3.336,3.342,3.348,3.353,3.359,
     .    3.364,3.370,3.376,3.381,3.386,3.392,3.397,3.403,3.408,3.413,
     .    3.419,3.424,3.429,3.434,3.440,3.445,3.450,3.455,3.460,3.465,
     .    3.470,3.475,3.480,3.485,3.490,3.495,3.499,3.504,3.509,3.514,
     .    3.518,3.523,3.528,3.533,3.537,3.542,3.546,3.551,3.555,3.560,
     .    3.564,3.569,3.573,3.578,3.582,3.586,3.591,3.595,3.599,3.604,
     .    3.608,3.612,3.616,3.621,3.625,3.629,3.633,3.637,3.641,3.645,
     .    3.649,3.653,3.657,3.661,3.665,3.669,3.673,3.677,3.681,3.685/
      data p7a/
     .    1.398,1.398,1.398,1.398,1.406,1.425,1.443,1.461,1.480,1.498,
     .    1.516,1.534,1.551,1.568,1.585,1.601,1.616,1.631,1.646,1.660,
     .    1.674,1.687,1.700,1.712,1.724,1.736,1.747,1.758,1.768,1.778,
     .    1.788,1.797,1.806,1.815,1.824,1.832,1.840,1.848,1.855,1.863,
     .    1.870,1.877,1.883,1.890,1.896,1.902,1.908,1.914,1.920,1.925,
     .    1.931,1.936,1.941,1.946,1.951,1.956,1.960,1.965,1.969,1.974,
     .    1.978,1.982,1.986,1.990,1.994,1.998,2.001,2.005,2.009,2.012,
     .    2.016,2.019,2.022,2.026,2.029,2.032,2.035,2.038,2.041,2.044,
     .    2.047,2.050,2.053,2.056,2.059,2.061,2.064,2.067,2.069,2.072,
     .    2.075,2.077,2.080,2.082,2.085,2.088,2.090,2.093,2.095,2.098,
     .    2.100,2.103,2.105,2.107,2.110,2.112,2.115,2.117,2.120,2.122,
     .    2.125,2.127,2.130,2.132,2.135,2.137,2.140,2.142,2.145,2.148,
     .    2.150,2.153,2.155,2.158,2.161,2.163,2.166,2.169,2.172,2.175,
     .    2.178,2.180,2.183,2.186,2.189,2.192,2.195,2.198,2.202,2.205,
     .    2.208,2.211,2.215,2.218,2.221,2.225,2.228,2.232,2.235,2.239,
     .    2.243,2.246,2.250,2.254,2.258,2.261,2.265,2.269,2.273,2.277,
     .    2.282,2.286,2.290,2.294,2.299,2.303,2.307,2.312,2.316,2.321,
     .    2.325,2.330,2.335,2.339,2.344,2.349,2.354,2.359,2.364,2.369,
     .    2.374,2.379,2.384,2.389,2.394,2.399,2.405,2.410,2.415,2.420/
      data p7b/
     .    2.325,2.330,2.335,2.339,2.344,2.349,2.354,2.359,2.364,2.369,
     .    2.374,2.379,2.384,2.389,2.394,2.399,2.405,2.410,2.415,2.420,
     .    2.426,2.431,2.437,2.442,2.448,2.453,2.459,2.464,2.470,2.476,
     .    2.481,2.487,2.493,2.498,2.504,2.510,2.516,2.521,2.527,2.533,
     .    2.539,2.545,2.551,2.556,2.562,2.568,2.574,2.580,2.586,2.592,
     .    2.598,2.604,2.610,2.616,2.622,2.628,2.634,2.640,2.646,2.652,
     .    2.658,2.664,2.670,2.676,2.682,2.687,2.693,2.699,2.705,2.711,
     .    2.717,2.723,2.729,2.735,2.741,2.747,2.753,2.759,2.764,2.770,
     .    2.776,2.782,2.788,2.794,2.799,2.805,2.811,2.817,2.823,2.828,
     .    2.834,2.840,2.846,2.851,2.857,2.863,2.868,2.874,2.879,2.885,
     .    2.891,2.896,2.902,2.907,2.913,2.918,2.924,2.929,2.935,2.940,
     .    2.945,2.951,2.956,2.962,2.967,2.972,2.978,2.983,2.988,2.993,
     .    2.999,3.004,3.009,3.014,3.019,3.025,3.030,3.035,3.040,3.045,
     .    3.050,3.055,3.060,3.065,3.070,3.075,3.080,3.085,3.090,3.095,
     .    3.099,3.104,3.109,3.114,3.119,3.123,3.128,3.133,3.138,3.142,
     .    3.147,3.152,3.156,3.161,3.165,3.170,3.175,3.179,3.184,3.188,
     .    3.193,3.197,3.202,3.206,3.210,3.215,3.219,3.224,3.228,3.232/
      data p8a/
     .    1.447,1.447,1.447,1.447,1.447,1.447,1.459,1.475,1.489,1.504,
     .    1.518,1.531,1.544,1.556,1.568,1.580,1.591,1.602,1.612,1.622,
     .    1.631,1.640,1.649,1.658,1.666,1.674,1.682,1.689,1.696,1.703,
     .    1.710,1.716,1.722,1.728,1.734,1.740,1.745,1.751,1.756,1.761,
     .    1.766,1.770,1.775,1.779,1.784,1.788,1.792,1.796,1.800,1.804,
     .    1.807,1.811,1.814,1.818,1.821,1.824,1.827,1.831,1.834,1.836,
     .    1.839,1.842,1.845,1.848,1.850,1.853,1.855,1.858,1.860,1.863,
     .    1.865,1.867,1.870,1.872,1.874,1.876,1.878,1.880,1.882,1.884,
     .    1.886,1.888,1.890,1.892,1.894,1.896,1.898,1.900,1.902,1.903,
     .    1.905,1.907,1.909,1.911,1.912,1.914,1.916,1.917,1.919,1.921,
     .    1.923,1.924,1.926,1.928,1.929,1.931,1.933,1.934,1.936,1.938,
     .    1.939,1.941,1.943,1.945,1.946,1.948,1.950,1.951,1.953,1.955,
     .    1.957,1.959,1.960,1.962,1.964,1.966,1.968,1.970,1.971,1.973,
     .    1.975,1.977,1.979,1.981,1.983,1.985,1.987,1.989,1.991,1.993,
     .    1.995,1.998,2.000,2.002,2.004,2.006,2.009,2.011,2.013,2.015,
     .    2.018,2.020,2.023,2.025,2.027,2.030,2.032,2.035,2.037,2.040,
     .    2.043,2.045,2.048,2.051,2.053,2.056,2.059,2.062,2.064,2.067,
     .    2.070,2.073,2.076,2.079,2.082,2.085,2.088,2.091,2.094,2.097,
     .    2.100,2.103,2.107,2.110,2.113,2.116,2.120,2.123,2.126,2.130/
      data p8b/
     .    2.070,2.073,2.076,2.079,2.082,2.085,2.088,2.091,2.094,2.097,
     .    2.100,2.103,2.107,2.110,2.113,2.116,2.120,2.123,2.126,2.130,
     .    2.133,2.137,2.140,2.143,2.147,2.151,2.154,2.158,2.161,2.165,
     .    2.168,2.172,2.176,2.180,2.183,2.187,2.191,2.195,2.198,2.202,
     .    2.206,2.210,2.214,2.218,2.222,2.226,2.230,2.233,2.237,2.241,
     .    2.245,2.250,2.254,2.258,2.262,2.266,2.270,2.274,2.278,2.282,
     .    2.286,2.291,2.295,2.299,2.303,2.307,2.312,2.316,2.320,2.324,
     .    2.329,2.333,2.337,2.341,2.346,2.350,2.354,2.359,2.363,2.367,
     .    2.371,2.376,2.380,2.384,2.389,2.393,2.397,2.402,2.406,2.410,
     .    2.415,2.419,2.423,2.428,2.432,2.436,2.441,2.445,2.449,2.454,
     .    2.458,2.462,2.467,2.471,2.475,2.480,2.484,2.488,2.493,2.497,
     .    2.501,2.506,2.510,2.514,2.519,2.523,2.527,2.531,2.536,2.540,
     .    2.544,2.548,2.553,2.557,2.561,2.565,2.570,2.574,2.578,2.582,
     .    2.586,2.591,2.595,2.599,2.603,2.607,2.611,2.616,2.620,2.624,
     .    2.628,2.632,2.636,2.640,2.644,2.648,2.652,2.656,2.661,2.665,
     .    2.669,2.673,2.677,2.681,2.685,2.689,2.693,2.696,2.700,2.704,
     .    2.708,2.712,2.716,2.720,2.724,2.728,2.732,2.736,2.739,2.743/
      data p9a/
     .    1.322,1.322,1.322,1.322,1.322,1.322,1.322,1.322,1.322,1.325,
     .    1.334,1.342,1.351,1.358,1.366,1.373,1.380,1.386,1.392,1.398,
     .    1.404,1.409,1.415,1.420,1.425,1.429,1.434,1.438,1.442,1.446,
     .    1.450,1.454,1.457,1.461,1.464,1.467,1.470,1.473,1.476,1.479,
     .    1.482,1.485,1.487,1.490,1.492,1.495,1.497,1.499,1.501,1.503,
     .    1.505,1.507,1.509,1.511,1.513,1.515,1.517,1.519,1.520,1.522,
     .    1.524,1.525,1.527,1.528,1.530,1.531,1.533,1.534,1.535,1.537,
     .    1.538,1.539,1.541,1.542,1.543,1.545,1.546,1.547,1.548,1.549,
     .    1.551,1.552,1.553,1.554,1.555,1.556,1.558,1.559,1.560,1.561,
     .    1.562,1.563,1.565,1.566,1.567,1.568,1.569,1.570,1.571,1.573,
     .    1.574,1.575,1.576,1.577,1.579,1.580,1.581,1.582,1.584,1.585,
     .    1.586,1.588,1.589,1.590,1.592,1.593,1.594,1.596,1.597,1.599,
     .    1.600,1.602,1.603,1.605,1.606,1.608,1.609,1.611,1.612,1.614,
     .    1.616,1.617,1.619,1.621,1.622,1.624,1.626,1.628,1.630,1.631,
     .    1.633,1.635,1.637,1.639,1.641,1.643,1.645,1.647,1.649,1.651,
     .    1.653,1.655,1.657,1.659,1.661,1.664,1.666,1.668,1.670,1.673,
     .    1.675,1.677,1.679,1.682,1.684,1.686,1.689,1.691,1.694,1.696,
     .    1.699,1.701,1.704,1.706,1.709,1.711,1.714,1.716,1.719,1.722,
     .    1.724,1.727,1.729,1.732,1.735,1.738,1.740,1.743,1.746,1.749/
      data p9b/
     .    1.699,1.701,1.704,1.706,1.709,1.711,1.714,1.716,1.719,1.722,
     .    1.724,1.727,1.729,1.732,1.735,1.738,1.740,1.743,1.746,1.749,
     .    1.751,1.754,1.757,1.760,1.763,1.765,1.768,1.771,1.774,1.777,
     .    1.780,1.783,1.786,1.789,1.792,1.795,1.798,1.801,1.804,1.807,
     .    1.810,1.813,1.816,1.819,1.822,1.825,1.828,1.831,1.834,1.837,
     .    1.840,1.843,1.847,1.850,1.853,1.856,1.859,1.862,1.865,1.869,
     .    1.872,1.875,1.878,1.881,1.884,1.888,1.891,1.894,1.897,1.901,
     .    1.904,1.907,1.910,1.913,1.917,1.920,1.923,1.926,1.930,1.933,
     .    1.936,1.939,1.943,1.946,1.949,1.952,1.956,1.959,1.962,1.965,
     .    1.969,1.972,1.975,1.978,1.982,1.985,1.988,1.992,1.995,1.998,
     .    2.001,2.005,2.008,2.011,2.014,2.018,2.021,2.024,2.027,2.031,
     .    2.034,2.037,2.040,2.044,2.047,2.050,2.053,2.057,2.060,2.063,
     .    2.066,2.070,2.073,2.076,2.079,2.083,2.086,2.089,2.092,2.095,
     .    2.099,2.102,2.105,2.108,2.111,2.115,2.118,2.121,2.124,2.127,
     .    2.131,2.134,2.137,2.140,2.143,2.146,2.149,2.153,2.156,2.159,
     .    2.162,2.165,2.168,2.171,2.175,2.178,2.181,2.184,2.187,2.190,
     .    2.193,2.196,2.199,2.202,2.205,2.208,2.212,2.215,2.218,2.221/
c
      if(t.lt.12000.) then
        pf=g0(ion-3)
        dut=0.
        dun=0.
        return
      endif
c
      it=t/1000
      if(it.ge.350) it=349
      t1=1000.*it
      t2=t1+1000.
      if(ion.eq.4) then
        if(t.le.200000.) then
          xu1=p4a(it-10)
          xu2=p4a(it-9)
        else
          xu1=p4b(it-180)
          xu2=p4b(it-179)
        endif
      else if(ion.eq.5) then
        if(t.le.200000.) then
          xu1=p5a(it-10)
          xu2=p5a(it-9)
        else
          xu1=p5b(it-180)
          xu2=p5b(it-179)
        endif
      else if(ion.eq.6) then
        if(t.le.200000.) then
          xu1=p6a(it-10)
          xu2=p6a(it-9)
        else
          xu1=p6b(it-180)
          xu2=p6b(it-179)
        endif
      else if(ion.eq.7) then
        if(t.le.200000.) then
          xu1=p7a(it-10)
          xu2=p7a(it-9)
        else
          xu1=p7b(it-180)
          xu2=p7b(it-179)
        endif
      else if(ion.eq.8) then
        if(t.le.200000.) then
          xu1=p8a(it-10)
          xu2=p8a(it-9)
        else
          xu1=p8b(it-180)
          xu2=p8b(it-179)
        endif
      else if(ion.eq.9) then
        if(t.le.200000.) then
          xu1=p9a(it-10)
          xu2=p9a(it-9)
        else
          xu1=p9b(it-180)
          xu2=p9b(it-179)
        endif
      endif
c
      dxt=xmil*(xu2-xu1)
      xu=xu1+(t-t1)*dxt
      pf=exp(xen*xu)
      dut=xen*pf*dxt
      dun=0.
      return
      end
c 
c ******************************************************************
c
      subroutine frac1
c     ================
c
      include 'PARAMS.FOR'
      include 'MODELP.FOR'
      parameter (mtemp=100,melec=60,mion1=30)
      dimension xt(mdepth),xne(mdepth)
      dimension kt0(mdepth),kn0(mdepth)
      common/fracop/frac(mtemp,melec,mion1),fracm(mtemp,melec),
     *              itemp(mtemp),ntt
c
      do 10 id=1,nd
         xt(id)=dlog10(temp(id))
         kt0(id)=2*int(20.*xt(id))
         xne(id)=dlog10(elec(id))
         kn0(id)=int(2.*xne(id))
   10 continue
c
      DO 20 IAT=1,30
         iatnum=iat
         call fractn(iatnum)
         if(iatnum.le.0) goto 20
         do 30 id=1,nd
           if(kt0(id).lt.itemp(1)) then
             kt1=1
             write(6,611) id,temp(id)
  611        format(' (FRACOP) Extrapol. in T (low)',i4,f7.0)
             goto 41
           endif
           if(kt0(id).ge.itemp(ntt)) then
             kt1=ntt-1
             write(6,612) id,temp(id)
  612        format(' (FRACOP) Extrapol. in T (high)',i4,f12.0)
             goto 41
           endif
           do 40 it=1,ntt
             if(kt0(id).eq.itemp(it)) then
               kt1=it
               goto 41
             endif
   40      continue
   41      continue
           if(kn0(id).lt.1) then
             kn1=1
             goto 49
           endif
           if(kn0(id).ge.60) then
             kn1=59
             write(6,614) id,xne(id)
  614        format(' (FRACOP) Extrapol. in Ne (high)',i4,f9.4)
             goto 49
           endif
           kn1=kn0(id)
   49      continue
           xt1=0.025*itemp(kt1)
           dxt=0.05
           at1=(xt(id)-xt1)/dxt
           xn1=0.5*kn1
           dxn=0.5
           an1=(xne(id)-xn1)/dxn
           do 50 ion=1,mion
              x11=frac(kt1,kn1,ion)
              x21=frac(kt1+1,kn1,ion)
              x12=frac(kt1,kn1+1,ion)
              x22=frac(kt1+1,kn1+1,ion)
              x1221=x11*x21*x12*x22
              if(x1221.eq.0.) then
                  xx1=x11+at1*(x21-x11)
                  xx2=x12+at1*(x22-x12)
                  rrx=xx1+an1*(xx2-xx1)
              else
                  x11=dlog10(x11)
                  x21=dlog10(x21)
                  x12=dlog10(x12)
                  x22=dlog10(x22)
                  xx1=x11+at1*(x21-x11)
                  xx2=x12+at1*(x22-x12)
                  rrx=xx1+an1*(xx2-xx1)
                  rrx=exp(2.3025851*rrx)
              endif
              rrr(id,ion,iat)=rrx*abndd(iat,id)*
     *                        dens(id)/wmm(id)/ytot(id)
   50      continue
   30    continue
   20 CONTINUE
c
      return
      end
c 
c ******************************************************************
c
      subroutine fractn(iatnum)
c     =========================
c
      implicit double precision (a-h,o-z)
      parameter (mtemp=100,
     *           melec= 60,
     *           mion1=30,
     *           mdat = 17)
      parameter (inp=71)
      dimension frac0(-1:mion1),ioo(-1:mion1),idat(mion1)
      dimension gg(mion1,mdat),g0(mion1),z0(-1:mion1)
      dimension uu(mion1,mdat),u0(mion1)
      dimension u6(6),u7(7),u8(8),u10(10),u11(11)
      dimension u12(12),u13(13),u14(14),u16(16),u18(18),u20(20)
      dimension u24(24),u25(25),u26(26),u28(28)
      equivalence (u6(1),uu(1,3)),(u7(1),uu(1,4)),(u8(1),uu(1,5))
      equivalence (u10(1),uu(1,6)),(u11(1),uu(1,7)),(u12(1),uu(1,8))
      equivalence (u13(1),uu(1,9)),(u14(1),uu(1,10)),(u16(1),uu(1,11))
      equivalence (u18(1),uu(1,12)),(u20(1),uu(1,13)),(u24(1),uu(1,14))
      equivalence (u25(1),uu(1,15)),(u26(1),uu(1,16)),(u28(1),uu(1,17))
      common/fracop/frac(mtemp,melec,mion1),fracm(mtemp,melec),
     *              itemp(mtemp),ntt
      character*30 filop
      data idat   / 1, 2, 0, 0, 0, 3, 4, 5, 0, 6,
     *              7, 8, 9,10, 0,11, 0,12, 0,13,
     *              0, 0, 0,14,15,16, 0,17, 0, 0/ 
      data gg/2.,29*0.,2.,1.,28*0.,
     *        2.,1.,2.,1.,6.,9.,24*0.,2.,1.,2.,1.,6.,9.,4.,23*0.,
     *        2.,1.,2.,1.,6.,9.,4.,9.,22*0.,
     *        2.,1.,2.,1.,6.,9.,4.,9.,6.,1.,20*0.,
     *        2.,1.,2.,1.,6.,9.,4.,9.,6.,1.,2.,19*0.,
     *        2.,1.,2.,1.,6.,9.,4.,9.,6.,1.,2.,1.,18*0.,
     *        2.,1.,2.,1.,6.,9.,4.,9.,6.,1.,2.,1.,6.,17*0.,
     *        2.,1.,2.,1.,6.,9.,4.,9.,6.,1.,2.,1.,6.,9.,16*0.,
     *        2.,1.,2.,1.,6.,9.,4.,9.,6.,1.,2.,1.,6.,9.,4.,9.,14*0.,
     *        2.,1.,2.,1.,6.,9.,4.,9.,6.,1.,2.,1.,6.,9.,4.,9.,6.,1.,
     *        12*0.,2.,1.,2.,1.,6.,9.,4.,9.,6.,1.,2.,1.,6.,9.,4.,9.,
     *        6.,1.,2.,1.,10*0.,2.,1.,2.,1.,6.,9.,4.,9.,6.,1.,2.,1.,
     *        6.,9.,4.,9.,6.,1.,10.,21.,28.,25.,6.,7.,6*0.,
     *        2.,1.,2.,1.,6.,9.,4.,9.,6.,1.,2.,1.,6.,9.,4.,9.,
     *           6.,1.,10.,21.,28.,25.,6.,7.,6.,5*0.,
     *        2.,1.,2.,1.,6.,9.,4.,9.,6.,1.,2.,1.,6.,9.,4.,9.,
     *           6.,1.,10.,21.,28.,25.,6.,25.,30.,25.,4*0.,
     *        2.,1.,2.,1.,6.,9.,4.,9.,6.,1.,2.,1.,6.,9.,4.,9.,
     *           6.,1.,10.,21.,28.,25.,6.,25.,28.,21.,10.,21.,0.,0./
      data uu(1,1)/109.6787/
      data uu(1,2)/198.3108/
      data uu(2,2)/438.9089/
      data u6/90.82,196.665,386.241,520.178,3162.395,3952.061/
      data u7/117.225,238.751,382.704,624.866,789.537,4452.758,5380.089/
      data u8/109.837,283.24,443.086,624.384,918.657,1114.008,5963.135,
     *        7028.393/
      data u10/173.93,330.391,511.8,783.3,1018.,1273.8,1671.792,
     *         1928.462,9645.005,10986.876/
      data u11/41.449,381.395,577.8,797.8,1116.2,1388.5,1681.5,2130.8,
     *         2418.7,11817.061,13297.676/
      data u12/61.671,121.268,646.41,881.1,1139.4,1504.3,1814.3,2144.7,
     *         2645.2,2964.4,14210.261,15829.951/
      data u13/48.278,151.86,229.446,967.8,1239.8,1536.3,1947.3,2295.4,
     *         2663.4,3214.8,3565.6,16825.022,18584.138/
      data u14/65.748,131.838,270.139,364.093,1345.1,1653.9,1988.4,
     *         2445.3,2831.9,3237.8,3839.8,4222.4,19661.693,21560.63/
      data u16/83.558,188.2,280.9,381.541,586.2,710.184,2265.9,2647.4,
     *         3057.7,3606.1,4071.4,4554.3,5255.9,5703.6,26002.663,
     *         28182.535/
      data u18/127.11,222.848,328.6,482.4,605.1,734.04,1002.73,1157.08,
     *         3407.3,3860.9,4347.,4986.6,5533.8,6095.5,6894.2,7404.4,
     *         33237.173,35699.936/
      data u20/49.306,95.752,410.642,542.6,681.6,877.4,1026.,1187.6,
     *         1520.64,1704.047,4774.,5301.,5861.,6595.,7215.,7860.,
     *         8770.,9338.,41366.,44177.41/
      data u24/54.576,132.966,249.7,396.5,560.2,731.02,1291.9,1490.,
     *         1688.,1971.,2184.,2404.,2862.,3098.52,8151.,8850.,
     *         9560.,10480.,11260.,12070.,13180.,13882.,60344.,63675.9/
      data u25/59.959,126.145,271.55,413.,584.,771.1,961.44,1569.,
     *         1789.,2003.,2307.,2536.,2771.,3250.,3509.82,9152.,
     *         9872.,10620.,11590.,12410.,13260.,14420.,15162.,
     *         65660.,69137.4/
      data u26/63.737,130.563,247.22,442.,605.,799.,1008.,1218.38,
     *         1884.,2114.,2341.,2668.,2912.,3163.,3686.,3946.82,
     *         10180.,10985.,11850.,12708.,13620.,14510.,15797.,
     *         16500.,71203.,74829.6/
      data u28/61.6,146.542,283.8,443.,613.5,870.,1070.,1310.,1560.,
     *         1812.,2589.,2840.,3100.,3470.,3740.,4020.,4606.,
     *         4896.2,12430.,13290.,14160.,15280.,16220.,17190.,
     *         18510.,19351.,82984.,86909.4/
c
      if(idat(iatnum).eq.0) then
         write(6,600) iatnum
  600    format(' data for element no. ',i3,' do not exist')
         iatnum=-1
         return
      end if
c
      g0(iatnum+1)=1.
      do i=1,iatnum
        ig0=iatnum-i+1
        g0(ig0)=gg(i,idat(iatnum))
        u0(i)=uu(i,idat(iatnum))*1000.
      enddo
c
      if(iatnum.eq.1) open(inp,file='ioniz.dat',status='old')
      do 10 it=1,mtemp
         do 10 ie=1,melec
            fracm(it,ie)=0.
            do 10 ion=1,mion1
               frac(it,ie,ion)=0.
   10 continue
c
      read(inp,*)
      read(inp,*) it0,it1,itstp
      ntt=(it1-it0)/itstp+1
c
      do 100 it=1,ntt
         read(inp,*) itt,ie0,ie1,iestp
         itemp(it)=itt
         net=(ie1-ie0)/iestp+1
         t=exp(2.3025851*0.025*itt)
         safac0=sqrt(t)*t/2.07d-16
         tkcm=0.69496*t
         do 30 ie=1,net
            read(inp,601) iee,ion0,ion1,
     *                    (ioo(i),frac0(i),i=ion0,min(ion1,ion0+3))
            ane=exp(2.3025851*0.25*iee)
            safac=safac0/ane
            nio=ion1-ion0
            if(nio.ge.3) then
               nlin=nio/4
               do ilin=1,nlin
                  read(inp,602) (ioo(i),frac0(i),
     *                 i=ion0+4*ilin,min(ion1,ion0+4*ilin+3))
               end do
            end if
            ieind=iee/2
            do 20 ion=ion0,ion1
              if(ion.lt.iatnum) then
               if(ion.eq.ion0) then
                  z0(ion)=g0(iatnum-ion)
               else
                  z0(ion)=frac0(ion)/frac0(ion-1)*safac*z0(ion-1)
                  z0(ion)=z0(ion)*exp(-u0(iatnum-ion)/tkcm)
               endif
                  frac(it,ieind,iatnum-ion)=frac0(ion)/z0(ion)
              else
                  u0hm=6090.5
                  z0hm=frac0(ion)/frac0(ion-1)*safac
                  z0hm=z0hm*exp(-u0hm/tkcm)
                  fracm(it,ieind)=frac0(ion)/z0hm
              end if
   20       continue
c           write(6,603) it,ieind,t,ane
c           write(6,604) (frac(it,ieind,i),i=1,mion1)
   30    continue
  100 continue
  601 format(3i4,2x,4(i4,1x,e9.3))
  602 format(14x,4(i4,1x,e9.3))
  603 format(2i5,f15.2,1pe10.3)
  604 format(1p8e10.3)
      return      
      end
C
C
C     *******************************************************************
C
C

      SUBROUTINE DWNFR0(ID)
C     =====================
C
C     Auxiliary quantities for dissolved fractions
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      PARAMETER (UN=1.,SIXTH=UN/6.,CCOR=0.09)
      parameter (p1=0.1402,p2=0.1285,p3=un,p4=3.15,p5=4.)
      parameter (f23=-2./3.)
C
      ANE=ELEC(ID)
      ELEC23(ID)=EXP(F23*LOG(ANE))
      ANES=EXP(SIXTH*LOG(ANE))
      ACOR=CCOR*ANES/SQRT(TEMP(ID))
      X=EXP(P4*LOG(UN+P3*ACOR))
      DWC2(ID)=P2*X
      A3=ACOR*ACOR*ACOR
      DO 10 IZZ=1,MZZ
         Z3(IZZ)=IZZ*IZZ*IZZ
         DWC1(IZZ,ID)=P1*(X+P5*IZZ*A3)
   10 CONTINUE
      RETURN
      END
C
C
C ********************************************************************
C
C
      SUBROUTINE DWNFR1(FR,FR0,ID,IZZ,DW1)
C     ====================================
C
C     dissolved fraction for frequency FR
C
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      PARAMETER (UN=1.,TKN=3.01,CKN=5.33333333,CB=8.3d14)
      PARAMETER (SQFRH=5.734152D7)
C
      IF(FR.LT.FR0) THEN
         XN=SQFRH*IZZ/SQRT(FR0-FR)
         if(xn.ge.tkn) then
            xkn=un
          else
            xn1=un/(xn+un)
            xkn=ckn*xn*xn1*xn1
         end if
         BETA=CB*Z3(IZZ)*XKN/(XN*XN*XN*XN)*ELEC23(ID)
         BETA3=BETA*BETA*BETA
         BETA32=SQRT(BETA3)
         F=(DWC1(IZZ,ID)*BETA3)/(UN+DWC2(ID)*BETA32)
         DW1=UN-F/(UN+F)
       ELSE
         DW1=UN
      END IF
      RETURN
      END
C
C
C ********************************************************************
C
C
      SUBROUTINE CHCKAB
C
C     check input abumdances of explicit atoms (unit 5) and those
C     which follow from the models atmosphere (unit 7) obtained by
C     summing all populations and upper sums
C     The program stops if it finds discrepancy more than 10 %
c
      INCLUDE 'PARAMS.FOR'
      INCLUDE 'MODELP.FOR'
      dimension sumpop(matom),sumiat(matom)
c
      IST=0
      DO ID1=1,3
      IF(ID1.EQ.1) ID=1
      IF(ID1.EQ.2) ID=46
      IF(ID1.EQ.3) ID=ND
      CALL WNSTOR(ID)
      ANE=ELEC(ID)
      CALL SABOLF(ID)
      DO IAT=1,NATOM
         SUM=0.
         sump=0.
         DO I=N0A(IAT),NKA(IAT) 
            IL=ILK(I)
            A=1.
            IF(IL.GT.0) A=1.+ANE*USUM(IL)
            SUM=SUM+A*POPUL(I,ID)
            SUMP=SUMP+POPUL(I,ID)
         END DO
         SUMIAT(IAT)=SUM
         SUMPOP(IAT)=SUMP
      END DO
      WRITE(6,600) ID
      DO IAT=1,NATOM
         X=SUMIAT(IAT)/SUMIAT(IATREF)
         WRITE(6,601) IAT,X,abund(iat,id),SUMPOP(IAT)/SUMPOP(IATREF)
         IF(X/abund(iat,id).GT.1.1.OR.X/abund(iat,id).LT.0.9) ist=ist+1
      END DO
      END DO
      IF(IST.GT.0) THEN
         WRITE(6,602) 
         STOP
      END IF
  600 FORMAT(' check of abundances (id =',i3/
     *       ' computed from model atmosphere  - input abundances'/)
  601 format(i5,1p3e20.3)
  602 format(' ERROR !!! - inconsistent abundances'/)
      RETURN
      END
